# This addon adds to the Celestia 3405 asteroid, 65 asteroid satellite, 21 pairs and 1 triple of asteroids with a common barycenter, including all previously available with refined parameters.
# Данный аддон добавляет в Celestia 3411 астероидов, 64 астероидных спутника, 22 пары и 1 тройку астероидов с общим барицентром, включая все ранее имевшиеся с уточнёнными параметрами. Среди них содержится 85 кандидатов в карликовые планеты. Каждый объект имеет русскоязычное название (находится в отдельном аддоне), а также все альтернативные обозначения.
# Among them there are 82 candidates in dwarf planets. Each object has a Russian-language name (located in a separate add-on), as well as all alternative designations.

# Above the SSC-file worked:
# Zemlyanin - creation of a tool for automatic import of objects from the JPL Small-Body Database Browser (the basis of 2446 asteroids), additional calculations for some bodies, the selection of colors of orbits;
# Art Blos - translation of names into Russian, adding alternative notations and links to information, additional calculations for some bodies, processing of all existing objects, further adding new ones from the Zemlyanin-generated full base of asteroids and other sources in the network;
# Diane Neisius - calculating the orbits of meteorites.

# Created on: 9/25/2014
# Updated: 12/30/2018

# =====================================================================
# Part 1. Asteroids
# =====================================================================

# Upgrading the base of asteroids - creating a multilevel of names:
# - 1st sequence - the basic string of names (classical localization)

# For extended (national) localization, there are:
# - 2nd alternative sequence of names (in the first place is the name of your own asteroid, if it is not, then the temporary designation)
# - 3rd alternative sequence of names (in the first place a temporary designation)
# Note. In this version, the national localization is the Russian version of the names of asteroids.
# Users can delete the Russian translation or replace it with their own language.
#
# - 4th alternative sequence of names (in the first place ".")
# - 5th alternative sequence of names (first of all it's the name of an asteroid without a registration number in English, if not, then a temporary designation)
# ----------------------------------------------------------------------
# Note. In variants 2, 3, 4, 5 only one time designation is used, the remaining alternative notation is not given.
# ----------------------------------------------------------------------
# In the initial state, the name strings are locked (at the beginning of the line are the signatures: #1_ or #2_ or #3_ or #4_)
# To activate the desired sequence of names, the file should be scanned with deletion at the beginning of the signature line: #1_ or #2_ or #3_ or #4_.
# Note: for the 5th alternative sequence of names, the file must be scanned with the following at the beginning of the signature line: # 4_ ".: on" (double quote)

# For the 2-5 sequence added reconstructed time symbols (further RVO). RVO is necessary to properly position the asteroids on a time scale.
# Decryption of the RVO: year of discovery + registration number + asterisk (*).
# Asteroids with RVO:
# - asteroids with 2 Pallas at 332 Siri, which did not have time marks.
# - asteroids with letters in the designation (for example, 4109 P-L), the year of discovery 1960.
# - asteroids with letters T-1 in the designation (for example, 4849 T-1), the year of discovery 1971.
# - asteroids with T-2 letters in the designation (for example, 5059 T-2), the year of discovery 1973.
# - asteroids with letters T-3 in the designation (for example, 5010 T-3), the year of discovery 1977.

# Extended Russian localization involves specifying a * (asterisk) in front of the name of the object in Russian.
# When searching for an object in the Enter system, the * (asterisk) input is required if the name is specified in Cyrillic (for extended Russian localization)
# For better readability of complex Chinese asteroids names in Russian translation, each syllable is written with a capital letter.

# The author of the modernization Gennady Lygin, aka Croc.
# Date of modernization on 01/07/2019
# ============================================================================

#1_"2 Pallas:Pallas" "Sol" #1=
#2_"*Паллада:2 Pallas:Pallas:1802-2*" "Sol" #2=
#3_"1802-2*:*Паллада:2 Pallas:Pallas" "Sol" #3=
".:Pallas:2 Pallas:1802-2*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2 pallas.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"pallas.jpg"
	Radius	275
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.617990239708
		SemiMajorAxis	2.773085152812
		Eccentricity	0.230597410901
		Inclination	34.837919132331
		AscendingNode	173.087177425298
		ArgOfPericenter	309.991558144537
		MeanAnomaly	291.651362921859
	}
	UniformRotation
	{
		Period	7.8132214
		Inclination	84
		AscendingNode	118
		MeridianAngle	339
	}
	LunarLambert	0.5
	Albedo	0.1587
	InfoURL	"https://en.wikipedia.org/wiki/2_Pallas"
}

#1_"3 Juno:Juno (asteroid)" "Sol" #1=
#2_"*Юнона (астероид):3 Juno:Juno (asteroid):1804-3*" "Sol" #2=
#3_"1804-3*:*Юнона (астероид):3 Juno:Juno (asteroid)" "Sol" #3=
".:Juno (asteroid):3 Juno:1804-3*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3 juno.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"juno.jpg"
	Radius	160
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.364614795847
		SemiMajorAxis	2.670700240558908
		Eccentricity	0.2554482627817375
		Inclination	12.98166179450518
		AscendingNode	169.8711811946533
		ArgOfPericenter	248.4099652667037
		MeanAnomaly	33.07715332505229
	}
	UniformRotation
	{
		Period	7.21
		Inclination	50
		AscendingNode	196
	}
	LunarLambert	0.5
	Albedo	0.2383
	InfoURL	"https://en.wikipedia.org/wiki/3_Juno"
}

#1_"4 Vesta:Vesta" "Sol" #1=
#2_"*Веста:4 Vesta:Vesta:1807-4*" "Sol" #2=
#3_"1807-4*:*Веста:4 Vesta:Vesta" "Sol" #3=
".:Vesta:4 Vesta:1807-4*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4 vesta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"vesta.dds"
	Color	[ 1.000 0.951 0.842 ]
	BlendTexture	true
	Radius	286.3
	Visible	false
	Clickable	false
	Timeline
	[
		{
			Ending	2455758.5  # 2011 Jul 16
			EllipticalOrbit
			{
				Epoch	2455758.5  # 2011 Jul 16
				Period	3.62836007024016
				SemiMajorAxis	2.361210927544374
				Eccentricity	0.08832829070479092
				Inclination	7.134622597005129
				AscendingNode	103.9043080435795
				ArgOfPericenter	149.8717478550207
				MeanAnomaly	45.00136659560411
			}
			UniformRotation
			{
				Period	5.34212766
				Epoch	2450124.90833  # 1996 Feb 11 09:48
				Inclination	40
				AscendingNode	91
				MeridianAngle	325.77
			}
		}
		{
			Ending	2456175.5  # 2012 Sept 05
			SampledTrajectory
			{
				Source	"4 Vesta-Dawn.xyzv"
				DoublePrecision	true
				Interpolation	"cubic"
			}
			UniformRotation
			{
				Period	5.34212766
				Epoch	2450124.90833  # 1996 Feb 11 09:48
				Inclination	40
				AscendingNode	91
				MeridianAngle	325.77
			}
		}
		{
			EllipticalOrbit
			{
				Epoch	2456175.5  # 2012 Sept 05
				Period	3.63292884988756
				SemiMajorAxis	2.363192647384937
				Eccentricity	0.08797739484482046
				Inclination	7.135759615391343
				AscendingNode	103.8670853031207
				ArgOfPericenter	150.4965119982386
				MeanAnomaly	157.6155276479609
			}
			UniformRotation
			{
				Period	5.34212766
				Epoch	2450124.90833  # 1996 Feb 11 09:48
				Inclination	40
				AscendingNode	91
				MeridianAngle	325.77
			}
		}
	]
	LunarLambert	0.5
	Albedo	0.4228
	InfoURL	"https://en.wikipedia.org/wiki/4_Vesta"
}

AltSurface "Topography" "Sol/4 Vesta"
{
	Texture	"vesta-topo.dds"
	LunarLambert	0.5
}

AltSurface "1997 (Hubble)" "Sol/4 Vesta"
{
	Texture	"vesta-hubble.png"
	Color	[ 1.000 0.951 0.842 ]
	BlendTexture	true
	LunarLambert	0.5
}

#1_"5 Astraea:Astraea:1969 SE" "Sol" #1=
#2_"*Астрея:5 Astraea:Astraea:1845-5*" "Sol" #2=
#3_"1845-5*:*Астрея:5 Astraea:Astraea" "Sol" #3=
".:Astraea:5 Astraea:1845-5*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5 astraea.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	83.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.129264264179
		SemiMajorAxis	2.573809010565
		Eccentricity	0.191135484153
		Inclination	5.368522063873
		AscendingNode	141.595567518442
		ArgOfPericenter	358.928976307537
		MeanAnomaly	260.189541840981
	}
	UniformRotation
	{
		Period	16.806
		Inclination	33
	}
	LunarLambert	0.5
	Albedo	0.274
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5"
}

#1_"6 Hebe:Hebe:1947 JB" "Sol" #1=
#2_"*Геба:6 Hebe:Hebe:1847-6*" "Sol" #2=
#3_"1847-6*:*Геба:6 Hebe:Hebe" "Sol" #3=
".:Hebe:6 Hebe:1847-6*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6 hebe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.895 0.811 ]
	BlendTexture	true
	Radius	102.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.777201849087
		SemiMajorAxis	2.425351344822
		Eccentricity	0.20144904126
		Inclination	14.748162341569
		AscendingNode	138.703621828055
		ArgOfPericenter	239.407929909549
		MeanAnomaly	29.214242077932
	}
	UniformRotation
	{
		Period	7.2745
		Inclination	42
		AscendingNode	69
	}
	LunarLambert	0.5
	Albedo	0.2679
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6"
}

#1_"7 Iris:Iris" "Sol" #1=
#2_"*Ирида:7 Iris:Iris:1847-7*" "Sol" #2=
#3_"1847-7*:*Ирида:7 Iris:Iris" "Sol" #3=
".:Iris:7 Iris:1847-7*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7 iris.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.903 0.813 ]
	BlendTexture	true
	Radius	120
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.687177060118
		SemiMajorAxis	2.386659850432
		Eccentricity	0.230794473062
		Inclination	5.522701053639
		AscendingNode	259.620745112804
		ArgOfPericenter	145.461261500671
		MeanAnomaly	72.148648650913
	}
	UniformRotation
	{
		Period	7.139
		Inclination	85
		AscendingNode	110
	}
	LunarLambert	0.5
	Albedo	0.2766
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7"
}

#1_"8 Flora:Flora" "Sol" #1=
#2_"*Флора:8 Flora:Flora:1847-8*" "Sol" #2=
#3_"1847-8*:*Флора:8 Flora:Flora" "Sol" #3=
".:Flora:8 Flora:1847-8*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"8 flora.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	68
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.26754657121
		SemiMajorAxis	2.201958126302
		Eccentricity	0.156337133523
		Inclination	5.88777142681
		AscendingNode	110.922321274183
		ArgOfPericenter	285.466915996966
		MeanAnomaly	71.838733866775
	}
	UniformRotation
	{
		Period	12.865
		Inclination	78
		AscendingNode	250
	}
	LunarLambert	0.5
	Albedo	0.226
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8"
}

#1_"9 Metis:Metis (asteroid):1974 QU2" "Sol" #1=
#2_"*Метида (астероид):9 Metis:Metis (asteroid):1848-9*" "Sol" #2=
#3_"1848-9*:*Метида (астероид):9 Metis:Metis (asteroid)" "Sol" #3=
".:Metis (asteroid):9 Metis:1848-9*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"9 metis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	111
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.686655380408
		SemiMajorAxis	2.386434727642
		Eccentricity	0.122290137207
		Inclination	5.574443831745
		AscendingNode	68.944752954067
		ArgOfPericenter	5.868801508668
		MeanAnomaly	209.685652098233
	}
	UniformRotation
	{
		Period	5.079
		Inclination	74
	}
	LunarLambert	0.5
	Albedo	0.118
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9"
}

#1_"10 Hygiea:Hygiea:A900 GA" "Sol" #1=
#2_"*Гигея:10 Hygiea:Hygiea:1849-10*" "Sol" #2=
#3_"1849-10*:*Гигея:10 Hygiea:Hygiea" "Sol" #3=
".:Hygiea:10 Hygiea:1849-10*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"10 hygiea.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.949 0.904 ]
	BlendTexture	true
	Radius	265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.56387566276
		SemiMajorAxis	3.139878255737
		Eccentricity	0.112690954914
		Inclination	3.832012281026
		AscendingNode	283.218265204903
		ArgOfPericenter	312.038513009788
		MeanAnomaly	46.192291358658
	}
	UniformRotation
	{
		Period	27.63
		Inclination	60
		AscendingNode	205
	}
	LunarLambert	0.5
	Albedo	0.0717
	InfoURL	"https://en.wikipedia.org/wiki/10_Hygiea"
}

#1_"11 Parthenope:Parthenope" "Sol" #1=
#2_"*Парфенопа:11 Parthenope:Parthenope:1850-11*" "Sol" #2=
#3_"1850-11*:*Парфенопа:11 Parthenope:Parthenope" "Sol" #3=
".:Parthenope:11 Parthenope:1850-11*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"11 parthenope.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	71.444
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.840755030168
		SemiMajorAxis	2.452480730972
		Eccentricity	0.100469565354
		Inclination	4.629774818
		AscendingNode	125.559046165476
		ArgOfPericenter	195.865750298417
		MeanAnomaly	124.598084251819
	}
	UniformRotation
	{
		Period	13.7204
	}
	LunarLambert	0.5
	Albedo	0.191
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11"
}

#1_"12 Victoria:Victoria" "Sol" #1=
#2_"*Виктория:12 Victoria:Victoria:1850-12*" "Sol" #2=
#3_"1850-12*:*Виктория:12 Victoria:Victoria" "Sol" #3=
".:Victoria:12 Victoria:1850-12*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"12 victoria.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.889 0.780 ]
	BlendTexture	true
	Radius	57.544
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.564634122647
		SemiMajorAxis	2.333482268866
		Eccentricity	0.221291489359
		Inclination	8.368835368535
		AscendingNode	235.486300918971
		ArgOfPericenter	69.534908697096
		MeanAnomaly	51.14794569953
	}
	UniformRotation
	{
		Period	8.6599
		Inclination	35
		AscendingNode	227
	}
	LunarLambert	0.5
	Albedo	0.163
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12"
}

#1_"13 Egeria:Egeria" "Sol" #1=
#2_"*Эгерия:13 Egeria:Egeria:1850-13*" "Sol" #2=
#3_"1850-13*:*Эгерия:13 Egeria:Egeria" "Sol" #3=
".:Egeria:13 Egeria:1850-13*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"13 egeria.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	107.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.136626736143
		SemiMajorAxis	2.576867500527
		Eccentricity	0.083775483868
		Inclination	16.540213952817
		AscendingNode	43.23687942515
		ArgOfPericenter	80.554801790255
		MeanAnomaly	44.598711222229
	}
	UniformRotation
	{
		Period	7.045
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13"
}

#1_"14 Irene:Irene:1952 TM:A906 QC:A913 EA" "Sol" #1=
#2_"*Ирена:14 Irene:Irene:1851-14*" "Sol" #2=
#3_"1851-14*:*Ирена:14 Irene:Irene" "Sol" #3=
".:Irene:14 Irene:1851-14*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"14 irene.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	83.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.160284059509
		SemiMajorAxis	2.586682877836
		Eccentricity	0.166083163551
		Inclination	9.118068811993
		AscendingNode	86.160054761814
		ArgOfPericenter	98.001250718557
		MeanAnomaly	145.557877237402
	}
	UniformRotation
	{
		Period	15.028
	}
	LunarLambert	0.5
	Albedo	0.159
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14"
}

#1_"15 Eunomia:Eunomia" "Sol" #1=
#2_"*Эвномия:15 Eunomia:Eunomia:1851-15*" "Sol" #2=
#3_"1851-15*:*Эвномия:15 Eunomia:Eunomia" "Sol" #3=
".:Eunomia:15 Eunomia:1851-15*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"15 eunomia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.908 0.817 ]
	BlendTexture	true
	Radius	178.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.299118113498
		SemiMajorAxis	2.643914763022
		Eccentricity	0.187459416379
		Inclination	11.738880564302
		AscendingNode	293.187114720433
		ArgOfPericenter	97.554182779461
		MeanAnomaly	277.52951988594
	}
	UniformRotation
	{
		Period	6.083
		Inclination	165
		AscendingNode	85
	}
	LunarLambert	0.5
	Albedo	0.248
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15"
}

#1_"16 Psyche:Psyche" "Sol" #1=
#2_"*Психея:16 Psyche:Psyche:1852-16*" "Sol" #2=
#3_"1852-16*:*Психея:16 Psyche:Psyche" "Sol" #3=
".:Psyche:16 Psyche:1852-16*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"16 psyche.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.918 0.842 ]
	BlendTexture	true
	Radius	107
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.004425931212
		SemiMajorAxis	2.925706179637
		Eccentricity	0.134858463479
		Inclination	3.09753380587
		AscendingNode	150.263004735697
		ArgOfPericenter	227.54627620102
		MeanAnomaly	171.497548601837
	}
	UniformRotation
	{
		Period	4.196
		Inclination	95
		AscendingNode	125
	}
	LunarLambert	0.5
	Albedo	0.1203
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16"
}

#1_"17 Thetis:Thetis:1954 SO1:A913 CA:A916 YF" "Sol" #1=
#2_"*Фетида:17 Thetis:Thetis:1852-17*" "Sol" #2=
#3_"1852-17*:*Фетида:17 Thetis:Thetis" "Sol" #3=
".:Thetis:17 Thetis:1852-17*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"17 thetis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.890 0.788 ]
	BlendTexture	true
	Radius	42.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.886588335981
		SemiMajorAxis	2.471953102576
		Eccentricity	0.132492147411
		Inclination	5.5908607766
		AscendingNode	125.568989011468
		ArgOfPericenter	135.804831112147
		MeanAnomaly	257.749976623102
	}
	UniformRotation
	{
		Period	12.27048
		Inclination	78
		AscendingNode	148
	}
	LunarLambert	0.5
	Albedo	0.193
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17"
}

#1_"18 Melpomene:Melpomene" "Sol" #1=
#2_"*Мельпомена:18 Melpomene:Melpomene:1852-18*" "Sol" #2=
#3_"1852-18*:*Мельпомена:18 Melpomene:Melpomene" "Sol" #3=
".:Melpomene:18 Melpomene:1852-18*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"18 melpomene.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.898 0.800 ]
	BlendTexture	true
	Radius	85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.476985537862
		SemiMajorAxis	2.295072740361
		Eccentricity	0.218829663647
		Inclination	10.133636938943
		AscendingNode	150.466893098817
		ArgOfPericenter	227.82061873802
		MeanAnomaly	97.354935021187
	}
	UniformRotation
	{
		Period	11.57
		Inclination	127
		AscendingNode	98
	}
	LunarLambert	0.5
	Albedo	0.181
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18"
}

#1_"19 Fortuna:Fortuna:A902 UG" "Sol" #1=
#2_"*Фортуна:19 Fortuna:Fortuna:1852-19*" "Sol" #2=
#3_"1852-19*:*Фортуна:19 Fortuna:Fortuna" "Sol" #3=
".:Fortuna:19 Fortuna:Fortuna:1852-19*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"19 fortuna.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.956 0.901 ]
	BlendTexture	true
	Radius	112.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.815854386057
		SemiMajorAxis	2.44186918414
		Eccentricity	0.158742310577
		Inclination	1.573886851573
		AscendingNode	211.142699376109
		ArgOfPericenter	182.097785506354
		MeanAnomaly	42.302741472419
	}
	UniformRotation
	{
		Period	7.4432
		Inclination	32
		AscendingNode	188
	}
	LunarLambert	0.5
	Albedo	0.037
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=19"
}

#1_"20 Massalia:Massalia" "Sol" #1=
#2_"*Массалия:20 Massalia:Massalia:1852-20*" "Sol" #2=
#3_"1852-20*:*Массалия:20 Massalia:Massalia" "Sol" #3=
".:Massalia:20 Massalia:1852-20*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"20 massalia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.907 0.824 ]
	BlendTexture	true
	Radius	80
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.738634687756
		SemiMajorAxis	2.408813737168
		Eccentricity	0.142890555257
		Inclination	0.70827546937
		AscendingNode	206.136753499966
		ArgOfPericenter	256.639107875668
		MeanAnomaly	56.002550908326
	}
	UniformRotation
	{
		Period	8.098
		Inclination	45
		AscendingNode	100
	}
	LunarLambert	0.5
	Albedo	0.241
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20"
}

#1_"21 Lutetia:Lutetia" "Sol" #1=
#2_"*Лютеция:21 Lutetia:Lutetia:1852-21*" "Sol" #2=
#3_"1852-21*:*Лютеция:21 Lutetia:Lutetia" "Sol" #3=
".:Lutetia:21 Lutetia:1852-21*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"21 lutetia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"lutetia.jpg"
	Color	[ 1.000 0.966 0.938 ]
	BlendTexture	true
	Radius	60.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2455387.5  # 2010 Jul 10
		Period	3.8019400433816
		SemiMajorAxis	2.435929459338225
		Eccentricity	0.1628635150749446
		Inclination	3.063729334850146
		AscendingNode	80.90023215493108
		ArgOfPericenter	250.1877248972368
		MeanAnomaly	230.6845505220987
	}
	UniformRotation
	{
		Period	8.1655
		Inclination	96
		AscendingNode	129
	}
	LunarLambert	0.5
	Albedo	0.2212
	InfoURL	"https://en.wikipedia.org/wiki/21_Lutetia"
}

#1_"22 Kalliope:Kalliope" "Sol" #1=
#2_"*Каллиопа:22 Kalliope:Kalliope:1852-22*" "Sol" #2=
#3_"1852-22*:*Каллиопа:22 Kalliope:Kalliope" "Sol" #3=
".:Kalliope:22 Kalliope:1852-22*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"22 kalliope.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.929 0.861 ]
	BlendTexture	true
	Radius	115.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.963153429621
		SemiMajorAxis	2.909598064873
		Eccentricity	0.099102664775
		Inclination	13.716707156614
		AscendingNode	66.065414135112
		ArgOfPericenter	354.938542296416
		MeanAnomaly	78.816792969881
	}
	UniformRotation
	{
		Period	4.1482003
		Inclination	103
		AscendingNode	110
	}
	LunarLambert	0.5
	Albedo	0.166
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=22"
}

#1_"Linus:22 Kalliope I:Kalliope I:2001 22 I" "Sol/22 Kalliope" #1=
#2_"*Линус:Linus:22 Kalliope I:*Каллиопа I:Kalliope I:2001 22 I" "Sol/22 Kalliope" #2=
#3_"2001 22 I:*Линус:Linus:22 Kalliope I:*Каллиопа I:Kalliope I" "Sol/22 Kalliope" #3=
".:Linus:22 Kalliope I:Kalliope I:2001 22 I" "Sol/22 Kalliope" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Color	[ 1.000 0.929 0.861 ]
	BlendTexture	true
	Radius	14
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	3.596
		SemiMajorAxis	1095
		Eccentricity	0.002
		Inclination	93.4
	}
	LunarLambert	0.5
	Albedo	0.166
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00022.html"
}

#1_"23 Thalia:Thalia:1938 CL:1974 QT2" "Sol" #1=
#2_"*Талия:23 Thalia:Thalia:1852-23*" "Sol" #2=
#3_"1852-23*:*Талия:23 Thalia:Thalia" "Sol" #3=
".:Thalia:23 Thalia:1852-23*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"23 thalia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.902 0.806 ]
	BlendTexture	true
	Radius	53.765
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.25263634808
		SemiMajorAxis	2.624823041308
		Eccentricity	0.235473279316
		Inclination	10.114935312043
		AscendingNode	66.883105230266
		ArgOfPericenter	60.825186829155
		MeanAnomaly	324.845704902792
	}
	UniformRotation
	{
		Period	12.312
		Inclination	145
		AscendingNode	89
	}
	LunarLambert	0.5
	Albedo	0.2536
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=23"
}

#1_"24 Themis:Themis:1947 BA:1955 OH" "Sol" #1=
#2_"*Фемида:24 Themis:Themis:1853-24*" "Sol" #2=
#3_"1853-24*:*Фемида:24 Themis:Themis" "Sol" #3=
".:Themis:24 Themis:1853-24*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"24 themis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	99
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.550774202333
		SemiMajorAxis	3.134947262237
		Eccentricity	0.125808939739
		Inclination	0.752272180345
		AscendingNode	35.922506636257
		ArgOfPericenter	106.671304749442
		MeanAnomaly	71.674017959692
	}
	UniformRotation
	{
		Period	8.374
	}
	LunarLambert	0.5
	Albedo	0.067
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=24"
}

#1_"25 Phocaea:Phocaea:1956 GC" "Sol" #1=
#2_"*Фокея:25 Phocaea:Phocaea:1853-24*" "Sol" #2=
#3_"1853-24*:*Фокея:25 Phocaea:Phocaea" "Sol" #3=
".:Phocaea:25 Phocaea:1853-24*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"25 phocaea.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	30.527
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.716764336982
		SemiMajorAxis	2.399410465155
		Eccentricity	0.255556926636
		Inclination	21.591152302775
		AscendingNode	214.22440336084
		ArgOfPericenter	90.051465516415
		MeanAnomaly	109.018116888742
	}
	UniformRotation
	{
		Period	9.9341
	}
	LunarLambert	0.5
	Albedo	0.35
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=25"
}

#1_"26 Proserpina:Proserpina:1935 KK:1954 WD1" "Sol" #1=
#2_"*Прозерпина:26 Proserpina:Proserpina:1853-26*" "Sol" #2=
#3_"1853-26*:*Прозерпина:26 Proserpina:Proserpina" "Sol" #3=
".:Proserpina:26 Proserpina:1853-26*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"26 proserpina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	47.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.32626299674
		SemiMajorAxis	2.655032305653
		Eccentricity	0.090322011907
		Inclination	3.563520625625
		AscendingNode	45.78834627773
		ArgOfPericenter	194.268916246198
		MeanAnomaly	100.321884879852
	}
	UniformRotation
	{
		Period	13.11
	}
	LunarLambert	0.5
	Albedo	0.1966
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=26"
}

#1_"27 Euterpe:Euterpe:1945 KB" "Sol" #1=
#2_"*Эвтерпа:27 Euterpe:Euterpe:1853-27*" "Sol" #2=
#3_"1853-27*:*Эвтерпа:27 Euterpe:Euterpe" "Sol" #3=
".:Euterpe:27 Euterpe:1853-27*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"27 euterpe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	62
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.595850774066
		SemiMajorAxis	2.34708583336
		Eccentricity	0.17227703538
		Inclination	1.583704547413
		AscendingNode	94.800122962395
		ArgOfPericenter	356.540181732769
		MeanAnomaly	256.565547278333
	}
	UniformRotation
	{
		Period	10.4082
	}
	LunarLambert	0.5
	Albedo	0.215
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=27"
}

#1_"28 Bellona:Bellona:1951 CC2" "Sol" #1=
#2_"*Беллона:28 Bellona:Bellona:1854-28*" "Sol" #2=
#3_"1854-28*:*Беллона:28 Bellona:Bellona" "Sol" #3=
".:Bellona:28 Bellona:1854-28*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"28 bellona.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	60.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.623378457556
		SemiMajorAxis	2.775241802777
		Eccentricity	0.15145291718
		Inclination	9.433336522151
		AscendingNode	144.324321974929
		ArgOfPericenter	344.616457307289
		MeanAnomaly	291.870652632012
	}
	UniformRotation
	{
		Period	15.706
	}
	LunarLambert	0.5
	Albedo	0.1763
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=28"
}

#1_"29 Amphitrite:Amphitrite:A899 NG" "Sol" #1=
#2_"*Амфитрита:29 Amphitrite:Amphitrite:1854-29*" "Sol" #2=
#3_"1854-29*:*Амфитрита:29 Amphitrite:Amphitrite" "Sol" #3=
".:Amphitrite:29 Amphitrite:1854-29*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"29 amphitrite.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.902 0.819 ]
	BlendTexture	true
	Radius	116.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.086899889928
		SemiMajorAxis	2.556174697225
		Eccentricity	0.071772887982
		Inclination	6.086216440999
		AscendingNode	356.415945343833
		ArgOfPericenter	62.684193440487
		MeanAnomaly	140.095327659233
	}
	UniformRotation
	{
		Period	5.3921
		Inclination	111
		AscendingNode	228
	}
	LunarLambert	0.5
	Albedo	0.216
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=29"
}

#1_"30 Urania:Urania:1948 JK" "Sol" #1=
#2_"*Урания:30 Urania:Urania:1854-30*" "Sol" #2=
#3_"1854-30*:*Урания:30 Urania:Urania" "Sol" #3=
".:Urania:30 Urania:1854-30*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"30 urania.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	55.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.638757773641
		SemiMajorAxis	2.365719752353
		Eccentricity	0.12675078063
		Inclination	2.09803047133
		AscendingNode	307.633225877015
		ArgOfPericenter	86.718586384763
		MeanAnomaly	316.294674644765
	}
	UniformRotation
	{
		Period	13.686
	}
	LunarLambert	0.5
	Albedo	0.192
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=30"
}

#1_"31 Euphrosyne:Euphrosyne:A907 GP:A918 GB" "Sol" #1=
#2_"*Евфросина:31 Euphrosyne:Euphrosyne:1854-31*" "Sol" #2=
#3_"1854-31*:*Евфросина:31 Euphrosyne:Euphrosyne" "Sol" #3=
".:Euphrosyne:31 Euphrosyne:1854-31*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"31 euphrosyne.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	133.54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.604655188152
		SemiMajorAxis	3.155201727926
		Eccentricity	0.221985046702
		Inclination	26.305686976211
		AscendingNode	31.144035963129
		ArgOfPericenter	61.431781738181
		MeanAnomaly	165.90708813352
	}
	UniformRotation
	{
		Period	5.53
	}
	LunarLambert	0.5
	Albedo	0.053
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=31"
}

#1_"32 Pomona:Pomona:1945 RB:1949 SH:1950 YD:A899 QA:A911 KF" "Sol" #1=
#2_"*Помона:32 Pomona:Pomona:1854-32*" "Sol" #2=
#3_"1854-32*:*Помона:32 Pomona:Pomona" "Sol" #3=
".:Pomona:32 Pomona:1854-32*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"32 pomona.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.900 0.807 ]
	BlendTexture	true
	Radius	40.38
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.161744745945
		SemiMajorAxis	2.587288303087
		Eccentricity	0.080162156578
		Inclination	5.523991800887
		AscendingNode	220.45699718957
		ArgOfPericenter	338.894228074634
		MeanAnomaly	13.748412528347
	}
	UniformRotation
	{
		Period	9.448
		Inclination	32
		AscendingNode	357
	}
	LunarLambert	0.5
	Albedo	0.2564
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=32"
}

#1_"33 Polyhymnia:Polyhymnia:1938 FE:1953 AK:1957 YL:1963 DG:1976 YT7:A887 HA" "Sol" #1=
#2_"*Полигимния:33 Polyhymnia:Polyhymnia:1854-33*" "Sol" #2=
#3_"1854-33*:*Полигимния:33 Polyhymnia:Polyhymnia" "Sol" #3=
".:Polyhymnia:33 Polyhymnia:1854-33*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	26.464
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.855579214471
		SemiMajorAxis	2.867401848793
		Eccentricity	0.336675265948
		Inclination	1.868771274821
		AscendingNode	8.577461706689
		ArgOfPericenter	338.09739856416
		MeanAnomaly	18.268879240829
	}
	UniformRotation
	{
		Period	18.608
	}
	LunarLambert	0.5
	Albedo	0.24
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=33"
}

#1_"34 Circe:Circe:1965 JL" "Sol" #1=
#2_"*Цирцея:34 Circe:Circe:1855-34*" "Sol" #2=
#3_"1855-34*:*Цирцея:34 Circe:Circe" "Sol" #3=
".:Circe:34 Circe:1855-34*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"34 circe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	66.496
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.406918217878
		SemiMajorAxis	2.687929410398
		Eccentricity	0.104597744193
		Inclination	5.49775046082
		AscendingNode	184.429125118247
		ArgOfPericenter	330.42618546
		MeanAnomaly	129.095216805479
	}
	UniformRotation
	{
		Period	12.15
	}
	LunarLambert	0.5
	Albedo	0.052
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=34"
}

#1_"35 Leukothea:Leukothea:1948 DC:1950 RS1:1976 WH" "Sol" #1=
#2_"*Левкофея:35 Leukothea:Leukothea:1855-35*" "Sol" #2=
#3_"1855-35*:*Левкофея:35 Leukothea:Leukothea" "Sol" #3=
".:Leukothea:35 Leukothea:1855-35*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"35 leukothea.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	51.528
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.175264252458
		SemiMajorAxis	2.991917071978
		Eccentricity	0.226902762732
		Inclination	7.934566107151
		AscendingNode	353.769306597755
		ArgOfPericenter	213.459814381756
		MeanAnomaly	270.685479183567
	}
	UniformRotation
	{
		Period	31.9
	}
	LunarLambert	0.5
	Albedo	0.066
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=35"
}

#1_"36 Atalante:Atalante:A901 SB:A912 HC" "Sol" #1=
#2_"*Аталанта:36 Atalante:Atalante:1855-36*" "Sol" #2=
#3_"1855-36*:*Аталанта:36 Atalante:Atalante" "Sol" #3=
".:Atalante:36 Atalante:1855-36*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"36 atalante.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	57.602
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.558626662753
		SemiMajorAxis	2.749268879152
		Eccentricity	0.302132113558
		Inclination	18.425447369305
		AscendingNode	358.414007614796
		ArgOfPericenter	46.978773210379
		MeanAnomaly	314.75116131193
	}
	UniformRotation
	{
		Period	9.93
	}
	LunarLambert	0.5
	Albedo	0.036
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=36"
}

#1_"37 Fides:Fides:1925 WH" "Sol" #1=
#2_"*Фидес:37 Fides:Fides:1855-37*" "Sol" #2=
#3_"1855-37*:*Фидес:37 Fides:Fides" "Sol" #3=
".:Fides:37 Fides:1855-37*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"37 fides.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.889 0.786 ]
	BlendTexture	true
	Radius	54.175
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.296139059668
		SemiMajorAxis	2.642693229657
		Eccentricity	0.173529450847
		Inclination	3.072750447082
		AscendingNode	7.297820132767
		ArgOfPericenter	62.942664411088
		MeanAnomaly	334.371181875555
	}
	UniformRotation
	{
		Period	7.3335
		Inclination	116
		AscendingNode	175
	}
	LunarLambert	0.5
	Albedo	0.1826
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=37"
}

#1_"38 Leda:Leda (asteroid):1949 QO2:A904 SF" "Sol" #1=
#2_"*Леда (астероид):38 Leda:Leda (asteroid):1856-38*" "Sol" #2=
#3_"1856-38*:*Леда (астероид):38 Leda:Leda (asteroid)" "Sol" #3=
".:Leda (asteroid):38 Leda:1856-38*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"38 leda.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	46.128
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.536193565686
		SemiMajorAxis	2.740241992354
		Eccentricity	0.155585482323
		Inclination	6.974021677649
		AscendingNode	295.762742922622
		ArgOfPericenter	169.762733889408
		MeanAnomaly	16.598905397858
	}
	UniformRotation
	{
		Period	12.838
	}
	LunarLambert	0.5
	Albedo	0.055
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=38"
}

#1_"39 Laetitia:Laetitia" "Sol" #1=
#2_"*Летиция:39 Laetitia:Laetitia:1856-39*" "Sol" #2=
#3_"1856-39*:*Летиция:39 Laetitia:Laetitia" "Sol" #3=
".:Laetitia:39 Laetitia:1856-39*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"39 laetitia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.902 0.833 ]
	BlendTexture	true
	Radius	109.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.609345913724
		SemiMajorAxis	2.769623482888
		Eccentricity	0.112898837085
		Inclination	10.377554189608
		AscendingNode	157.111979153534
		ArgOfPericenter	208.3530307352
		MeanAnomaly	174.082005815506
	}
	UniformRotation
	{
		Period	5.138
		Inclination	55
		AscendingNode	53
	}
	LunarLambert	0.5
	Albedo	0.269
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=39"
}

#1_"40 Harmonia:Harmonia:1950 XU" "Sol" #1=
#2_"*Гармония:40 Harmonia:Harmonia:1856-40*" "Sol" #2=
#3_"1856-40*:*Гармония:40 Harmonia:Harmonia" "Sol" #3=
".:Harmonia:40 Harmonia:1856-40*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"40 harmonia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	55.626
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.4137469328
		SemiMajorAxis	2.2671595293
		Eccentricity	0.046741628742
		Inclination	4.257585239965
		AscendingNode	94.238643307844
		ArgOfPericenter	268.670510709347
		MeanAnomaly	6.660097758627
	}
	UniformRotation
	{
		Period	8.91
	}
	LunarLambert	0.5
	Albedo	0.22
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=40"
}

#1_"41 Daphne:Daphne:1949 TG" "Sol" #1=
#2_"*Дафна:41 Daphne:Daphne:1856-41*" "Sol" #2=
#3_"1856-41*:*Дафна:41 Daphne:Daphne" "Sol" #3=
".:Daphne:41 Daphne:1856-41*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"41 daphne.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	119.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.586569584118
		SemiMajorAxis	2.760492191177
		Eccentricity	0.275789342277
		Inclination	15.794730097353
		AscendingNode	178.090523961456
		ArgOfPericenter	45.863178063033
		MeanAnomaly	5.400470602317
	}
	UniformRotation
	{
		Period	5.9879856
	}
	LunarLambert	0.5
	Albedo	0.059
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=41"
}

#1_"2008 41 I" "Sol/41 Daphne" #1=
#2_"2008 41 I" "Sol/41 Daphne" #2=
#3_"2008 41 I" "Sol/41 Daphne" #3=
".:2008 41 I" "Sol/41 Daphne" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	1.1
		SemiMajorAxis	443
	}
	LunarLambert	0.5
	Albedo	0.059
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00041.html"
}

#1_"42 Isis:Isis:1939 GM:1950 DD1:A910 TA" "Sol" #1=
#2_"*Изида:42 Isis:Isis:1856-42*" "Sol" #2=
#3_"1856-42*:*Изида:42 Isis:Isis" "Sol" #3=
".:Isis:42 Isis:1856-42*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"42 isis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.896 0.797 ]
	BlendTexture	true
	Radius	55.498
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.820792097005
		SemiMajorAxis	2.443975247271
		Eccentricity	0.221923473053
		Inclination	8.520528579212
		AscendingNode	84.342294695386
		ArgOfPericenter	236.795338118688
		MeanAnomaly	150.840346441308
	}
	UniformRotation
	{
		Period	13.59
		Inclination	104
		AscendingNode	210
	}
	LunarLambert	0.5
	Albedo	0.139
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=42"
}

#1_"43 Ariadne:Ariadne" "Sol" #1=
#2_"*Ариадна:43 Ariadne:Ariadne:1857-43*" "Sol" #2=
#3_"1857-43*:*Ариадна:43 Ariadne:Ariadne" "Sol" #3=
".:Ariadne:43 Ariadne:1857-43*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"43 ariadne.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	47.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.270948766211
		SemiMajorAxis	2.203486325178
		Eccentricity	0.168445665503
		Inclination	3.470719718169
		AscendingNode	264.81823262227
		ArgOfPericenter	16.170713445304
		MeanAnomaly	317.221885168396
	}
	UniformRotation
	{
		Period	5.76218
		Inclination	105
		AscendingNode	343
	}
	LunarLambert	0.5
	Albedo	0.234
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=43"
}

#1_"44 Nysa:Nysa:1977 CE" "Sol" #1=
#2_"*Ниса:44 Nysa:Nysa:1857-44*" "Sol" #2=
#3_"1857-44*:*Ниса:44 Nysa:Nysa" "Sol" #3=
".:Nysa:44 Nysa:1857-44*" "Sol" #4=


{
	Class	"asteroid"
	Mesh	"44 nysa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	56.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.773333139838
		SemiMajorAxis	2.423694989668
		Eccentricity	0.148777624716
		Inclination	3.706792794368
		AscendingNode	131.558502688452
		ArgOfPericenter	343.391011992211
		MeanAnomaly	24.591813248678
	}
	UniformRotation
	{
		Period	6.422
	}
	LunarLambert	0.5
	Albedo	0.482
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=44"
}

#1_"45 Eugenia:Eugenia:1941 BN" "Sol" #1=
#2_"*Евгения:45 Eugenia:Eugenia:1857-45*" "Sol" #2=
#3_"1857-45*:*Евгения:45 Eugenia:Eugenia" "Sol" #3=
".:Eugenia:45 Eugenia:1857-45*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"45 eugenia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.946 0.898 ]
	BlendTexture	true
	Radius	152.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.484917855643
		SemiMajorAxis	2.719553001322
		Eccentricity	0.083995064986
		Inclination	6.60400093601
		AscendingNode	147.671344344275
		ArgOfPericenter	88.756620020242
		MeanAnomaly	265.975038609184
	}
	UniformRotation
	{
		Period	5.69916
		Inclination	117
		AscendingNode	214
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=45"
}

#1_"2004 45 I" "Sol/45 Eugenia" #1=
#2_"2004 45 I" "Sol/45 Eugenia" #2=
#3_"2004 45 I" "Sol/45 Eugenia" #3=
".:2004 45 I" "Sol/45 Eugenia" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.946 0.898 ]
	BlendTexture	true
	Radius	2.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2452980.0  # 2003 Dec 06 12:00
		Period	1.793
		SemiMajorAxis	610.59
		Eccentricity	0.11
		AscendingNode	206.67
		ArgOfPericenter	95.0
		MeanAnomaly	173.0
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00045.html"
}

#1_"Petit-Prince:45 Eugenia I:Евгения I:Eugenia I:1998 45 I" "Sol/45 Eugenia" #1=
#2_"*Маленький принц:Petit-Prince:45 Eugenia I:*Евгения I:Eugenia I:1998 45 I" "Sol/45 Eugenia" #2=
#3_"1998 45 I:*Маленький принц:Petit-Prince:45 Eugenia I:*Евгения I:Eugenia I" "Sol/45 Eugenia" #3=
".:Petit-Prince:45 Eugenia I:Eugenia I:1998 45 I" "Sol/45 Eugenia" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.946 0.898 ]
	BlendTexture	true
	Radius	3.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2452980.0  # 2003 Dec 06 12:00
		Period	4.716
		SemiMajorAxis	1164.42
		Eccentricity	0.002
		Inclination	8.0
		AscendingNode	201.93
		ArgOfPericenter	138.0
		MeanAnomaly	5.0
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00045.html"
}

#1_"46 Hestia:Hestia:1935 EY" "Sol" #1=
#2_"*Гестия:46 Hestia:Hestia:1857-46*" "Sol" #2=
#3_"1857-46*:*Гестия:46 Hestia:Hestia" "Sol" #3=
".:Hestia:46 Hestia:1857-46*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	56.207
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.012704828655
		SemiMajorAxis	2.525143178785
		Eccentricity	0.171748366705
		Inclination	2.344621733381
		AscendingNode	181.128697137695
		ArgOfPericenter	176.545218865712
		MeanAnomaly	38.073176973484
	}
	UniformRotation
	{
		Period	21.04
	}
	LunarLambert	0.5
	Albedo	0.046
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=46"
}

#1_"47 Aglaja:Aglaja:1948 EU:1982 DX2" "Sol" #1=
#2_"*Аглая:47 Aglaja:Aglaja:1857-47*" "Sol" #2=
#3_"1857-47*:*Аглая:47 Aglaja:Aglaja" "Sol" #3=
".:Aglaja:47 Aglaja:1857-47*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	84.087
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.885354635938
		SemiMajorAxis	2.879112236973
		Eccentricity	0.132877153298
		Inclination	4.983128053896
		AscendingNode	3.127617530408
		ArgOfPericenter	313.88350219
		MeanAnomaly	90.784010056863
	}
	UniformRotation
	{
		Period	13.178
	}
	LunarLambert	0.5
	Albedo	0.082
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=47"
}

#1_"48 Doris:Doris:1948 FE" "Sol" #1=
#2_"*Дорида:48 Doris:Doris:1857-48*" "Sol" #2=
#3_"1857-48*:*Дорида:48 Doris:Doris" "Sol" #3=
".:Doris:48 Doris:1857-48*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"48 doris.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	139
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.483190927414
		SemiMajorAxis	3.109449043526
		Eccentricity	0.073540216389
		Inclination	6.54747122433
		AscendingNode	183.579878389229
		ArgOfPericenter	253.567678687774
		MeanAnomaly	141.46631276693
	}
	UniformRotation
	{
		Period	11.89
	}
	LunarLambert	0.5
	Albedo	0.065
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=48"
}

#1_"49 Pales:Pales:1947 FG:1950 XJ:1954 MF:1988 VU7:A908 AF" "Sol" #1=
#2_"*Палес:49 Pales:Pales:1857-49*" "Sol" #2=
#3_"1857-49*:*Палес:49 Pales:Pales" "Sol" #3=
".:Pales:49 Pales:1857-49*" "Sol" #4=


{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	83.126
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.441822176705
		SemiMajorAxis	3.093789510168
		Eccentricity	0.227486478231
		Inclination	3.173777489376
		AscendingNode	285.996225210545
		ArgOfPericenter	110.198425617023
		MeanAnomaly	312.90266247867
	}
	UniformRotation
	{
		Period	20.704
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=49"
}

#1_"50 Virginia:Virginia:1977 LU1:A900 SB:A909 WA" "Sol" #1=
#2_"*Виргиния:50 Virginia:Virginia:1857-50*" "Sol" #2=
#3_"1857-50*:*Виргиния:50 Virginia:Virginia" "Sol" #3=
".:Virginia:50 Virginia:1857-50*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	42.037
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.313771355865
		SemiMajorAxis	2.649919087302
		Eccentricity	0.285383057333
		Inclination	2.837155561739
		AscendingNode	173.52899377512
		ArgOfPericenter	200.25936713309
		MeanAnomaly	152.545392759763
	}
	UniformRotation
	{
		Period	14.315
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=50"
}

#1_"51 Nemausa:Nemausa:1949 HC1:1954 QX" "Sol" #1=
#2_"*Немауза:51 Nemausa:Nemausa:1858-51*" "Sol" #2=
#3_"1858-51*:*Немауза:51 Nemausa:Nemausa" "Sol" #3=
".:Nemausa:51 Nemausa:1858-51*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"51 nemausa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.637795329946
		SemiMajorAxis	2.365302582066
		Eccentricity	0.06691659829
		Inclination	9.980173238345
		AscendingNode	176.0164155487
		ArgOfPericenter	2.598156283601
		MeanAnomaly	293.489360239636
	}
	UniformRotation
	{
		Period	7.783
	}
	LunarLambert	0.5
	Albedo	0.105
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=51"
}

#1_"52 Europa:Europa (asteroid):1948 LA" "Sol" #1=
#2_"*Европа (астероид):52 Europa:Europa (asteroid):1858-52*" "Sol" #2=
#3_"1858-52*:*Европа (астероид):52 Europa:Europa (asteroid)" "Sol" #3=
".:Europa (asteroid):52 Europa:1858-52*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"52 europa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	189.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.443678513927
		SemiMajorAxis	3.094493047815
		Eccentricity	0.109886572769
		Inclination	7.47679574141
		AscendingNode	128.619819522041
		ArgOfPericenter	343.811840985066
		MeanAnomaly	128.201582010108
	}
	UniformRotation
	{
		Period	5.6304
	}
	LunarLambert	0.5
	Albedo	0.057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=52"
}

#1_"53 Kalypso:Kalypso:1951 CD2:1951 CE2:1972 JB:A917 BD" "Sol" #1=
#2_"*Калипсо (астероид):53 Kalypso:Kalypso:1858-53*" "Sol" #2=
#3_"1858-53*:*Калипсо (астероид):53 Kalypso:Kalypso" "Sol" #3=
".:Kalypso:53 Kalypso:1858-53*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"53 kalypso.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	45.446
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.233630975805
		SemiMajorAxis	2.616996841873
		Eccentricity	0.206414044283
		Inclination	5.17152570348
		AscendingNode	143.561143701844
		ArgOfPericenter	313.440338581584
		MeanAnomaly	51.640194787579
	}
	UniformRotation
	{
		Period	9.036
	}
	LunarLambert	0.5
	Albedo	0.031
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=53"
}

#1_"54 Alexandra:Alexandra:1950 BT:1974 HG1" "Sol" #1=
#2_"*Александра:54 Alexandra:Alexandra:1858-54*" "Sol" #2=
#3_"1858-54*:*Александра:54 Alexandra:Alexandra" "Sol" #3=
".:Alexandra:54 Alexandra:1858-54*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"54 alexandra.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	80
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.461823383599
		SemiMajorAxis	2.710208992671
		Eccentricity	0.198111804013
		Inclination	11.799445829617
		AscendingNode	313.326466892631
		ArgOfPericenter	345.062651085786
		MeanAnomaly	245.747831462301
	}
	UniformRotation
	{
		Period	7.024
	}
	LunarLambert	0.5
	Albedo	0.041
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=54"
}

#1_"55 Pandora:Pandora (asteroid)" "Sol" #1=
#2_"*Пандора (астероид):55 Pandora:Pandora (asteroid):1858-55*" "Sol" #2=
#3_"1858-55*:*Пандора (астероид):55 Pandora:Pandora (asteroid)" "Sol" #3=
".:Pandora (asteroid):55 Pandora:1858-55*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"55 pandora.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	42.397
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.584643008712
		SemiMajorAxis	2.759719112494
		Eccentricity	0.142322116447
		Inclination	7.185789020045
		AscendingNode	10.432775050293
		ArgOfPericenter	3.916496083461
		MeanAnomaly	18.8526159676
	}
	UniformRotation
	{
		Period	4.804
	}
	LunarLambert	0.5
	Albedo	0.204
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=55"
}

#1_"56 Melete:Melete:1949 TH:1986 EN5:1990 HG4" "Sol" #1=
#2_"*Мелета:56 Melete:Melete:1857-56*" "Sol" #2=
#3_"1857-56*:*Мелета:56 Melete:Melete" "Sol" #3=
".:Melete:56 Melete:1857-56*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"56 melete.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	60.666
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.188951505556
		SemiMajorAxis	2.598552049642
		Eccentricity	0.236960970051
		Inclination	8.073639237956
		AscendingNode	193.020919005352
		ArgOfPericenter	104.811027990439
		MeanAnomaly	229.857460960318
	}
	UniformRotation
	{
		Period	18.147
	}
	LunarLambert	0.5
	Albedo	0.057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=56"
}

#1_"57 Mnemosyne:Mnemosyne:1959 NT" "Sol" #1=
#2_"*Мнемозина:57 Mnemosyne:Mnemosyne:1858-59*" "Sol" #2=
#3_"1858-59*:*Мнемозина:57 Mnemosyne:Mnemosyne" "Sol" #3=
".:Mnemosyne:57 Mnemosyne:1858-59*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	56.295
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.596188215843
		SemiMajorAxis	3.152023211057
		Eccentricity	0.114494852909
		Inclination	15.214248648788
		AscendingNode	199.219204669025
		ArgOfPericenter	211.090462373872
		MeanAnomaly	220.954875894014
	}
	UniformRotation
	{
		Period	12.463
	}
	LunarLambert	0.5
	Albedo	0.2149
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=57"
}

#1_"58 Concordia:Concordia:1928 XE" "Sol" #1=
#2_"*Конкордия:58 Concordia:Concordia:1860-58*" "Sol" #2=
#3_"1860-58*:*Конкордия:58 Concordia:Concordia" "Sol" #3=
".:Concordia:58 Concordia:1860-58*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	53.258
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.440720101405
		SemiMajorAxis	2.701656512211
		Eccentricity	0.044166293429
		Inclination	5.062997943329
		AscendingNode	161.125915272219
		ArgOfPericenter	30.064406479064
		MeanAnomaly	303.845774374452
	}
	UniformRotation
	{
		Period	9.895
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=58"
}

#1_"59 Elpis:Elpis:A900 SC" "Sol" #1=
#2_"*Элпида:59 Elpis:Elpis:1860-59*" "Sol" #2=
#3_"1860-59*:*Элпида:59 Elpis:Elpis" "Sol" #3=
".:Elpis:59 Elpis:1860-59*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	82.56
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.466356436173
		SemiMajorAxis	2.712044332091
		Eccentricity	0.119251974371
		Inclination	8.641192378799
		AscendingNode	170.038305606114
		ArgOfPericenter	211.57894167
		MeanAnomaly	165.613612806236
	}
	UniformRotation
	{
		Period	13.69
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=59"
}

#1_"60 Echo:Echo:A899 EB" "Sol" #1=
#2_"*Эхо:60 Echo:Echo:1860-60*" "Sol" #2=
#3_"1860-60*:*Эхо:60 Echo:Echo" "Sol" #3=
".:Echo:60 Echo:1860-60*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"60 echo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	21.609
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.701383941852
		SemiMajorAxis	2.392786535183
		Eccentricity	0.183640310602
		Inclination	3.60096560177
		AscendingNode	191.610304765794
		ArgOfPericenter	270.917325910873
		MeanAnomaly	142.763569180323
	}
	UniformRotation
	{
		Period	25.208
	}
	LunarLambert	0.5
	Albedo	0.373
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=60"
}

#1_"61 Danae:Danae:1953 RL1:A917 SM" "Sol" #1=
#2_"*Даная:61 Danae:Danae:1860-61*" "Sol" #2=
#3_"1860-61*:*Даная:61 Danae:Danae" "Sol" #3=
".:Danae:61 Danae:1860-61*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	42.968
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.152830334366
		SemiMajorAxis	2.983264501394
		Eccentricity	0.167377962298
		Inclination	18.211817973399
		AscendingNode	333.728151708957
		ArgOfPericenter	12.877274497124
		MeanAnomaly	325.551228421258
	}
	UniformRotation
	{
		Period	11.45
	}
	LunarLambert	0.5
	Albedo	0.203
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=61"
}

#1_"62 Erato:Erato:1935 FW:1953 OS:2002 JN104:A906 BE:A907 GE:A910 VA" "Sol" #1=
#2_"*Эрато:62 Erato:Erato:1860-62*" "Sol" #2=
#3_"1860-62*:*Эрато:62 Erato:Erato" "Sol" #3=
".:Erato:62 Erato:1860-62*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"62 erato.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	53.46
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.533078469084
		SemiMajorAxis	3.128280959975
		Eccentricity	0.171308436487
		Inclination	2.230007825464
		AscendingNode	125.56906551287
		ArgOfPericenter	274.055810688944
		MeanAnomaly	317.595786362987
	}
	UniformRotation
	{
		Period	9.2213
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=62"
}

#1_"63 Ausonia:Ausonia:1947 NA:1948 WT" "Sol" #1=
#2_"*Аузониа:63 Ausonia:Ausonia:1861-63*" "Sol" #2=
#3_"1861-63*:*Аузониа:63 Ausonia:Ausonia" "Sol" #3=
".:Ausonia:63 Ausonia:1861-63*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"63 ausonia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.868 0.758 ]
	BlendTexture	true
	Radius	58.022
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.706410412383
		SemiMajorAxis	2.394952310773
		Eccentricity	0.127687844877
		Inclination	5.780168255868
		AscendingNode	337.767787749613
		ArgOfPericenter	296.074382680232
		MeanAnomaly	73.948371276435
	}
	UniformRotation
	{
		Period	9.298
		Inclination	105
		AscendingNode	210
	}
	LunarLambert	0.5
	Albedo	0.125
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=63"
}

#1_"64 Angelina:Angelina:1930 QY" "Sol" #1=
#2_"*Ангелина:64 Angelina:Angelina:1861-64*" "Sol" #2=
#3_"1861-64*:*Ангелина:64 Angelina:Angelina" "Sol" #3=
".:Angelina:64 Angelina:1861-64*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"64 angelina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	30
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.390406746418
		SemiMajorAxis	2.681211271923
		Eccentricity	0.126597447386
		Inclination	1.310176937679
		AscendingNode	309.153135443509
		ArgOfPericenter	178.742517153002
		MeanAnomaly	39.596012812952
	}
	UniformRotation
	{
		Period	8.752
	}
	LunarLambert	0.5
	Albedo	0.483
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=64"
}

#1_"65 Cybele:Cybele:1949 YQ" "Sol" #1=
#2_"*Кибела:65 Cybele:Cybele:1861-65*" "Sol" #2=
#3_"1861-65*:*Кибела:65 Cybele:Cybele" "Sol" #3=
".:Cybele:65 Cybele:1861-65*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"65 cybele.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	151
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.347877232491
		SemiMajorAxis	3.428310991769
		Eccentricity	0.110664572757
		Inclination	3.56249281591
		AscendingNode	155.638344564608
		ArgOfPericenter	102.36351304218
		MeanAnomaly	12.888607163437
	}
	UniformRotation
	{
		Period	6.0814
	}
	LunarLambert	0.5
	Albedo	0.0706
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=65"
}

#1_"66 Maja:Maja:1947 FO:1974 KR:1992 OX10:A902 UF:A906 QD" "Sol" #1=
#2_"*Майя (астероид):66 Maja:Maja:1861-66*" "Sol" #2=
#3_"1861-66*:*Майя (астероид):66 Maja:Maja" "Sol" #3=
".:Maja:66 Maja:1861-66*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"66 maja.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	35.91
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.305147487877
		SemiMajorAxis	2.646386188971
		Eccentricity	0.170554623984
		Inclination	3.04671013924
		AscendingNode	7.537360160209
		ArgOfPericenter	43.982648511094
		MeanAnomaly	12.811291016244
	}
	UniformRotation
	{
		Period	9.73509
	}
	LunarLambert	0.5
	Albedo	0.0618
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=66"
}

#1_"67 Asia:Asia" "Sol" #1=
#2_"*Асия:67 Asia:Asia:1861-67*" "Sol" #2=
#3_"1861-67*:*Асия:67 Asia:Asia" "Sol" #3=
".:Asia:67 Asia:1861-67*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	28.154
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.770488575157
		SemiMajorAxis	2.422476752205
		Eccentricity	0.18452413183
		Inclination	6.027392781081
		AscendingNode	202.459310324095
		ArgOfPericenter	107.015701164735
		MeanAnomaly	220.001873214266
	}
	UniformRotation
	{
		Period	15.853
	}
	LunarLambert	0.5
	Albedo	0.228
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=67"
}

#1_"68 Leto:Leto" "Sol" #1=
#2_"*Лето:68 Leto:Leto:1861-68*" "Sol" #2=
#3_"1861-68*:*Лето:68 Leto:Leto" "Sol" #3=
".:Leto:68 Leto:1861-68*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"68 leto.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	61.254
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.637769404916
		SemiMajorAxis	2.780997718956
		Eccentricity	0.187177957478
		Inclination	7.971901191114
		AscendingNode	44.136904641153
		ArgOfPericenter	304.92951821132
		MeanAnomaly	281.137614831721
	}
	UniformRotation
	{
		Period	14.848
	}
	LunarLambert	0.5
	Albedo	0.228
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=68"
}

#1_"69 Hesperia:Hesperia:1932 CM1:1945 NB" "Sol" #1=
#2_"*Гесперия:69 Hesperia:Hesperia:1861-69*" "Sol" #2=
#3_"1861-69*:*Гесперия:69 Hesperia:Hesperia" "Sol" #3=
".:Hesperia:69 Hesperia:1861-69*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"69 hesperia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.935 0.865 ]
	BlendTexture	true
	Radius	67.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.136481084975
		SemiMajorAxis	2.976950823807
		Eccentricity	0.170501024457
		Inclination	8.585625076065
		AscendingNode	185.026518479439
		ArgOfPericenter	289.790854823029
		MeanAnomaly	353.305963560324
	}
	UniformRotation
	{
		Period	5.655
		Inclination	135
		AscendingNode	163
	}
	LunarLambert	0.5
	Albedo	0.1402
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=69"
}

#1_"70 Panopaea:Panopaea" "Sol" #1=
#2_"*Панопея:70 Panopaea:Panopaea:1861-70*" "Sol" #2=
#3_"1861-70*:*Панопея:70 Panopaea:Panopaea" "Sol" #3=
".:Panopaea:70 Panopaea:1861-70*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	63.956
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.228551183911
		SemiMajorAxis	2.614903058498
		Eccentricity	0.182164544703
		Inclination	11.590520252387
		AscendingNode	47.736459200476
		ArgOfPericenter	255.449834293489
		MeanAnomaly	57.565249572905
	}
	UniformRotation
	{
		Period	15.808
	}
	LunarLambert	0.5
	Albedo	0.038
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=70"
}

#1_"71 Niobe:Niobe" "Sol" #1=
#2_"*Ниоба:71 Niobe:Niobe:1861-71*" "Sol" #2=
#3_"1861-71*:*Ниоба:71 Niobe:Niobe" "Sol" #3=
".:Niobe:71 Niobe:1861-71*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"71 niobe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	41.71
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.57928174641
		SemiMajorAxis	2.757567223654
		Eccentricity	0.174112998955
		Inclination	23.268016763139
		AscendingNode	316.03912775028
		ArgOfPericenter	266.6527754077
		MeanAnomaly	279.860116356687
	}
	UniformRotation
	{
		Period	35.864
	}
	LunarLambert	0.5
	Albedo	0.3052
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=71"
}

#1_"72 Feronia:Feronia:1927 TK:1950 LJ:A902 GA" "Sol" #1=
#2_"*Ферония:72 Feronia:Feronia:1861-72*" "Sol" #2=
#3_"1861-72*:*Ферония:72 Feronia:Feronia" "Sol" #3=
".:Feronia:72 Feronia:1861-72*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"72 feronia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	37.483
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.410890927189
		SemiMajorAxis	2.265894853729
		Eccentricity	0.120887396116
		Inclination	5.416479404682
		AscendingNode	207.978517452224
		ArgOfPericenter	103.140845727418
		MeanAnomaly	264.261039612375
	}
	UniformRotation
	{
		Period	8.097
	}
	LunarLambert	0.5
	Albedo	0.083
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=72"
}

#1_"73 Klytia:Klytia:1949 HE1:1952 BA:1954 JG" "Sol" #1=
#2_"*Клития:73 Klytia:Klytia:1862-73*" "Sol" #2=
#3_"1862-73*:*Клития:73 Klytia:Klytia" "Sol" #3=
".:Klytia:73 Klytia:1862-73*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"73 klytia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	22.295
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.347766451579
		SemiMajorAxis	2.663822829292
		Eccentricity	0.044019293392
		Inclination	2.371079264699
		AscendingNode	7.038173053609
		ArgOfPericenter	53.069145439686
		MeanAnomaly	153.396724348462
	}
	UniformRotation
	{
		Period	8.297
	}
	LunarLambert	0.5
	Albedo	0.223
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=73"
}

#1_"74 Galatea:Galatea (asteroid):A908 OC" "Sol" #1=
#2_"*Галатея (астероид):74 Galatea:Galatea (asteroid):1862-74*" "Sol" #2=
#3_"1862-74*:*Галатея (астероид):74 Galatea:Galatea (asteroid)" "Sol" #3=
".:Galatea (asteroid):74 Galatea:1862-74*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	59.355
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.631100921991
		SemiMajorAxis	2.778331281533
		Eccentricity	0.239993217721
		Inclination	4.077264610746
		AscendingNode	197.278448989527
		ArgOfPericenter	174.164976803022
		MeanAnomaly	294.770600369674
	}
	UniformRotation
	{
		Period	17.268
	}
	LunarLambert	0.5
	Albedo	0.0431
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=74"
}

#1_"75 Eurydike:Eurydike:1947 BC:1958 SA" "Sol" #1=
#2_"*Эвридика:75 Eurydike:Eurydike:1862-75*" "Sol" #2=
#3_"1862-75*:*Эвридика:75 Eurydike:Eurydike" "Sol" #3=
".:Eurydike:75 Eurydike:1862-75*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	31.188
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.368408071114
		SemiMajorAxis	2.672247415553
		Eccentricity	0.305667339646
		Inclination	5.000985098065
		AscendingNode	359.424078450504
		ArgOfPericenter	339.439334640329
		MeanAnomaly	320.766764709645
	}
	UniformRotation
	{
		Period	5.357
	}
	LunarLambert	0.5
	Albedo	0.117
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=75"
}

#1_"76 Freia:Freia:A911 OB" "Sol" #1=
#2_"*Фрейя:76 Freia:Freia:1862-76*" "Sol" #2=
#3_"1862-76*:*Фрейя:76 Freia:Freia" "Sol" #3=
".:Freia:76 Freia:1862-76*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"76 freia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	72.712
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.318855915197
		SemiMajorAxis	3.417853945704
		Eccentricity	0.166058049289
		Inclination	2.117371351641
		AscendingNode	204.374156491934
		ArgOfPericenter	253.280053439311
		MeanAnomaly	32.965393344817
	}
	UniformRotation
	{
		Period	9.973
	}
	LunarLambert	0.5
	Albedo	0.058
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=76"
}

#1_"77 Frigga:Frigga:1936 SP" "Sol" #1=
#2_"*Фригга:77 Frigga:Frigga:1862-77*" "Sol" #2=
#3_"1862-77*:*Фригга:77 Frigga:Frigga" "Sol" #3=
".:Frigga:77 Frigga:1862-77*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	30.695
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.362355549344
		SemiMajorAxis	2.669778541681
		Eccentricity	0.130679484021
		Inclination	2.429151390043
		AscendingNode	1.279935759925
		ArgOfPericenter	60.804370467731
		MeanAnomaly	282.85376865491
	}
	UniformRotation
	{
		Period	9.012
	}
	LunarLambert	0.5
	Albedo	0.177
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=77"
}

#1_"78 Diana:Diana" "Sol" #1=
#2_"*Диана:78 Diana:Diana:1863-78*" "Sol" #2=
#3_"1863-78*:*Диана:78 Diana:Diana" "Sol" #3=
".:Diana:78 Diana:1863-78*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	60.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.237479883813
		SemiMajorAxis	2.618582723207
		Eccentricity	0.207527527433
		Inclination	8.704838275491
		AscendingNode	333.41938491216
		ArgOfPericenter	153.056117557084
		MeanAnomaly	305.867168137422
	}
	UniformRotation
	{
		Period	7.2991
	}
	LunarLambert	0.5
	Albedo	0.0706
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=78"
}

#1_"79 Eurynome:Eurynome" "Sol" #1=
#2_"*Эвринома:79 Eurynome:Eurynome:1863-79*" "Sol" #2=
#3_"1863-79*:*Эвринома:79 Eurynome:Eurynome" "Sol" #3=
".:Eurynome:79 Eurynome:1863-79*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"79 eurynome.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	31.74
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.821175409191
		SemiMajorAxis	2.444138702005
		Eccentricity	0.191549208079
		Inclination	4.617664819685
		AscendingNode	206.633121462248
		ArgOfPericenter	200.864145285315
		MeanAnomaly	176.616657179927
	}
	UniformRotation
	{
		Period	5.978
	}
	LunarLambert	0.5
	Albedo	0.287
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=79"
}

#1_"80 Sappho:Sappho" "Sol" #1=
#2_"*Сапфо:80 Sappho:Sappho:1864-80*" "Sol" #2=
#3_"1864-80*:*Сапфо:80 Sappho:Sappho" "Sol" #3=
".:Sappho:80 Sappho:1864-80*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"80 sappho.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	34.282
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.47845295541
		SemiMajorAxis	2.295718432466
		Eccentricity	0.199796183744
		Inclination	8.675808319327
		AscendingNode	218.698778249368
		ArgOfPericenter	139.662237526596
		MeanAnomaly	287.260144007948
	}
	UniformRotation
	{
		Period	14.03
	}
	LunarLambert	0.5
	Albedo	0.206
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=80"
}

#1_"81 Terpsichore:Terpsichore:1936 QR:1936 RK:1974 LF:A909 AA" "Sol" #1=
#2_"*Терпсихора:81 Terpsichore:Terpsichore:1864-81*" "Sol" #2=
#3_"1864-81*:*Терпсихора:81 Terpsichore:Terpsichore" "Sol" #3=
".:Terpsichore:81 Terpsichore:1864-81*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58.864
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.825500330611
		SemiMajorAxis	2.855547782022
		Eccentricity	0.207285365793
		Inclination	7.801352789469
		AscendingNode	1.011925041109
		ArgOfPericenter	51.696113838194
		MeanAnomaly	20.284515105897
	}
	UniformRotation
	{
		Period	10.943
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=81"
}

#1_"82 Alkmene:Alkmene:1952 BB:1963 OA:1973 GO" "Sol" #1=
#2_"*Алкмена:82 Alkmene:Alkmene:1864-82*" "Sol" #2=
#3_"1864-82*:*Алкмена:82 Alkmene:Alkmene" "Sol" #3=
".:Alkmene:82 Alkmene:1864-82*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"82 alkmene.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	28.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.599092504026
		SemiMajorAxis	2.76551463914
		Eccentricity	0.218616545307
		Inclination	2.828679435328
		AscendingNode	25.507052479014
		ArgOfPericenter	111.277588475474
		MeanAnomaly	192.563108177556
	}
	UniformRotation
	{
		Period	12.999
	}
	LunarLambert	0.5
	Albedo	0.167
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=82"
}

#1_"83 Beatrix:Beatrix:1950 QV" "Sol" #1=
#2_"*Беатрис:83 Beatrix:Beatrix:1865-83*" "Sol" #2=
#3_"1865-83*:*Беатрис:83 Beatrix:Beatrix" "Sol" #3=
".:Beatrix:83 Beatrix:1865-83*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	55.252
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.79256640346
		SemiMajorAxis	2.431923974718
		Eccentricity	0.081800288256
		Inclination	4.964182677509
		AscendingNode	27.745865542804
		ArgOfPericenter	168.971109218016
		MeanAnomaly	173.464435473707
	}
	UniformRotation
	{
		Period	10.16
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=83"
}

#1_"84 Klio:Klio:1974 VJ3" "Sol" #1=
#2_"*Клио:84 Klio:Klio:1865-84*" "Sol" #2=
#3_"1865-84*:*Клио:84 Klio:Klio" "Sol" #3=
".:Klio:84 Klio:1865-84*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	39.58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.629552902728
		SemiMajorAxis	2.361728401876
		Eccentricity	0.236540642895
		Inclination	9.331127497207
		AscendingNode	327.597419679555
		ArgOfPericenter	14.642086091746
		MeanAnomaly	33.611926030009
	}
	UniformRotation
	{
		Period	23.562
	}
	LunarLambert	0.5
	Albedo	0.0527
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=84"
}

#1_"85 Io:Io (asteroid):A899 LA:A899 UA" "Sol" #1=
#2_"*Ио (астероид):85 Io:Io (asteroid):1865-85*" "Sol" #2=
#3_"1865-85*:*Ио (астероид):85 Io:Io (asteroid)" "Sol" #3=
".:Io (asteroid):85 Io:1865-85*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"85 io.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	90
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.321066701252
		SemiMajorAxis	2.652905898377
		Eccentricity	0.19412112615
		Inclination	11.961499216442
		AscendingNode	203.119700884901
		ArgOfPericenter	123.111664165548
		MeanAnomaly	83.677508700981
	}
	UniformRotation
	{
		Period	6.875
		Inclination	120
	}
	LunarLambert	0.5
	Albedo	0.0666
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=85"
}

#1_"86 Semele:Semele:1978 BB" "Sol" #1=
#2_"*Семела:86 Semele:Semele:1866-86*" "Sol" #2=
#3_"1866-86*:*Семела:86 Semele:Semele" "Sol" #3=
".:Semele:86 Semele:1866-86*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	54.964
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.497559011912
		SemiMajorAxis	3.114878648065
		Eccentricity	0.209671327056
		Inclination	4.82020733694
		AscendingNode	86.405437139164
		ArgOfPericenter	308.694176834764
		MeanAnomaly	64.366492568276
	}
	UniformRotation
	{
		Period	16.634
	}
	LunarLambert	0.5
	Albedo	0.056
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=86"
}

#1_"87 Sylvia:Sylvia:A909 GA" "Sol" #1=
#2_"*Сильвия:87 Sylvia:Sylvia:1866-87*" "Sol" #2=
#3_"1866-87*:*Сильвия:87 Sylvia:Sylvia" "Sol" #3=
".:Sylvia:87 Sylvia:1866-87*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"87 sylvia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.937 0.880 ]
	BlendTexture	true
	Radius	192
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	6.495430988052
		SemiMajorAxis	3.481233710965
		Eccentricity	0.092565751846
		Inclination	10.876609632171
		AscendingNode	73.050545955994
		ArgOfPericenter	263.529065106678
		MeanAnomaly	1.865052575291
	}
	UniformRotation
	{
		Period	5.18364
		Inclination	29.1
		AscendingNode	161
	}
	LunarLambert	0.5
	Albedo	0.046
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=87"
}

#1_"Remus:87 Sylvia II:Sylvia II:2004 87 I" "Sol/87 Sylvia" #1=
#2_"*Рем:Remus:87 Sylvia II:*Сильвия II:Sylvia II:2004 87 I" "Sol/87 Sylvia" #2=
#3_"2004 87 I:*Рем:Remus:87 Sylvia II:*Сильвия II:Sylvia II" "Sol/87 Sylvia" #3=
".:Remus:87 Sylvia II:Sylvia II:2004 87 I" "Sol/87 Sylvia" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.937 0.880 ]
	BlendTexture	true
	Radius	5.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2453249.5  # 2004 Sept 01
		Period	1.373
		SemiMajorAxis	701.64
		Eccentricity	0.093
		Inclination	2.0
		AscendingNode	194.28
		ArgOfPericenter	135.0
		MeanAnomaly	281.0
	}
	LunarLambert	0.5
	Albedo	0.046
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00087.html"
}

#1_"Romulus:87 Sylvia I:Сильвия I:Sylvia I:2001 87 I" "Sol/87 Sylvia" #1=
#2_"*Ромул:Romulus:87 Sylvia I:*Сильвия I:Sylvia I:2001 87 I" "Sol/87 Sylvia" #2=
#3_"2001 87 I:*Ромул:Romulus:87 Sylvia I:*Сильвия I:Sylvia I" "Sol/87 Sylvia" #3=
".:Romulus:87 Sylvia I:Sylvia I:2001 87 I" "Sol/87 Sylvia" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.937 0.880 ]
	BlendTexture	true
	Radius	5.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2453249.5  # 2004 Sept 01
		Period	3.654
		SemiMajorAxis	1351.35
		Eccentricity	0.0069
		Inclination	1.7
		AscendingNode	193.17
		ArgOfPericenter	175.0
		MeanAnomaly	167.0
	}
	LunarLambert	0.5
	Albedo	0.046
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00087.html"
}

#1_"88 Thisbe:Thisbe:A903 PA:A906 BL" "Sol" #1=
#2_"*Фисба:88 Thisbe:Thisbe:1866-88*" "Sol" #2=
#3_"1866-88*:*Фисба:88 Thisbe:Thisbe" "Sol" #3=
".:Thisbe:88 Thisbe:1866-88*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"88 thisbe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.958 0.931 ]
	BlendTexture	true
	Radius	127.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.612499780181
		SemiMajorAxis	2.77088671733
		Eccentricity	0.162119618295
		Inclination	5.210498652609
		AscendingNode	276.495019081385
		ArgOfPericenter	35.982378991872
		MeanAnomaly	281.04433402219
	}
	UniformRotation
	{
		Period	6.042
		Inclination	42
		AscendingNode	297
	}
	LunarLambert	0.5
	Albedo	0.0671
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=88"
}

#1_"89 Julia:Julia:A893 EA" "Sol" #1=
#2_"*Юлия:89 Julia:Julia:1866-89*" "Sol" #2=
#3_"1866-89*:*Юлия:89 Julia:Julia" "Sol" #3=
".:Julia:89 Julia:1866-89*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"89 julia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	72.742
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.073208997404
		SemiMajorAxis	2.550462807621
		Eccentricity	0.184507364401
		Inclination	16.12703609116
		AscendingNode	311.559999838776
		ArgOfPericenter	45.459885043191
		MeanAnomaly	352.190822124122
	}
	UniformRotation
	{
		Period	11.387
	}
	LunarLambert	0.5
	Albedo	0.189
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=89"
}

#1_"Antiope System" "Sol" #1=
#2_"*Система Антиопы:Antiope System" "Sol" #2=
#3_"Antiope System:*Система Антиопы" "Sol" #3=
".:Antiope System" "Sol" #4=
{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	80
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.59365993354
		SemiMajorAxis	3.15107377853
		Eccentricity	0.164589059356
		Inclination	2.206859156361
		AscendingNode	69.993894189384
		ArgOfPericenter	244.636682741381
		MeanAnomaly	223.277548591198
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00090.html"
}

#1_"90 Antiope:Antiope:1952 BK2" "Sol/Antiope System" #1=
#2_"*Антиопа:90 Antiope:Antiope:1866-90*" "Sol/Antiope System" #2=
#3_"1866-90*:*Антиопа:90 Antiope:Antiope" "Sol/Antiope System" #3=
".:Antiope:90 Antiope:1866-90*" "Sol/Antiope System" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"antiope.dds"
	SemiAxes	[ 46.5 43.5 41.8 ]
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Antiope System" }
	}
	EllipticalOrbit
	{
		Period	0.6877125
		SemiMajorAxis	80
		Eccentricity	0.003
		Inclination	63.7
		ArgOfPericenter	180
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Antiope System" }
	}
	UniformRotation
	{
		Period	16.5051
		Inclination	63.7
	}
	LunarLambert	0.5
	Albedo	0.058
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=90"
}

#1_"2000 90 I" "Sol/Antiope System" #1=
#2"2000 90 I" "Sol/Antiope System" #2=
#3_"2000 90 I" "Sol/Antiope System" #3=
".:2000 90 I" "Sol/Antiope System" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"2000 90 I.dds"
	SemiAxes	[ 44.7 41.4 39.8 ]
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Antiope System" }
	}
	EllipticalOrbit
	{
		Period	0.6877125
		SemiMajorAxis	91
		Eccentricity	0.003
		Inclination	63.7
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Antiope System" }
	}
	UniformRotation
	{
		Period	16.5051
		Inclination	63.7
	}
	LunarLambert	0.5
	Albedo	0.058
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00090.html"
}


#1_"91 Aegina:Aegina" "Sol" #1=
#2_"*Эгина:91 Aegina:Aegina:1866-91*" "Sol" #2=
#3_"1866-91*:*Эгина:91 Aegina:Aegina" "Sol" #3=
".:Aegina:91 Aegina:1866-91*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	51.701
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.167139246191
		SemiMajorAxis	2.589523601781
		Eccentricity	0.106788127498
		Inclination	2.106770438414
		AscendingNode	10.666824734571
		ArgOfPericenter	72.731416722354
		MeanAnomaly	149.98866869601
	}
	UniformRotation
	{
		Period	6.025
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=91"
}

#1_"92 Undina:Undina" "Sol" #1=
#2_"*Ундина:92 Undina:Undina:1867-92*" "Sol" #2=
#3_"1867-92*:*Ундина:92 Undina:Undina" "Sol" #3=
".:Undina:92 Undina:1867-92*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	63.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.688010896337
		SemiMajorAxis	3.186408693429
		Eccentricity	0.10381966841
		Inclination	9.930851980351
		AscendingNode	101.591611069396
		ArgOfPericenter	239.755648571092
		MeanAnomaly	261.950250911823
	}
	UniformRotation
	{
		Period	15.941
	}
	LunarLambert	0.5
	Albedo	0.2509
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=92"
}

#1_"93 Minerva:Minerva:1949 QN2:A902 DA" "Sol" #1=
#2_"*Минерва:93 Minerva:Minerva:1867-93*" "Sol" #2=
#3_"1867-93*:*Минерва:93 Minerva:Minerva" "Sol" #3=
".:Minerva:93 Minerva:1867-93*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"93 minerva.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	77.078
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.573720560137
		SemiMajorAxis	2.755334202342
		Eccentricity	0.139061401356
		Inclination	8.558538225961
		AscendingNode	4.053913701602
		ArgOfPericenter	274.642823708538
		MeanAnomaly	348.010896833564
	}
	UniformRotation
	{
		Period	5.981767
	}
	LunarLambert	0.5
	Albedo	0.056
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=93"
}

#1_"Gorgoneion:93 Minerva II:Minerva II:2009 93 II" "Sol/93 Minerva" #1=
#2_"*Горгонейон:Gorgoneion:93 Minerva II:*Минерва II:Minerva II:2009 93 II" "Sol/93 Minerva" #2=
#3_"2009 93 II:*Горгонейон:Gorgoneion:93 Minerva II:*Минерва II:Minerva II" "Sol/93 Minerva" #3=
".:Gorgoneion:93 Minerva II:Minerva II:2009 93 II" "Sol/93 Minerva" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	1.1147
		SemiMajorAxis	375
		Eccentricity	0.05
		Inclination	91.4
		AscendingNode	132.6
		ArgOfPericenter	347.5
	}
	LunarLambert	0.5
	Albedo	0.056
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00093.html"
}

#1_"Aegis:93 Minerva I:Minerva I:2009 93 I" "Sol/93 Minerva" #1=
#2_"*Эгида:Aegis:93 Minerva I:*Минерва I:Minerva I:2009 93 I" "Sol/93 Minerva" #2=
#3_"2009 93 I:*Эгида:Aegis:93 Minerva I:*Минерва I:Minerva I" "Sol/93 Minerva" #3=
".:Aegis:93 Minerva I:Minerva I:2009 93 I" "Sol/93 Minerva" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid.dds"
	Radius	1.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	2.406
		SemiMajorAxis	623.5
		Eccentricity	0.0
		Inclination	89.0
		AscendingNode	126.0
		ArgOfPericenter	82.0
	}
	LunarLambert	0.5
	Albedo	0.056
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00093.html"
}

#1_"94 Aurora:Aurora:A912 TC" "Sol" #1=
#2_"*Аврора:94 Aurora:Aurora:1867-94*" "Sol" #2=
#3_"1867-94*:*Аврора:94 Aurora:Aurora" "Sol" #3=
".:Aurora:94 Aurora:1867-94*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"94 aurora.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	112.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.60747466796
		SemiMajorAxis	3.156259810485
		Eccentricity	0.093562392012
		Inclination	7.97132567602
		AscendingNode	2.580420183592
		ArgOfPericenter	60.598692624415
		MeanAnomaly	203.222472545969
	}
	UniformRotation
	{
		Period	7.22
	}
	LunarLambert	0.5
	Albedo	0.0395
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=94"
}

#1_"95 Arethusa:Arethusa" "Sol" #1=
#2_"*Аретуса:95 Arethusa:Arethusa:1867-95*" "Sol" #2=
#3_"1867-95*:*Аретуса:95 Arethusa:Arethusa" "Sol" #3=
".:Arethusa:95 Arethusa:1867-95*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"95 arethusa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	73.984
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.36442627269
		SemiMajorAxis	3.064385408471
		Eccentricity	0.152454495966
		Inclination	12.99559608013
		AscendingNode	243.043275100694
		ArgOfPericenter	154.349959043242
		MeanAnomaly	139.736872898539
	}
	UniformRotation
	{
		Period	8.705
	}
	LunarLambert	0.5
	Albedo	0.058
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=95"
}

#1_"96 Aegle:Aegle" "Sol" #1=
#2_"*Эгла:96 Aegle:Aegle:1868-96*" "Sol" #2=
#3_"1868-96*:*Эгла:96 Aegle:Aegle" "Sol" #3=
".:Aegle:96 Aegle:1868-96*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	88.887
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.332799338414
		SemiMajorAxis	3.052329120944
		Eccentricity	0.138988557961
		Inclination	15.968854821945
		AscendingNode	321.631927354229
		ArgOfPericenter	208.671792518213
		MeanAnomaly	168.30271382248
	}
	UniformRotation
	{
		Period	13.82
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=96"
}

#1_"97 Klotho:Klotho" "Sol" #1=
#2_"*Клото:97 Klotho:Klotho:1868-97*" "Sol" #2=
#3_"1868-97*:*Клото:97 Klotho:Klotho" "Sol" #3=
".:Klotho:97 Klotho:1868-97*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"97 klotho.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	50.358
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.364625244104
		SemiMajorAxis	2.670704502737
		Eccentricity	0.254572272917
		Inclination	11.783653354037
		AscendingNode	159.706033897128
		ArgOfPericenter	268.564158519464
		MeanAnomaly	309.682791814042
	}
	UniformRotation
	{
		Period	35.15
	}
	LunarLambert	0.5
	Albedo	0.128
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=97"
}

#1_"98 Ianthe:Ianthe:1931 RK1:1949 SE1:1975 XO" "Sol" #1=
#2_"*Ианта:98 Ianthe:Ianthe:1868-98*" "Sol" #2=
#3_"1868-98*:*Ианта:98 Ianthe:Ianthe" "Sol" #3=
".:Ianthe:98 Ianthe:1868-98*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"98 ianthe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	66.389
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.408686306654
		SemiMajorAxis	2.688648307346
		Eccentricity	0.185852396139
		Inclination	15.576483019269
		AscendingNode	354.004107527733
		ArgOfPericenter	158.57171742202
		MeanAnomaly	128.029760151933
	}
	UniformRotation
	{
		Period	16.479
	}
	LunarLambert	0.5
	Albedo	0.029
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=98"
}

#1_"99 Dike:Dike:1935 UC:1935 YL:1939 UT:1948 UE:1948 WC:1961 XJ:1974 VB:A915 BA" "Sol" #1=
#2_"*Дике:99 Dike:Dike:1868-99*" "Sol" #2=
#3_"1868-99*:*Дике:99 Dike:Dike" "Sol" #3=
".:Dike:99 Dike:1868-99*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"99 dike.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	33.677
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.351480525706
		SemiMajorAxis	2.665339658295
		Eccentricity	0.195832407921
		Inclination	13.845915185269
		AscendingNode	41.604896984352
		ArgOfPericenter	195.401061033306
		MeanAnomaly	242.316783926762
	}
	UniformRotation
	{
		Period	18.127
	}
	LunarLambert	0.5
	Albedo	0.065
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=99"
}

#1_"100 Hekate:Hekate:1955 QA" "Sol" #1=
#2_"*Геката:100 Hekate:Hekate:1868-100*" "Sol" #2=
#3_"1868-100*:*Геката:100 Hekate:Hekate" "Sol" #3=
".:Hekate:100 Hekate:1868-100*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	42.867
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.429578783012
		SemiMajorAxis	3.089147351766
		Eccentricity	0.168248436422
		Inclination	6.429954381031
		AscendingNode	127.203513190535
		ArgOfPericenter	184.848705046733
		MeanAnomaly	315.661171321254
	}
	UniformRotation
	{
		Period	27.066
	}
	LunarLambert	0.5
	Albedo	0.205
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=100"
}

#1_"101 Helena:Helena" "Sol" #1=
#2_"*Елена (астероид):101 Helena:Helena:1868-101*" "Sol" #2=
#3_"1868-101*:*Елена (астероид):101 Helena:Helena" "Sol" #3=
".:Helena:101 Helena:1868-101*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	32.92
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.151018583818
		SemiMajorAxis	2.582840872178
		Eccentricity	0.140661401659
		Inclination	10.200803664529
		AscendingNode	343.433316050717
		ArgOfPericenter	347.367529916082
		MeanAnomaly	94.708414258112
	}
	UniformRotation
	{
		Period	23.08
	}
	LunarLambert	0.5
	Albedo	0.1898
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=101"
}

#1_"102 Miriam:Miriam:1944 FC:1972 PC" "Sol" #1=
#2_"*Мириам:102 Miriam:Miriam:1868-105*" "Sol" #2=
#3_"1868-105*:*Мириам:102 Miriam:Miriam" "Sol" #3=
".:Miriam:102 Miriam:1868-105*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	41.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.339203034204
		SemiMajorAxis	2.660323879996
		Eccentricity	0.253006671641
		Inclination	5.178537862473
		AscendingNode	210.865856931874
		ArgOfPericenter	147.3202740346
		MeanAnomaly	247.59048457707
	}
	UniformRotation
	{
		Period	23.613
	}
	LunarLambert	0.5
	Albedo	0.0507
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=102"
}

#1_"103 Hera:Hera:1927 CV:1950 CM" "Sol" #1=
#2_"*Гера:103 Hera:Hera:1868-103*" "Sol" #2=
#3_"1868-103*:*Гера:103 Hera:Hera" "Sol" #3=
".:Hera:103 Hera:1868-103*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"103 hera.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	41.954
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.441951870199
		SemiMajorAxis	2.702156080192
		Eccentricity	0.081346659483
		Inclination	5.41948368994
		AscendingNode	136.188173420422
		ArgOfPericenter	188.639550911212
		MeanAnomaly	359.885483645729
	}
	UniformRotation
	{
		Period	23.74
	}
	LunarLambert	0.5
	Albedo	0.217
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=103"
}

#1_"104 Klymene:Klymene:1951 OE:1968 OS:A893 FA" "Sol" #1=
#2_"*Климена:104 Klymene:Klymene:1868-104*" "Sol" #2=
#3_"1868-104*:*Климена:104 Klymene:Klymene" "Sol" #3=
".:Klymene:104 Klymene:1868-104*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"104 klymene.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	68.276
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.587456190195
		SemiMajorAxis	3.148743513143
		Eccentricity	0.155799297301
		Inclination	2.789020786391
		AscendingNode	41.77118230815
		ArgOfPericenter	31.895002293872
		MeanAnomaly	356.083653923145
	}
	UniformRotation
	{
		Period	8.984
	}
	LunarLambert	0.5
	Albedo	0.052
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=104"
}

#1_"105 Artemis:Artemis" "Sol" #1=
#2_"*Артемида:105 Artemis:Artemis:1868-105*" "Sol" #2=
#3_"1868-105*:*Артемида:105 Artemis:Artemis" "Sol" #3=
".:Artemis:105 Artemis:1868-105*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	59.54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.6570428435924
		SemiMajorAxis	2.373638426045939
		Eccentricity	0.1775595318156135
		Inclination	21.44212937396894
		AscendingNode	188.2616246398785
		ArgOfPericenter	57.1646495020114
		MeanAnomaly	95.0528847419056
	}
	UniformRotation
	{
		Period	37.15506
	}
	LunarLambert	0.5
	Albedo	0.0465
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=105"
}

#1_"106 Dione:Dione (asteroid):A902 TA" "Sol" #1=
#2_"*Диона (астероид):106 Dione:Dione (asteroid):1868-106*" "Sol" #2=
#3_"1868-106*:*Диона (астероид):106 Dione:Dione (asteroid)" "Sol" #3=
".:Dione (asteroid):106 Dione:1868-106*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	73.295
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.660617455975
		SemiMajorAxis	3.176169975471
		Eccentricity	0.167000029758
		Inclination	4.596680456431
		AscendingNode	62.170298937784
		ArgOfPericenter	329.73700598
		MeanAnomaly	306.999970473331
	}
	UniformRotation
	{
		Period	16.26
	}
	LunarLambert	0.5
	Albedo	0.0893
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=106"
}

#1_"107 Camilla:Camilla:1938 OG:1949 HD1:A893 QA" "Sol" #1=
#2_"*Камилла:107 Camilla:Camilla:1868-107*" "Sol" #2=
#3_"1868-107*:*Камилла:107 Camilla:Camilla" "Sol" #3=
".:Camilla:107 Camilla:1868-107*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"107 camilla.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.936 0.887 ]
	BlendTexture	true
	Radius	142.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	6.521840091174
		SemiMajorAxis	3.490663321155
		Eccentricity	0.065735329958
		Inclination	10.002143875502
		AscendingNode	172.610868355844
		ArgOfPericenter	306.863822492938
		MeanAnomaly	235.600832867007
	}
	UniformRotation
	{
		Period	4.843932
		Inclination	29
		AscendingNode	162
	}
	LunarLambert	0.5
	Albedo	0.059
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=107"
}

#1_"2016 107 I" "Sol/107 Camilla" #1=
#2_"2016 107 I" "Sol/107 Camilla" #2=
#3_"2016 107 I" "Sol/107 Camilla" #3=
".:2016 107 I" "Sol/107 Camilla" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.936 0.887 ]
	BlendTexture	true
	Radius	1.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.5
		SemiMajorAxis	340
	}
	LunarLambert	0.5
	Albedo	0.059
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00107.html"
}

#1_"2001 107 I" "Sol/107 Camilla" #1=
#2_"2001 107 I" "Sol/107 Camilla" #2=
#3_"2001 107 I" "Sol/107 Camilla" #3=
".:2001 107 I" "Sol/107 Camilla" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.936 0.887 ]
	BlendTexture	true
	Radius	8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	3.722
		SemiMajorAxis	1250
		Eccentricity	0.002
		Inclination	3.0
	}
	LunarLambert	0.5
	Albedo	0.059
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00107.html"
}

#1_"108 Hecuba:Hecuba" "Sol" #1=
#2_"*Гекуба:108 Hecuba:Hecuba:1869-108*" "Sol" #2=
#3_"1869-108*:*Гекуба:108 Hecuba:Hecuba" "Sol" #3=
".:Hecuba:108 Hecuba:1869-108*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	32.485
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.827088408115
		SemiMajorAxis	3.238139864982
		Eccentricity	0.05537603937
		Inclination	4.220534440503
		AscendingNode	350.018341088896
		ArgOfPericenter	204.203366162882
		MeanAnomaly	65.653492459186
	}
	UniformRotation
	{
		Period	14.256
	}
	LunarLambert	0.5
	Albedo	0.2431
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=108"
}

#1_"109 Felicitas:Felicitas:A911 HA" "Sol" #1=
#2_"*Фелица:109 Felicitas:Felicitas:1869-109*" "Sol" #2=
#3_"1869-109*:*Фелица:109 Felicitas:Felicitas" "Sol" #3=
".:Felicitas:109 Felicitas:1869-109*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	44.72
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.430354427194
		SemiMajorAxis	2.697450678211
		Eccentricity	0.297025132939
		Inclination	7.880756504989
		AscendingNode	3.166947023919
		ArgOfPericenter	56.37832948898
		MeanAnomaly	257.214011979544
	}
	UniformRotation
	{
		Period	13.191
	}
	LunarLambert	0.5
	Albedo	0.0699
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=109"
}

#1_"110 Lydia:Lydia:1972 YS1:A899 VA" "Sol" #1=
#2_"*Лидия:110 Lydia:Lydia:1870-110*" "Sol" #2=
#3_"1870-110*:*Лидия:110 Lydia:Lydia" "Sol" #3=
".:Lydia:110 Lydia:1870-110*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"110 lydia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	43.045
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.515107016248
		SemiMajorAxis	2.731743367967
		Eccentricity	0.080774846717
		Inclination	5.965075464332
		AscendingNode	56.87623790988
		ArgOfPericenter	283.706786290016
		MeanAnomaly	217.159471727609
	}
	UniformRotation
	{
		Period	10.927
	}
	LunarLambert	0.5
	Albedo	0.1808
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=110"
}

#1_"111 Ate:Ate:1935 AA:A911 KE" "Sol" #1=
#2_"*Ата:111 Ate:Ate:1870-111*" "Sol" #2=
#3_"1870-111*:*Ата:111 Ate:Ate" "Sol" #3=
".:Ate:111 Ate:1870-111*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	67.275
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.176897766147
		SemiMajorAxis	2.593564753874
		Eccentricity	0.103700989255
		Inclination	4.932359013857
		AscendingNode	305.759813098802
		ArgOfPericenter	166.511109940866
		MeanAnomaly	48.885608103418
	}
	UniformRotation
	{
		Period	22.072
	}
	LunarLambert	0.5
	Albedo	0.0605
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=111"
}

#1_"112 Iphigenia:Iphigenia" "Sol" #1=
#2_"*Ифигения:112 Iphigenia:Iphigenia:1870-112*" "Sol" #2=
#3_"1870-112*:*Ифигения:112 Iphigenia:Iphigenia" "Sol" #3=
".:Iphigenia:112 Iphigenia:1870-112*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"112 iphigenia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	34.909
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.796249798937
		SemiMajorAxis	2.433498333162
		Eccentricity	0.128722484645
		Inclination	2.603909748943
		AscendingNode	323.536528301964
		ArgOfPericenter	16.605317153933
		MeanAnomaly	14.253535009261
	}
	UniformRotation
	{
		Period	31.466
	}
	LunarLambert	0.5
	Albedo	0.042
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=112"
}

#1_"113 Amalthea:Amalthea (asteroid):1931 TN3:1951 CY" "Sol" #1=
#2_"*Амальтея (астероид):113 Amalthea:Amalthea (asteroid):1871-113*" "Sol" #2=
#3_"1871-113*:*Амальтея (астероид):113 Amalthea:Amalthea (asteroid)" "Sol" #3=
".:Amalthea (asteroid):113 Amalthea:1871-113*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	24.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.663115214102
		SemiMajorAxis	2.376265252632
		Eccentricity	0.08635607892
		Inclination	5.042412374897
		AscendingNode	123.491099498898
		ArgOfPericenter	78.983174261978
		MeanAnomaly	65.19016788077
	}
	UniformRotation
	{
		Period	9.95
	}
	LunarLambert	0.5
	Albedo	0.2649
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=113"
}

# Период и большая полуось гипотетические ввиду отсутствия данных
#1_"2017 113 I" "Sol/113 Amalthea" #1=
#2_"2017 113 I" "Sol/113 Amalthea" #2=
#3_"2017 113 I" "Sol/113 Amalthea" #3=
".:2017 113 I" "Sol/113 Amalthea" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid.dds"
	Radius	2.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.8082  # Период и большая полуось гипотетические ввиду отсутствия данных
		SemiMajorAxis	95
	}
	LunarLambert	0.5
	Albedo	0.2649
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00113.html"
}

#1_"114 Kassandra:Kassandra" "Sol" #1=
#2_"*Кассандра:114 Kassandra:Kassandra:1871-114*" "Sol" #2=
#3_"1871-114*:*Кассандра:114 Kassandra:Kassandra" "Sol" #3=
".:Kassandra:114 Kassandra:1871-114*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"114 kassandra.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	47.089
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.382438626581
		SemiMajorAxis	2.67796621492
		Eccentricity	0.135214288507
		Inclination	4.936481091628
		AscendingNode	164.218723916527
		ArgOfPericenter	352.290566636441
		MeanAnomaly	286.868909113138
	}
	UniformRotation
	{
		Period	10.7431
	}
	LunarLambert	0.5
	Albedo	0.089
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=114"
}

#1_"115 Thyra:Thyra" "Sol" #1=
#2_"*Тира:115 Thyra:Thyra:1871-115*" "Sol" #2=
#3_"1871-115*:*Тира:115 Thyra:Thyra" "Sol" #3=
".:Thyra:115 Thyra:1871-115*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"115 thyra.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	39.915
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.671746225257
		SemiMajorAxis	2.37999641678
		Eccentricity	0.19185887538
		Inclination	11.600370952503
		AscendingNode	308.913373824505
		ArgOfPericenter	96.767750968811
		MeanAnomaly	307.514607200611
	}
	UniformRotation
	{
		Period	7.241
	}
	LunarLambert	0.5
	Albedo	0.2747
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=115"
}

#1_"116 Sirona:Sirona:1954 UC3:1998 EK13:1998 ES21" "Sol" #1=
#2_"*Сирона:116 Sirona:Sirona:1871-116*" "Sol" #2=
#3_"1871-116*:*Сирона:116 Sirona:Sirona" "Sol" #3=
".:Sirona:116 Sirona:1871-116*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"116 sirona.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	35.85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.600891280969
		SemiMajorAxis	2.766235682802
		Eccentricity	0.141847572155
		Inclination	3.563495715585
		AscendingNode	63.739903902699
		ArgOfPericenter	94.969929854963
		MeanAnomaly	239.000566397936
	}
	UniformRotation
	{
		Period	12.028
	}
	LunarLambert	0.5
	Albedo	0.256
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=116"
}

#1_"117 Lomia:Lomia:A900 DA:A900 MC" "Sol" #1=
#2_"*Ломия:117 Lomia:Lomia:1871-117*" "Sol" #2=
#3_"1871-117*:*Ломия:117 Lomia:Lomia" "Sol" #3=
".:Lomia:117 Lomia:1871-117*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"117 lomia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	104.487
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.172429746344
		SemiMajorAxis	2.990824518226
		Eccentricity	0.028369464298
		Inclination	14.902095841246
		AscendingNode	348.796039822165
		ArgOfPericenter	53.143343658501
		MeanAnomaly	202.512684109554
	}
	UniformRotation
	{
		Period	9.127
	}
	LunarLambert	0.5
	Albedo	0.027
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=117"
}

#1_"118 Peitho:Peitho" "Sol" #1=
#2_"*Пейто:118 Peitho:Peitho:1872-118*" "Sol" #2=
#3_"1872-118*:*Пейто:118 Peitho:Peitho" "Sol" #3=
".:Peitho:118 Peitho:1872-118*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	20.865
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.806052454737
		SemiMajorAxis	2.437685709883
		Eccentricity	0.163192856862
		Inclination	7.742096068616
		AscendingNode	47.710776905182
		ArgOfPericenter	33.275162261134
		MeanAnomaly	255.871233087383
	}
	UniformRotation
	{
		Period	7.8055
	}
	LunarLambert	0.5
	Albedo	0.224
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=118"
}

#1_"119 Althaea:Althaea:1972 KO" "Sol" #1=
#2_"*Алфея:119 Althaea:Althaea:1872-119*" "Sol" #2=
#3_"1872-119*:*Алфея:119 Althaea:Althaea" "Sol" #3=
".:Althaea:119 Althaea:1872-119*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"119 althaea.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	28.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.148299677193
		SemiMajorAxis	2.581712912882
		Eccentricity	0.081006155492
		Inclination	5.782312800679
		AscendingNode	203.679514249684
		ArgOfPericenter	169.928447329663
		MeanAnomaly	332.346824313605
	}
	UniformRotation
	{
		Period	11.484
	}
	LunarLambert	0.5
	Albedo	0.2306
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=119"
}

#1_"120 Lachesis:Lachesis:A910 CF:A918 UB" "Sol" #1=
#2_"*Лахесис:120 Lachesis:Lachesis:1872-120*" "Sol" #2=
#3_"1872-120*:*Лахесис:120 Lachesis:Lachesis" "Sol" #3=
".:Lachesis:120 Lachesis:1872-120*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"120 lachesis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	77.566
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.511194707257
		SemiMajorAxis	3.120027114568
		Eccentricity	0.053209819599
		Inclination	6.96342990884
		AscendingNode	341.194881998471
		ArgOfPericenter	232.159101866741
		MeanAnomaly	309.442919669558
	}
	UniformRotation
	{
		Period	46.551
	}
	LunarLambert	0.5
	Albedo	0.058
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=120"
}

#1_"121 Hermione:Hermione:1970 VE" "Sol" #1=
#2_"*Гермиона:121 Hermione:Hermione:1872-121*" "Sol" #2=
#3_"1872-121*:*Гермиона:121 Hermione:Hermione" "Sol" #3=
".:Hermione:121 Hermione:1872-121*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"121 hermione.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	134
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.407492492461
		SemiMajorAxis	3.449741891237
		Eccentricity	0.134133221941
		Inclination	7.596147480801
		AscendingNode	73.140694243714
		ArgOfPericenter	298.361705536868
		MeanAnomaly	332.108902154439
	}
	UniformRotation
	{
		Period	5.55128
		Inclination	73
	}
	LunarLambert	0.5
	Albedo	0.0482
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=121"
}

#1_"2002 121 I" "Sol/121 Hermione" #1=
#2_"2002 121 I" "Sol/121 Hermione" #2=
#3_"2002 121 I" "Sol/121 Hermione" #3=
".:2002 121 I" "Sol/121 Hermione" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	2.563
		SemiMajorAxis	747
		Eccentricity	0.0
		Inclination	3.0
	}
	LunarLambert	0.5
	Albedo	0.0482
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00121.html"
}

#1_"122 Gerda:Gerda:1948 TQ1" "Sol" #1=
#2_"*Герда:122 Gerda:Gerda:1872-122*" "Sol" #2=
#3_"1872-122*:*Герда:122 Gerda:Gerda" "Sol" #3=
".:Gerda:122 Gerda:1872-122*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"122 gerda.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	35.338
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.785088019432
		SemiMajorAxis	3.222561239869
		Eccentricity	0.032838713688
		Inclination	1.640048335426
		AscendingNode	178.151598378408
		ArgOfPericenter	320.932378907616
		MeanAnomaly	62.082446571236
	}
	UniformRotation
	{
		Period	10.685
	}
	LunarLambert	0.5
	Albedo	0.297
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=122"
}

#1_"123 Brunhild:Brunhild" "Sol" #1=
#2_"*Брунхильда:123 Brunhild:Brunhild:1872-123*" "Sol" #2=
#3_"1872-123*:*Брунхильда:123 Brunhild:Brunhild" "Sol" #3=
".:Brunhild:123 Brunhild:1872-123*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	23.985
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.424882369539
		SemiMajorAxis	2.69522908833
		Eccentricity	0.118384378424
		Inclination	6.419650410217
		AscendingNode	307.864160655221
		ArgOfPericenter	125.641659007049
		MeanAnomaly	323.545103483183
	}
	UniformRotation
	{
		Period	10.04
	}
	LunarLambert	0.5
	Albedo	0.2134
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=123"
}

#1_"124 Alkeste:Alkeste" "Sol" #1=
#2_"*Алькеста:124 Alkeste:Alkeste:1872-124*" "Sol" #2=
#3_"1872-124*:*Алькеста:124 Alkeste:Alkeste" "Sol" #3=
".:Alkeste:124 Alkeste:1872-124*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	38.18
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.265291995986
		SemiMajorAxis	2.630028029302
		Eccentricity	0.076887283743
		Inclination	2.953442896288
		AscendingNode	188.057873542704
		ArgOfPericenter	61.407455496604
		MeanAnomaly	205.228946398459
	}
	UniformRotation
	{
		Period	9.921
	}
	LunarLambert	0.5
	Albedo	0.1728
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=124"
}

#1_"125 Liberatrix:Liberatrix:1943 FE:1949 OE1:1949 SM:1954 TD1:A902 EG" "Sol" #1=
#2_"*Либератрикс:125 Liberatrix:Liberatrix:1872-125*" "Sol" #2=
#3_"1872-125*:*Либератрикс:125 Liberatrix:Liberatrix" "Sol" #3=
".:Liberatrix:125 Liberatrix:1872-125*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"125 liberatrix.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	24.209
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.544361458112
		SemiMajorAxis	2.743530401458
		Eccentricity	0.079322453366
		Inclination	4.658397892293
		AscendingNode	169.040251002006
		ArgOfPericenter	108.712786410472
		MeanAnomaly	178.594445352182
	}
	UniformRotation
	{
		Period	3.968
	}
	LunarLambert	0.5
	Albedo	0.182
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=125"
}

#1_"126 Velleda:Velleda:1949 YF:1950 BD1" "Sol" #1=
#2_"*Веледа:126 Velleda:Velleda:1872-126*" "Sol" #2=
#3_"1872-126*:*Веледа:126 Velleda:Velleda" "Sol" #3=
".:Velleda:126 Velleda:1872-126*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	22.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.812206758433
		SemiMajorAxis	2.440312791914
		Eccentricity	0.105314418251
		Inclination	2.923712735484
		AscendingNode	23.337595735321
		ArgOfPericenter	328.349758243761
		MeanAnomaly	147.012659786896
	}
	UniformRotation
	{
		Period	5.3672
	}
	LunarLambert	0.5
	Albedo	0.1723
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=126"
}

#1_"127 Johanna:Johanna" "Sol" #1=
#2_"*Жанна:127 Johanna:Johanna:1872-127*" "Sol" #2=
#3_"1872-127*:*Жанна:127 Johanna:Johanna" "Sol" #3=
".:Johanna:127 Johanna:1872-127*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"127 johanna.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	61
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.571924717282
		SemiMajorAxis	2.754612911941
		Eccentricity	0.066092875438
		Inclination	8.241473227245
		AscendingNode	31.195975527169
		ArgOfPericenter	95.097608756773
		MeanAnomaly	298.038942918054
	}
	UniformRotation
	{
		Period	12.7988
	}
	LunarLambert	0.5
	Albedo	0.042
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=127"
}

#1_"128 Nemesis:Nemesis (asteroid):1952 HW1" "Sol" #1=
#2_"*Немезида:128 Nemesis:Nemesis (asteroid):1872-128*" "Sol" #2=
#3_"1872-128*:*Немезида:128 Nemesis:Nemesis (asteroid)" "Sol" #3=
".:Nemesis (asteroid):128 Nemesis:1872-128*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	94.08
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.56591793593
		SemiMajorAxis	2.7521996347
		Eccentricity	0.124913557156
		Inclination	6.245807502941
		AscendingNode	76.391892487045
		ArgOfPericenter	303.553661054776
		MeanAnomaly	86.399022426391
	}
	UniformRotation
	{
		Period	39
	}
	LunarLambert	0.5
	Albedo	0.0504
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=128"
}

#1_"129 Antigone:Antigone:A878 CA:A907 BA" "Sol" #1=
#2_"*Антигона:129 Antigone:Antigone:1873-129*" "Sol" #2=
#3_"1873-129*:*Антигона:129 Antigone:Antigone" "Sol" #3=
".:Antigone:129 Antigone:1873-129*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"129 antigone.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.944 0.909 ]
	BlendTexture	true
	Radius	56.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.86233215978
		SemiMajorAxis	2.870059811448
		Eccentricity	0.211692669101
		Inclination	12.262036455684
		AscendingNode	135.688606384216
		ArgOfPericenter	111.11107138735
		MeanAnomaly	178.38136810314
	}
	UniformRotation
	{
		Period	4.9572
		Inclination	32
		AscendingNode	297
	}
	LunarLambert	0.5
	Albedo	0.151
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=129"
}

#1_"130 Elektra:Elektra" "Sol" #1=
#2_"*Электра (астероид):130 Elektra:Elektra:1873-130*" "Sol" #2=
#3_"1873-130*:*Электра (астероид):130 Elektra:Elektra" "Sol" #3=
".:Elektra:130 Elektra:1873-130*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"130 elektra.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	107.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.518383952702
		SemiMajorAxis	3.122739867793
		Eccentricity	0.208322128654
		Inclination	22.867736567548
		AscendingNode	145.409099363154
		ArgOfPericenter	235.653503839027
		MeanAnomaly	22.433885029846
	}
	UniformRotation
	{
		Period	5.22468
		Inclination	157
	}
	LunarLambert	0.5
	Albedo	0.086
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=130"
}

#1_"2014 130 I" "Sol/130 Elektra" #1=
#2_"2014 130 I" "Sol/130 Elektra" #2=
#3_"2014 130 I" "Sol/130 Elektra" #3=
".:2014 130 I" "Sol/130 Elektra" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	2.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	1.1
		SemiMajorAxis	460
	}
	LunarLambert	0.5
	Albedo	0.086
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00130.html"
}

#1_"2003 130 I" "Sol/130 Elektra" #1=
#2_"2003 130 I" "Sol/130 Elektra" #2=
#3_"2003 130 I" "Sol/130 Elektra" #3=
".:2003 130 I" "Sol/130 Elektra" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid.dds"
	Radius	3.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	5.258
		SemiMajorAxis	1318
		Eccentricity	0.13
		Inclination	3.0
	}
	LunarLambert	0.5
	Albedo	0.086
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00130.html"
}

#1_"131 Vala:Vala:1945 KA:1952 DS3:1953 QE" "Sol" #1=
#2_"*Вала:131 Vala:Vala:1873-131*" "Sol" #2=
#3_"1873-131*:*Вала:131 Vala:Vala" "Sol" #3=
".:Vala:131 Vala:1873-131*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	20.22
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.792233413281
		SemiMajorAxis	2.4317816228
		Eccentricity	0.068012276642
		Inclination	4.960115975152
		AscendingNode	65.691568087929
		ArgOfPericenter	160.962380690199
		MeanAnomaly	132.959714761786
	}
	UniformRotation
	{
		Period	5.1812
	}
	LunarLambert	0.5
	Albedo	0.1051
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=131"
}

#1_"132 Aethra:Aethra:1949 MD:1953 LF:A922 XB" "Sol" #1=
#2_"*Эфра:132 Aethra:Aethra:1873-132*" "Sol" #2=
#3_"1873-132*:*Эфра:132 Aethra:Aethra" "Sol" #3=
".:Aethra:132 Aethra:1873-132*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"132 aethra.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	21.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.210462911616
		SemiMajorAxis	2.607440634253
		Eccentricity	0.390213301472
		Inclination	24.994779396665
		AscendingNode	258.421500826445
		ArgOfPericenter	255.200574165999
		MeanAnomaly	257.805394851588
	}
	UniformRotation
	{
		Period	5.1684
	}
	LunarLambert	0.5
	Albedo	0.199
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=132"
}

#1_"133 Cyrene:Cyrene:1936 HO:1948 QC:1959 UR:A910 NB" "Sol" #1=
#2_"*Кирена:133 Cyrene:Cyrene:1873-133*" "Sol" #2=
#3_"1873-133*:*Кирена:133 Cyrene:Cyrene" "Sol" #3=
".:Cyrene:133 Cyrene:1873-133*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	33.285
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.355410092103
		SemiMajorAxis	3.060950832105
		Eccentricity	0.138207163317
		Inclination	7.227417332607
		AscendingNode	319.095646345298
		ArgOfPericenter	290.179124816808
		MeanAnomaly	205.449203717331
	}
	UniformRotation
	{
		Period	12.708
	}
	LunarLambert	0.5
	Albedo	0.2563
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=133"
}

#1_"134 Sophrosyne:Sophrosyne" "Sol" #1=
#2_"*Софросина:134 Sophrosyne:Sophrosyne:1873-134*" "Sol" #2=
#3_"1873-134*:*Софросина:134 Sophrosyne:Sophrosyne" "Sol" #3=
".:134 Sophrosyne:Sophrosyne:1873-134*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.103992971618
		SemiMajorAxis	2.563297048093
		Eccentricity	0.117099141859
		Inclination	11.601210553064
		AscendingNode	345.987375794189
		ArgOfPericenter	84.934445646654
		MeanAnomaly	85.499488126403
	}
	UniformRotation
	{
		Period	17.196
	}
	LunarLambert	0.5
	Albedo	0.0364
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=134"
}

#1_"135 Hertha:Hertha" "Sol" #1=
#2_"*Герта:135 Hertha:Hertha:1874-135*" "Sol" #2=
#3_"1874-135*:*Герта:135 Hertha:Hertha" "Sol" #3=
".:Hertha:135 Hertha:1874-135*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"135 hertha.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.902 0.811 ]
	BlendTexture	true
	Radius	39.62
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.782007920678
		SemiMajorAxis	2.427408236341
		Eccentricity	0.207806068137
		Inclination	2.305729583795
		AscendingNode	343.648713169588
		ArgOfPericenter	340.205112961246
		MeanAnomaly	181.713514252605
	}
	UniformRotation
	{
		Period	8.403
		Inclination	32
		AscendingNode	186
	}
	LunarLambert	0.5
	Albedo	0.1436
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=135"
}

#1_"136 Austria:Austria:1950 HT" "Sol" #1=
#2_"*Австрия:136 Austria:Austria:1874-136*" "Sol" #2=
#3_"1874-136*:*Австрия:136 Austria:Austria" "Sol" #3=
".:Austria:136 Austria:1874-136*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"136 austria.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	18.446
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.457859136513
		SemiMajorAxis	2.286648426579
		Eccentricity	0.084953535517
		Inclination	9.572425937094
		AscendingNode	186.498112641605
		ArgOfPericenter	132.224794846994
		MeanAnomaly	121.584600327686
	}
	UniformRotation
	{
		Period	11.4969
	}
	LunarLambert	0.5
	Albedo	0.201
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=136"
}

#1_"137 Meliboea:Meliboea:1958 UE:1962 GB:A923 FA" "Sol" #1=
#2_"*Мелибея:137 Meliboea:Meliboea:1874-137*" "Sol" #2=
#3_"1874-137*:*Мелибея:137 Meliboea:Meliboea" "Sol" #3=
".:Meliboea:137 Meliboea:1874-137*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	72.71
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.506411114203
		SemiMajorAxis	3.118221444383
		Eccentricity	0.216894758796
		Inclination	13.412054130596
		AscendingNode	202.363486618098
		ArgOfPericenter	107.033964103144
		MeanAnomaly	113.801863142068
	}
	UniformRotation
	{
		Period	25.676
	}
	LunarLambert	0.5
	Albedo	0.0503
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=137"
}

#1_"138 Tolosa:Tolosa:A909 SB" "Sol" #1=
#2_"*Тулуза:138 Tolosa:Tolosa:1874-138*" "Sol" #2=
#3_"1874-138*:*Тулуза:138 Tolosa:Tolosa" "Sol" #3=
".:Tolosa:138 Tolosa:1874-138*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"138 tolosa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	26.452
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.836227253669
		SemiMajorAxis	2.450552903859
		Eccentricity	0.161653774411
		Inclination	3.202957443232
		AscendingNode	54.80382098155
		ArgOfPericenter	260.531259366688
		MeanAnomaly	194.273906132832
	}
	UniformRotation
	{
		Period	10.101
	}
	LunarLambert	0.5
	Albedo	0.273
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=138"
}

#1_"139 Juewa:Juewa" "Sol" #1=
#2_"*ЖуйХуа Син:RuiHua Xing:=Звезда счастья Китая:139 Juewa:Juewa:*ЦзюэХуа:1874-139*" "Sol" #2=
#3_"1874-139*:*ЖуйХуа Син:RuiHua Xing:=Звезда счастья Китая:139 Juewa:Juewa:*ЦзюэХуа" "Sol" #3=
".:RuiHua Xing:139 Juewa:Juewa:1874-139*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	78.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.637139924969
		SemiMajorAxis	2.780746071846
		Eccentricity	0.17571785029
		Inclination	10.910023330399
		AscendingNode	1.850648996285
		ArgOfPericenter	165.84224198625
		MeanAnomaly	292.543876597069
	}
	UniformRotation
	{
		Period	20.991
	}
	LunarLambert	0.5
	Albedo	0.0557
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=139"
}

#1_"140 Siwa:Siwa:1948 AL" "Sol" #1=
#2_"*Жива:140 Siwa:Siwa:1874-140*" "Sol" #2=
#3_"1874-140*:*Жива:140 Siwa:Siwa" "Sol" #3=
".:Siwa:140 Siwa:1874-140*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	54.895
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.515915353071
		SemiMajorAxis	2.732069399792
		Eccentricity	0.216332853939
		Inclination	3.186592283687
		AscendingNode	107.266164100195
		ArgOfPericenter	196.770951804651
		MeanAnomaly	69.616400869764
	}
	UniformRotation
	{
		Period	34.407
	}
	LunarLambert	0.5
	Albedo	0.0676
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=140"
}

#1_"141 Lumen:Lumen" "Sol" #1=
#2_"*Люмен:141 Lumen:Lumen:1875-141*" "Sol" #2=
#3_"1875-141*:*Люмен:141 Lumen:Lumen" "Sol" #3=
".:Lumen:141 Lumen:1875-141*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	65.515
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.350585251369
		SemiMajorAxis	2.664974067471
		Eccentricity	0.214487182608
		Inclination	11.897051449641
		AscendingNode	318.507869533002
		ArgOfPericenter	58.195339833434
		MeanAnomaly	156.394682953235
	}
	UniformRotation
	{
		Period	19.87
	}
	LunarLambert	0.5
	Albedo	0.054
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=141"
}

#1_"142 Polana:Polana:1954 BH:1956 XZ:1963 SA:A923 WA" "Sol" #1=
#2_"*Пулана:142 Polana:Polana:1875-142*" "Sol" #2=
#3_"1875-142*:*Пулана:142 Polana:Polana" "Sol" #3=
".:Polana:142 Polana:1875-142*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.760780591493
		SemiMajorAxis	2.4183168195
		Eccentricity	0.134350825433
		Inclination	2.238324661081
		AscendingNode	291.277024258397
		ArgOfPericenter	291.8965644537
		MeanAnomaly	343.81091765255
	}
	UniformRotation
	{
		Period	9.764
	}
	LunarLambert	0.5
	Albedo	0.0451
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=142"
}

#1_"143 Adria:Adria:1960 WK1" "Sol" #1=
#2_"*Адрия:143 Adria:Adria:1875-143*" "Sol" #2=
#3_"1875-143*:*Адрия:143 Adria:Adria" "Sol" #3=
".:Adria:143 Adria:1875-143*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	44.965
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.589298188593
		SemiMajorAxis	2.761586915613
		Eccentricity	0.073776004006
		Inclination	11.448538855394
		AscendingNode	333.072645106521
		ArgOfPericenter	253.380370346376
		MeanAnomaly	96.328463248657
	}
	UniformRotation
	{
		Period	22.005
	}
	LunarLambert	0.5
	Albedo	0.0491
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=143"
}

#1_"144 Vibilia:Vibilia" "Sol" #1=
#2_"*Вибилия:144 Vibilia:Vibilia:1875-144*" "Sol" #2=
#3_"1875-144*:*Вибилия:144 Vibilia:Vibilia" "Sol" #3=
".:Vibilia:144 Vibilia:1875-144*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"144 vibilia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	71.19
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.331758770787
		SemiMajorAxis	2.657280338204
		Eccentricity	0.234187730362
		Inclination	4.812297422677
		AscendingNode	76.204439616644
		ArgOfPericenter	294.358039373966
		MeanAnomaly	230.96445997548
	}
	UniformRotation
	{
		Period	13.819
	}
	LunarLambert	0.5
	Albedo	0.0597
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=144"
}

#1_"145 Adeona:Adeona" "Sol" #1=
#2_"*Адеона:145 Adeona:Adeona:1875-145*" "Sol" #2=
#3_"1875-145*:*Адеона:145 Adeona:Adeona" "Sol" #3=
".:Adeona:145 Adeona:1875-145*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	75.57
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.369094325822
		SemiMajorAxis	2.672527272552
		Eccentricity	0.144813213278
		Inclination	12.636725915658
		AscendingNode	77.431606528703
		ArgOfPericenter	43.916236431731
		MeanAnomaly	98.512680426809
	}
	UniformRotation
	{
		Period	15.071
	}
	LunarLambert	0.5
	Albedo	0.0433
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=145"
}

#1_"146 Lucina:Lucina:1950 CY" "Sol" #1=
#2_"*Луцина:146 Lucina:Lucina:1875-146*" "Sol" #2=
#3_"1875-146*:*Луцина:146 Lucina:Lucina" "Sol" #3=
".:Lucina:146 Lucina:1875-146*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"146 lucina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	80.155
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.482890016785
		SemiMajorAxis	2.71873318238
		Eccentricity	0.066372495074
		Inclination	13.093770670702
		AscendingNode	83.984568507802
		ArgOfPericenter	147.00007774474
		MeanAnomaly	66.154333540121
	}
	UniformRotation
	{
		Period	18.557
	}
	LunarLambert	0.5
	Albedo	0.036
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=146"
}

#1_"147 Protogeneia:Protogeneia" "Sol" #1=
#2_"*Протогенея:147 Protogeneia:Protogeneia:1875-147*" "Sol" #2=
#3_"1875-147*:*Протогенея:147 Protogeneia:Protogeneia" "Sol" #3=
".:Protogeneia:147 Protogeneia:1875-147*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"147 protogeneia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	66.465
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.555853174906
		SemiMajorAxis	3.136859293894
		Eccentricity	0.028361388725
		Inclination	1.930168038658
		AscendingNode	248.374734360781
		ArgOfPericenter	101.555570250287
		MeanAnomaly	345.550105193404
	}
	UniformRotation
	{
		Period	7.8528
	}
	LunarLambert	0.5
	Albedo	0.0492
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=147"
}

#1_"148 Gallia:Gallia" "Sol" #1=
#2_"*Галлия:148 Gallia:Gallia:1875-148*" "Sol" #2=
#3_"1875-148*:*Галлия:148 Gallia:Gallia" "Sol" #3=
".:Gallia:148 Gallia:1875-148*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	48.875
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.61438579041
		SemiMajorAxis	2.771641993192
		Eccentricity	0.18433261325
		Inclination	25.313699659155
		AscendingNode	145.089289254233
		ArgOfPericenter	252.377536778607
		MeanAnomaly	22.824470657534
	}
	UniformRotation
	{
		Period	20.664
	}
	LunarLambert	0.5
	Albedo	0.164
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=148"
}

#1_"149 Medusa:Medusa:1905 BA:A906 HB" "Sol" #1=
#2_"*Медуза:149 Medusa:Medusa:1875-149*" "Sol" #2=
#3_"1875-149*:*Медуза:149 Medusa:Medusa" "Sol" #3=
".:Medusa:149 Medusa:1875-149*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"149 medusa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	11.86
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.207770616737
		SemiMajorAxis	2.175020736137
		Eccentricity	0.065266171988
		Inclination	0.938897419234
		AscendingNode	159.613234445654
		ArgOfPericenter	250.975206045694
		MeanAnomaly	95.901446278546
	}
	UniformRotation
	{
		Period	26.023
	}
	LunarLambert	0.5
	Albedo	0.152
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=149"
}

#1_"150 Nuwa:Nuwa:2002 JR70:1908 AL" "Sol" #1=
#2_"*Нюйва:150 Nuwa:Nuwa:1875-150*" "Sol" #2=
#3_"1875-150*:*Нюйва:150 Nuwa:Nuwa" "Sol" #3=
".:Nuwa:150 Nuwa:2002 JR70:1875-150*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"150 nuwa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	59.564
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.150100459437
		SemiMajorAxis	2.982210755822
		Eccentricity	0.126349703832
		Inclination	2.193398519725
		AscendingNode	206.241982339684
		ArgOfPericenter	151.613258086421
		MeanAnomaly	23.36932877034
	}
	UniformRotation
	{
		Period	8.1347
	}
	LunarLambert	0.5
	Albedo	0.052
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=150"
}

#1_"151 Abundantia:Abundantia:1974 QS2:1974 QZ2" "Sol" #1=
#2_"*Абунданция:151 Abundantia:Abundantia:1875-151*" "Sol" #2=
#3_"1875-151*:*Абунданция:151 Abundantia:Abundantia" "Sol" #3=
".:Abundantia:151 Abundantia:1875-151*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	22.685
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.173348722015
		SemiMajorAxis	2.592095405043
		Eccentricity	0.033980222506
		Inclination	6.434527895452
		AscendingNode	38.880940047736
		ArgOfPericenter	130.55057272
		MeanAnomaly	0.516648740898
	}
	UniformRotation
	{
		Period	9.864
	}
	LunarLambert	0.5
	Albedo	0.1728
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=151"
}

#1_"152 Atala:Atala" "Sol" #1=
#2_"*Атала:152 Atala:Atala:1875-152*" "Sol" #2=
#3_"1875-152*:*Атала:152 Atala:Atala" "Sol" #3=
".:Atala:152 Atala:1875-152*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"152 atala.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	29.482
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	5.5615052883763
		SemiMajorAxis	3.138986405523178
		Eccentricity	0.07672274901882067
		Inclination	12.11366959037745
		AscendingNode	39.97268043298813
		ArgOfPericenter	59.43089407380756
		MeanAnomaly	342.0862656368088
	}
	UniformRotation
	{
		Period	6.246
	}
	LunarLambert	0.5
	Albedo	0.257
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=152"
}

#1_"153 Hilda:Hilda:1935 GD" "Sol" #1=
#2_"*Хильда:153 Hilda:Hilda:1875-153*" "Sol" #2=
#3_"1875-153*:*Хильда:153 Hilda:Hilda" "Sol" #3=
".:Hilda:153 Hilda:1875-153*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	85.315
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.926340758798
		SemiMajorAxis	3.975359032398
		Eccentricity	0.139078841613
		Inclination	7.826419387823
		AscendingNode	228.17877509918
		ArgOfPericenter	38.593762931213
		MeanAnomaly	337.145763349056
	}
	UniformRotation
	{
		Period	5.9587
	}
	LunarLambert	0.5
	Albedo	0.0618
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=153"
}

#1_"154 Bertha:Bertha" "Sol" #1=
#2_"*Берта:154 Bertha:Bertha:1875-154*" "Sol" #2=
#3_"1875-154*:*Берта:154 Bertha:Bertha" "Sol" #3=
".:Bertha:154 Bertha:1875-154*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"154 bertha.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	96.306
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.711658542114
		SemiMajorAxis	3.195234151076
		Eccentricity	0.077127189043
		Inclination	20.975113615174
		AscendingNode	36.757773196148
		ArgOfPericenter	159.34082301
		MeanAnomaly	21.92193459893
	}
	UniformRotation
	{
		Period	25.224
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=154"
}

#1_"155 Scylla:Scylla:1930 UN:1930 XS:1934 RU:1939 TK:1941 HL:1950 FL:1950 FN:A907 TJ" "Sol" #1=
#2_"*Сцилла:155 Scylla:Scylla:1875-155*" "Sol" #2=
#3_"1875-155*:*Сцилла:155 Scylla:Scylla" "Sol" #3=
".:Scylla:155 Scylla:1875-155*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"155 scylla.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	19.802
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.572264631068
		SemiMajorAxis	2.754749443688
		Eccentricity	0.278133060412
		Inclination	11.39107219136
		AscendingNode	41.012311879842
		ArgOfPericenter	45.873305583169
		MeanAnomaly	104.342688896136
	}
	UniformRotation
	{
		Period	7.9597
	}
	LunarLambert	0.5
	Albedo	0.027
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=155"
}

#1_"156 Xanthippe:Xanthippe:1936 FG1:1942 RP:1949 BN:A901 SA:A902 VA" "Sol" #1=
#2_"*Ксантиппа:156 Xanthippe:Xanthippe:1875-156*" "Sol" #2=
#3_"1875-156*:*Ксантиппа:156 Xanthippe:Xanthippe" "Sol" #3=
".:Xanthippe:156 Xanthippe:1875-156*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	60.495
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.505447390529
		SemiMajorAxis	2.727845780555
		Eccentricity	0.226881360656
		Inclination	9.775923266409
		AscendingNode	241.851204937904
		ArgOfPericenter	338.423871410625
		MeanAnomaly	131.489016517599
	}
	UniformRotation
	{
		Period	22.37
	}
	LunarLambert	0.5
	Albedo	0.0422
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=156"
}

#1_"157 Dejanira:Dejanira:1978 TS1:A904 VB" "Sol" #1=
#2_"*Деянира:157 Dejanira:Dejanira:1875-157*" "Sol" #2=
#3_"1875-157*:*Деянира:157 Dejanira:Dejanira" "Sol" #3=
".:Dejanira:157 Dejanira:1875-157*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"157 dejanira.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.98
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.148881361335
		SemiMajorAxis	2.581954249732
		Eccentricity	0.195219339812
		Inclination	12.158697757321
		AscendingNode	62.081677038564
		ArgOfPericenter	46.230029382111
		MeanAnomaly	217.163863122674
	}
	UniformRotation
	{
		Period	15.825
	}
	LunarLambert	0.5
	Albedo	0.173
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=157"
}

#1_"158 Koronis:Koronis:1955 HA1:A893 PA:A911 HB" "Sol" #1=
#2_"*Коронида:158 Koronis:Koronis:1876-158*" "Sol" #2=
#3_"1876-158*:*Коронида:158 Koronis:Koronis" "Sol" #3=
".:Koronis:158 Koronis:1876-158*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"158 koronis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	19.512
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.861369127206
		SemiMajorAxis	2.869680836607
		Eccentricity	0.052559262181
		Inclination	1.001465170619
		AscendingNode	277.996412984258
		ArgOfPericenter	142.22460597884
		MeanAnomaly	253.808087104087
	}
	UniformRotation
	{
		Period	14.218
	}
	LunarLambert	0.5
	Albedo	0.213
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=158"
}

#1_"159 Aemilia:Aemilia:1959 EG1" "Sol" #1=
#2_"*Эмилия:159 Aemilia:Aemilia:1876-159*" "Sol" #2=
#3_"1876-159*:*Эмилия:159 Aemilia:Aemilia" "Sol" #3=
".:Aemilia:159 Aemilia:1876-159*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	62.485
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.462685038077
		SemiMajorAxis	3.10169178106
		Eccentricity	0.108276426366
		Inclination	6.131119947617
		AscendingNode	134.13288921861
		ArgOfPericenter	333.277778543575
		MeanAnomaly	105.935575219724
	}
	UniformRotation
	{
		Period	24.476
	}
	LunarLambert	0.5
	Albedo	0.0639
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=159"
}

#1_"160 Una:Una" "Sol" #1=
#2_"*Уна:160 Una:Una:1876-160*" "Sol" #2=
#3_"1876-160*:*Уна:160 Una:Una" "Sol" #3=
".:Una:160 Una:1876-160*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"160 una.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	40.62
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.503837053594
		SemiMajorAxis	2.727195750765
		Eccentricity	0.064747520678
		Inclination	3.824318459888
		AscendingNode	8.632157726895
		ArgOfPericenter	52.565386983365
		MeanAnomaly	13.614124960757
	}
	UniformRotation
	{
		Period	11.033
	}
	LunarLambert	0.5
	Albedo	0.0625
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=160"
}

#1_"161 Athor:Athor:1961 PF:1973 YN4:A899 TA" "Sol" #1=
#2_"*Атхор:161 Athor:Athor:1876-161*" "Sol" #2=
#3_"1876-161*:*Атхор:161 Athor:Athor" "Sol" #3=
".:Athor:161 Athor:1876-161*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"161 athor.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	20.496
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.673696504708
		SemiMajorAxis	2.380839112509
		Eccentricity	0.136719993377
		Inclination	9.05432744003
		AscendingNode	18.637625641502
		ArgOfPericenter	294.684221620243
		MeanAnomaly	188.028288711759
	}
	UniformRotation
	{
		Period	7.28
	}
	LunarLambert	0.5
	Albedo	0.23
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=161"
}

#1_"162 Laurentia:Laurentia" "Sol" #1=
#2_"*Лаврентия:162 Laurentia:Laurentia:1876-162*" "Sol" #2=
#3_"1876-162*:*Лаврентия:162 Laurentia:Laurentia" "Sol" #3=
".:Laurentia:162 Laurentia:1876-162*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"162 laurentia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	48.51
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.246200079622
		SemiMajorAxis	3.019194545966
		Eccentricity	0.178716291615
		Inclination	6.096192606814
		AscendingNode	35.545713090829
		ArgOfPericenter	116.103730531201
		MeanAnomaly	187.443214882199
	}
	UniformRotation
	{
		Period	11.8686
	}
	LunarLambert	0.5
	Albedo	0.051
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=162"
}

#1_"163 Erigone:Erigone:1957 OT:A892 RA" "Sol" #1=
#2_"*Эригона:163 Erigone:Erigone:1876-163*" "Sol" #2=
#3_"1876-163*:*Эригона:163 Erigone:Erigone" "Sol" #3=
".:Erigone:163 Erigone:1876-163*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"163 erigone.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	34.694
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.641726179818
		SemiMajorAxis	2.367006173549
		Eccentricity	0.190462399509
		Inclination	4.814905706732
		AscendingNode	160.162610651136
		ArgOfPericenter	298.286506667183
		MeanAnomaly	28.247699878867
	}
	UniformRotation
	{
		Period	16.136
	}
	LunarLambert	0.5
	Albedo	0.027
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=163"
}

#1_"164 Eva:Eva" "Sol" #1=
#2_"*Ева:164 Eva:Eva:1876-164*" "Sol" #2=
#3_"1876-164*:*Ева:164 Eva:Eva" "Sol" #3=
".:Eva:164 Eva:1876-164*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"164 eva.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	50.127
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.277220867447
		SemiMajorAxis	2.634929399199
		Eccentricity	0.344659661752
		Inclination	24.460820888343
		AscendingNode	77.088944107085
		ArgOfPericenter	283.652648062014
		MeanAnomaly	81.459263040459
	}
	UniformRotation
	{
		Period	13.66
	}
	LunarLambert	0.5
	Albedo	0.049
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=164"
}

#1_"165 Loreley:Loreley:1948 QS:1959 PB:1960 WG" "Sol" #1=
#2_"*Лорелей:165 Loreley:Loreley:1876-165*" "Sol" #2=
#3_"1876-165*:*Лорелей:165 Loreley:Loreley" "Sol" #3=
".:Loreley:165 Loreley:1876-165*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"165 loreley.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	90.042
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.521966245835
		SemiMajorAxis	3.124091152242
		Eccentricity	0.08520665496
		Inclination	11.226373089693
		AscendingNode	302.521091508503
		ArgOfPericenter	347.177388793931
		MeanAnomaly	197.388832497875
	}
	UniformRotation
	{
		Period	7.226
	}
	LunarLambert	0.5
	Albedo	0.047
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=165"
}

#1_"166 Rhodope:Rhodope" "Sol" #1=
#2_"*Родопа:166 Rhodope:Rhodope:1876-166*" "Sol" #2=
#3_"1876-166*:*Родопа:166 Rhodope:Rhodope" "Sol" #3=
".:Rhodope:166 Rhodope:1876-166*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"166 rhodope.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	26.196
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.400810981184
		SemiMajorAxis	2.68544549545
		Eccentricity	0.211252706616
		Inclination	12.029038127101
		AscendingNode	128.930688261011
		ArgOfPericenter	264.611778767906
		MeanAnomaly	145.257823807541
	}
	UniformRotation
	{
		Period	4.715
	}
	LunarLambert	0.5
	Albedo	0.046
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=166"
}

#1_"167 Urda:Urda:A899 KC:A905 QA:A906 WA" "Sol" #1=
#2_"*Урда:167 Urda:Urda:1876-167*" "Sol" #2=
#3_"1876-167*:*Урда:167 Urda:Urda" "Sol" #3=
".:Urda:167 Urda:1876-167*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"167 urda.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	19.968
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.818012962459
		SemiMajorAxis	2.852593190931
		Eccentricity	0.036217812343
		Inclination	2.212276418992
		AscendingNode	166.226253778735
		ArgOfPericenter	133.341892221438
		MeanAnomaly	274.593098008608
	}
	UniformRotation
	{
		Period	13.07
	}
	LunarLambert	0.5
	Albedo	0.223
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=167"
}

#1_"168 Sibylla:Sibylla:1949 MO:A911 HF" "Sol" #1=
#2_"*Сибилла:168 Sibylla:Sibylla:1876-168*" "Sol" #2=
#3_"1876-168*:*Сибилла:168 Sibylla:Sibylla" "Sol" #3=
".:Sibylla:168 Sibylla:1876-168*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	74.195
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.206057675539
		SemiMajorAxis	3.377057096504
		Eccentricity	0.068974912106
		Inclination	4.634371065228
		AscendingNode	206.378899256277
		ArgOfPericenter	170.493382131981
		MeanAnomaly	79.784434224057
	}
	UniformRotation
	{
		Period	47.009
	}
	LunarLambert	0.5
	Albedo	0.0535
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=168"
}

#1_"169 Zelia:Zelia:1933 FC2" "Sol" #1=
#2_"*Зелия:169 Zelia:Zelia:1876-169*" "Sol" #2=
#3_"1876-169*:*Зелия:169 Zelia:Zelia" "Sol" #3=
".:Zelia:169 Zelia:1876-169*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.620368796754
		SemiMajorAxis	2.357742691194
		Eccentricity	0.130956923068
		Inclination	5.500295423917
		AscendingNode	354.783219118891
		ArgOfPericenter	334.378144638848
		MeanAnomaly	86.968631254045
	}
	UniformRotation
	{
		Period	14.537
	}
	LunarLambert	0.5
	Albedo	0.2347
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=169"
}

#1_"170 Maria:Maria:1958 AC" "Sol" #1=
#2_"*Мария:170 Maria:Maria:1877-170*" "Sol" #2=
#3_"1877-170*:*Мария:170 Maria:Maria" "Sol" #3=
".:Maria:170 Maria:1877-170*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	22.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.079609990761
		SemiMajorAxis	2.553134120354
		Eccentricity	0.062636845637
		Inclination	14.385780386703
		AscendingNode	301.364879021808
		ArgOfPericenter	159.153270003686
		MeanAnomaly	303.204958088717
	}
	UniformRotation
	{
		Period	13.12
	}
	LunarLambert	0.5
	Albedo	0.1579
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=170"
}

#1_"171 Ophelia:Ophelia (asteroid)" "Sol" #1=
#2_"*Офелия (астероид):171 Ophelia:Ophelia (asteroid):1877-171*" "Sol" #2=
#3_"1877-171*:*Офелия (астероид):171 Ophelia:Ophelia (asteroid)" "Sol" #3=
".:Ophelia (asteroid):171 Ophelia:1877-171*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"171 ophelia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	65.404
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.536060857561
		SemiMajorAxis	3.129404976945
		Eccentricity	0.131552001977
		Inclination	2.546799753189
		AscendingNode	100.539523107924
		ArgOfPericenter	57.045473331134
		MeanAnomaly	264.177591540541
	}
	UniformRotation
	{
		Period	6.6654
	}
	LunarLambert	0.5
	Albedo	0.076
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=171"
}

#1_"172 Baucis:Baucis:A921 EE" "Sol" #1=
#2_"*Бавкида:172 Baucis:Baucis:1877-172*" "Sol" #2=
#3_"1877-172*:*Бавкида:172 Baucis:Baucis" "Sol" #3=
".:Baucis:172 Baucis:1877-172*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	31.215
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.670876748712
		SemiMajorAxis	2.379620676807
		Eccentricity	0.115040932769
		Inclination	10.028736091835
		AscendingNode	331.980399047622
		ArgOfPericenter	359.209259519076
		MeanAnomaly	14.351937130579
	}
	UniformRotation
	{
		Period	27.417
	}
	LunarLambert	0.5
	Albedo	0.1382
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=172"
}

#1_"173 Ino:Ino:A922 SB" "Sol" #1=
#2_"*Ино:173 Ino:Ino:1922 SB:1877-173*" "Sol" #2=
#3_"1877-173*:*Ино:173 Ino:Ino:1922 SB" "Sol" #3=
".:Ino:173 Ino:1877-173*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	77.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.545295508673
		SemiMajorAxis	2.743906326416
		Eccentricity	0.206013868174
		Inclination	14.211757294943
		AscendingNode	148.271710131808
		ArgOfPericenter	228.023980000587
		MeanAnomaly	48.155849446385
	}
	UniformRotation
	{
		Period	6.163
	}
	LunarLambert	0.5
	Albedo	0.0642
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=173"
}

#1_"174 Phaedra:Phaedra" "Sol" #1=
#2_"*Федра:174 Phaedra:Phaedra:1877-174*" "Sol" #2=
#3_"1877-174*:*Федра:174 Phaedra:Phaedra" "Sol" #3=
".:Phaedra:174 Phaedra:1877-174*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"174 phaedra.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	32.425
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.838586963824
		SemiMajorAxis	2.860708232871
		Eccentricity	0.143240106263
		Inclination	12.130733926071
		AscendingNode	327.710838309299
		ArgOfPericenter	289.131689480291
		MeanAnomaly	208.643558142929
	}
	UniformRotation
	{
		Period	5.744
	}
	LunarLambert	0.5
	Albedo	0.169
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=174"
}

#1_"175 Andromache:Andromache:1946 MB:1946 OD:A893 KA:A895 XB" "Sol" #1=
#2_"*Андромаха:175 Andromache:Andromache:1877-175*" "Sol" #2=
#3_"1877-175*:*Андромаха:175 Andromache:Andromache" "Sol" #3=
".:Andromache:175 Andromache:1877-175*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	50.585
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.683494852591
		SemiMajorAxis	3.184721886312
		Eccentricity	0.232629461455
		Inclination	3.218506154473
		AscendingNode	21.361009600919
		ArgOfPericenter	320.506150502645
		MeanAnomaly	291.597428744078
	}
	UniformRotation
	{
		Period	8.324
	}
	LunarLambert	0.5
	Albedo	0.0819
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=175"
}

#1_"176 Iduna:Iduna:1945 RQ" "Sol" #1=
#2_"*Идуна:176 Iduna:Iduna:1877-176*" "Sol" #2=
#3_"1877-176*:*Идуна:176 Iduna:Iduna" "Sol" #3=
".:Iduna:176 Iduna:1877-176*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"176 iduna.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	53.488
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.676112592401
		SemiMajorAxis	3.181963543808
		Eccentricity	0.170039869997
		Inclination	22.67503961899
		AscendingNode	200.504612334468
		ArgOfPericenter	188.423678609921
		MeanAnomaly	234.219146541116
	}
	UniformRotation
	{
		Period	11.2877
	}
	LunarLambert	0.5
	Albedo	0.106
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=176"
}

#1_"177 Irma:Irma:1937 UA:1962 DB:A900 UB:A900 VA:A912 HE" "Sol" #1=
#2_"*Ирма:177 Irma:Irma:1877-177*" "Sol" #2=
#3_"1877-177*:*Ирма:177 Irma:Irma" "Sol" #3=
".:Irma:1177 Irma:1877-177*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.61
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.607938473361
		SemiMajorAxis	2.76905966055
		Eccentricity	0.23778037658
		Inclination	1.3894592378
		AscendingNode	347.55188114774
		ArgOfPericenter	38.225077525314
		MeanAnomaly	273.723622555893
	}
	UniformRotation
	{
		Period	13.856
	}
	LunarLambert	0.5
	Albedo	0.0527
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=177"
}

#1_"178 Belisana:Belisana:1935 UA1:A899 LE:A904 UA" "Sol" #1=
#2_"*Белисана:178 Belisana:Belisana:1877-178*" "Sol" #2=
#3_"1877-178*:*Белисана:178 Belisana:Belisana" "Sol" #3=
".:Belisana:178 Belisana:1877-178*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"178 belisana.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	17.905
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.858592162035
		SemiMajorAxis	2.460068029388
		Eccentricity	0.042610759376
		Inclination	1.895222864496
		AscendingNode	51.114242200963
		ArgOfPericenter	212.891678518206
		MeanAnomaly	326.236807176321
	}
	UniformRotation
	{
		Period	12.323
	}
	LunarLambert	0.5
	Albedo	0.2438
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=178"
}

#1_"179 Klytaemnestra:Klytaemnestra" "Sol" #1=
#2_"*Клитемнестра:179 Klytaemnestra:Klytaemnestra:1877-179*" "Sol" #2=
#3_"1877-179*:*Клитемнестра:179 Klytaemnestra:Klytaemnestra" "Sol" #3=
".:Klytaemnestra:179 Klytaemnestra:1877-179*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"179 klytaemnestra.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	34.973
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.123794193044
		SemiMajorAxis	2.972046841552
		Eccentricity	0.114222288052
		Inclination	7.814640284907
		AscendingNode	251.939020911783
		ArgOfPericenter	103.872837634639
		MeanAnomaly	323.279100369806
	}
	UniformRotation
	{
		Period	11.173
	}
	LunarLambert	0.5
	Albedo	0.198
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=179"
}

#1_"180 Garumna:Garumna" "Sol" #1=
#2_"*Гарумна:180 Garumna:Garumna:1878-180*" "Sol" #2=
#3_"1878-180*:Garumna:*Гарумна:180 Garumna:Garumna" "Sol" #3=
".:Garumna:180 Garumna:1878-180*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"180 garumna.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	11.72
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.492803996865
		SemiMajorAxis	2.722740053185
		Eccentricity	0.164887697066
		Inclination	0.866014284889
		AscendingNode	312.16913907504
		ArgOfPericenter	175.919433975573
		MeanAnomaly	345.759238481329
	}
	UniformRotation
	{
		Period	23.866
	}
	LunarLambert	0.5
	Albedo	0.242
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=180"
}

#1_"181 Eucharis:Eucharis:A906 GA" "Sol" #1=
#2_"*Эвхарида:181 Eucharis:Eucharis:1878-181*" "Sol" #2=
#3_"1878-181*:*Эвхарида:181 Eucharis:Eucharis" "Sol" #3=
".:Eucharis:181 Eucharis:1878-181*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	53.33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.535407469921
		SemiMajorAxis	3.129158742326
		Eccentricity	0.203245452403
		Inclination	18.89156856705
		AscendingNode	143.223640646417
		ArgOfPericenter	318.812141653345
		MeanAnomaly	285.579306334506
	}
	UniformRotation
	{
		Period	52.23
	}
	LunarLambert	0.5
	Albedo	0.1135
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=181"
}

#1_"182 Elsa:Elsa:1948 XS:1950 HY" "Sol" #1=
#2_"*Эльза:182 Elsa:Elsa:1878-182*" "Sol" #2=
#3_"1878-182*:*Эльза:182 Elsa:Elsa" "Sol" #3=
".:Elsa:182 Elsa:1878-182*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"182 elsa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	19.76
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.756249914255
		SemiMajorAxis	2.41637417066
		Eccentricity	0.185734987068
		Inclination	2.004552935079
		AscendingNode	107.240925855612
		ArgOfPericenter	310.226330089595
		MeanAnomaly	223.017698259716
	}
	UniformRotation
	{
		Period	80.088
	}
	LunarLambert	0.5
	Albedo	0.196
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=182"
}

#1_"183 Istria:Istria:1948 CG" "Sol" #1=
#2_"*Истрия:183 Istria:Istria:1878-183*" "Sol" #2=
#3_"1878-183*:*Истрия:183 Istria:Istria" "Sol" #3=
".:Istria:183 Istria:1878-183*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"183 istria.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	16.464
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.660183795804
		SemiMajorAxis	2.789950911981
		Eccentricity	0.351333495502
		Inclination	26.392688856602
		AscendingNode	141.955908087653
		ArgOfPericenter	264.205535361755
		MeanAnomaly	167.828960477465
	}
	UniformRotation
	{
		Period	11.77
	}
	LunarLambert	0.5
	Albedo	0.227
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=183"
}

#1_"184 Dejopeja:Dejopeja:1959 LL:A903 QB" "Sol" #1=
#2_"*Дейопея:184 Dejopeja:Dejopeja:1878-184*" "Sol" #2=
#3_"1878-184*:*Дейопея:184 Dejopeja:Dejopeja" "Sol" #3=
".:Dejopeja:184 Dejopeja:1878-184*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"184 dejopeja.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	31.242
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.686784724942
		SemiMajorAxis	3.185950744989
		Eccentricity	0.066921891746
		Inclination	1.143886133437
		AscendingNode	331.613127681534
		ArgOfPericenter	209.303353174164
		MeanAnomaly	15.618481632053
	}
	UniformRotation
	{
		Period	6.455
	}
	LunarLambert	0.5
	Albedo	0.215
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=184"
}

#1_"185 Eunike:Eunike" "Sol" #1=
#2_"*Эвника:185 Eunike:Eunike:1878-185*" "Sol" #2=
#3_"1878-185*:*Эвника:185 Eunike:Eunike" "Sol" #3=
".:Eunike:185 Eunike:1878-185*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	78.755
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.528691433031
		SemiMajorAxis	2.737219880046
		Eccentricity	0.129385064247
		Inclination	23.238183269973
		AscendingNode	153.843268139952
		ArgOfPericenter	224.196245212446
		MeanAnomaly	196.74266156311
	}
	UniformRotation
	{
		Period	21.797
	}
	LunarLambert	0.5
	Albedo	0.0638
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=185"
}

#1_"186 Celuta:Celuta:1954 FD" "Sol" #1=
#2_"*Келута:186 Celuta:Celuta:1878-186*" "Sol" #2=
#3_"1878-186*:*Келута:186 Celuta:Celuta" "Sol" #3=
".:Celuta:186 Celuta:1878-186*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"186 celuta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	24.995
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.630278660351
		SemiMajorAxis	2.362043222153
		Eccentricity	0.149713162855
		Inclination	13.174025412065
		AscendingNode	14.824749893037
		ArgOfPericenter	315.086126751786
		MeanAnomaly	112.978141561642
	}
	UniformRotation
	{
		Period	19.842
	}
	LunarLambert	0.5
	Albedo	0.1929
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=186"
}

#1_"187 Lamberta:Lamberta:1946 LB:1948 XR" "Sol" #1=
#2_"*Ламберта:187 Lamberta:Lamberta:1878-187*" "Sol" #2=
#3_"1878-187*:*Ламберта:187 Lamberta:Lamberta" "Sol" #3=
".:Lamberta:187 Lamberta:1878-187*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"187 lamberta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	73.647
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.507185975393
		SemiMajorAxis	2.728547492063
		Eccentricity	0.240768555039
		Inclination	10.585885896817
		AscendingNode	21.709273192422
		ArgOfPericenter	196.921438381225
		MeanAnomaly	86.212122826585
	}
	UniformRotation
	{
		Period	10.67
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=187"
}

#1_"188 Menippe:Menippe:1948 WQ:A897 QA" "Sol" #1=
#2_"*Мениппа:188 Menippe:Menippe:1878-188*" "Sol" #2=
#3_"1878-188*:*Мениппа:188 Menippe:Menippe" "Sol" #3=
".:Menippe:188 Menippe:1878-188*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"188 menippe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	17.876
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.593549295334
		SemiMajorAxis	2.763292040386
		Eccentricity	0.177742247938
		Inclination	11.699343636236
		AscendingNode	240.947376496092
		ArgOfPericenter	69.942655506406
		MeanAnomaly	218.021644865854
	}
	UniformRotation
	{
		Period	11.98
	}
	LunarLambert	0.5
	Albedo	0.242
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=188"
}

#1_"189 Phthia:Phthia" "Sol" #1=
#2_"*Фтия:189 Phthia:Phthia:1878-189*" "Sol" #2=
#3_"1878-189*:*Фтия:189 Phthia:Phthia" "Sol" #3=
".:Phthia:189 Phthia:1878-189*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"189 phthia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	19.245
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.834893087092
		SemiMajorAxis	2.449984700587
		Eccentricity	0.037082599755
		Inclination	5.177384937796
		AscendingNode	203.430204777097
		ArgOfPericenter	168.559666288728
		MeanAnomaly	182.251434647742
	}
	UniformRotation
	{
		Period	22.346
	}
	LunarLambert	0.5
	Albedo	0.17
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=189"
}

#1_"190 Ismene:Ismene:1947 QJ:1951 DB" "Sol" #1=
#2_"*Исмена:190 Ismene:Ismene:1878-190*" "Sol" #2=
#3_"1878-190*:*Исмена:190 Ismene:Ismene" "Sol" #3=
".:Ismene:190 Ismene:1878-190*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	79.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.979902830253
		SemiMajorAxis	3.993247856386
		Eccentricity	0.166155707784
		Inclination	6.172971779004
		AscendingNode	175.469693585656
		ArgOfPericenter	272.069379851327
		MeanAnomaly	60.035322857819
	}
	UniformRotation
	{
		Period	6.52
	}
	LunarLambert	0.5
	Albedo	0.066
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=190"
}

#1_"191 Kolga:Kolga:1949 YP" "Sol" #1=
#2_"*Колга:191 Kolga:Kolga:1878-191*" "Sol" #2=
#3_"1878-191*:*Колга:191 Kolga:Kolga" "Sol" #3=
".:Kolga:191 Kolga:1878-191*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	50.515
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.922761475747
		SemiMajorAxis	2.893790327423
		Eccentricity	0.091319202823
		Inclination	11.507549237284
		AscendingNode	159.316413464726
		ArgOfPericenter	227.268238744844
		MeanAnomaly	205.933484183763
	}
	UniformRotation
	{
		Period	17.604
	}
	LunarLambert	0.5
	Albedo	0.0408
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=191"
}

#1_"192 Nausikaa:Nausikaa:1933 HH" "Sol" #1=
#2_"*Навсикая:192 Nausikaa:Nausikaa:1879-192*" "Sol" #2=
#3_"1879-192*:*Навсикая:192 Nausikaa:Nausikaa" "Sol" #3=
".:Nausikaa:192 Nausikaa:1879-192*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"192 nausikaa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.879 0.767 ]
	BlendTexture	true
	Radius	49.388
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.724925727031
		SemiMajorAxis	2.402921649122
		Eccentricity	0.24607062972
		Inclination	6.813741498985
		AscendingNode	343.25010806085
		ArgOfPericenter	30.058207768673
		MeanAnomaly	295.570535226706
	}
	UniformRotation
	{
		Period	13.625
		Inclination	97
		AscendingNode	36
	}
	LunarLambert	0.5
	Albedo	0.327
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=192"
}

#1_"193 Ambrosia:Ambrosia:A915 RB" "Sol" #1=
#2_"*Амброзия:193 Ambrosia:Ambrosia:1879-193*" "Sol" #2=
#3_"1879-193*:*Амброзия:193 Ambrosia:Ambrosia" "Sol" #3=
".:Ambrosia:193 Ambrosia:1879-193*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"193 ambrosia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.151
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.194906115744
		SemiMajorAxis	2.601014034205
		Eccentricity	0.296561728535
		Inclination	12.009728515177
		AscendingNode	349.973140297523
		ArgOfPericenter	81.378796897655
		MeanAnomaly	237.423063031782
	}
	UniformRotation
	{
		Period	6.581
	}
	LunarLambert	0.5
	Albedo	0.343
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=193"
}

#1_"194 Prokne:Prokne" "Sol" #1=
#2_"*Прокна:194 Prokne:Prokne:1879-194*" "Sol" #2=
#3_"1879-194*:*Прокна:194 Prokne:Prokne" "Sol" #3=
".:Prokne:194 Prokne:1879-194*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	84.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.229217537377
		SemiMajorAxis	2.61517776314
		Eccentricity	0.237887057551
		Inclination	18.509398000155
		AscendingNode	159.317910342177
		ArgOfPericenter	163.288841551711
		MeanAnomaly	262.428392820283
	}
	UniformRotation
	{
		Period	15.679
	}
	LunarLambert	0.5
	Albedo	0.0528
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=194"
}

#1_"195 Eurykleia:Eurykleia:1949 QB2" "Sol" #1=
#2_"*Эвриклея:195 Eurykleia:Eurykleia:1879-195*" "Sol" #2=
#3_"1879-195*:*Эвриклея:195 Eurykleia:Eurykleia" "Sol" #3=
".:Eurykleia:195 Eurykleia:1879-195*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	42.855
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.884699569697
		SemiMajorAxis	2.878854862088
		Eccentricity	0.044320033983
		Inclination	6.96631282667
		AscendingNode	7.029708352798
		ArgOfPericenter	121.010424884063
		MeanAnomaly	350.585799781446
	}
	UniformRotation
	{
		Period	16.521
	}
	LunarLambert	0.5
	Albedo	0.0599
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=195"
}

#1_"196 Philomela:Philomela:1934 JO" "Sol" #1=
#2_"*Филомела:196 Philomela:Philomela:1879-196*" "Sol" #2=
#3_"1879-196*:*Филомела:196 Philomela:Philomela" "Sol" #3=
".:Philomela:196 Philomela:1879-196*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"196 philomela.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	72.313
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.490978185385
		SemiMajorAxis	3.112392384887
		Eccentricity	0.019586673222
		Inclination	7.259814415988
		AscendingNode	72.526405298791
		ArgOfPericenter	198.045186843761
		MeanAnomaly	166.533930151551
	}
	UniformRotation
	{
		Period	8.334
	}
	LunarLambert	0.5
	Albedo	0.342
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=196"
}

#1_"197 Arete:Arete:1934 RE1:1950 DY" "Sol" #1=
#2_"*Арета:197 Arete:Arete:1879-197*" "Sol" #2=
#3_"1879-197*:*Арета:197 Arete:Arete" "Sol" #3=
".:Arete:197 Arete:1879-197*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.59
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.530664150511
		SemiMajorAxis	2.738014718854
		Eccentricity	0.163771618404
		Inclination	8.794762756994
		AscendingNode	81.611627805681
		ArgOfPericenter	246.559419161546
		MeanAnomaly	249.767562197964
	}
	UniformRotation
	{
		Period	6.6084
	}
	LunarLambert	0.5
	Albedo	0.4417
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=197"
}

#1_"198 Ampella:Ampella:1957 YA1" "Sol" #1=
#2_"*Ампелия:198 Ampella:Ampella:1879-198*" "Sol" #2=
#3_"1879-198*:*Ампелия:198 Ampella:Ampella" "Sol" #3=
".:Ampella:198 Ampella:1879-198*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	28.58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.855468580062
		SemiMajorAxis	2.458740211548
		Eccentricity	0.228289311112
		Inclination	9.313459674675
		AscendingNode	268.464525025057
		ArgOfPericenter	88.520498754933
		MeanAnomaly	337.731778594816
	}
	UniformRotation
	{
		Period	10.379
	}
	LunarLambert	0.5
	Albedo	0.2517
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=198"
}

#1_"199 Byblis:Byblis:1971 WB" "Sol" #1=
#2_"*Библида:199 Byblis:Byblis:1879-199*" "Sol" #2=
#3_"1879-199*:*Библида:199 Byblis:Byblis" "Sol" #3=
".:Byblis:199 Byblis:1879-199*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"199 byblis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	38.064
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	5.638374437955
		SemiMajorAxis	3.167844151767
		Eccentricity	0.179247073555
		Inclination	15.475329212266
		AscendingNode	88.600994277978
		ArgOfPericenter	180.176583866531
		MeanAnomaly	16.716468766943
	}
	UniformRotation
	{
		Period	5.2201
	}
	LunarLambert	0.5
	Albedo	0.107
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=199"
}

#1_"200 Dynamene:Dynamene:1955 HZ:1961 TO1:1974 HE1:A904 CA" "Sol" #1=
#2_"*Динамена:200 Dynamene:Dynamene:1879-200*" "Sol" #2=
#3_"1879-200*:*Динамена:200 Dynamene:Dynamene" "Sol" #3=
".:Dynamene:200 Dynamene:1879-200*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	64.18
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.530172052222
		SemiMajorAxis	2.737816455538
		Eccentricity	0.133560026893
		Inclination	6.896069489252
		AscendingNode	324.578079750589
		ArgOfPericenter	85.118270744047
		MeanAnomaly	239.956835814414
	}
	UniformRotation
	{
		Period	37.394
	}
	LunarLambert	0.5
	Albedo	0.0533
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=200"
}

#1_"201 Penelope:Penelope:A869 GA" "Sol" #1=
#2_"*Пенелопа:201 Penelope:Penelope:1879-201*" "Sol" #2=
#3_"1879-201*:*Пенелопа:201 Penelope:Penelope" "Sol" #3=
".:Penelope:201 Penelope:1879-201*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"201 penelope.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.939 0.876 ]
	BlendTexture	true
	Radius	42.938
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.381950275825
		SemiMajorAxis	2.677767267679
		Eccentricity	0.181199764889
		Inclination	5.757930380866
		AscendingNode	157.028642740136
		ArgOfPericenter	180.971892964938
		MeanAnomaly	304.268130883905
	}
	UniformRotation
	{
		Period	3.7474
		Inclination	105
		AscendingNode	174
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=201"
}

#1_"202 Chryseis:Chryseis:1935 BL:A901 TA" "Sol" #1=
#2_"*Хрисеида:202 Chryseis:Chryseis:1879-202*" "Sol" #2=
#3_"1879-202*:*Хрисеида:202 Chryseis:Chryseis" "Sol" #3=
".:Chryseis:202 Chryseis:1879-202*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	43.075
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.379305736924
		SemiMajorAxis	3.070049308396
		Eccentricity	0.101797787437
		Inclination	8.854840368593
		AscendingNode	136.847913394457
		ArgOfPericenter	1.225060008248
		MeanAnomaly	261.283753514331
	}
	UniformRotation
	{
		Period	23.67
	}
	LunarLambert	0.5
	Albedo	0.2562
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=202"
}

#1_"203 Pompeja:Pompeja:A895 EA" "Sol" #1=
#2_"*Помпея:203 Pompeja:Pompeja:1879-203*" "Sol" #2=
#3_"1879-203*:*Помпея:203 Pompeja:Pompeja" "Sol" #3=
".:Pompeja:203 Pompeja:1879-203*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58.125
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.53013817049
		SemiMajorAxis	2.737802804536
		Eccentricity	0.05890879133
		Inclination	3.177954238627
		AscendingNode	347.920016528841
		ArgOfPericenter	57.025747069364
		MeanAnomaly	277.099987650758
	}
	UniformRotation
	{
		Period	24.052
	}
	LunarLambert	0.5
	Albedo	0.041
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=203"
}

#1_"204 Kallisto:Kallisto" "Sol" #1=
#2_"*Каллисто (астероид):204 Kallisto:Kallisto:1879-204*" "Sol" #2=
#3_"1879-204*:*Каллисто (астероид):204 Kallisto:Kallisto" "Sol" #3=
".:Kallisto:204 Kallisto:1879-204*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	24.285
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.363857316706
		SemiMajorAxis	2.670391231503
		Eccentricity	0.17481899669
		Inclination	8.28552629628
		AscendingNode	205.120615635963
		ArgOfPericenter	55.532593089421
		MeanAnomaly	94.867716453497
	}
	UniformRotation
	{
		Period	19.489
	}
	LunarLambert	0.5
	Albedo	0.2082
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=204"
}

#1_"205 Martha:Martha" "Sol" #1=
#2_"*Марфа:205 Martha:Martha:1879-205*" "Sol" #2=
#3_"1879-205*:*Марфа:205 Martha:Martha" "Sol" #3=
".:Martha:205 Martha:1879-205*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.29
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.630197466589
		SemiMajorAxis	2.777969930446
		Eccentricity	0.034143148426
		Inclination	10.681838377885
		AscendingNode	211.904523711933
		ArgOfPericenter	176.089188790516
		MeanAnomaly	71.861312369105
	}
	UniformRotation
	{
		Period	14.911
	}
	LunarLambert	0.5
	Albedo	0.0553
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=205"
}

#1_"206 Hersilia:Hersilia:1961 WG:1974 PM" "Sol" #1=
#2_"*Герсилия:206 Hersilia:Hersilia:1879-206*" "Sol" #2=
#3_"1879-206*:*Герсилия:206 Hersilia:Hersilia" "Sol" #3=
".:Hersilia:206 Hersilia:1879-206*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	56.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.539070307209
		SemiMajorAxis	2.74140039897
		Eccentricity	0.037714007719
		Inclination	3.778506888941
		AscendingNode	145.169957840636
		ArgOfPericenter	299.337786582254
		MeanAnomaly	219.058995766087
	}
	UniformRotation
	{
		Period	11.128
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=206"
}

#1_"207 Hedda:Hedda:1932 CL1:1934 XJ:1953 BF" "Sol" #1=
#2_"*Гедда:207 Hedda:Hedda:1879-207*" "Sol" #2=
#3_"1879-207*:*Гедда:207 Hedda:Hedda" "Sol" #3=
".:Hedda:207 Hedda:1879-207*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.451301891458
		SemiMajorAxis	2.283756684134
		Eccentricity	0.029648217936
		Inclination	3.802820244731
		AscendingNode	29.241248075339
		ArgOfPericenter	193.384903640659
		MeanAnomaly	223.242397265968
	}
	UniformRotation
	{
		Period	30.098
	}
	LunarLambert	0.5
	Albedo	0.0552
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=207"
}

#1_"208 Lacrimosa:Lacrimosa" "Sol" #1=
#2_"*Лакримоза:208 Lacrimosa:Lacrimosa:1879-208*" "Sol" #2=
#3_"1879-208*:*Лакримоза:208 Lacrimosa:Lacrimosa" "Sol" #3=
".:Lacrimosa:208 Lacrimosa:1879-208*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"208 lacrimosa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	20.028
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.918156960416
		SemiMajorAxis	2.891985570744
		Eccentricity	0.013466459951
		Inclination	1.745904243292
		AscendingNode	4.265243417482
		ArgOfPericenter	107.774553114608
		MeanAnomaly	90.144639482879
	}
	UniformRotation
	{
		Period	14.085
	}
	LunarLambert	0.5
	Albedo	0.206
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=208"
}

#1_"209 Dido:Dido:1909 AB:1909 GB:A912 RB" "Sol" #1=
#2_"*Дидона:209 Dido:Dido:1879-209*" "Sol" #2=
#3_"1879-209*:*Дидона:209 Dido:Dido" "Sol" #3=
".:Dido:209 Dido:1879-209*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	79.97
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.5801125464
		SemiMajorAxis	3.145983960541
		Eccentricity	0.059977547306
		Inclination	7.169426975723
		AscendingNode	0.72683819888
		ArgOfPericenter	249.414740071543
		MeanAnomaly	205.002312397554
	}
	UniformRotation
	{
		Period	5.7366
	}
	LunarLambert	0.5
	Albedo	0.0349
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=209"
}

#1_"210 Isabella:Isabella:1953 EZ1:1962 BF" "Sol" #1=
#2_"*Изабелла:210 Isabella:Isabella:1879-210*" "Sol" #2=
#3_"1879-210*:*Изабелла:210 Isabella:Isabella" "Sol" #3=
".:Isabella:210 Isabella:1879-210*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"210 isabella.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	43.325
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.491233637234
		SemiMajorAxis	2.722105567433
		Eccentricity	0.121066804442
		Inclination	5.255858975689
		AscendingNode	32.651691176312
		ArgOfPericenter	14.694333232685
		MeanAnomaly	22.150692864435
	}
	UniformRotation
	{
		Period	6.672
	}
	LunarLambert	0.5
	Albedo	0.0436
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=210"
}

#1_"211 Isolda:Isolda:1950 FM:A912 AB:A912 BA" "Sol" #1=
#2_"*Изольда:211 Isolda:Isolda:1879-211*" "Sol" #2=
#3_"1879-211*:*Изольда:211 Isolda:Isolda" "Sol" #3=
".:Isolda:211 Isolda:1950 FM:1879-211*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	71.595
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.301906363388
		SemiMajorAxis	3.040529588898
		Eccentricity	0.161833970078
		Inclination	3.887125086386
		AscendingNode	263.651775732075
		ArgOfPericenter	173.550059358611
		MeanAnomaly	148.62104679413
	}
	UniformRotation
	{
		Period	18.365
	}
	LunarLambert	0.5
	Albedo	0.0602
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=211"
}

#1_"212 Medea:Medea:1930 FW" "Sol" #1=
#2_"*Медея:212 Medea:Medea:1880-212*" "Sol" #2=
#3_"1880-212*:*Медея:212 Medea:Medea" "Sol" #3=
".:Medea:212 Medea:1880-212*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"212 medea.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	68.06
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.504161399263
		SemiMajorAxis	3.117372060274
		Eccentricity	0.105261598407
		Inclination	4.263689635386
		AscendingNode	313.488474049311
		ArgOfPericenter	100.839585661844
		MeanAnomaly	280.717551236555
	}
	UniformRotation
	{
		Period	10.283
	}
	LunarLambert	0.5
	Albedo	0.0465
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=212"
}

#1_"213 Lilaea:Lilaea:1950 TE3" "Sol" #1=
#2_"*Лилея:213 Lilaea:Lilaea:1880-213*" "Sol" #2=
#3_"1880-213*:*Лилея:213 Lilaea:Lilaea" "Sol" #3=
".:Lilaea:213 Lilaea:1880-213*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	41.505
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.566432881201
		SemiMajorAxis	2.752406559947
		Eccentricity	0.146116691069
		Inclination	6.802833481893
		AscendingNode	122.115693754907
		ArgOfPericenter	162.501780207392
		MeanAnomaly	69.760346604712
	}
	UniformRotation
	{
		Period	8.045
	}
	LunarLambert	0.5
	Albedo	0.0897
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=213"
}

#1_"214 Aschera:Aschera:1947 BP:1948 JE:1949 QG2:1949 SX1:1950 XH:1953 OO:A903 SE" "Sol" #1=
#2_"*Ашера:214 Aschera:Aschera:1880-214*" "Sol" #2=
#3_"1880-214*:*Ашера:214 Aschera:Aschera" "Sol" #3=
".:Aschera:214 Aschera:1880-214*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"214 aschera.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	12.478
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.222582787621
		SemiMajorAxis	2.612441939515
		Eccentricity	0.032108442789
		Inclination	3.436214671541
		AscendingNode	342.000817918338
		ArgOfPericenter	132.869856289044
		MeanAnomaly	25.618624690944
	}
	UniformRotation
	{
		Period	6.835
	}
	LunarLambert	0.5
	Albedo	0.522
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=214"
}

#1_"215 Oenone:Oenone" "Sol" #1=
#2_"*Энона:215 Oenone:Oenone:1880-215*" "Sol" #2=
#3_"1880-215*:*Энона:215 Oenone:Oenone" "Sol" #3=
".:Oenone:215 Oenone:1880-215*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	17.755
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.602355361825
		SemiMajorAxis	2.766822493443
		Eccentricity	0.036428544196
		Inclination	1.685831020161
		AscendingNode	25.008165543117
		ArgOfPericenter	316.507444189367
		MeanAnomaly	321.856098209036
	}
	UniformRotation
	{
		Period	27.937
	}
	LunarLambert	0.5
	Albedo	0.2044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=215"
}

#1_"216 Kleopatra:Kleopatra:A905 OA:A910 RA" "Sol" #1=
#2_"*Клеопатра:216 Kleopatra:Kleopatra:1880-216*" "Sol" #2=
#3_"1880-216*:*Клеопатра:216 Kleopatra:Kleopatra" "Sol" #3=
".:Kleopatra:216 Kleopatra:1880-216*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"216 kleopatra.cmod"
	MeshCenter	[ -3.049 2.379 1.429 ]
	Texture	"kleopatra.jpg"
	Radius	138
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458200.5  # 2018 Mar 23
		Period	4.670567585982
		SemiMajorAxis	2.794093740995
		Eccentricity	0.250873074015
		Inclination	13.113415302806
		AscendingNode	215.358562549286
		ArgOfPericenter	180.111284490109
		MeanAnomaly	346.241182618875
	}
	UniformRotation
	{
		Period	5.385280
		Inclination	63
		AscendingNode	162
	}
	LunarLambert	0.5
	Albedo	0.1164
	InfoURL	"https://en.wikipedia.org/wiki/216_Kleopatra"
}

#1_"Cleoselene:216 Kleopatra II:Kleopatra II:2008 216 II" "Sol/216 Kleopatra" #1=
#2_"*Клеоселена:Cleoselene:216 Kleopatra II:*Клеопатра II:Kleopatra II:2008 216 II" "Sol/216 Kleopatra" #2=
#3_"2008 216 II:*Клеоселена:Cleoselene:216 Kleopatra II:*Клеопатра II:Kleopatra II" "Sol/216 Kleopatra" #3=
".:Cleoselene:216 Kleopatra II:Kleopatra II:2008 216 II" "Sol/216 Kleopatra" #4=

{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"kleopatra.jpg"
	Radius	3.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	1.24
		SemiMajorAxis	454
		Eccentricity	0.0
	}
	LunarLambert	0.5
	Albedo	0.1164
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00216.html"
}

#1_"Alexhelios:216 Kleopatra I:Kleopatra I:2008 216 I" "Sol/216 Kleopatra" #1=
#2_"*Алексгелиос:Alexhelios:216 Kleopatra I:*Клеопатра I:Kleopatra I:2008 216 I" "Sol/216 Kleopatra" #2=
#3_"2008 216 I:*Алексгелиос:Alexhelios:216 Kleopatra I:*Клеопатра I:Kleopatra I" "Sol/216 Kleopatra" #3=
".:Alexhelios:216 Kleopatra I:Kleopatra I:2008 216 I" "Sol/216 Kleopatra" #4=

{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"kleopatra.jpg"
	Radius	4.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	2.32
		SemiMajorAxis	678
		Eccentricity	0.0
	}
	LunarLambert	0.5
	Albedo	0.1164
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00216.html"
}

#1_"217 Eudora:Eudora:A914 RA" "Sol" #1=
#2_"*Эвдора:217 Eudora:Eudora:1880-217*" "Sol" #2=
#3_"1880-217*:*Эвдора:217 Eudora:Eudora" "Sol" #3=
".:Eudora:217 Eudora:1880-217*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.861843467887
		SemiMajorAxis	2.869867503393
		Eccentricity	0.308661999635
		Inclination	10.512675755053
		AscendingNode	162.589241644857
		ArgOfPericenter	155.201679200729
		MeanAnomaly	227.649591614598
	}
	UniformRotation
	{
		Period	25.272
	}
	LunarLambert	0.5
	Albedo	0.0484
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=217"
}

#1_"218 Bianca:Bianca (asteroid)" "Sol" #1=
#2_"*Бианка (астероид):218 Bianca:Bianca (asteroid):1880-218*" "Sol" #2=
#3_"1880-218*:*Бианка (астероид):218 Bianca:Bianca (asteroid)" "Sol" #3=
".:Bianca (asteroid):218 Bianca:1880-218*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"218 bianca.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	30.31
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.35633962613
		SemiMajorAxis	2.667323464934
		Eccentricity	0.116593651797
		Inclination	15.199343382682
		AscendingNode	170.638718967221
		ArgOfPericenter	62.997903854225
		MeanAnomaly	34.407510584999
	}
	UniformRotation
	{
		Period	6.337
	}
	LunarLambert	0.5
	Albedo	0.1746
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=218"
}

#1_"219 Thusnelda:Thusnelda" "Sol" #1=
#2_"*Туснельда:219 Thusnelda:Thusnelda:1880-219*" "Sol" #2=
#3_"1880-219*:*Туснельда:219 Thusnelda:Thusnelda" "Sol" #3=
".:Thusnelda:219 Thusnelda:1880-219*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	20.28
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.611897575972
		SemiMajorAxis	2.354063368789
		Eccentricity	0.222957184958
		Inclination	10.845273088858
		AscendingNode	200.916140537475
		ArgOfPericenter	142.216443905745
		MeanAnomaly	74.996504399494
	}
	UniformRotation
	{
		Period	29.842
	}
	LunarLambert	0.5
	Albedo	0.2009
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=219"
}

#1_"220 Stephania:Stephania:1925 VE:1931 FP:1932 UA:1943 WB:1946 MA:1950 TT4:1961 WB" "Sol" #1=
#2_"*Стефания:220 Stephania:Stephania:1881-2210*" "Sol" #2=
#3_"1881-2210*:*Стефания:220 Stephania:Stephania" "Sol" #3=
".:Stephania:220 Stephania:1881-2210*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"220 stephania.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	15.869
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.597946125844
		SemiMajorAxis	2.347997530994
		Eccentricity	0.258651217778
		Inclination	7.589747865808
		AscendingNode	257.99406440957
		ArgOfPericenter	78.441006514
		MeanAnomaly	325.200650197084
	}
	UniformRotation
	{
		Period	18.198
	}
	LunarLambert	0.5
	Albedo	0.069
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=220"
}

#1_"221 Eos:Eos" "Sol" #1=
#2_"*Эос:221 Eos:Eos:1882-221*" "Sol" #2=
#3_"1882-221*:*Эос:221 Eos:Eos" "Sol" #3=
".:Eos:221 Eos:1882-221*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"221 eos.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	47.734
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.224455761764
		SemiMajorAxis	3.010846184663
		Eccentricity	0.104522872464
		Inclination	10.880280410199
		AscendingNode	141.848709540397
		ArgOfPericenter	193.772119621519
		MeanAnomaly	313.139756657615
	}
	UniformRotation
	{
		Period	10.443
	}
	LunarLambert	0.5
	Albedo	0.166
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=221"
}

#1_"222 Lucia:Lucia:A899 EC:A919 AB" "Sol" #1=
#2_"*Люция:222 Lucia:Lucia:1882-222*" "Sol" #2=
#3_"1882-222*:*Люция:222 Lucia:Lucia" "Sol" #3=
".:Lucia:222 Lucia:1882-222*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"222 lucia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	27.675
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.584306524464
		SemiMajorAxis	3.147560097866
		Eccentricity	0.13233683771
		Inclination	2.150452638285
		AscendingNode	80.243836524863
		ArgOfPericenter	179.993237327012
		MeanAnomaly	244.161344330477
	}
	UniformRotation
	{
		Period	7.8
	}
	LunarLambert	0.5
	Albedo	0.128
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=222"
}

#1_"223 Rosa:Rosa:1942 EL:A887 BA" "Sol" #1=
#2_"*Роза:223 Rosa:Rosa:1882-223*" "Sol" #2=
#3_"1882-223*:*Роза:223 Rosa:Rosa" "Sol" #3=
".:Rosa:223 Rosa:1882-223*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	43.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.448778626173
		SemiMajorAxis	3.09642553991
		Eccentricity	0.116087329341
		Inclination	1.935429239485
		AscendingNode	47.9368615188
		ArgOfPericenter	61.584426010626
		MeanAnomaly	201.175468964376
	}
	UniformRotation
	{
		Period	20.283
	}
	LunarLambert	0.5
	Albedo	0.0309
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=223"
}

#1_"224 Oceana:Oceana:1933 HO:A899 EA" "Sol" #1=
#2_"*Океана:224 Oceana:Oceana:1882-224*" "Sol" #2=
#3_"1882-224*:*Океана:224 Oceana:Oceana" "Sol" #3=
".:Oceana:224 Oceana:1933 HO:1882-224*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	30.91
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.307167736557
		SemiMajorAxis	2.647214025906
		Eccentricity	0.043200878653
		Inclination	5.840233014238
		AscendingNode	352.823840598978
		ArgOfPericenter	282.991376656754
		MeanAnomaly	225.406703553621
	}
	UniformRotation
	{
		Period	9.401
	}
	LunarLambert	0.5
	Albedo	0.1694
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=224"
}

#1_"225 Henrietta:Henrietta" "Sol" #1=
#2_"*Генриетта:225 Henrietta:Henrietta:1882-225*" "Sol" #2=
#3_"1882-225*:*Генриетта:225 Henrietta:Henrietta" "Sol" #3=
".:Henrietta:225 Henrietta:1882-225*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	60.245
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.243547465417
		SemiMajorAxis	3.390643610596
		Eccentricity	0.263940424094
		Inclination	20.870572440663
		AscendingNode	197.1073974272
		ArgOfPericenter	104.268829703991
		MeanAnomaly	64.247564645097
	}
	UniformRotation
	{
		Period	7.3556
	}
	LunarLambert	0.5
	Albedo	0.0396
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=225"
}

#1_"226 Weringia:Weringia:A912 CC" "Sol" #1=
#2_"*Верингия:226 Weringia:Weringia:1882-226*" "Sol" #2=
#3_"1882-226*:*Верингия:226 Weringia:Weringia" "Sol" #3=
".:Weringia:226 Weringia:1882-226*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"226 weringia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	15.747
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.472044604787
		SemiMajorAxis	2.714346475995
		Eccentricity	0.202837285371
		Inclination	15.966226632889
		AscendingNode	134.9729458363
		ArgOfPericenter	153.878611030713
		MeanAnomaly	242.748382619546
	}
	UniformRotation
	{
		Period	11.147
	}
	LunarLambert	0.5
	Albedo	0.352
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=226"
}

#1_"227 Philosophia:Philosophia:1933 SD1:1949 OO1:A919 AA" "Sol" #1=
#2_"*Философия:227 Philosophia:Philosophia:1882-227*" "Sol" #2=
#3_"1882-227*:*Философия:227 Philosophia:Philosophia" "Sol" #3=
".:Philosophia:227 Philosophia:1882-227*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	43.655
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.624620476694
		SemiMajorAxis	3.162690404074
		Eccentricity	0.190573854136
		Inclination	9.154464659076
		AscendingNode	326.253821482462
		ArgOfPericenter	266.910758241965
		MeanAnomaly	326.225336009175
	}
	UniformRotation
	{
		Period	18.048
	}
	LunarLambert	0.5
	Albedo	0.0768
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=227"
}

#1_"228 Agathe:Agathe" "Sol" #1=
#2_"*Агата:228 Agathe:Agathe:1882-228*" "Sol" #2=
#3_"1882-228*:*Агата:228 Agathe:Agathe" "Sol" #3=
".:Agathe:228 Agathe:1882-228*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.268197325109
		SemiMajorAxis	2.202250473122
		Eccentricity	0.241591114626
		Inclination	2.537142178974
		AscendingNode	313.371835347818
		ArgOfPericenter	19.023117873746
		MeanAnomaly	178.110142658951
	}
	UniformRotation
	{
		Period	6.484
	}
	LunarLambert	0.5
	Albedo	0.2082
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=228"
}

#1_"229 Adelinda:Adelinda:1946 UK:1981 GU1:A908 UG" "Sol" #1=
#2_"*Аделинда:229 Adelinda:Adelinda:1882-229*" "Sol" #2=
#3_"1882-229*:*Аделинда:229 Adelinda:Adelinda" "Sol" #3=
".:Adelinda:229 Adelinda:1882-229*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	46.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.334252415397
		SemiMajorAxis	3.423403646748
		Eccentricity	0.139353336705
		Inclination	2.078599207901
		AscendingNode	28.05320186463
		ArgOfPericenter	311.458166380424
		MeanAnomaly	344.46686390041
	}
	UniformRotation
	{
		Period	6.6
	}
	LunarLambert	0.5
	Albedo	0.0453
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=229"
}

#1_"230 Athamantis:Athamantis:1949 WG" "Sol" #1=
#2_"*Афаманта:230 Athamantis:Athamantis:1882-230*" "Sol" #2=
#3_"1882-230*:*Афаманта:230 Athamantis:Athamantis" "Sol" #3=
".:Athamantis:230 Athamantis:1882-230*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"230 athamantis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.883 0.787 ]
	BlendTexture	true
	Radius	55.666
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.677398085735
		SemiMajorAxis	2.382438117685
		Eccentricity	0.061569932381
		Inclination	9.442777482095
		AscendingNode	239.912004418687
		ArgOfPericenter	138.971540192219
		MeanAnomaly	315.476329501063
	}
	UniformRotation
	{
		Period	24.0055
		Inclination	63
		AscendingNode	164
	}
	LunarLambert	0.5
	Albedo	0.164
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=230"
}

#1_"231 Vindobona:Vindobona:1962 UJ" "Sol" #1=
#2_"*Виндобона:231 Vindobona:Vindobona:1882-231*" "Sol" #2=
#3_"1882-231*:*Виндобона:231 Vindobona:Vindobona" "Sol" #3=
".:Vindobona:231 Vindobona:1882-231*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	41.165
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.006905158573
		SemiMajorAxis	2.926672376644
		Eccentricity	0.151765337776
		Inclination	5.099413359063
		AscendingNode	350.547331576028
		ArgOfPericenter	268.104692390465
		MeanAnomaly	254.871060126293
	}
	UniformRotation
	{
		Period	14.245
	}
	LunarLambert	0.5
	Albedo	0.0545
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=231"
}

#1_"232 Russia:Russia:1929 QA:1954 SV:1970 SN1:A921 UA" "Sol" #1=
#2_"*Россия:232 Russia:Russia:1883-232*" "Sol" #2=
#3_"1883-232*:*Россия:232 Russia:Russia" "Sol" #3=
".:Russia:232 Russia:1883-232*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.0794392401995
		SemiMajorAxis	2.553062879536818
		Eccentricity	0.1743242336604184
		Inclination	6.065613948206127
		AscendingNode	152.2523113364647
		ArgOfPericenter	52.10456749218241
		MeanAnomaly	68.80594216454352
	}
	UniformRotation
	{
		Period	21.91
	}
	LunarLambert	0.5
	Albedo	0.0494
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=232"
}

#1_"233 Asterope:Asterope (asteroid)" "Sol" #1=
#2_"*Астеропа (астероид):233 Asterope:Asterope (asteroid):1883-233*" "Sol" #2=
#3_"1883-233*:*Астеропа (астероид):233 Asterope:Asterope (asteroid)" "Sol" #3=
".:Asterope (asteroid):233 Asterope:1883-233*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"233 asterope.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	49.836
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.344018307646
		SemiMajorAxis	2.662291648228
		Eccentricity	0.099285001837
		Inclination	7.688777340916
		AscendingNode	221.974556646502
		ArgOfPericenter	125.41605526445
		MeanAnomaly	229.29492700717
	}
	UniformRotation
	{
		Period	19.7
	}
	LunarLambert	0.5
	Albedo	0.094
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=233"
}

#1_"234 Barbara:Barbara:1942 RL1:1953 RE:1975 XP" "Sol" #1=
#2_"*Барбара:234 Barbara:Barbara:1883-234*" "Sol" #2=
#3_"1883-234*:*Барбара:234 Barbara:Barbara" "Sol" #3=
".:Barbara:234 Barbara:1883-234*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"234 barbara.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	22.738
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.684033856554
		SemiMajorAxis	2.385303288873
		Eccentricity	0.245368691171
		Inclination	15.374791099949
		AscendingNode	144.5534018632
		ArgOfPericenter	192.361591318956
		MeanAnomaly	216.379114205098
	}
	UniformRotation
	{
		Period	26.4744
	}
	LunarLambert	0.5
	Albedo	0.205
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=234"
}

#1_"235 Carolina:Carolina:1934 GY:1939 GN:1956 VK:A909 GJ" "Sol" #1=
#2_"*Каролина:235 Carolina:Carolina:1883-235*" "Sol" #2=
#3_"1883-235*:*Каролина:235 Carolina:Carolina" "Sol" #3=
".:Carolina:235 Carolina:1883-235*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	28.79
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.892278279893
		SemiMajorAxis	2.881831826986
		Eccentricity	0.063105518027
		Inclination	9.028570650428
		AscendingNode	66.042448908827
		ArgOfPericenter	209.711693458277
		MeanAnomaly	56.792711368681
	}
	UniformRotation
	{
		Period	17.61
	}
	LunarLambert	0.5
	Albedo	0.158
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=235"
}

#1_"236 Honoria:Honoria:1930 KK:1953 GJ1:A904 PA1*" "Sol" #1=
#2_"*Гонория:236 Honoria:Honoria:1884-236*" "Sol" #2=
#3_"1884-236*:*Гонория:236 Honoria:Honoria" "Sol" #3=
".:Honoria:236 Honoria:1884-236*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	43.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.682464846017
		SemiMajorAxis	2.798836628209
		Eccentricity	0.18977038897
		Inclination	7.69161748284
		AscendingNode	185.86189308834
		ArgOfPericenter	174.916936706089
		MeanAnomaly	168.112921196489
	}
	UniformRotation
	{
		Period	12.333
	}
	LunarLambert	0.5
	Albedo	0.1271
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=236"
}

#1_"237 Coelestina:Coelestina" "Sol" #1=
#2_"*Целестина:237 Coelestina:Coelestina:1884-237*" "Sol" #2=
#3_"1884-237*:*Целестина:237 Coelestina:Coelestina" "Sol" #3=
".:Coelestina:237 Coelestina:1884-237*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"237 coelestina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	20.54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.589836342114
		SemiMajorAxis	2.761802798829
		Eccentricity	0.073128346629
		Inclination	9.74815303265
		AscendingNode	84.364791278702
		ArgOfPericenter	199.437172238484
		MeanAnomaly	124.273377014526
	}
	UniformRotation
	{
		Period	29.215
	}
	LunarLambert	0.5
	Albedo	0.2108
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=237"
}

#1_"238 Hypatia:Hypatia:1947 HA" "Sol" #1=
#2_"*Гипатия:238 Hypatia:Hypatia:1884-238*" "Sol" #2=
#3_"1884-238*:*Гипатия:238 Hypatia:Hypatia" "Sol" #3=
".:Hypatia:238 Hypatia:1947 HA:1884-238*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	74.245
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.958098649527
		SemiMajorAxis	2.907622187211
		Eccentricity	0.086568486779
		Inclination	12.392520870183
		AscendingNode	183.944750706343
		ArgOfPericenter	209.93857398961
		MeanAnomaly	51.734963263057
	}
	UniformRotation
	{
		Period	8.8745
	}
	LunarLambert	0.5
	Albedo	0.0428
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=238"
}

#1_"239 Adrastea:Adrastea (asteroid):1955 MK1:1956 UJ:A915 TD" "Sol" #1=
#2_"*Адрастея (астероид):239 Adrastea:Adrastea (asteroid):1884-239*" "Sol" #2=
#3_"1884-239*:*Адрастея (астероид):239 Adrastea:Adrastea (asteroid)" "Sol" #3=
".:Adrastea (asteroid):239 Adrastea:1884-239*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"239 adrastea.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	18.804
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.114582404385
		SemiMajorAxis	2.968483586609
		Eccentricity	0.234026237171
		Inclination	6.171164461043
		AscendingNode	180.631060612199
		ArgOfPericenter	210.309640028834
		MeanAnomaly	117.696703142092
	}
	UniformRotation
	{
		Period	18.4707
	}
	LunarLambert	0.5
	Albedo	0.095
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=239"
}

#1_"240 Vanadis:Vanadis" "Sol" #1=
#2_"*Ванадида:240 Vanadis:Vanadis:1884-240*" "Sol" #2=
#3_"1884-240*:*Ванадида:240 Vanadis:Vanadis" "Sol" #3=
".:Vanadis:240 Vanadis:1884-240*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	51.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.352895975221
		SemiMajorAxis	2.665917614726
		Eccentricity	0.205712525198
		Inclination	2.104334525175
		AscendingNode	115.192114490021
		ArgOfPericenter	300.097433235267
		MeanAnomaly	284.702833808281
	}
	UniformRotation
	{
		Period	10.64
	}
	LunarLambert	0.5
	Albedo	0.0411
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=240"
}

#1_"241 Germania:Germania:1953 US:1953 VK1" "Sol" #1=
#2_"*Германия:241 Germania:Germania:1884-241*" "Sol" #2=
#3_"1884-241*:*Германия:241 Germania:Germania" "Sol" #3=
".:Germania:241 Germania:1884-241*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	84.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.33111127323
		SemiMajorAxis	3.051684956149
		Eccentricity	0.100893420722
		Inclination	5.504385437279
		AscendingNode	270.421022823115
		ArgOfPericenter	80.495779848718
		MeanAnomaly	166.958539843501
	}
	UniformRotation
	{
		Period	15.51
	}
	LunarLambert	0.5
	Albedo	0.0575
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=241"
}

#1_"242 Kriemhild:Kriemhild" "Sol" #1=
#2_"*Кримхильда:242 Kriemhild:Kriemhild:1884-242*" "Sol" #2=
#3_"1884-242*:*Кримхильда:242 Kriemhild:Kriemhild" "Sol" #3=
".:Kriemhild:242 Kriemhild:1884-242*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"242 kriemhild.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	20.401
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.844740108305
		SemiMajorAxis	2.863132993454
		Eccentricity	0.11932218408
		Inclination	11.349015734554
		AscendingNode	206.941553295552
		ArgOfPericenter	279.546078415347
		MeanAnomaly	229.112138092971
	}
	UniformRotation
	{
		Period	4.5478
	}
	LunarLambert	0.5
	Albedo	0.222
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=242"
}

#1_"243 Ida:Ida:1988 DB1:A910 CD" "Sol" #1=
#2_"*Ида:243 Ida:Ida:1884-243*" "Sol" #2=
#3_"1884-243*:*Ида:243 Ida:Ida" "Sol" #3=
".:Ida:243 Ida:1988 DB1:1884-243*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"243 ida.cmod"
	MeshCenter	[ -1.424 -0.417 0.115 ]
	Texture	"ida.jpg"
	Radius	29.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2449227.5  # 1993 Aug 28
		Period	4.8462685261763
		SemiMajorAxis	2.863735135636234
		Eccentricity	0.04310710055698948
		Inclination	1.137110894899130
		AscendingNode	324.5866431229683
		ArgOfPericenter	113.0166231618901
		MeanAnomaly	131.4933081625327
	}
	UniformRotation
	{
		Period	4.633632
		Inclination	156.96
		AscendingNode	352.77
		MeridianAngle	359.46
	}
	LunarLambert	0.5
	Albedo	0.2383
	InfoURL	"https://en.wikipedia.org/wiki/243_Ida"
}

AltSurface "Limit of knowledge" "Sol/243 Ida"
{
	Texture	"idamosaic.jpg"
	Color	[ 0.68 0.61 0.52 ]
	BlendTexture	true
	LunarLambert	0.5
}

#1_"Dactyl:243 Ida I:Ida I:1993 243 I" "Sol/243 Ida" #1=
#2_"*Дактиль:Dactyl:243 Ida I:*Ида I:Ida I:1993 243 I" "Sol/243 Ida" #2=
#3_"1993 243 I:*Дактиль:Dactyl:243 Ida I:*Ида I:Ida I" "Sol/243 Ida" #3=
".:Dactyl:243 Ida I:Ida I:1993 243 I" "Sol/243 Ida" #4=

{
	Class	"moon"
	Mesh	"dactyl.cmod"
	Texture	"dactyl.jpg"
	Radius	0.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2449228.2028  # 1993 Aug 28 16:52:02
		Period	0.96534
		SemiMajorAxis	83.5
		Eccentricity	0.13
		Inclination	8.0
		AscendingNode	90.0
		ArgOfPericenter	310.0
	}
	UniformRotation
	{
		MeridianAngle	123
	}
	LunarLambert	0.5
	Albedo	0.21
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00243.html"
}

#1_"244 Sita:Sita:1957 KT:1976 HY:1979 FL3:A900 UA" "Sol" #1=
#2_"*Сита:244 Sita:Sita:1884-244*" "Sol" #2=
#3_"1884-244*:*Сита:244 Sita:Sita" "Sol" #3=
".:Sita:244 Sita:1884-244*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"gaspra.jpg"
	Radius	5.475
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.205779982259
		SemiMajorAxis	2.174120813269
		Eccentricity	0.13765782998
		Inclination	2.844115158459
		AscendingNode	208.99160389493
		ArgOfPericenter	166.130196001493
		MeanAnomaly	221.83508383199
	}
	UniformRotation
	{
		Period	129.51
	}
	LunarLambert	0.5
	Albedo	0.1941
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=244"
}

#1_"245 Vera:Vera:A919 HB" "Sol" #1=
#2_"*Вера:245 Vera:Vera:1885-245*" "Sol" #2=
#3_"1885-245*:*Вера:245 Vera:Vera" "Sol" #3=
".:Vera:245 Vera:1919 HB:1885-245*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"245 vera.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	37.974
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.455850687034
		SemiMajorAxis	3.099104228979
		Eccentricity	0.193555967204
		Inclination	5.159265884564
		AscendingNode	61.403665089608
		ArgOfPericenter	328.972094468747
		MeanAnomaly	13.270891996665
	}
	UniformRotation
	{
		Period	14.38
	}
	LunarLambert	0.5
	Albedo	0.228
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=245"
}

#1_"246 Asporina:Asporina" "Sol" #1=
#2_"*Аспорина:246 Asporina:Asporina:1885-246*" "Sol" #2=
#3_"1885-246*:*Аспорина:246 Asporina:Asporina" "Sol" #3=
".:Asporina:246 Asporina:1885-246*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"246 asporina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	25.446
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.422875905716
		SemiMajorAxis	2.694414258618
		Eccentricity	0.109482032097
		Inclination	15.624950215954
		AscendingNode	162.348744327594
		ArgOfPericenter	96.748390159233
		MeanAnomaly	38.574544714857
	}
	UniformRotation
	{
		Period	16.222
	}
	LunarLambert	0.5
	Albedo	0.193
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=246"
}

#1_"247 Eukrate:Eukrate:1947 TA:1960 TC:A901 TB" "Sol" #1=
#2_"*Эвкрата:247 Eukrate:Eukrate:1885-247*" "Sol" #2=
#3_"1885-247*:*Эвкрата:247 Eukrate:Eukrate" "Sol" #3=
".:Eukrate:247 Eukrate:1885-247*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"247 eukrate.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	65.468
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.541611492379
		SemiMajorAxis	2.742423480161
		Eccentricity	0.242587537562
		Inclination	24.98877603862
		AscendingNode	0.165711313034
		ArgOfPericenter	54.836878544719
		MeanAnomaly	305.889197468171
	}
	UniformRotation
	{
		Period	12.093
	}
	LunarLambert	0.5
	Albedo	0.064
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=247"
}

#1_"248 Lameia:Lameia:1959 LO" "Sol" #1=
#2_"*Ламия:248 Lameia:Lameia:1885-248*" "Sol" #2=
#3_"1885-248*:*Ламия:248 Lameia:Lameia" "Sol" #3=
".:Lameia:248 Lameia:1885-248*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.883152228094
		SemiMajorAxis	2.470495929193
		Eccentricity	0.066744218218
		Inclination	4.058492190454
		AscendingNode	246.869657621968
		ArgOfPericenter	11.215984982172
		MeanAnomaly	111.430261573879
	}
	UniformRotation
	{
		Period	12
	}
	LunarLambert	0.5
	Albedo	0.0615
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=248"
}

#1_"249 Ilse:Ilse:1973 PB" "Sol" #1=
#2_"*Ильза:249 Ilse:Ilse:1973 PB:1885-249*" "Sol" #2=
#3_"1885-249*:*Ильза:249 Ilse:Ilse:1973 PB" "Sol" #3=
".:Ilse:249 Ilse:1973 PB:1885-249*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"249 ilse.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	17.415
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.667427776388
		SemiMajorAxis	2.378129928203
		Eccentricity	0.216251341388
		Inclination	9.621429812412
		AscendingNode	334.743428596861
		ArgOfPericenter	42.155832790814
		MeanAnomaly	62.973044334453
	}
	UniformRotation
	{
		Period	84.94
	}
	LunarLambert	0.5
	Albedo	0.0428
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=249"
}

#1_"250 Bettina:Bettina" "Sol" #1=
#2_"*Беттина:250 Bettina:Bettina:1885-250*" "Sol" #2=
#3_"1885-250*:*Беттина:250 Bettina:Bettina" "Sol" #3=
".:Bettina:250 Bettina:Bettina:1885-250*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"250 bettina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.917 0.850 ]
	BlendTexture	true
	Radius	60.498
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.579214247224
		SemiMajorAxis	3.145646319725
		Eccentricity	0.131292346761
		Inclination	12.816090574542
		AscendingNode	23.886290816228
		ArgOfPericenter	76.435134837558
		MeanAnomaly	311.19092398279
	}
	UniformRotation
	{
		Period	5.0545
		Inclination	102
		AscendingNode	12
	}
	LunarLambert	0.5
	Albedo	0.112
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=250"
}

#1_"251 Sophia:Sophia:1950 RH1:1953 FN1:A907 UA" "Sol" #1=
#2_"*София:251 Sophia:Sophia:1885-251*" "Sol" #2=
#3_"1885-251*:*София:251 Sophia:Sophia" "Sol" #3=
".:Sophia:251 Sophia:1950 RH1:1885-251*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.450119273016
		SemiMajorAxis	3.096933426564
		Eccentricity	0.099520143337
		Inclination	10.509927663029
		AscendingNode	156.159870572821
		ArgOfPericenter	285.772146574298
		MeanAnomaly	191.545869469268
	}
	UniformRotation
	{
		Period	20.216
	}
	LunarLambert	0.5
	Albedo	0.2188
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=251"
}

#1_"252 Clementina:Clementina" "Sol" #1=
#2_"*Клементина:252 Clementina:Clementina:1885-252*" "Sol" #2=
#3_"1885-252*:*Клементина:252 Clementina:Clementina" "Sol" #3=
".:Clementina:252 Clementina:1885-252*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.614812599441
		SemiMajorAxis	3.159012727648
		Eccentricity	0.070072322476
		Inclination	10.04359828253
		AscendingNode	202.04917858509
		ArgOfPericenter	155.786010575924
		MeanAnomaly	25.867211301834
	}
	UniformRotation
	{
		Period	10.864
	}
	LunarLambert	0.5
	Albedo	0.0843
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=252"
}

#1_"253 Mathilde:Mathilde:1949 OL1:A915 TN" "Sol" #1=
#2_"*Матильда:253 Mathilde:Mathilde:1885-253*" "Sol" #2=
#3_"1885-253*:*Матильда:253 Mathilde:Mathilde" "Sol" #3=
".:Mathilde:253 Mathilde:1885-253*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"253 mathilde.cmod"
	Texture	"mathilde.jpg"
	Radius	33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.305465902303
		SemiMajorAxis	2.646516674188
		Eccentricity	0.265866219776
		Inclination	6.74113015438
		AscendingNode	179.606846249382
		ArgOfPericenter	157.277981479241
		MeanAnomaly	33.339667571414
	}
	UniformRotation
	{
		Period	417.7
	}
	LunarLambert	0.5
	Albedo	0.0436
	InfoURL	"https://en.wikipedia.org/wiki/253_Mathilde"
}

AltSurface "Limit of knowledge" "Sol/253 Mathilde"
{
	Texture	"mathilde-lok.jpg"
	Color	[ 0.58 0.57 0.59 ]
	BlendTexture	true
	LunarLambert	0.5
}

#1_"254 Augusta:Augusta" "Sol" #1=
#2_"*Августа:254 Augusta:Augusta:1886-254*" "Sol" #2=
#3_"1886-254*:*Августа:254 Augusta:Augusta" "Sol" #3=
".:Augusta:254 Augusta:1886-254*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"254 augusta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.234
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.250533140663
		SemiMajorAxis	2.194308054807
		Eccentricity	0.122258970808
		Inclination	4.512396596266
		AscendingNode	28.498995606821
		ArgOfPericenter	233.138909348707
		MeanAnomaly	159.058664231483
	}
	UniformRotation
	{
		Period	5.8949
	}
	LunarLambert	0.5
	Albedo	0.17
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=254"
}

#1_"255 Oppavia:Oppavia:1938 VC:1938 XC:1945 GD:1951 SG:A904 EC:A924 TA" "Sol" #1=
#2_"*Оппавия:255 Oppavia:Oppavia:1886-255*" "Sol" #2=
#3_"1886-255*:*Оппавия:255 Oppavia:Oppavia" "Sol" #3=
".:Oppavia:255 Oppavia:1886-255*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.552625413202
		SemiMajorAxis	2.746855481138
		Eccentricity	0.077208534249
		Inclination	9.470641655392
		AscendingNode	13.675699866129
		ArgOfPericenter	155.738616834805
		MeanAnomaly	131.517480630005
	}
	UniformRotation
	{
		Period	19.499
	}
	LunarLambert	0.5
	Albedo	0.0374
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=255"
}

#1_"256 Walpurga:Walpurga:1951 VJ" "Sol" #1=
#2_"*Вальпурга:256 Walpurga:Walpurga:1886-256*" "Sol" #2=
#3_"1886-256*:*Вальпурга:256 Walpurga:Walpurga" "Sol" #3=
".:Walpurga:256 Walpurga:1886-256*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.67
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.195903235601
		SemiMajorAxis	2.999866315698
		Eccentricity	0.068423185251
		Inclination	13.310202584885
		AscendingNode	182.999471640141
		ArgOfPericenter	47.078756684496
		MeanAnomaly	237.916784631386
	}
	UniformRotation
	{
		Period	16.664
	}
	LunarLambert	0.5
	Albedo	0.053
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=256"
}

#1_"257 Silesia:Silesia:1929 DD:1952 FL1:1952 HU" "Sol" #1=
#2_"*Силезия:257 Silesia:Silesia:1886-257*" "Sol" #2=
#3_"1886-257*:*Силезия:257 Silesia:Silesia" "Sol" #3=
".:Silesia:257 Silesia:1886-257*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"257 silesia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	36.33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.512910746339
		SemiMajorAxis	3.120674743129
		Eccentricity	0.111998164002
		Inclination	3.634656011794
		AscendingNode	34.368035687868
		ArgOfPericenter	27.502071223384
		MeanAnomaly	283.394707959945
	}
	UniformRotation
	{
		Period	15.7095
	}
	LunarLambert	0.5
	Albedo	0.0545
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=257"
}

#1_"258 Tyche:Tyche (asteroid)" "Sol" #1=
#2_"*Тихея:258 Tyche:Tyche (asteroid):1886-258*" "Sol" #2=
#3_"1886-258*:*Тихея:258 Tyche:Tyche (asteroid)" "Sol" #3=
".:Tyche (asteroid):258 Tyche:1886-258*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"258 tyche.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	32.39
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.229038550358
		SemiMajorAxis	2.615103977045
		Eccentricity	0.204555089223
		Inclination	14.298719260238
		AscendingNode	207.64355227784
		ArgOfPericenter	154.688120466344
		MeanAnomaly	18.452973833811
	}
	UniformRotation
	{
		Period	10.041
	}
	LunarLambert	0.5
	Albedo	0.1676
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=258"
}

#1_"259 Aletheia:Aletheia:1947 LD" "Sol" #1=
#2_"*Алетейя:259 Aletheia:Aletheia:1886-259*" "Sol" #2=
#3_"1886-259*:*Алетейя:259 Aletheia:Aletheia" "Sol" #3=
".:Aletheia:259 Aletheia:1886-259*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	89.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.55087268868
		SemiMajorAxis	3.134984343982
		Eccentricity	0.127574473023
		Inclination	10.814129212724
		AscendingNode	86.869781146457
		ArgOfPericenter	168.08823466632
		MeanAnomaly	35.740260809193
	}
	UniformRotation
	{
		Period	8.143
	}
	LunarLambert	0.5
	Albedo	0.0436
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=259"
}

#1_"260 Huberta:Huberta:A906 VH:A911 ME" "Sol" #1=
#2_"*Губерта:260 Huberta:Huberta:1886-260*" "Sol" #2=
#3_"1886-260*:*Губерта:260 Huberta:Huberta" "Sol" #3=
".:Huberta:260 Huberta:1886-260*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"260 huberta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	50.77
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.396287242364
		SemiMajorAxis	3.445718841034
		Eccentricity	0.115490342006
		Inclination	6.415675387264
		AscendingNode	165.390174232852
		ArgOfPericenter	181.198415731675
		MeanAnomaly	17.91686989044
	}
	UniformRotation
	{
		Period	8.29
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=260"
}

#1_"261 Prymno:Prymno" "Sol" #1=
#2_"*Примно:261 Prymno:Prymno:1886-261*" "Sol" #2=
#3_"1886-261*:*Примно:261 Prymno:Prymno" "Sol" #3=
".:Prymno:261 Prymno:1886-261*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	25.465
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.560082056836
		SemiMajorAxis	2.331495262338
		Eccentricity	0.089134167913
		Inclination	3.636213347804
		AscendingNode	96.66053580719
		ArgOfPericenter	66.145226488768
		MeanAnomaly	229.426484120908
	}
	UniformRotation
	{
		Period	8.002
	}
	LunarLambert	0.5
	Albedo	0.1141
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=261"
}

#1_"263 Dresda:Dresda:1950 XV:1977 PC:A905 OC:A915 RL:1917 BA" "Sol" #1=
#2_"*Дрезда:263 Dresda:Dresda:1886-263*" "Sol" #2=
#3_"1886-263*:*Дрезда:263 Dresda:Dresda" "Sol" #3=
".:Dresda:263 Dresda:1886-263*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"263 dresda.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	11.976
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.904440500575
		SemiMajorAxis	2.88660601282
		Eccentricity	0.075296475062
		Inclination	1.313810699801
		AscendingNode	216.483655460966
		ArgOfPericenter	160.470146632051
		MeanAnomaly	59.922305797309
	}
	UniformRotation
	{
		Period	16.809
	}
	LunarLambert	0.5
	Albedo	0.198
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=263"
}

#1_"264 Libussa:Libussa" "Sol" #1=
#2_"*Либусса:264 Libussa:Libussa:1886-264*" "Sol" #2=
#3_"1886-264*:*Либусса:264 Libussa:Libussa" "Sol" #3=
".:Libussa:264 Libussa:1886-264*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"264 libussa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	31.484
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.679899451702
		SemiMajorAxis	2.79781426419
		Eccentricity	0.136534497407
		Inclination	10.423235989488
		AscendingNode	49.622034720351
		ArgOfPericenter	341.072275944362
		MeanAnomaly	128.223347039687
	}
	UniformRotation
	{
		Period	9.2276
	}
	LunarLambert	0.5
	Albedo	0.187
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=264"
}

#1_"265 Anna:Anna:1933 QN:1933 RC" "Sol" #1=
#2_"*Анна:265 Anna:Anna:1887-265*" "Sol" #2=
#3_"1887-265*:*Анна:265 Anna:Anna" "Sol" #3=
".:Anna:265 Anna:1887-265*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"265 anna.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	11.384
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.766450619146
		SemiMajorAxis	2.420746896572
		Eccentricity	0.267304216709
		Inclination	25.64204766056
		AscendingNode	335.568050682547
		ArgOfPericenter	251.51215418636
		MeanAnomaly	287.940672268352
	}
	UniformRotation
	{
		Period	11.681
	}
	LunarLambert	0.5
	Albedo	0.113
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=265"
}

#1_"266 Aline:Aline" "Sol" #1=
#2_"*Алина:266 Aline:Aline:1887-266*" "Sol" #2=
#3_"1887-266*:*Алина:266 Aline:Aline" "Sol" #3=
".:Aline:266 Aline:1887-266*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	54.545
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.697619477718
		SemiMajorAxis	2.804872265883
		Eccentricity	0.156677629943
		Inclination	13.397288660622
		AscendingNode	235.915149929576
		ArgOfPericenter	150.524389206488
		MeanAnomaly	287.258725509089
	}
	UniformRotation
	{
		Period	13.018
	}
	LunarLambert	0.5
	Albedo	0.0448
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=266"
}

#1_"267 Tirza:Tirza:1965 GC:A922 AA" "Sol" #1=
#2_"*Тирза:267 Tirza:Tirza:1887-267*" "Sol" #2=
#3_"1887-267*:*Тирза:267 Tirza:Tirza" "Sol" #3=
".:Tirza:267 Tirza:1887-267*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.623546240879
		SemiMajorAxis	2.775308945088
		Eccentricity	0.100031508455
		Inclination	6.006407019789
		AscendingNode	73.886989109847
		ArgOfPericenter	195.668979868341
		MeanAnomaly	200.617915812891
	}
	UniformRotation
	{
		Period	7.648
	}
	LunarLambert	0.5
	Albedo	0.0402
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=267"
}

#1_"268 Adorea:Adorea" "Sol" #1=
#2_"*Адорея:268 Adorea:Adorea:1887-268*" "Sol" #2=
#3_"1887-268*:*Адорея:268 Adorea:Adorea" "Sol" #3=
".:Adorea:268 Adorea:1887-268*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	69.945
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.43815870373
		SemiMajorAxis	3.092400847086
		Eccentricity	0.136431549139
		Inclination	2.440095226222
		AscendingNode	120.915004992422
		ArgOfPericenter	69.508334032348
		MeanAnomaly	193.515179786479
	}
	UniformRotation
	{
		Period	7.8
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=268"
}

#1_"269 Justitia:Justitia:1942 XY" "Sol" #1=
#2_"*Юстиция:269 Justitia:Justitia:1887-269*" "Sol" #2=
#3_"1887-269*:*Юстиция:269 Justitia:Justitia" "Sol" #3=
".:Justitia:269 Justitia:1887-269*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.230008698767
		SemiMajorAxis	2.615503901195
		Eccentricity	0.213995325954
		Inclination	5.479800301727
		AscendingNode	156.757676224014
		ArgOfPericenter	119.724940868737
		MeanAnomaly	79.605372679172
	}
	UniformRotation
	{
		Period	16.545
	}
	LunarLambert	0.5
	Albedo	0.0974
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=269"
}

#1_"270 Anahita:Anahita:1926 VG" "Sol" #1=
#2_"*Анахита:270 Anahita:Anahita:1887-270*" "Sol" #2=
#3_"1887-270*:*Анахита:270 Anahita:Anahita" "Sol" #3=
".:Anahita:270 Anahita:1887-270*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"270 anahita.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	25.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.25894334212
		SemiMajorAxis	2.198091357038
		Eccentricity	0.150660690443
		Inclination	2.367533811493
		AscendingNode	254.486166626482
		ArgOfPericenter	80.188607852534
		MeanAnomaly	38.07607776729
	}
	UniformRotation
	{
		Period	15.06
	}
	LunarLambert	0.5
	Albedo	0.211
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=270"
}

#1_"271 Penthesilea:Penthesilea:A916 GG:A916 HA" "Sol" #1=
#2_"*Пентесилея:271 Penthesilea:Penthesilea:1887-271*" "Sol" #2=
#3_"1887-271*:*Пентесилея:271 Penthesilea:Penthesilea" "Sol" #3=
".:Penthesilea:271 Penthesilea:1887-271*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"271 penthesilea.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	32.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.208486257392
		SemiMajorAxis	3.004707586764
		Eccentricity	0.103197737707
		Inclination	3.539666749388
		AscendingNode	335.373486330525
		ArgOfPericenter	58.6306521732
		MeanAnomaly	129.973256972334
	}
	UniformRotation
	{
		Period	18.787
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=271"
}

#1_"272 Antonia:Antonia:1944 FE" "Sol" #1=
#2_"*Антония:272 Antonia:Antonia:1888-272*" "Sol" #2=
#3_"1888-272*:*Антония:272 Antonia:Antonia" "Sol" #3=
".:Antonia:272 Antonia:1888-272*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"272 antonia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.631052509497
		SemiMajorAxis	2.778311918796
		Eccentricity	0.027230220727
		Inclination	4.439233786231
		AscendingNode	37.419439741362
		ArgOfPericenter	63.722756120556
		MeanAnomaly	180.619442747241
	}
	UniformRotation
	{
		Period	3.8548
	}
	LunarLambert	0.5
	Albedo	0.128
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=272"
}

#1_"273 Atropos:Atropos:A910 CC" "Sol" #1=
#2_"*Атропа:273 Atropos:Atropos:1888-273*" "Sol" #2=
#3_"1888-273*:*Атропа:273 Atropos:Atropos" "Sol" #3=
".:Atropos:273 Atropos:1888-273*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.635
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.706605242607
		SemiMajorAxis	2.395036238339
		Eccentricity	0.160097650813
		Inclination	20.453543673965
		AscendingNode	158.960321658952
		ArgOfPericenter	121.233941513177
		MeanAnomaly	328.21987507433
	}
	UniformRotation
	{
		Period	23.924
	}
	LunarLambert	0.5
	Albedo	0.1624
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=273"
}

#1_"274 Philagoria:Philagoria" "Sol" #1=
#2_"*Филагория:274 Philagoria:Philagoria:1888-274*" "Sol" #2=
#3_"1888-274*:*Филагория:274 Philagoria:Philagoria" "Sol" #3=
".:Philagoria:274 Philagoria:1888-274*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"274 philagoria.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.654
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.31898811006
		SemiMajorAxis	3.047056764049
		Eccentricity	0.121065054557
		Inclination	3.678822462989
		AscendingNode	92.850493119466
		ArgOfPericenter	119.145440702961
		MeanAnomaly	294.441494265351
	}
	UniformRotation
	{
		Period	17.938
	}
	LunarLambert	0.5
	Albedo	0.237
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=274"
}

#1_"275 Sapientia:Sapientia:1962 GE:1962 HA:A906 AB" "Sol" #1=
#2_"*Сапиенция:275 Sapientia:Sapientia:1888-275*" "Sol" #2=
#3_"1888-275*:*Сапиенция:275 Sapientia:Sapientia" "Sol" #3=
".:Sapientia:275 Sapientia:1888-275*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	51.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.613979753927
		SemiMajorAxis	2.771479399609
		Eccentricity	0.163071972722
		Inclination	4.764087221585
		AscendingNode	134.099594220024
		ArgOfPericenter	39.925709480507
		MeanAnomaly	172.868062551611
	}
	UniformRotation
	{
		Period	14.766
	}
	LunarLambert	0.5
	Albedo	0.036
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=275"
}

#1_"276 Adelheid:Adelheid" "Sol" #1=
#2_"*Аделаида:276 Adelheid:Adelheid:1888-276*" "Sol" #2=
#3_"1888-276*:*Аделаида:276 Adelheid:Adelheid" "Sol" #3=
".:Adelheid:276 Adelheid:1888-276*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"276 adelheid.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	57.362
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.500077894808
		SemiMajorAxis	3.115830029761
		Eccentricity	0.068595366633
		Inclination	21.615880929746
		AscendingNode	211.182889564318
		ArgOfPericenter	265.094938501484
		MeanAnomaly	97.568682662769
	}
	UniformRotation
	{
		Period	6.315
	}
	LunarLambert	0.5
	Albedo	0.051
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=276"
}

#1_"277 Elvira:Elvira" "Sol" #1=
#2_"*Эльвира:277 Elvira:Elvira:1888-277*" "Sol" #2=
#3_"1888-277*:*Эльвира:277 Elvira:Elvira" "Sol" #3=
".:Elvira:277 Elvira:1888-277*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"277 elvira.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	15.211
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.904286749746
		SemiMajorAxis	2.886545683765
		Eccentricity	0.090499099353
		Inclination	1.161352596262
		AscendingNode	231.334522401062
		ArgOfPericenter	137.60168541075
		MeanAnomaly	145.532936719739
	}
	UniformRotation
	{
		Period	29.69
	}
	LunarLambert	0.5
	Albedo	0.196
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=277"
}

#1_"278 Paulina:Paulina:1959 XF" "Sol" #1=
#2_"*Паулина:278 Paulina:Paulina:1888-278*" "Sol" #2=
#3_"1888-278*:*Паулина:278 Paulina:Paulina" "Sol" #3=
".:Paulina:278 Paulina:1888-278*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"278 paulina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	16.386
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.575042383821
		SemiMajorAxis	2.755865045238
		Eccentricity	0.133057929238
		Inclination	7.818559231307
		AscendingNode	62.075038151561
		ArgOfPericenter	139.652158540537
		MeanAnomaly	275.441797117228
	}
	UniformRotation
	{
		Period	6.497
	}
	LunarLambert	0.5
	Albedo	0.247
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=278"
}

#1_"279 Thule:Thule:1927 EC:1954 FF:A920 GA:A923 RA" "Sol" #1=
#2_"*Туле:279 Thule:Thule:1888-279*" "Sol" #2=
#3_"1888-279*:*Туле:279 Thule:Thule" "Sol" #3=
".:Thule:279 Thule:1888-279*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	63.295
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	8.934927812118
		SemiMajorAxis	4.305813653356
		Eccentricity	0.012398872275
		Inclination	2.330677672531
		AscendingNode	73.579051859481
		ArgOfPericenter	47.636699868593
		MeanAnomaly	351.647002624042
	}
	UniformRotation
	{
		Period	15.962
	}
	LunarLambert	0.5
	Albedo	0.0412
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=279"
}

#1_"280 Philia:Philia" "Sol" #1=
#2_"*Филия:280 Philia:Philia:1888-280*" "Sol" #2=
#3_"1888-280*:*Филия:280 Philia:Philia" "Sol" #3=
".:Philia:280 Philia:1888-280*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.845
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.048116065146
		SemiMajorAxis	2.942709691276
		Eccentricity	0.10693461673
		Inclination	7.445231961803
		AscendingNode	9.916020065714
		ArgOfPericenter	89.771637574018
		MeanAnomaly	295.930681193277
	}
	UniformRotation
	{
		Period	70.26
	}
	LunarLambert	0.5
	Albedo	0.0444
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=280"
}

#1_"281 Lucretia:Lucretia:1948 EK:1984 JX:A906 FD" "Sol" #1=
#2_"*Лукреция:281 Lucretia:Lucretia:1888-281*" "Sol" #2=
#3_"1888-281*:*Лукреция:281 Lucretia:Lucretia" "Sol" #3=
".:Lucretia:281 Lucretia:1888-281*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"281 lucretia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	5.518
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.235884622955
		SemiMajorAxis	2.187710665022
		Eccentricity	0.131830879429
		Inclination	5.302482980196
		AscendingNode	31.435136727138
		ArgOfPericenter	16.594595083224
		MeanAnomaly	339.330552252623
	}
	UniformRotation
	{
		Period	4.348
	}
	LunarLambert	0.5
	Albedo	0.226
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=281"
}

#1_"282 Clorinde:Clorinde:1955 RQ" "Sol" #1=
#2_"*Клоринда:282 Clorinde:Clorinde:1889-282*" "Sol" #2=
#3_"1889-282*:*Клоринда:282 Clorinde:Clorinde" "Sol" #3=
".:Clorinde:282 Clorinde:1889-282*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.515
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.57684622507
		SemiMajorAxis	2.338808758117
		Eccentricity	0.081010347478
		Inclination	9.033252025562
		AscendingNode	144.973751307198
		ArgOfPericenter	296.03224258053
		MeanAnomaly	111.957072440366
	}
	UniformRotation
	{
		Period	6.42
	}
	LunarLambert	0.5
	Albedo	0.0502
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=282"
}

#1_"283 Emma:Emma:1980 FJ12" "Sol" #1=
#2_"*Эмма:283 Emma:Emma:1889-283*" "Sol" #2=
#3_"1889-283*:*Эмма:283 Emma:Emma" "Sol" #3=
".:Emma:283 Emma:1889-283*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"283 emma.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	66.192
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.317431970975
		SemiMajorAxis	3.046462431034
		Eccentricity	0.148267448587
		Inclination	7.993512578157
		AscendingNode	304.370862464012
		ArgOfPericenter	53.611417562499
		MeanAnomaly	15.931438506539
	}
	UniformRotation
	{
		Period	6.896
	}
	LunarLambert	0.5
	Albedo	0.023
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=283"
}

#1_"2003 283 I" "Sol/283 Emma" #1=
#2_"2003 283 I" "Sol/283 Emma" #2=
#3_"2003 283 I" "Sol/283 Emma" #3=
".:2003 283 I" "Sol/283 Emma" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	3.353
		SemiMajorAxis	581
		Eccentricity	0.12
		Inclination	0.0
	}
	LunarLambert	0.5
	Albedo	0.023
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00283.html"
}

#1_"284 Amalia:Amalia" "Sol" #1=
#2_"*Амалия:284 Amalia:Amalia:1889-284*" "Sol" #2=
#3_"1889-284*:*Амалия:284 Amalia:Amalia" "Sol" #3=
".:Amalia:284 Amalia:1889-284*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.475
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.625651215518
		SemiMajorAxis	2.360035562111
		Eccentricity	0.221723248191
		Inclination	8.0546474547
		AscendingNode	233.834975098476
		ArgOfPericenter	57.696217728361
		MeanAnomaly	197.212161805354
	}
	UniformRotation
	{
		Period	8.545
	}
	LunarLambert	0.5
	Albedo	0.0602
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=284"
}

#1_"285 Regina:Regina:1951 AC1:A911 QJ" "Sol" #1=
#2_"*Регина:285 Regina:Regina:1889-285*" "Sol" #2=
#3_"1889-285*:*Регина:285 Regina:Regina" "Sol" #3=
".:Regina:285 Regina:1889-285*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.565
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.417097789671
		SemiMajorAxis	3.084411513068
		Eccentricity	0.207198154928
		Inclination	17.619187525696
		AscendingNode	311.387530187151
		ArgOfPericenter	14.532996250637
		MeanAnomaly	28.020542155669
	}
	UniformRotation
	{
		Period	9.542
	}
	LunarLambert	0.5
	Albedo	0.0547
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=285"
}

#1_"286 Iclea:Iclea" "Sol" #1=
#2_"*Иклея:286 Iclea:Iclea:1889-286*" "Sol" #2=
#3_"1889-286*:*Иклея:286 Iclea:Iclea" "Sol" #3=
".:Iclea:286 Iclea:1889-286*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	47.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.713447392514
		SemiMajorAxis	3.195901265836
		Eccentricity	0.029241426821
		Inclination	17.900988694447
		AscendingNode	149.118376662297
		ArgOfPericenter	214.107579213031
		MeanAnomaly	305.247007712868
	}
	UniformRotation
	{
		Period	15.365
	}
	LunarLambert	0.5
	Albedo	0.0508
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=286"
}

#1_"287 Nephthys:Nephthys" "Sol" #1=
#2_"*Нефтида:287 Nephthys:Nephthys:1889-287*" "Sol" #2=
#3_"1889-287*:*Нефтида:287 Nephthys:Nephthys" "Sol" #3=
".:Nephthys:287 Nephthys:1889-287*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"287 nephthys.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	29.808
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.608589739841
		SemiMajorAxis	2.352625888953
		Eccentricity	0.02300815017
		Inclination	10.034409771788
		AscendingNode	142.383856255947
		ArgOfPericenter	121.091468829328
		MeanAnomaly	321.847400560819
	}
	UniformRotation
	{
		Period	7.605
	}
	LunarLambert	0.5
	Albedo	0.238
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=287"
}

#1_"288 Glauke:Glauke:1955 MO:1959 GB:1961 WF" "Sol" #1=
#2_"*Главка:288 Glauke:Glauke:1890-288*" "Sol" #2=
#3_"1890-288*:*Главка:288 Glauke:Glauke" "Sol" #3=
".:Glauke:288 Glauke:1890-288*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.105
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.588393681645
		SemiMajorAxis	2.761224048713
		Eccentricity	0.204442827324
		Inclination	4.33557707645
		AscendingNode	120.142011219742
		ArgOfPericenter	84.755021440433
		MeanAnomaly	47.459733243382
	}
	UniformRotation
	{
		Period	1200
	}
	LunarLambert	0.5
	Albedo	0.1973
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=288"
}

#1_"289 Nenetta:Nenetta:1949 HF1:A912 RC" "Sol" #1=
#2_"*Ненетта:289 Nenetta:Nenetta:1890-289*" "Sol" #2=
#3_"1890-289*:*Ненетта:289 Nenetta:Nenetta" "Sol" #3=
".:Nenetta:289 Nenetta:1890-289*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.865
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.87221105324
		SemiMajorAxis	2.873945933297
		Eccentricity	0.204739574033
		Inclination	6.694676607981
		AscendingNode	182.116625542465
		ArgOfPericenter	189.155688508712
		MeanAnomaly	342.939111145266
	}
	UniformRotation
	{
		Period	6.902
	}
	LunarLambert	0.5
	Albedo	0.2438
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=289"
}

#1_"290 Bruna:Bruna" "Sol" #1=
#2_"*Бруна:290 Bruna:Bruna:1890-290*" "Sol" #2=
#3_"1890-290*:*Бруна:290 Bruna:Bruna" "Sol" #3=
".:Bruna:290 Bruna:1890-290*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"290 bruna.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.911
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.573596427951
		SemiMajorAxis	2.337391903734
		Eccentricity	0.257466728825
		Inclination	22.332177464961
		AscendingNode	10.500609626407
		ArgOfPericenter	105.072418796734
		MeanAnomaly	61.417918013602
	}
	UniformRotation
	{
		Period	13.807
	}
	LunarLambert	0.5
	Albedo	0.314
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=290"
}

#1_"291 Alice:Alice:1954 UJ3" "Sol" #1=
#2_"*Алиса:291 Alice:Alice:1954 UJ3:1890-291*" "Sol" #2=
#3_"1890-291*:*Алиса:291 Alice:Alice:1954 UJ3" "Sol" #3=
".:Alice:291 Alice:1890-291*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"291 alice.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	9.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.311896739719
		SemiMajorAxis	2.221838000152
		Eccentricity	0.092329968103
		Inclination	1.854805570067
		AscendingNode	161.659468749151
		ArgOfPericenter	331.916871734679
		MeanAnomaly	296.44231993683
	}
	UniformRotation
	{
		Period	4.313
		Inclination	35
	}
	LunarLambert	0.5
	Albedo	0.425
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=291"
}

#1_"292 Ludovica:Ludovica:1930 GM" "Sol" #1=
#2_"*Людовика:292 Ludovica:Ludovica:1890-292*" "Sol" #2=
#3_"1890-292*:*Людовика:292 Ludovica:Ludovica" "Sol" #3=
".:Ludovica:292 Ludovica:1890-292*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.021986428882
		SemiMajorAxis	2.52903553975
		Eccentricity	0.034067328424
		Inclination	14.897763214758
		AscendingNode	43.540999678437
		ArgOfPericenter	287.52505775626
		MeanAnomaly	239.278429815368
	}
	UniformRotation
	{
		Period	8.93
	}
	LunarLambert	0.5
	Albedo	0.2652
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=292"
}

#1_"293 Brasilia:Brasilia:A909 HB" "Sol" #1=
#2_"*Бразилия:293 Brasilia:Brasilia:1890-293*" "Sol" #2=
#3_"1890-293*:*Бразилия:293 Brasilia:Brasilia" "Sol" #3=
".:Brasilia:293 Brasilia:1890-293*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"293 brasilia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	28.743
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.841354452525
		SemiMajorAxis	2.861798940174
		Eccentricity	0.107584910808
		Inclination	15.581331592083
		AscendingNode	61.3604370025
		ArgOfPericenter	87.079056744379
		MeanAnomaly	345.476849434575
	}
	UniformRotation
	{
		Period	8.17
	}
	LunarLambert	0.5
	Albedo	0.056
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=293"
}

#1_"294 Felicia:Felicia:1926 AG:1929 NE:1951 PA:1973 KD:A913 VA" "Sol" #1=
#2_"*Фелиция:294 Felicia:Felicia:1890-294*" "Sol" #2=
#3_"1890-294*:*Фелиция:294 Felicia:Felicia" "Sol" #3=
".:Felicia:294 Felicia:1890-294*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.485
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.581055512596
		SemiMajorAxis	3.146338370714
		Eccentricity	0.24009069759
		Inclination	6.29218963873
		AscendingNode	136.023942976146
		ArgOfPericenter	185.022194461787
		MeanAnomaly	109.50409709331
	}
	UniformRotation
	{
		Period	10.4227
	}
	LunarLambert	0.5
	Albedo	0.091
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=294"
}

#1_"295 Theresia:Theresia" "Sol" #1=
#2_"*Терезия:295 Theresia:Theresia:1890-295*" "Sol" #2=
#3_"1890-295*:*Терезия:295 Theresia:Theresia" "Sol" #3=
".:Theresia:295 Theresia:1890-295*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.86
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.670061123322
		SemiMajorAxis	2.793891748453
		Eccentricity	0.172349841608
		Inclination	2.708988885331
		AscendingNode	276.056193655586
		ArgOfPericenter	148.105085322692
		MeanAnomaly	140.030530039651
	}
	UniformRotation
	{
		Period	10.73
	}
	LunarLambert	0.5
	Albedo	0.193
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=295"
}

#1_"296 Phaetusa:Phaetusa:1930 YH:A917 XB" "Sol" #1=
#2_"*Фаэтуса:296 Phaetusa:Phaetusa:1890-296*" "Sol" #2=
#3_"1890-296*:Phaetusa:*Фаэтуса:296 Phaetusa" "Sol" #3=
".:Phaetusa:296 Phaetusa:1890-296*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"296 phaetusa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.098
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.327178279908
		SemiMajorAxis	2.228667329296
		Eccentricity	0.160788867684
		Inclination	1.747370687115
		AscendingNode	121.585178227645
		ArgOfPericenter	252.600157600482
		MeanAnomaly	331.790444799016
	}
	UniformRotation
	{
		Period	4.5385
	}
	LunarLambert	0.5
	Albedo	0.379
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=296"
}

#1_"297 Caecilia:Caecilia:1935 PB:1947 SB:1955 BK1:A924 RA" "Sol" #1=
#2_"*Цецилия:297 Caecilia:Caecilia:1890-297*" "Sol" #2=
#3_"1890-297*:*Цецилия:297 Caecilia:Caecilia" "Sol" #3=
".:Caecilia:297 Caecilia:1890-297*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"297 caecilia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	19.74
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.630965221404
		SemiMajorAxis	3.165068365109
		Eccentricity	0.142940890242
		Inclination	7.552509823629
		AscendingNode	332.108381100206
		ArgOfPericenter	354.325107873948
		MeanAnomaly	11.476759278493
	}
	UniformRotation
	{
		Period	4.163
	}
	LunarLambert	0.5
	Albedo	0.1796
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=297"
}

#1_"299 Thora:Thora:1935 PC:1939 PK" "Sol" #1=
#2_"*Тора:299 Thora:Thora:1890-299*" "Sol" #2=
#3_"1890-299*:*Тора:299 Thora:Thora" "Sol" #3=
".:Thora:299 Thora:1890-299*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.53
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.797664141464
		SemiMajorAxis	2.434102716731
		Eccentricity	0.062404125574
		Inclination	1.60363595784
		AscendingNode	241.550364551558
		ArgOfPericenter	150.795659487068
		MeanAnomaly	245.068247435193
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1673
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=299"
}

#1_"300 Geraldina:Geraldina:1933 BV:1950 DV:1953 PJ:1953 RO1:1961 AD:A923 LB" "Sol" #1=
#2_"*Джеральдина:300 Geraldina:Geraldina:1890-300*" "Sol" #2=
#3_"1890-300*:*Джеральдина:300 Geraldina:Geraldina" "Sol" #3=
".:Geraldina:300 Geraldina:1890-300*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.09
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.734727591364
		SemiMajorAxis	3.203831943731
		Eccentricity	0.056787893337
		Inclination	0.73238616958
		AscendingNode	42.666852772132
		ArgOfPericenter	326.228115511953
		MeanAnomaly	209.088863723025
	}
	UniformRotation
	{
		Period	6.8423
	}
	LunarLambert	0.5
	Albedo	0.0397
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=300"
}

#1_"301 Bavaria:Bavaria:1928 DH1:1951 FD:1952 OF" "Sol" #1=
#2_"*Бавария:301 Bavaria:Bavaria:1890-301*" "Sol" #2=
#3_"1890-301*:*Бавария:301 Bavaria:Bavaria" "Sol" #3=
".:Bavaria:301 Bavaria:1890-301*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.16
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.498017170549
		SemiMajorAxis	2.724845846244
		Eccentricity	0.066289792391
		Inclination	4.894687684868
		AscendingNode	142.376585518961
		ArgOfPericenter	125.547284760113
		MeanAnomaly	344.494689298773
	}
	UniformRotation
	{
		Period	12.253
	}
	LunarLambert	0.5
	Albedo	0.0546
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=301"
}

#1_"302 Clarissa:Clarissa:1929 CK1:1946 UN:1948 ED:1953 NN:A909 YA" "Sol" #1=
#2_"*Кларисса:302 Clarissa:Clarissa:1890-302*" "Sol" #2=
#3_"1890-302*:*Кларисса:302 Clarissa:Clarissa" "Sol" #3=
".:Clarissa:302 Clarissa:1890-302*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"302 clarissa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	19.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.733302260112
		SemiMajorAxis	2.406522726071
		Eccentricity	0.111279073194
		Inclination	3.412723228878
		AscendingNode	7.868676920054
		ArgOfPericenter	54.906946341471
		MeanAnomaly	55.000258112176
	}
	UniformRotation
	{
		Period	14.381
	}
	LunarLambert	0.5
	Albedo	0.0524
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=302"
}

#1_"303 Josephina:Josephina:1948 MA:1974 KC" "Sol" #1=
#2_"*Жозефина:303 Josephina:Josephina:1891-303*" "Sol" #2=
#3_"1891-303*:*Жозефина:303 Josephina:Josephina" "Sol" #3=
".:Josephina:303 Josephina:1891-303*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	49.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.520647916677
		SemiMajorAxis	3.123593896473
		Eccentricity	0.062319347785
		Inclination	6.872703527755
		AscendingNode	344.005648504716
		ArgOfPericenter	64.161954860271
		MeanAnomaly	250.018478455019
	}
	UniformRotation
	{
		Period	12.497
	}
	LunarLambert	0.5
	Albedo	0.0594
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=303"
}

#1_"304 Olga:Olga:1952 SJ" "Sol" #1=
#2_"*Ольга:304 Olga:Olga:1891-304*" "Sol" #2=
#3_"1891-304*:*Ольга:304 Olga:Olga" "Sol" #3=
".:Olga:304 Olga:1891-304*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.93
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.72414997115
		SemiMajorAxis	2.402588014674
		Eccentricity	0.222290310996
		Inclination	15.853111173003
		AscendingNode	159.083111843203
		ArgOfPericenter	172.49730882067
		MeanAnomaly	264.781493135843
	}
	UniformRotation
	{
		Period	18.36
	}
	LunarLambert	0.5
	Albedo	0.0488
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=304"
}

#1_"305 Gordonia:Gordonia:1938 SC1:1970 SP1" "Sol" #1=
#2_"*Гордония:305 Gordonia:Gordonia:1891-305*" "Sol" #2=
#3_"1891-305*:*Гордония:305 Gordonia:Gordonia" "Sol" #3=
".:Gordonia:305 Gordonia:1891-305*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	24.585
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.437058638424
		SemiMajorAxis	3.09198379936
		Eccentricity	0.192528570121
		Inclination	4.442554402412
		AscendingNode	207.520158143376
		ArgOfPericenter	261.207230654845
		MeanAnomaly	294.420811837699
	}
	UniformRotation
	{
		Period	16.2
	}
	LunarLambert	0.5
	Albedo	0.2269
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=305"
}

#1_"306 Unitas:Unitas" "Sol" #1=
#2_"*Юнитас:306 Unitas:Unitas:1891-306*" "Sol" #2=
#3_"1891-306*:*Юнитас:306 Unitas:Unitas" "Sol" #3=
".:Unitas:306 Unitas:1891-306*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"306 unitas.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	23.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.620094685852
		SemiMajorAxis	2.357623681011
		Eccentricity	0.151218890935
		Inclination	7.277961101266
		AscendingNode	141.914625575334
		ArgOfPericenter	168.10829982405
		MeanAnomaly	285.553567027782
	}
	UniformRotation
	{
		Period	8.736
	}
	LunarLambert	0.5
	Albedo	0.201
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=306"
}

#1_"307 Nike:Nike:1957 LM" "Sol" #1=
#2_"*Ника:307 Nike:Nike:1891-307*" "Sol" #2=
#3_"1891-307*:*Ника:307 Nike:Nike" "Sol" #3=
".:Nike:307 Nike:1891-307*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	30.6565
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2441653.5  # 1972 Dec 02
		Period	4.9736568552429
		SemiMajorAxis	2.913701635749875
		Eccentricity	0.1387528455725211
		Inclination	6.123277549641921
		AscendingNode	101.6878806760241
		ArgOfPericenter	322.3432217293508
		MeanAnomaly	244.8987630938351
	}
	UniformRotation
	{
		Period	11.857
	}
	LunarLambert	0.5
	Albedo	0.043
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=307"
}

#1_"308 Polyxo:Polyxo:1950 FQ" "Sol" #1=
#2_"*Поликсо:308 Polyxo:Polyxo:1891-308*" "Sol" #2=
#3_"1891-308*:*Поликсо:308 Polyxo:Polyxo" "Sol" #3=
".:Polyxo:308 Polyxo:1891-308*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	70.345
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.557629682576
		SemiMajorAxis	2.74886801771
		Eccentricity	0.039665765047
		Inclination	4.361079353183
		AscendingNode	181.737097745656
		ArgOfPericenter	115.814422380362
		MeanAnomaly	300.402081634766
	}
	UniformRotation
	{
		Period	12.032
	}
	LunarLambert	0.5
	Albedo	0.0482
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=308"
}

#1_"309 Fraternitas:Fraternitas:1925 BC:1927 RA:1943 FB:1974 LB:A914 TE" "Sol" #1=
#2_"*Фратернитас:309 Fraternitas:Fraternitas:1891-309*" "Sol" #2=
#3_"1891-309*:*Фратернитас:309 Fraternitas:Fraternitas" "Sol" #3=
".:Fraternitas:309 Fraternitas:1891-309*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.66
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.349354458287
		SemiMajorAxis	2.66447142455
		Eccentricity	0.11548997699
		Inclination	3.720008442756
		AscendingNode	356.572644448892
		ArgOfPericenter	310.625119908351
		MeanAnomaly	54.140756550665
	}
	UniformRotation
	{
		Period	13.2
	}
	LunarLambert	0.5
	Albedo	0.0595
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=309"
}

#1_"310 Margarita:Margarita:A920 TB" "Sol" #1=
#2_"*Маргарита (астероид):310 Margarita:Margarita:1891-310*" "Sol" #2=
#3_"1891-310*:*Маргарита (астероид):310 Margarita:Margarita" "Sol" #3=
".:Margarita:310 Margarita:1891-310*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"310 margarita.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	16.854
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.589733617082
		SemiMajorAxis	2.761761590774
		Eccentricity	0.113344552208
		Inclination	3.171680794657
		AscendingNode	229.294679795384
		ArgOfPericenter	324.400132986534
		MeanAnomaly	9.40559005917
	}
	UniformRotation
	{
		Period	12.07
	}
	LunarLambert	0.5
	Albedo	0.115
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=310"
}

#1_"311 Claudia:Claudia:1927 YA:A902 RA:A905 EA" "Sol" #1=
#2_"*Клавдия:311 Claudia:Claudia:1891-311*" "Sol" #2=
#3_"1891-311*:*Клавдия:311 Claudia:Claudia" "Sol" #3=
".:Claudia:311 Claudia:1891-311*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"311 claudia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	13.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.93302725573
		SemiMajorAxis	2.897812013151
		Eccentricity	0.002593549894
		Inclination	3.227192366854
		AscendingNode	81.02307362428
		ArgOfPericenter	43.90168278556
		MeanAnomaly	147.809435698101
	}
	UniformRotation
	{
		Period	7.532
	}
	LunarLambert	0.5
	Albedo	0.322
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=311"
}

#1_"312 Pierretta:Pierretta" "Sol" #1=
#2_"*Пирретта:312 Pierretta:Pierretta:1891-312*" "Sol" #2=
#3_"1891-312*:*Пирретта:312 Pierretta:Pierretta" "Sol" #3=
".:Pierretta:312 Pierretta:Pierretta:1891-312*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"312 pierretta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	23.096
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.643845772818
		SemiMajorAxis	2.783426282623
		Eccentricity	0.158685611004
		Inclination	9.028195917708
		AscendingNode	6.283322228221
		ArgOfPericenter	262.402481281718
		MeanAnomaly	275.387201071876
	}
	UniformRotation
	{
		Period	10.282
	}
	LunarLambert	0.5
	Albedo	0.23
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=312"
}

#1_"313 Chaldaea:Chaldaea" "Sol" #1=
#2_"*Халдея:313 Chaldaea:Chaldaea:1891-313*" "Sol" #2=
#3_"1891-313*:*Халдея:313 Chaldaea:Chaldaea" "Sol" #3=
".:Chaldaea:313 Chaldaea:1891-313*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"313 chaldaea.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	38.926
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.660391184095
		SemiMajorAxis	2.375087053202
		Eccentricity	0.181179414573
		Inclination	11.652573139461
		AscendingNode	176.64810479174
		ArgOfPericenter	315.917802108419
		MeanAnomaly	100.87939334611
	}
	UniformRotation
	{
		Period	8.392
	}
	LunarLambert	0.5
	Albedo	0.039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=313"
}

#1_"314 Rosalia:Rosalia:1930 QC:1958 RN" "Sol" #1=
#2_"*Розалия:314 Rosalia:Rosalia:1891-314*" "Sol" #2=
#3_"1891-314*:*Розалия:314 Rosalia:Rosalia" "Sol" #3=
".:Rosalia:314 Rosalia:1891-314*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.825
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.599367419599
		SemiMajorAxis	3.153216877778
		Eccentricity	0.177098798304
		Inclination	12.559798546027
		AscendingNode	170.314263529867
		ArgOfPericenter	190.313927748507
		MeanAnomaly	11.093677118809
	}
	UniformRotation
	{
		Period	20.43
	}
	LunarLambert	0.5
	Albedo	0.0787
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=314"
}

#1_"315 Constantia:Constantia" "Sol" #1=
#2_"*Констанция:315 Constantia:Constantia:1891-315*" "Sol" #2=
#3_"1891-315*:Constantia:*Констанция:315 Constantia" "Sol" #3=
".:Constantia:315 Constantia:1891-315*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"315 constantia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	3.267
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.354706863251
		SemiMajorAxis	2.240943549725
		Eccentricity	0.168909650889
		Inclination	2.429153106728
		AscendingNode	161.661356672097
		ArgOfPericenter	172.787421738435
		MeanAnomaly	145.464644131629
	}
	UniformRotation
	{
		Period	5.345
	}
	LunarLambert	0.5
	Albedo	0.217
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=315"
}

#1_"316 Goberta:Goberta:1938 DO2:1939 BB" "Sol" #1=
#2_"*Гоберта:316 Goberta:Goberta:1891-316*" "Sol" #2=
#3_"1891-316*:*Гоберта:316 Goberta:Goberta" "Sol" #3=
".:Goberta:316 Goberta:1891-316*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	23.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.668390518727
		SemiMajorAxis	3.179076951827
		Eccentricity	0.136676736514
		Inclination	2.339010697116
		AscendingNode	123.92327644969
		ArgOfPericenter	314.726320477178
		MeanAnomaly	211.436065377892
	}
	UniformRotation
	{
		Period	8.605
	}
	LunarLambert	0.5
	Albedo	0.0925
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=316"
}

#1_"317 Roxane:Roxane" "Sol" #1=
#2_"*Роксана:317 Roxane:Roxane:1891-317*" "Sol" #2=
#3_"1891-317*:*Роксана:317 Roxane:Roxane" "Sol" #3=
".:Roxane:317 Roxane:1891-317*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"317 roxane.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.93
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.45679051268
		SemiMajorAxis	2.286177288651
		Eccentricity	0.08583024403
		Inclination	1.765616382025
		AscendingNode	151.383324624551
		ArgOfPericenter	187.10279911493
		MeanAnomaly	228.114288950513
	}
	UniformRotation
	{
		Period	8.169
	}
	LunarLambert	0.5
	Albedo	0.4928
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=317"
}

#1_"2009 317 I" "Sol/317 Roxane" #1=
#2_"2009 317 I" "Sol/317 Roxane" #2=
#3_"2009 317 I" "Sol/317 Roxane" #3=
".:2009 317 I" "Sol/317 Roxane" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid.dds"
	Radius	2.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	14
		SemiMajorAxis	257
	}
	LunarLambert	0.5
	Albedo	0.4928
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00317.html"
}

#1_"318 Magdalena:Magdalena" "Sol" #1=
#2_"*Магдалена:318 Magdalena:Magdalena:1891-318*" "Sol" #2=
#3_"1891-318*:*Магдалена:318 Magdalena:Magdalena" "Sol" #3=
".:Magdalena:318 Magdalena:1891-318*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	42.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.712762303614
		SemiMajorAxis	3.195645784327
		Eccentricity	0.08541038193
		Inclination	10.65483501473
		AscendingNode	161.507758752737
		ArgOfPericenter	297.356884688897
		MeanAnomaly	54.255313124121
	}
	UniformRotation
	{
		Period	59.5
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=318"
}

#1_"319 Leona:Leona:A920 HE" "Sol" #1=
#2_"*Леона:319 Leona:Leona:1891-319*" "Sol" #2=
#3_"1891-319*:*Леона:319 Leona:Leona" "Sol" #3=
".:Leona:319 Leona:1891-319*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.08
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.283313799364
		SemiMajorAxis	3.405025470754
		Eccentricity	0.217836567188
		Inclination	10.562771276838
		AscendingNode	184.963284339018
		ArgOfPericenter	228.372007912768
		MeanAnomaly	224.526488861075
	}
	UniformRotation
	{
		Period	9.6
	}
	LunarLambert	0.5
	Albedo	0.0457
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=319"
}

#1_"321 Florentina:Florentina:1959 RS" "Sol" #1=
#2_"*Флорентина:321 Florentina:Florentina:1891-321*" "Sol" #2=
#3_"1891-321*:*Флорентина:321 Florentina:Florentina" "Sol" #3=
".:Florentina:321 Florentina:1891-321*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"321 florentina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	13.987
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.899889145622
		SemiMajorAxis	2.884819876164
		Eccentricity	0.044040701538
		Inclination	2.586786980623
		AscendingNode	40.283838630388
		ArgOfPericenter	37.107361499604
		MeanAnomaly	0.6681692463
	}
	UniformRotation
	{
		Period	2.871
	}
	LunarLambert	0.5
	Albedo	0.425
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=321"
}

#1_"322 Phaeo:Phaeo" "Sol" #1=
#2_"*Фео:322 Phaeo:Phaeo:1891-322*" "Sol" #2=
#3_"1891-322*:*Фео:322 Phaeo:Phaeo" "Sol" #3=
".:Phaeo:322 Phaeo:1891-322*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	35.42
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.636771293083
		SemiMajorAxis	2.780598698643
		Eccentricity	0.246342300065
		Inclination	8.054590704375
		AscendingNode	252.370833298555
		ArgOfPericenter	115.174894187232
		MeanAnomaly	215.321635670283
	}
	UniformRotation
	{
		Period	17.5845
	}
	LunarLambert	0.5
	Albedo	0.0876
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=322"
}

#1_"323 Brucia:Brucia:1934 JC:A923 JA" "Sol" #1=
#2_"*Брюсия:323 Brucia:Brucia:1891-323*" "Sol" #2=
#3_"1891-323*:*Брюсия:323 Brucia:Brucia" "Sol" #3=
".:Brucia:323 Brucia:1891-323*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	17.91
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.675455431234
		SemiMajorAxis	2.381598998718
		Eccentricity	0.300852449669
		Inclination	24.23310085449
		AscendingNode	97.404402565712
		ArgOfPericenter	291.302886815141
		MeanAnomaly	198.486944725779
	}
	UniformRotation
	{
		Period	9.465
	}
	LunarLambert	0.5
	Albedo	0.1765
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=323"
}

#1_"324 Bamberga:Bamberga" "Sol" #1=
#2_"*Бамберга:324 Bamberga:Bamberga:1892-324*" "Sol" #2=
#3_"1892-324*:*Бамберга:324 Bamberga:Bamberga" "Sol" #3=
".:Bamberga:324 Bamberga:1892-324*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	114.72
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.404941135814
		SemiMajorAxis	2.687125423848
		Eccentricity	0.337242373585
		Inclination	11.107058334784
		AscendingNode	327.923911633305
		ArgOfPericenter	44.210898670447
		MeanAnomaly	91.104553590736
	}
	UniformRotation
	{
		Period	29.43
	}
	LunarLambert	0.5
	Albedo	0.0628
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=324"
}

#1_"325 Heidelberga:Heidelberga:1949 HQ" "Sol" #1=
#2_"*Хайдельберга:325 Heidelberga:Heidelberga:1892-325*" "Sol" #2=
#3_"1892-325*:*Хайдельберга:325 Heidelberga:Heidelberga" "Sol" #3=
".:Heidelberga:325 Heidelberga:1892-325*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	37.86
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.757460000543
		SemiMajorAxis	3.212293000839
		Eccentricity	0.159620941091
		Inclination	8.554232767363
		AscendingNode	344.88501401344
		ArgOfPericenter	68.557266679778
		MeanAnomaly	264.507881601458
	}
	UniformRotation
	{
		Period	6.737
	}
	LunarLambert	0.5
	Albedo	0.1068
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=325"
}

#1_"326 Tamara:Tamara:A899 OD" "Sol" #1=
#2_"*Тамара:326 Tamara:Tamara:1892-326*" "Sol" #2=
#3_"1892-326*:*Тамара:326 Tamara:Tamara" "Sol" #3=
".:Tamara:326 Tamara:1892-326*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	46.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.529286802315
		SemiMajorAxis	2.318030609766
		Eccentricity	0.190055306956
		Inclination	23.721060714506
		AscendingNode	32.251002540825
		ArgOfPericenter	238.38111147846
		MeanAnomaly	218.764366426328
	}
	UniformRotation
	{
		Period	14.445
	}
	LunarLambert	0.5
	Albedo	0.0368
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=326"
}

#1_"327 Columbia:Columbia (asteroid):1934 JN" "Sol" #1=
#2_"*Колумбия:327 Columbia:Columbia (asteroid):1892-327*" "Sol" #2=
#3_"1892-327*:*Колумбия:327 Columbia:Columbia (asteroid)" "Sol" #3=
".:Columbia (asteroid):327 Columbia:1892-327*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"327 columbia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	15.146
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.62335594781
		SemiMajorAxis	2.775232794928
		Eccentricity	0.06314976221
		Inclination	7.149749200597
		AscendingNode	354.815249616398
		ArgOfPericenter	306.608748458976
		MeanAnomaly	85.080065122029
	}
	UniformRotation
	{
		Period	5.932
	}
	LunarLambert	0.5
	Albedo	0.214
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=327"
}

#1_"328 Gudrun:Gudrun:1947 FH:1949 SV1:1952 DG3:1974 JA" "Sol" #1=
#2_"*Гудрун:328 Gudrun:Gudrun:1892-328*" "Sol" #2=
#3_"1892-328*:*Гудрун:328 Gudrun:Gudrun" "Sol" #3=
".:Gudrun:328 Gudrun:1892-328*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	61.46
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.488961015164
		SemiMajorAxis	3.111630090874
		Eccentricity	0.106195455223
		Inclination	16.115058961049
		AscendingNode	352.331559040062
		ArgOfPericenter	103.755027515833
		MeanAnomaly	217.688188483984
	}
	UniformRotation
	{
		Period	10.992
	}
	LunarLambert	0.5
	Albedo	0.0425
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=328"
}

#1_"329 Svea:Svea" "Sol" #1=
#2_"*Свея:329 Svea:Svea:1892-329*" "Sol" #2=
#3_"1892-329*:*Свея:329 Svea:Svea" "Sol" #3=
".:Svea:329 Svea:1892-329*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.897772843742
		SemiMajorAxis	2.476693221309
		Eccentricity	0.025267887885
		Inclination	15.881288365763
		AscendingNode	178.489550554249
		ArgOfPericenter	56.083510376841
		MeanAnomaly	130.642178520174
	}
	UniformRotation
	{
		Period	22.77
	}
	LunarLambert	0.5
	Albedo	0.0399
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=329"
}

#1_"331 Etheridgea:Etheridgea:1949 CM" "Sol" #1=
#2_"*Эфериджия:331 Etheridgea:Etheridgea:1892-331*" "Sol" #2=
#3_"1892-331*:*Эфериджия:331 Etheridgea:Etheridgea" "Sol" #3=
".:Etheridgea:331 Etheridgea:1892-331*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	37.46
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.261117857006
		SemiMajorAxis	3.02491530296
		Eccentricity	0.100515214
		Inclination	6.053053243429
		AscendingNode	22.036565118252
		ArgOfPericenter	333.246948889028
		MeanAnomaly	335.905016296072
	}
	UniformRotation
	{
		Period	13.092
	}
	LunarLambert	0.5
	Albedo	0.0447
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=331"
}

#1_"332 Siri:Siri:A896 BA:A922 XA" "Sol" #1=
#2_"*Сири:332 Siri:Siri:1892-332*" "Sol" #2=
#3_"1892-332*:*Сири:332 Siri:Siri" "Sol" #3=
".:Siri:332 Siri:1892-332*" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	20.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.616424113672
		SemiMajorAxis	2.772458148979
		Eccentricity	0.090057257156
		Inclination	2.847209247122
		AscendingNode	31.585173887839
		ArgOfPericenter	296.343890744476
		MeanAnomaly	58.296798471125
	}
	UniformRotation
	{
		Period	8.0074
	}
	LunarLambert	0.5
	Albedo	0.1719
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=332"
}

#1_"333 Badenia:Badenia:1892 A:1930 JD:1932 TC:1936 QQ:1937 VB:1950 BP1:A895 DC:A911 CA" "Sol" #1=
#2_"*Бадения:333 Badenia:Badenia:1892 A" "Sol" #2=
#3_"1892 A:*Бадения:333 Badenia:Badenia" "Sol" #3=
".:Badenia:333 Badenia:1892 A" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	39.085
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.535489643143
		SemiMajorAxis	3.129189710528
		Eccentricity	0.161023332405
		Inclination	3.77331457279
		AscendingNode	353.585925934067
		ArgOfPericenter	19.612387628201
		MeanAnomaly	27.788142454924
	}
	UniformRotation
	{
		Period	8.192
	}
	LunarLambert	0.5
	Albedo	0.0475
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=333"
}

#1_"334 Chicago:Chicago:1892 L:A903 HA" "Sol" #1=
#2_"*Чикаго:334 Chicago:Chicago:1892 L" "Sol" #2=
#3_"1892 L:*Чикаго:334 Chicago:Chicago" "Sol" #3=
".:Chicago:334 Chicago:1892 L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	79.275
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.690382059154
		SemiMajorAxis	3.896067530727
		Eccentricity	0.021992505383
		Inclination	4.641568961207
		AscendingNode	130.184919546197
		ArgOfPericenter	149.251293496284
		MeanAnomaly	32.426669767358
	}
	UniformRotation
	{
		Period	7.361
	}
	LunarLambert	0.5
	Albedo	0.0618
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=334"
}

#1_"335 Roberta:Roberta:1892 C:1956 EB1:1973 KE:A910 EC" "Sol" #1=
#2_"*Роберта:335 Roberta:Roberta:1892 C" "Sol" #2=
#3_"1892 C:*Роберта:335 Roberta:Roberta" "Sol" #3=
".:Roberta:335 Roberta:1892 C" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	44.535
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.898703899406
		SemiMajorAxis	2.477087608489
		Eccentricity	0.172353907242
		Inclination	5.09780621874
		AscendingNode	148.457455290827
		ArgOfPericenter	139.630618071865
		MeanAnomaly	204.120314572739
	}
	UniformRotation
	{
		Period	12.054
	}
	LunarLambert	0.5
	Albedo	0.058
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=335"
}

#1_"336 Lacadiera:Lacadiera:1892 D:A895 OA" "Sol" #1=
#2_"*Лакадира:336 Lacadiera:Lacadiera:1892 D" "Sol" #2=
#3_"1892 D:*Лакадира:336 Lacadiera:Lacadiera" "Sol" #3=
".:Lacadiera:336 Lacadiera:1892 D" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"336 lacadiera.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	33.756
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.377868648902
		SemiMajorAxis	2.251246429036
		Eccentricity	0.096038334751
		Inclination	5.652471008798
		AscendingNode	235.107616832368
		ArgOfPericenter	31.089377123321
		MeanAnomaly	149.175465994632
	}
	UniformRotation
	{
		Period	13.7
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=336"
}

#1_"337 Devosa:Devosa:1892 E:1936 SQ:1960 FA:1976 MJ" "Sol" #1=
#2_"*Девоса:337 Devosa:Devosa:1892 E" "Sol" #2=
#3_"1892 E:*Девоса:337 Devosa:Devosa" "Sol" #3=
".:Devosa:337 Devosa:1892 E" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Color	[ 1.000 0.932 0.878 ]
	BlendTexture	true
	Radius	29.555
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.67999766614
		SemiMajorAxis	2.383560761077
		Eccentricity	0.137172548042
		Inclination	7.852680112812
		AscendingNode	355.488049428561
		ArgOfPericenter	98.856609145491
		MeanAnomaly	8.723657517308
	}
	UniformRotation
	{
		Period	4.653
		Inclination	47
		AscendingNode	299
	}
	LunarLambert	0.5
	Albedo	0.1614
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=337"
}

#1_"338 Budrosa:Budrosa:1892 F" "Sol" #1=
#2_"*Будроса:338 Budrosa:Budrosa:1892 F" "Sol" #2=
#3_"1892 F:*Будроса:338 Budrosa:Budrosa" "Sol" #3=
".:Budrosa:338 Budrosa:1892 F" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	31.555
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.967812076587
		SemiMajorAxis	2.911418502994
		Eccentricity	0.022767189994
		Inclination	6.049814439564
		AscendingNode	287.442977005925
		ArgOfPericenter	112.822676482344
		MeanAnomaly	181.239648901043
	}
	UniformRotation
	{
		Period	4.6084
	}
	LunarLambert	0.5
	Albedo	0.1766
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=338"
}

#1_"339 Dorothea:Dorothea:1892 G" "Sol" #1=
#2_"*Доротея:339 Dorothea:Dorothea:1892 G" "Sol" #2=
#3_"1892 G:*Доротея:339 Dorothea:Dorothea" "Sol" #3=
".:Dorothea:339 Dorothea:1892 G" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	19.125
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.242681377823
		SemiMajorAxis	3.017844383556
		Eccentricity	0.095124974388
		Inclination	9.946008172801
		AscendingNode	173.537039677139
		ArgOfPericenter	163.517480297494
		MeanAnomaly	159.487040902418
	}
	UniformRotation
	{
		Period	5.974
	}
	LunarLambert	0.5
	Albedo	0.2431
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=339"
}

#1_"340 Eduarda:Eduarda:1892 H:1954 FA:1959 JT" "Sol" #1=
#2_"*Эдуарда:340 Eduarda:Eduarda:1892 H" "Sol" #2=
#3_"1892 H:*Эдуарда:340 Eduarda:Eduarda" "Sol" #3=
".:Eduarda:340 Eduarda:1892 H" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"340 eduarda.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	14.012
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.554337441276
		SemiMajorAxis	2.747544079998
		Eccentricity	0.114857797055
		Inclination	4.676715011064
		AscendingNode	27.056613610382
		ArgOfPericenter	41.627302732761
		MeanAnomaly	253.86242099432
	}
	UniformRotation
	{
		Period	8.0062
	}
	LunarLambert	0.5
	Albedo	0.247
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=340"
}

#1_"341 California:California:1892 J:1979 FY2" "Sol" #1=
#2_"*Калифорния:341 California:California:1892 J" "Sol" #2=
#3_"1892 J:*Калифорния:341 California:California" "Sol" #3=
".:California:341 California:1892 J" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"gaspra.jpg"
	Radius	7.335
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.263395690527
		SemiMajorAxis	2.200092914079
		Eccentricity	0.193895808182
		Inclination	5.667154827079
		AscendingNode	29.063804859107
		ArgOfPericenter	293.770040960179
		MeanAnomaly	194.419861369485
	}
	UniformRotation
	{
		Period	8.74
	}
	LunarLambert	0.5
	Albedo	0.495
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=341"
}

#1_"342 Endymion:Endymion:1892 K" "Sol" #1=
#2_"*Эндимион:342 Endymion:Endymion:1892 K" "Sol" #2=
#3_"1892 K:*Эндимион:342 Endymion:Endymion" "Sol" #3=
".:Endymion:342 Endymion:1892 K" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	30.315
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.11841487678
		SemiMajorAxis	2.569298684307
		Eccentricity	0.127973941783
		Inclination	7.347707278888
		AscendingNode	232.707544352171
		ArgOfPericenter	224.590989391297
		MeanAnomaly	192.384833133133
	}
	UniformRotation
	{
		Period	6.319
	}
	LunarLambert	0.5
	Albedo	0.0393
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=342"
}

#1_"343 Ostara:Ostara:1892 N" "Sol" #1=
#2_"*Остара:343 Ostara:Ostara:1892 N" "Sol" #2=
#3_"1892 N:*Остара:343 Ostara:Ostara" "Sol" #3=
".:Ostara:343 Ostara:1892 N" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"343 ostara.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	9.106
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.745771369047
		SemiMajorAxis	2.41187821974
		Eccentricity	0.229162437
		Inclination	3.265185925591
		AscendingNode	38.64119654025
		ArgOfPericenter	9.653848498878
		MeanAnomaly	218.715500977654
	}
	UniformRotation
	{
		Period	109.87
	}
	LunarLambert	0.5
	Albedo	0.092
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=343"
}

#1_"344 Desiderata:Desiderata:1892 M" "Sol" #1=
#2_"*Дезидерата:344 Desiderata:Desiderata:1892 M" "Sol" #2=
#3_"1892 M:*Дезидерата:344 Desiderata:Desiderata" "Sol" #3=
".:Desiderata:344 Desiderata:1892 M" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	66.135
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.182232172913
		SemiMajorAxis	2.595772482666
		Eccentricity	0.314869905508
		Inclination	18.344947968586
		AscendingNode	48.189978463526
		ArgOfPericenter	237.337792238368
		MeanAnomaly	159.938715592537
	}
	UniformRotation
	{
		Period	10.747
	}
	LunarLambert	0.5
	Albedo	0.0592
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=344"
}

#1_"345 Tercidina:Tercidina:1892 O" "Sol" #1=
#2_"*Терцидина:345 Tercidina:Tercidina:1892 O" "Sol" #2=
#3_"1892 O:*Терцидина:345 Tercidina:Tercidina" "Sol" #3=
".:Tercidina:345 Tercidina:1892 O" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"345 tercidina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	63
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.544972981898
		SemiMajorAxis	2.324893972372
		Eccentricity	0.061457312282
		Inclination	9.747974073761
		AscendingNode	212.640467852914
		ArgOfPericenter	230.31715299856
		MeanAnomaly	121.84972337916
	}
	UniformRotation
	{
		Period	12.371
	}
	LunarLambert	0.5
	Albedo	0.037
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=345"
}

#1_"346 Hermentaria:Hermentaria:1892 P" "Sol" #1=
#2_"*Герментария:346 Hermentaria:Hermentaria:1892 P" "Sol" #2=
#3_"1892 P:*Герментария:346 Hermentaria:Hermentaria" "Sol" #3=
".:Hermentaria:346 Hermentaria:1892 P" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	53.26
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.677476262918
		SemiMajorAxis	2.796848400512
		Eccentricity	0.099382707224
		Inclination	8.757826619693
		AscendingNode	92.108862522541
		ArgOfPericenter	291.224851845919
		MeanAnomaly	63.135431101145
	}
	UniformRotation
	{
		Period	28.43
	}
	LunarLambert	0.5
	Albedo	0.2189
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=346"
}

#1_"347 Pariana:Pariana:1892 Q" "Sol" #1=
#2_"*Париана:347 Pariana:Pariana:1892 Q" "Sol" #2=
#3_"1892 Q:*Париана:347 Pariana:Pariana" "Sol" #3=
".:Pariana:347 Pariana:1892 Q" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	25.68
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.218669272407
		SemiMajorAxis	2.610827538773
		Eccentricity	0.166725053247
		Inclination	11.680650873451
		AscendingNode	85.556927971028
		ArgOfPericenter	86.362725717968
		MeanAnomaly	227.749097430786
	}
	UniformRotation
	{
		Period	4.0529
	}
	LunarLambert	0.5
	Albedo	0.1845
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=347"
}

#1_"348 May:May:1892 R" "Sol" #1=
#2_"*Май:348 May:May:1892 R" "Sol" #2=
#3_"1892 R:*Май:348 May:May" "Sol" #3=
".:May:348 May:1892 R" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	41.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.11874601126
		SemiMajorAxis	2.970094395517
		Eccentricity	0.067440599067
		Inclination	9.744808151972
		AscendingNode	90.049704593285
		ArgOfPericenter	13.053466146001
		MeanAnomaly	266.603062742977
	}
	UniformRotation
	{
		Period	7.3812
	}
	LunarLambert	0.5
	Albedo	0.0448
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=348"
}

#1_"349 Dembowska:Dembowska:1892 T" "Sol" #1=
#2_"*Дембовска:349 Dembowska:Dembowska:1892 T" "Sol" #2=
#3_"1892 T:*Дембовска:349 Dembowska:Dembowska" "Sol" #3=
".:Dembowska:349 Dembowska:1892 T" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"349 dembowska.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.879 0.782 ]
	BlendTexture	true
	Radius	69.885
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.000441703167
		SemiMajorAxis	2.924153123995
		Eccentricity	0.091535276381
		Inclination	8.246169181633
		AscendingNode	32.349737261777
		ArgOfPericenter	346.086862420398
		MeanAnomaly	25.866201519205
	}
	UniformRotation
	{
		Period	4.701
		Inclination	67
		AscendingNode	240
	}
	LunarLambert	0.5
	Albedo	0.384
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=349"
}

#1_"350 Ornamenta:Ornamenta:1892 U:1954 ED" "Sol" #1=
#2_"*Орнамента:350 Ornamenta:Ornamenta:1892 U" "Sol" #2=
#3_"1892 U:*Орнамента:350 Ornamenta:Ornamenta" "Sol" #3=
".:Ornamenta:350 Ornamenta:1892 U:1954 ED" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"350 ornamenta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	64.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.488322805213
		SemiMajorAxis	3.111388890184
		Eccentricity	0.159167262754
		Inclination	24.893036733513
		AscendingNode	90.139649749004
		ArgOfPericenter	338.642616129493
		MeanAnomaly	68.892550136727
	}
	UniformRotation
	{
		Period	9.178
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=350"
}

#1_"351 Yrsa:Yrsa:1892 V:1927 OB:1950 PD1:1959 LN" "Sol" #1=
#2_"*Ирса:351 Yrsa:Yrsa:1892 V" "Sol" #2=
#3_"1892 V:*Ирса:351 Yrsa:Yrsa" "Sol" #3=
".:Yrsa:351 Yrsa:1892 V" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"351 yrsa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	19.86
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.603890407401
		SemiMajorAxis	2.767437680266
		Eccentricity	0.152683300851
		Inclination	9.196038081739
		AscendingNode	99.270308839337
		ArgOfPericenter	31.429137679017
		MeanAnomaly	151.546564159846
	}
	UniformRotation
	{
		Period	13.29
	}
	LunarLambert	0.5
	Albedo	0.286
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=351"
}

#1_"352 Gisela:Gisela:1893 B:1950 XT:A895 XA" "Sol" #1=
#2_"*Жизела:352 Gisela:Gisela:1893 B" "Sol" #2=
#3_"1893 B:*Жизела:352 Gisela:Gisela" "Sol" #3=
".:Gisela:352 Gisela:1893 B" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"352 gisela.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	13.372
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.250053415226
		SemiMajorAxis	2.19409215355
		Eccentricity	0.149547726576
		Inclination	3.380948814812
		AscendingNode	247.364637381303
		ArgOfPericenter	144.198167665675
		MeanAnomaly	252.639947076016
	}
	UniformRotation
	{
		Period	7.49
	}
	LunarLambert	0.5
	Albedo	0.195
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=352"
}

#1_"353 Ruperto-Carola:Ruperto-Carola:1893 F:1937 XA:A914 QA" "Sol" #1=
#2_"*Руперто-Карола:353 Ruperto-Carola:Ruperto-Carola:1893 F" "Sol" #2=
#3_"1893 F:Ruperto-Carola:*Руперто-Карола:353 Ruperto-Carola" "Sol" #3=
".:Ruperto-Carola:353 Ruperto-Carola:1893 F" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"353 ruperto-carola.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.012
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.523175893584
		SemiMajorAxis	2.734996970018
		Eccentricity	0.327256843511
		Inclination	5.707646960463
		AscendingNode	102.475781298329
		ArgOfPericenter	321.444444805786
		MeanAnomaly	189.133979144405
	}
	UniformRotation
	{
		Period	2.73898
	}
	LunarLambert	0.5
	Albedo	0.392
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=353"
}

#1_"354 Eleonora:Eleonora:1893 A:A918 RF" "Sol" #1=
#2_"*Элеонора:354 Eleonora:Eleonora:1893 A" "Sol" #2=
#3_"1893 A:*Элеонора:354 Eleonora:Eleonora" "Sol" #3=
".:Eleonora:354 Eleonora:1893 A" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"354 eleonora.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.871 0.753 ]
	BlendTexture	true
	Radius	74.485
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.683895531193
		SemiMajorAxis	2.799406705482
		Eccentricity	0.115383374568
		Inclination	18.402323832154
		AscendingNode	140.371958021284
		ArgOfPericenter	5.687894361173
		MeanAnomaly	357.241016590448
	}
	UniformRotation
	{
		Period	4.277
		Inclination	70
		AscendingNode	86
	}
	LunarLambert	0.5
	Albedo	0.201
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=354"
}

#1_"355 Gabriella:Gabriella:1893 E:1931 OD:1943 ME:A911 QH:A915 RM" "Sol" #1=
#2_"*Габриелла:355 Gabriella:Gabriella:1893 E" "Sol" #2=
#3_"1893 E:*Габриелла:355 Gabriella:Gabriella" "Sol" #3=
".:Gabriella:355 Gabriella:1893 E" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"355 gabriella.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	12.02
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.042088208046
		SemiMajorAxis	2.537455236616
		Eccentricity	0.106992473119
		Inclination	4.283602156669
		AscendingNode	351.826977644998
		ArgOfPericenter	105.7482101554
		MeanAnomaly	64.397433152153
	}
	UniformRotation
	{
		Period	4.83
	}
	LunarLambert	0.5
	Albedo	0.341
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=355"
}

#1_"356 Liguria:Liguria:1893 G:1951 WU2:1953 FX1:A893 CA" "Sol" #1=
#2_"*Лигурия:356 Liguria:Liguria:1893 G" "Sol" #2=
#3_"1893 G:*Лигурия:356 Liguria:Liguria" "Sol" #3=
".:Liguria:356 Liguria:1893 G" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	65.655
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.582601585272
		SemiMajorAxis	2.758899830462
		Eccentricity	0.237473669138
		Inclination	8.223712213295
		AscendingNode	354.798428743043
		ArgOfPericenter	78.513558370344
		MeanAnomaly	259.948968933677
	}
	UniformRotation
	{
		Period	31.82
	}
	LunarLambert	0.5
	Albedo	0.0528
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=356"
}

#1_"357 Ninina:Ninina:1893 J:1972 BN:A907 SA" "Sol" #1=
#2_"*Нинина:357 Ninina:Ninina:1893 J" "Sol" #2=
#3_"1893 J:*Нинина:357 Ninina:Ninina" "Sol" #3=
".:Ninina:357 Ninina:1893 J" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	53.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.590721768335
		SemiMajorAxis	3.149970245106
		Eccentricity	0.073397665114
		Inclination	15.085723157994
		AscendingNode	137.845260696706
		ArgOfPericenter	252.34048120887
		MeanAnomaly	40.697776975868
	}
	UniformRotation
	{
		Period	35.98
	}
	LunarLambert	0.5
	Albedo	0.051
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=357"
}

#1_"358 Apollonia:Apollonia:1893 K:1949 OG1:A901 XA" "Sol" #1=
#2_"*Аполлония:358 Apollonia:Apollonia:1893 K" "Sol" #2=
#3_"1893 K:*Аполлония:358 Apollonia:Apollonia" "Sol" #3=
".:Apollonia:358 Apollonia:1893 K" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	44.725
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.884876014408
		SemiMajorAxis	2.878924188175
		Eccentricity	0.152104539881
		Inclination	3.550448170235
		AscendingNode	172.165028658517
		ArgOfPericenter	253.809731768984
		MeanAnomaly	57.653478279983
	}
	UniformRotation
	{
		Period	50.6
	}
	LunarLambert	0.5
	Albedo	0.0506
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=358"
}

#1_"359 Georgia:Georgia:1893 M:1952 HM4:1953 TR:1958 XO:A902 EB" "Sol" #1=
#2_"*Георгия:359 Georgia:Georgia:1893 M" "Sol" #2=
#3_"1893 M:*Георгия:359 Georgia:Georgia" "Sol" #3=
".:Georgia:359 Georgia:1893 M" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	21.945
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.50691478245
		SemiMajorAxis	2.728438041621
		Eccentricity	0.156408214339
		Inclination	6.770734650243
		AscendingNode	6.07539250238
		ArgOfPericenter	338.546486244914
		MeanAnomaly	192.662266713502
	}
	UniformRotation
	{
		Period	5.537
	}
	LunarLambert	0.5
	Albedo	0.2621
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=359"
}

#1_"360 Carlova:Carlova:1893 N:A903 BC" "Sol" #1=
#2_"*Карлова:360 Carlova:Carlova:1893 N" "Sol" #2=
#3_"1893 N:*Карлова:360 Carlova:Carlova" "Sol" #3=
".:Carlova:360 Carlova:1893 N" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"360 carlova.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	64.562
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.201020744695
		SemiMajorAxis	3.001835729358
		Eccentricity	0.177757423189
		Inclination	11.697103436392
		AscendingNode	132.547543972827
		ArgOfPericenter	287.86659334081
		MeanAnomaly	66.275063392662
	}
	UniformRotation
	{
		Period	6.183
	}
	LunarLambert	0.5
	Albedo	0.043
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=360"
}

#1_"361 Bononia:Bononia:1893 P:1953 VD2:1975 LJ" "Sol" #1=
#2_"*Бонония:361 Bononia:Bononia:1893 P" "Sol" #2=
#3_"1893 P:*Бонония:361 Bononia:Bononia" "Sol" #3=
".:Bononia:361 Bononia:1893 P" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"361 bononia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	77.167
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.886220405925
		SemiMajorAxis	3.961933109471
		Eccentricity	0.214353467
		Inclination	12.623405914888
		AscendingNode	18.883035077347
		ArgOfPericenter	68.273607810874
		MeanAnomaly	254.305705174856
	}
	UniformRotation
	{
		Period	13.83
	}
	LunarLambert	0.5
	Albedo	0.038
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=361"
}

#1_"362 Havnia:Havnia:1893 R" "Sol" #1=
#2_"*Гафния:362 Havnia:Havnia:1893 R" "Sol" #2=
#3_"1893 R:*Гафния:362 Havnia:Havnia" "Sol" #3=
".:Havnia:362 Havnia:1893 R" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	49
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.142498863388
		SemiMajorAxis	2.579305576615
		Eccentricity	0.043259514801
		Inclination	8.067575310002
		AscendingNode	27.353181302685
		ArgOfPericenter	29.494390317926
		MeanAnomaly	259.964786266509
	}
	UniformRotation
	{
		Period	16.92
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=362"
}

#1_"363 Padua:Padua:1893 S:1930 HP:1945 QG:1945 RD:A891 WA" "Sol" #1=
#2_"*Падуя:363 Padua:Padua:1893 S" "Sol" #2=
#3_"1893 S:*Падуя:363 Padua:Padua" "Sol" #3=
".:Padua:363 Padua:1893 S" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	48.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.553045485702
		SemiMajorAxis	2.747024447482
		Eccentricity	0.070188708898
		Inclination	5.944114313435
		AscendingNode	64.890078736789
		ArgOfPericenter	293.978959809296
		MeanAnomaly	65.545133010222
	}
	UniformRotation
	{
		Period	8.401
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=363"
}

#1_"364 Isara:Isara:1893 T:1976 AB" "Sol" #1=
#2_"*Изара:364 Isara:Isara:1893 T" "Sol" #2=
#3_"1893 T:*Изара:364 Isara:Isara" "Sol" #3=
".:Isara:364 Isara:1893 T" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"364 isara.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	12.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.309232955944
		SemiMajorAxis	2.220646479573
		Eccentricity	0.149078367527
		Inclination	6.004860442966
		AscendingNode	105.56877222961
		ArgOfPericenter	312.94235939075
		MeanAnomaly	24.234991212019
	}
	UniformRotation
	{
		Period	9.156
	}
	LunarLambert	0.5
	Albedo	0.3
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=364"
}

#1_"365 Corduba:Corduba:1893 V:A914 VA" "Sol" #1=
#2_"*Кордуба:365 Corduba:Corduba:1893 V" "Sol" #2=
#3_"1893 V:*Кордуба:365 Corduba:Corduba" "Sol" #3=
".:Corduba:365 Corduba:1893 V" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"365 corduba.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	43.386
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.692458980771
		SemiMajorAxis	2.802817723682
		Eccentricity	0.156733635559
		Inclination	12.786837004011
		AscendingNode	185.198291358718
		ArgOfPericenter	216.677627389796
		MeanAnomaly	107.408720771238
	}
	UniformRotation
	{
		Period	12.705
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=365"
}

#1_"366 Vincentina:Vincentina:1893 W:1931 AS:A909 BN" "Sol" #1=
#2_"*Винчентина:366 Vincentina:Vincentina:1893 W" "Sol" #2=
#3_"1893 W:*Винчентина:366 Vincentina:Vincentina" "Sol" #3=
".:Vincentina:366 Vincentina:1893 W" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	46.875
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.593503126172
		SemiMajorAxis	3.151014888775
		Eccentricity	0.053908569039
		Inclination	10.568989688281
		AscendingNode	346.748507442914
		ArgOfPericenter	330.03923745654
		MeanAnomaly	179.952822198808
	}
	UniformRotation
	{
		Period	12.7365
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=366"
}

#1_"367 Amicitia:Amicitia:1893 AA:1927 UO:1957 TM:1965 GA" "Sol" #1=
#2_"*Амицития:367 Amicitia:Amicitia:1893 AA" "Sol" #2=
#3_"1893 AA:*Амицития:367 Amicitia:Amicitia" "Sol" #3=
".:Amicitia:367 Amicitia:1893 AA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"367 amicitia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	10.622
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.307146763302
		SemiMajorAxis	2.219713094446
		Eccentricity	0.095886857672
		Inclination	2.941650955525
		AscendingNode	83.464409306311
		ArgOfPericenter	55.578694763604
		MeanAnomaly	4.882809932363
	}
	UniformRotation
	{
		Period	5.0554
	}
	LunarLambert	0.5
	Albedo	0.393
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=367"
}

#1_"368 Haidea:Haidea:1893 AB:A905 VH:A921 TA" "Sol" #1=
#2_"*Хайдея:368 Haidea:Haidea:1893 AB" "Sol" #2=
#3_"1893 AB:*Хайдея:368 Haidea:Haidea" "Sol" #3=
".:Haidea:368 Haidea:1893 AB:1905 VH:1921 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.409762132238
		SemiMajorAxis	3.081626344478
		Eccentricity	0.199478755159
		Inclination	7.763665521027
		AscendingNode	227.017825583465
		ArgOfPericenter	93.177546628077
		MeanAnomaly	162.180440194029
	}
	UniformRotation
	{
		Period	9.823
	}
	LunarLambert	0.5
	Albedo	0.0389
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=368"
}

#1_"369 Aeria:Aeria:1893 AE:1949 MY:A894 WA" "Sol" #1=
#2_"*Аэрия:369 Aeria:Aeria:1893 AE" "Sol" #2=
#3_"1893 AE:*Аэрия:369 Aeria:Aeria" "Sol" #3=
".:Aeria:369 Aeria:1893 AE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	30
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.312332211656
		SemiMajorAxis	2.64932968382
		Eccentricity	0.097762729401
		Inclination	12.70784269978
		AscendingNode	94.285806205072
		ArgOfPericenter	268.447987029344
		MeanAnomaly	337.197280273851
	}
	UniformRotation
	{
		Period	4.778
	}
	LunarLambert	0.5
	Albedo	0.1919
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=369"
}

#1_"371 Bohemia:Bohemia:1893 AD" "Sol" #1=
#2_"*Богемия:371 Bohemia:Bohemia:1893 AD" "Sol" #2=
#3_"1893 AD:*Богемия:371 Bohemia:Bohemia" "Sol" #3=
".:Bohemia:371 Bohemia:1893 AD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"371 bohemia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	26.488
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.502341081482
		SemiMajorAxis	2.726591816146
		Eccentricity	0.063969770949
		Inclination	7.396685166719
		AscendingNode	283.45851371065
		ArgOfPericenter	343.692217048568
		MeanAnomaly	11.658206105824
	}
	UniformRotation
	{
		Period	10.7391
	}
	LunarLambert	0.5
	Albedo	0.234
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=371"
}

#1_"372 Palma:Palma:1893 AH:1940 CN:1949 SP1" "Sol" #1=
#2_"*Пальма:372 Palma:Palma:1893 AH" "Sol" #2=
#3_"1893 AH:*Пальма:372 Palma:Palma" "Sol" #3=
".:Palma:372 Palma:1893 AH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"372 palma.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.964 0.943 ]
	BlendTexture	true
	Radius	86.821
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.590775666527
		SemiMajorAxis	3.149990490247
		Eccentricity	0.260117736406
		Inclination	23.829417844104
		AscendingNode	327.372503209309
		ArgOfPericenter	115.598878815073
		MeanAnomaly	170.036188449622
	}
	UniformRotation
	{
		Period	8.567
		Inclination	88
		AscendingNode	158
	}
	LunarLambert	0.5
	Albedo	0.059
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=372"
}

#1_"373 Melusina:Melusina:1893 AJ:1937 TL:1948 TZ" "Sol" #1=
#2_"*Мелюзина:373 Melusina:Melusina:1893 AJ" "Sol" #2=
#3_"1893 AJ:*Мелюзина:373 Melusina:Melusina" "Sol" #3=
".:Melusina:373 Melusina:1893 AJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	47.885
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.502571767239
		SemiMajorAxis	3.116771821938
		Eccentricity	0.142559959485
		Inclination	15.43096131297
		AscendingNode	3.835851357699
		ArgOfPericenter	347.757393077623
		MeanAnomaly	20.005024261047
	}
	UniformRotation
	{
		Period	12.97
	}
	LunarLambert	0.5
	Albedo	0.0429
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=373"
}

#1_"374 Burgundia:Burgundia:1893 AK:1947 FE:1948 NK" "Sol" #1=
#2_"*Бургундия:374 Burgundia:Burgundia:1893 AK" "Sol" #2=
#3_"1893 AK:*Бургундия:374 Burgundia:Burgundia" "Sol" #3=
".:Burgundia:374 Burgundia:1893 AK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	22.335
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.631906428585
		SemiMajorAxis	2.778653436651
		Eccentricity	0.081237725586
		Inclination	8.986704513976
		AscendingNode	219.082774053529
		ArgOfPericenter	25.797956937156
		MeanAnomaly	167.068617317392
	}
	UniformRotation
	{
		Period	6.972
	}
	LunarLambert	0.5
	Albedo	0.3014
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=374"
}

#1_"375 Ursula:Ursula:1893 AL" "Sol" #1=
#2_"*Урсула:375 Ursula:Ursula:1893 AL" "Sol" #2=
#3_"1893 AL:*Урсула:375 Ursula:Ursula" "Sol" #3=
".:Ursula:375 Ursula:1893 AL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	108
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.526082508249
		SemiMajorAxis	3.125643495651
		Eccentricity	0.105991459345
		Inclination	15.942127170216
		AscendingNode	336.576292395683
		ArgOfPericenter	342.570231988623
		MeanAnomaly	10.117721071695
	}
	UniformRotation
	{
		Period	16.83
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=375"
}

#1_"376 Geometria:Geometria:1893 AM:1950 BQ1:1954 BJ" "Sol" #1=
#2_"*Геометрия:376 Geometria:Geometria:1893 AM" "Sol" #2=
#3_"1893 AM:*Геометрия:376 Geometria:Geometria" "Sol" #3=
".:3Geometria:76 Geometria:1893 AM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"376 geometria.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	17.732
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.461621833529
		SemiMajorAxis	2.288306949037
		Eccentricity	0.172520514676
		Inclination	5.434651807707
		AscendingNode	302.041736997515
		ArgOfPericenter	316.840390163124
		MeanAnomaly	92.2079702539
	}
	UniformRotation
	{
		Period	7.74
	}
	LunarLambert	0.5
	Albedo	0.321
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=376"
}

#1_"377 Campania:Campania:1893 AN:1935 GP:1946 UP" "Sol" #1=
#2_"*Кампания:377 Campania:Campania:1893 AN" "Sol" #2=
#3_"1893 AN:*Кампания:377 Campania:Campania" "Sol" #3=
".:Campania:377 Campania:1893 AN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"377 campania.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	45.173
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.41034122194
		SemiMajorAxis	2.689321101394
		Eccentricity	0.078379004998
		Inclination	6.678376838653
		AscendingNode	210.134824225815
		ArgOfPericenter	196.32138409346
		MeanAnomaly	138.898592745382
	}
	UniformRotation
	{
		Period	11.664
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=377"
}

#1_"378 Holmia:Holmia:1893 AP:1953 XS1:1960 FJ:1962 TP:1962 UC:1979 KP1" "Sol" #1=
#2_"*Гольмия:378 Holmia:Holmia:1893 AP" "Sol" #2=
#3_"1893 AP:*Гольмия:378 Holmia:Holmia" "Sol" #3=
".:Holmia:378 Holmia:1893 AP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"378 holmia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.916
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.632928437236
		SemiMajorAxis	2.779062152942
		Eccentricity	0.128063734002
		Inclination	6.997920493035
		AscendingNode	232.602391179303
		ArgOfPericenter	157.780497354339
		MeanAnomaly	84.103965405741
	}
	UniformRotation
	{
		Period	4.45
	}
	LunarLambert	0.5
	Albedo	0.339
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=378"
}

#1_"379 Huenna:Huenna:1894 AQ:1948 XM:A895 DB:A911 BA" "Sol" #1=
#2_"*Гуенна:379 Huenna:Huenna:1894 AQ" "Sol" #2=
#3_"1894 AQ:*Гуенна:379 Huenna:Huenna" "Sol" #3=
".:Huenna:379 Huenna:1894 AQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	43.735
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.554037281032
		SemiMajorAxis	3.136175748842
		Eccentricity	0.186198827699
		Inclination	1.669688758302
		AscendingNode	172.04118782467
		ArgOfPericenter	179.918397161572
		MeanAnomaly	19.612716308855
	}
	UniformRotation
	{
		Period	7.022
	}
	LunarLambert	0.5
	Albedo	0.0587
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=379"
}

#1_"2003 379 I" "Sol/379 Huenna" #1=
#2_"2003 379 I" "Sol/379 Huenna" #2=
#3_"2003 379 I" "Sol/379 Huenna" #3=
".:2003 379 I" "Sol/379 Huenna" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"antiope.dds"
	Radius	2.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	87.6
		SemiMajorAxis	3336
		Eccentricity	0.222
	}
	LunarLambert	0.5
	Albedo	0.0587
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00379.html"
}

#1_"380 Fiducia:Fiducia:1894 AR:1933 CA:1975 LX" "Sol" #1=
#2_"*Фидуция:380 Fiducia:Fiducia:1894 AR" "Sol" #2=
#3_"1894 AR:*Фидуция:380 Fiducia:Fiducia" "Sol" #3=
".:Fiducia:380 Fiducia:1894 AR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.595
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.383590872127
		SemiMajorAxis	2.678435594294
		Eccentricity	0.114937770793
		Inclination	6.158414140262
		AscendingNode	95.122405120228
		ArgOfPericenter	239.727680095112
		MeanAnomaly	336.656952932435
	}
	UniformRotation
	{
		Period	13.69
	}
	LunarLambert	0.5
	Albedo	0.0563
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=380"
}

#1_"381 Myrrha:Myrrha:1894 AS" "Sol" #1=
#2_"*Мирра:381 Myrrha:Myrrha:1894 AS" "Sol" #2=
#3_"1894 AS:*Мирра:381 Myrrha:Myrrha" "Sol" #3=
".:Myrrha:381 Myrrha:1894 AS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"381 myrrha.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	73.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.801441489246
		SemiMajorAxis	3.228631474225
		Eccentricity	0.090021001273
		Inclination	12.561313499829
		AscendingNode	125.123776922356
		ArgOfPericenter	141.749282526311
		MeanAnomaly	249.786136999672
	}
	UniformRotation
	{
		Period	6.572
	}
	LunarLambert	0.5
	Albedo	0.064
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=381"
}

#1_"382 Dodona:Dodona:1894 AT" "Sol" #1=
#2_"*Додона:382 Dodona:Dodona:1894 AT" "Sol" #2=
#3_"1894 AT:*Додона:382 Dodona:Dodona" "Sol" #3=
".:Dodona:382 Dodona:1894 AT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"382 dodona.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	32.604
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.513049178324
		SemiMajorAxis	3.120726984061
		Eccentricity	0.173867805908
		Inclination	7.400969641918
		AscendingNode	313.541052454561
		ArgOfPericenter	270.309526903991
		MeanAnomaly	258.944725307433
	}
	UniformRotation
	{
		Period	4.113
	}
	LunarLambert	0.5
	Albedo	0.129
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=382"
}

#1_"383 Janina:Janina:1894 AU:1925 QC:1936 QQ1:1936 RO" "Sol" #1=
#2_"*Янина:383 Janina:Janina:1894 AU" "Sol" #2=
#3_"1894 AU:*Янина:383 Janina:Janina" "Sol" #3=
".:Janina:383 Janina:1894 AU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	22.76
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.571274601139
		SemiMajorAxis	3.142661282196
		Eccentricity	0.163287569832
		Inclination	2.65299822575
		AscendingNode	93.062976083389
		ArgOfPericenter	321.855721195164
		MeanAnomaly	331.17051342557
	}
	UniformRotation
	{
		Period	6.4
	}
	LunarLambert	0.5
	Albedo	0.0926
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=383"
}

#1_"384 Burdigala:Burdigala:1894 AV:1950 DW:1969 ME" "Sol" #1=
#2_"*Бурдигала:384 Burdigala:Burdigala:1894 AV" "Sol" #2=
#3_"1894 AV:*Бурдигала:384 Burdigala:Burdigala" "Sol" #3=
".:Burdigala:384 Burdigala:1894 AV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	18.465
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.319626812378
		SemiMajorAxis	2.652316522014
		Eccentricity	0.148646770937
		Inclination	5.58900065771
		AscendingNode	47.877571242844
		ArgOfPericenter	35.350759124783
		MeanAnomaly	35.883852445321
	}
	UniformRotation
	{
		Period	21.1
	}
	LunarLambert	0.5
	Albedo	0.1805
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=384"
}

#1_"385 Ilmatar:Ilmatar:1894 AX:1942 FQ:1953 TQ:1987 QG3:A918 CC" "Sol" #1=
#2_"*Ильматар:385 Ilmatar:Ilmatar:1894 AX" "Sol" #2=
#3_"1894 AX:*Ильматар:385 Ilmatar:Ilmatar" "Sol" #3=
".:Ilmatar:385 Ilmatar:1894 AX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	45.765
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.811031600989
		SemiMajorAxis	2.849836896035
		Eccentricity	0.122401081496
		Inclination	13.551647051579
		AscendingNode	345.024742383468
		ArgOfPericenter	187.687085989506
		MeanAnomaly	44.006834368934
	}
	UniformRotation
	{
		Period	62.35
	}
	LunarLambert	0.5
	Albedo	0.2129
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=385"
}

#1_"386 Siegena:Siegena:1894 AY:1948 EW" "Sol" #1=
#2_"*Зигена:386 Siegena:Siegena:1894 AY" "Sol" #2=
#3_"1894 AY:*Зигена:386 Siegena:Siegena" "Sol" #3=
".:Siegena:386 Siegena:1894 AY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"386 siegena.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	82.505
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.933623816591
		SemiMajorAxis	2.898045633914
		Eccentricity	0.170030849064
		Inclination	20.248608577845
		AscendingNode	166.885640177832
		ArgOfPericenter	219.708799498057
		MeanAnomaly	146.501923897398
	}
	UniformRotation
	{
		Period	9.763
	}
	LunarLambert	0.5
	Albedo	0.0692
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=386"
}

#1_"387 Aquitania:Aquitania:1894 AZ:1945 NA:1948 BG:1953 EO1" "Sol" #1=
#2_"*Аквитания:387 Aquitania:Aquitania:1894 AZ" "Sol" #2=
#3_"1894 AZ:*Аквитания:387 Aquitania:Aquitania" "Sol" #3=
".:Aquitania:387 Aquitania:1894 AZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"387 aquitania.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	50.255
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.537714158401
		SemiMajorAxis	2.740854335308
		Eccentricity	0.235123701731
		Inclination	18.112573359542
		AscendingNode	128.241157784976
		ArgOfPericenter	157.143467557648
		MeanAnomaly	330.992694694305
	}
	UniformRotation
	{
		Period	24.144
	}
	LunarLambert	0.5
	Albedo	0.19
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=387"
}

#1_"388 Charybdis:Charybdis:1894 BA" "Sol" #1=
#2_"*Харибда:388 Charybdis:Charybdis:1894 BA" "Sol" #2=
#3_"1894 BA:*Харибда:388 Charybdis:Charybdis" "Sol" #3=
".:Charybdis:388 Charybdis:1894 BA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	57.085
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.205986045894
		SemiMajorAxis	3.003745950281
		Eccentricity	0.064625409979
		Inclination	6.446023103425
		AscendingNode	354.291228894172
		ArgOfPericenter	333.357894900206
		MeanAnomaly	257.08724923362
	}
	UniformRotation
	{
		Period	9.516
	}
	LunarLambert	0.5
	Albedo	0.0506
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=388"
}

#1_"389 Industria:Industria:1894 BB:1938 XG:1946 OJ:A910 EA" "Sol" #1=
#2_"*Индустрия:389 Industria:Industria:1894 BB" "Sol" #2=
#3_"1894 BB:*Индустрия:389 Industria:Industria" "Sol" #3=
".:Industria:389 Industria:1894 BB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"389 industria.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	37.189
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.210629346986
		SemiMajorAxis	2.607509346806
		Eccentricity	0.06758455354
		Inclination	8.123587438976
		AscendingNode	282.37008763194
		ArgOfPericenter	265.713788021691
		MeanAnomaly	207.68250029369
	}
	UniformRotation
	{
		Period	8.53
	}
	LunarLambert	0.5
	Albedo	0.225
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=389"
}

#1_"390 Alma:Alma:1894 BC:1930 QW:1950 BV:1950 CH:1953 YB:1963 DF" "Sol" #1=
#2_"*Альма:390 Alma:Alma:1894 BC" "Sol" #2=
#3_"1894 BC:*Альма:390 Alma:Alma" "Sol" #3=
".:Alma:390 Alma:1894 BC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"390 alma.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	12.844
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.318400171001
		SemiMajorAxis	2.651814380613
		Eccentricity	0.133110363273
		Inclination	12.166224051854
		AscendingNode	305.231150949478
		ArgOfPericenter	190.354770975137
		MeanAnomaly	359.762039335144
	}
	UniformRotation
	{
		Period	3.74
	}
	LunarLambert	0.5
	Albedo	0.268
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=390"
}

#1_"391 Ingeborg:Ingeborg:1894 BE:1934 AJ" "Sol" #1=
#2_"*Ингеборг:391 Ingeborg:Ingeborg:1894 BE" "Sol" #2=
#3_"1894 BE:Ingeborg:*Ингеборг:391 Ingeborg" "Sol" #3=
".:Ingeborg:391 Ingeborg:1894 BE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"391 ingeborg.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.876
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.53670359041
		SemiMajorAxis	2.3212770307
		Eccentricity	0.305088390183
		Inclination	23.198127786458
		AscendingNode	212.874846229473
		ArgOfPericenter	146.97342288402
		MeanAnomaly	236.493488868471
	}
	UniformRotation
	{
		Period	26.391
	}
	LunarLambert	0.5
	Albedo	0.29
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=391"
}

#1_"392 Wilhelmina:Wilhelmina:1894 BF:1931 HD:1933 SW:1933 UZ:1952 ON" "Sol" #1=
#2_"*Вильгельмина:392 Wilhelmina:Wilhelmina:1894 BF" "Sol" #2=
#3_"1894 BF:*Вильгельмина:392 Wilhelmina:Wilhelmina" "Sol" #3=
".:Wilhelmina:392 Wilhelmina:1894 BF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.893250264953
		SemiMajorAxis	2.882213517558
		Eccentricity	0.141532884313
		Inclination	14.32298405145
		AscendingNode	209.832074502957
		ArgOfPericenter	174.27769338221
		MeanAnomaly	201.010955330379
	}
	UniformRotation
	{
		Period	17.96
	}
	LunarLambert	0.5
	Albedo	0.0589
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=392"
}

#1_"393 Lampetia:Lampetia:1894 BG:A907 GR" "Sol" #1=
#2_"*Лампеция:393 Lampetia:Lampetia:1894 BG" "Sol" #2=
#3_"1894 BG:*Лампеция:393 Lampetia:Lampetia" "Sol" #3=
".:Lampetia:393 Lampetia:1894 BG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	48.445
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.630247409783
		SemiMajorAxis	2.77798990662
		Eccentricity	0.331642778287
		Inclination	14.878077113493
		AscendingNode	212.461435934935
		ArgOfPericenter	90.881619152348
		MeanAnomaly	45.393304601335
	}
	UniformRotation
	{
		Period	38.7
	}
	LunarLambert	0.5
	Albedo	0.0829
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=393"
}

#1_"394 Arduina:Arduina:1894 BH:1906 HA:1912 TB:A916 LB" "Sol" #1=
#2_"*Ардуина:394 Arduina:Arduina:1894 BH" "Sol" #2=
#3_"1894 BH:*Ардуина:394 Arduina:Arduina" "Sol" #3=
".:Arduina:394 Arduina:1894 BH" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"394 arduina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	14.985
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.594676607516
		SemiMajorAxis	2.763744118606
		Eccentricity	0.227025510593
		Inclination	6.217151735652
		AscendingNode	67.313051828679
		ArgOfPericenter	269.71823906398
		MeanAnomaly	103.730994735552
	}
	UniformRotation
	{
		Period	16.53
	}
	LunarLambert	0.5
	Albedo	0.294
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=394"
}

#1_"395 Delia:Delia:1894 BK:1926 SA:1972 JF:A916 OG:A924 EM" "Sol" #1=
#2_"*Делия:395 Delia:Delia:1894 BK" "Sol" #2=
#3_"1894 BK:*Делия:395 Delia:Delia" "Sol" #3=
".:Delia:395 Delia:1894 BK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.49
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.64629918807
		SemiMajorAxis	2.78440654764
		Eccentricity	0.086380313347
		Inclination	3.350606410054
		AscendingNode	259.390451562449
		ArgOfPericenter	11.588040061114
		MeanAnomaly	85.544348050727
	}
	UniformRotation
	{
		Period	19.71
	}
	LunarLambert	0.5
	Albedo	0.0479
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=395"
}

#1_"396 Aeolia:Aeolia:1894 BL:1925 RH:1950 CL:A916 UG" "Sol" #1=
#2_"*Эолия:396 Aeolia:Aeolia:1894 BL" "Sol" #2=
#3_"1894 BL:*Эолия:396 Aeolia:Aeolia" "Sol" #3=
".:Aeolia:396 Aeolia:1894 BL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	17.045
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.538234790771
		SemiMajorAxis	2.741063978336
		Eccentricity	0.159124341044
		Inclination	2.550136069577
		AscendingNode	249.945593913283
		ArgOfPericenter	21.824326977856
		MeanAnomaly	311.571550056292
	}
	UniformRotation
	{
		Period	22.2
	}
	LunarLambert	0.5
	Albedo	0.1667
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=396"
}

#1_"397 Vienna:Vienna:1894 BM:1941 WA1:1951 AV1" "Sol" #1=
#2_"*Вена:397 Vienna:Vienna:1894 BM" "Sol" #2=
#3_"1894 BM:*Вена:397 Vienna:Vienna" "Sol" #3=
".:Vienna:397 Vienna:1894 BM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	21.67
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.281075948506
		SemiMajorAxis	2.636512411698
		Eccentricity	0.245313308219
		Inclination	12.829753443705
		AscendingNode	228.177701838852
		ArgOfPericenter	139.409888833523
		MeanAnomaly	64.795123727391
	}
	UniformRotation
	{
		Period	15.48
	}
	LunarLambert	0.5
	Albedo	0.1776
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=397"
}

#1_"398 Admete:Admete:1894 BN:1951 LP:1952 QC1:A907 RE" "Sol" #1=
#2_"*Адмета:398 Admete:Admete:1894 BN" "Sol" #2=
#3_"1894 BN:*Адмета:398 Admete:Admete" "Sol" #3=
".:Admete:398 Admete:1894 BN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.49
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.532461513711
		SemiMajorAxis	2.738738804243
		Eccentricity	0.22392030327
		Inclination	9.528447577987
		AscendingNode	279.988626602418
		ArgOfPericenter	159.025501598704
		MeanAnomaly	183.759199682184
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0607
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=398"
}

#1_"399 Persephone:Persephone:1895 BP:1948 CC" "Sol" #1=
#2_"*Персефона:399 Persephone:Persephone:1895 BP" "Sol" #2=
#3_"1895 BP:*Персефона:399 Persephone:Persephone" "Sol" #3=
".:Persephone:399 Persephone:1895 BP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"399 persephone.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	19.783
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.334942203703
		SemiMajorAxis	3.053146739328
		Eccentricity	0.073126578539
		Inclination	13.112123018283
		AscendingNode	346.392974964986
		ArgOfPericenter	193.737285750607
		MeanAnomaly	144.539284090976
	}
	UniformRotation
	{
		Period	9.136
	}
	LunarLambert	0.5
	Albedo	0.311
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=399"
}

#1_"400 Ducrosa:Ducrosa:1895 BU:1939 BH:1950 BC1:1950 BQ:1950 CB" "Sol" #1=
#2_"*Дакроса:400 Ducrosa:Ducrosa:1895 BU" "Sol" #2=
#3_"1895 BU:*Дакроса:400 Ducrosa:Ducrosa" "Sol" #3=
".:Ducrosa:400 Ducrosa:1895 BU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"400 ducrosa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	18
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.527281186475
		SemiMajorAxis	3.126095474107
		Eccentricity	0.116230169255
		Inclination	10.535643903624
		AscendingNode	327.145010794345
		ArgOfPericenter	238.534524806078
		MeanAnomaly	187.066664229313
	}
	UniformRotation
	{
		Period	6.87
	}
	LunarLambert	0.5
	Albedo	0.112
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=400"
}

#1_"401 Ottilia:Ottilia:1895 BT:1931 DA" "Sol" #1=
#2_"*Оттилия:401 Ottilia:Ottilia:1895 BT" "Sol" #2=
#3_"1895 BT:*Оттилия:401 Ottilia:Ottilia" "Sol" #3=
".:Ottilia:401 Ottilia:1895 BT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	49.56
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.110672782837
		SemiMajorAxis	3.34236507152
		Eccentricity	0.037593298132
		Inclination	5.9716173651
		AscendingNode	36.156358195766
		ArgOfPericenter	294.424835556222
		MeanAnomaly	76.381931958688
	}
	UniformRotation
	{
		Period	6.049
	}
	LunarLambert	0.5
	Albedo	0.0412
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=401"
}

#1_"402 Chloe:Chloe:1895 BW:1949 OC1:A908 LA" "Sol" #1=
#2_"*Хлоя:402 Chloe:Chloe:1895 BW" "Sol" #2=
#3_"1895 BW:*Хлоя:402 Chloe:Chloe" "Sol" #3=
".:Chloe:402 Chloe:1895 BW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"402 chloe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	27.71
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.094471547469
		SemiMajorAxis	2.55933088058
		Eccentricity	0.11091492974
		Inclination	11.826366796697
		AscendingNode	129.42105316291
		ArgOfPericenter	17.431988683167
		MeanAnomaly	119.123250345441
	}
	UniformRotation
	{
		Period	10.664
	}
	LunarLambert	0.5
	Albedo	0.164
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=402"
}

#1_"403 Cyane:Cyane:1895 BX" "Sol" #1=
#2_"*Киана:403 Cyane:Cyane:1895 BX" "Sol" #2=
#3_"1895 BX:*Киана:403 Cyane:Cyane" "Sol" #3=
".:Cyane:403 Cyane:1895 BX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"403 cyane.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	26.787
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.711639817114
		SemiMajorAxis	2.810450371385
		Eccentricity	0.096513230164
		Inclination	9.147503631493
		AscendingNode	244.419780309348
		ArgOfPericenter	255.374863701564
		MeanAnomaly	224.882607602271
	}
	UniformRotation
	{
		Period	12.283
	}
	LunarLambert	0.5
	Albedo	0.173
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=403"
}

#1_"404 Arsinoe:Arsinoe:1895 BY:1947 XE:1975 VB10:A901 VC" "Sol" #1=
#2_"*Арсиноя:404 Arsinoe:Arsinoe:1895 BY" "Sol" #2=
#3_"1895 BY:*Арсиноя:404 Arsinoe:Arsinoe" "Sol" #3=
".:Arsinoe:404 Arsinoe:1895 BY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"404 arsinoe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	47.485
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.176984765389
		SemiMajorAxis	2.593600767426
		Eccentricity	0.199435645124
		Inclination	14.110659399736
		AscendingNode	92.643696091242
		ArgOfPericenter	120.474004929985
		MeanAnomaly	259.953165231473
	}
	UniformRotation
	{
		Period	8.887
	}
	LunarLambert	0.5
	Albedo	0.037
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=404"
}

#1_"405 Thia:Thia:1895 BZ:1950 XA:1951 AO:1956 EZ" "Sol" #1=
#2_"*Тейя:405 Thia:Thia:1895 BZ" "Sol" #2=
#3_"1895 BZ:*Тейя:405 Thia:Thia" "Sol" #3=
".:Thia:405 Thia:1895 BZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	62.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.157436899662
		SemiMajorAxis	2.585502583445
		Eccentricity	0.242356198856
		Inclination	11.939266853917
		AscendingNode	255.258245827053
		ArgOfPericenter	308.742995343023
		MeanAnomaly	345.390648281664
	}
	UniformRotation
	{
		Period	10.08
	}
	LunarLambert	0.5
	Albedo	0.0468
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=405"
}

#1_"406 Erna:Erna:1895 CB:1949 KD1:A903 DA:A905 OB" "Sol" #1=
#2_"*Эрна:406 Erna:Erna:1895 CB" "Sol" #2=
#3_"1895 CB:*Эрна:406 Erna:Erna" "Sol" #3=
".:Erna:406 Erna:1895 CB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"406 erna.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	23.133
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.978019801452
		SemiMajorAxis	2.915405340694
		Eccentricity	0.182194687184
		Inclination	4.193496380118
		AscendingNode	315.773518495347
		ArgOfPericenter	37.298616547425
		MeanAnomaly	330.740795905875
	}
	UniformRotation
	{
		Period	8.789
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=406"
}

#1_"407 Arachne:Arachne:1895 CC:1950 UG" "Sol" #1=
#2_"*Арахна:407 Arachne:Arachne:1895 CC" "Sol" #2=
#3_"1895 CC:*Арахна:407 Arachne:Arachne" "Sol" #3=
".:Arachne:407 Arachne:1895 CC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"407 arachne.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	47.535
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.251975041242
		SemiMajorAxis	2.624550918594
		Eccentricity	0.068975476297
		Inclination	7.52736837826
		AscendingNode	294.736033695373
		ArgOfPericenter	80.822057274337
		MeanAnomaly	17.215193129858
	}
	UniformRotation
	{
		Period	22.627
	}
	LunarLambert	0.5
	Albedo	0.0548
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=407"
}

#1_"408 Fama:Fama:1895 CD:1917 Sdv:1940 TG:A906 RC:A908 AB" "Sol" #1=
#2_"*Фама:408 Fama:Fama:1895 CD" "Sol" #2=
#3_"1895 CD:*Фама:408 Fama:Fama" "Sol" #3=
".:Fama:408 Fama:1895 CD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	20.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.64230501097
		SemiMajorAxis	3.169316206836
		Eccentricity	0.139805962698
		Inclination	9.10678956345
		AscendingNode	297.452255214641
		ArgOfPericenter	108.106073337547
		MeanAnomaly	44.625254834493
	}
	UniformRotation
	{
		Period	202.1
	}
	LunarLambert	0.5
	Albedo	0.1681
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=408"
}

#1_"409 Aspasia:Aspasia:1895 CE:1948 RT1:1949 CB:A904 AB" "Sol" #1=
#2_"*Аспасия:409 Aspasia:Aspasia:1895 CE" "Sol" #2=
#3_"1895 CE:*Аспасия:409 Aspasia:Aspasia" "Sol" #3=
".:Aspasia:409 Aspasia:1895 CE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"409 aspasia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	85.506
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.134774459218
		SemiMajorAxis	2.576098205673
		Eccentricity	0.073090439597
		Inclination	11.266577922688
		AscendingNode	242.152295481059
		ArgOfPericenter	353.219695396868
		MeanAnomaly	356.216652532221
	}
	UniformRotation
	{
		Period	9.022
	}
	LunarLambert	0.5
	Albedo	0.054
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=409"
}

#1_"410 Chloris:Chloris:1896 CH:A902 UK:A906 GB" "Sol" #1=
#2_"*Хлорида:410 Chloris:Chloris:1896 CH" "Sol" #2=
#3_"1896 CH:*Хлорида:410 Chloris:Chloris" "Sol" #3=
".:Chloris:410 Chloris:1896 CH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	61.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.496173767608
		SemiMajorAxis	2.724101320851
		Eccentricity	0.241296586886
		Inclination	10.963030328987
		AscendingNode	96.952495497657
		ArgOfPericenter	172.986181092646
		MeanAnomaly	354.244482631645
	}
	UniformRotation
	{
		Period	32.5
	}
	LunarLambert	0.5
	Albedo	0.0554
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=410"
}

#1_"411 Xanthe:Xanthe:1896 CJ:A906 BD:A907 GA" "Sol" #1=
#2_"*Ксанта:411 Xanthe:Xanthe:1896 CJ" "Sol" #2=
#3_"1896 CJ:*Ксанта:411 Xanthe:Xanthe" "Sol" #3=
".:Xanthe:411 Xanthe:1896 CJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.025664844581
		SemiMajorAxis	2.933978183995
		Eccentricity	0.116969571955
		Inclination	15.344231838669
		AscendingNode	107.470077221212
		ArgOfPericenter	181.933322724023
		MeanAnomaly	52.037106366927
	}
	UniformRotation
	{
		Period	11.344
	}
	LunarLambert	0.5
	Albedo	0.0831
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=411"
}

#1_"412 Elisabetha:Elisabetha:1896 CK:1953 NM" "Sol" #1=
#2_"*Элизабета:412 Elisabetha:Elisabetha:1896 CK" "Sol" #2=
#3_"1896 CK:*Элизабета:412 Elisabetha:Elisabetha" "Sol" #3=
".:Elisabetha:412 Elisabetha:1896 CK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	45.48
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.58965093795
		SemiMajorAxis	2.761728423891
		Eccentricity	0.043902333099
		Inclination	13.777177968124
		AscendingNode	106.525056971723
		ArgOfPericenter	93.202012236108
		MeanAnomaly	230.818094684509
	}
	UniformRotation
	{
		Period	19.635
	}
	LunarLambert	0.5
	Albedo	0.0536
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=412"
}

#1_"413 Edburga:Edburga:1896 CL:A917 CD" "Sol" #1=
#2_"*Эдбурга:413 Edburga:Edburga:1896 CL" "Sol" #2=
#3_"1896 CL:*Эдбурга:413 Edburga:Edburga" "Sol" #3=
".:Edburga:413 Edburga:1896 CL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"413 edburga.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	17.121
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.15227180058
		SemiMajorAxis	2.583360695857
		Eccentricity	0.343647926132
		Inclination	18.72139320403
		AscendingNode	103.869250354817
		ArgOfPericenter	252.678011113357
		MeanAnomaly	300.998138302052
	}
	UniformRotation
	{
		Period	15.773
	}
	LunarLambert	0.5
	Albedo	0.129
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=413"
}

#1_"414 Liriope:Liriope:1896 CN:1928 WE:1931 MF:1960 WV:A907 VP:A922 BA" "Sol" #1=
#2_"*Лириопа:414 Liriope:Liriope:1896 CN" "Sol" #2=
#3_"1896 CN:*Лириопа:414 Liriope:Liriope" "Sol" #3=
".:Liriope:414 Liriope:1896 CN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.945
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.569225643736
		SemiMajorAxis	3.507550922731
		Eccentricity	0.072266510409
		Inclination	9.558593156298
		AscendingNode	110.606576451881
		ArgOfPericenter	320.429254108594
		MeanAnomaly	88.80841675244
	}
	UniformRotation
	{
		Period	7.353
	}
	LunarLambert	0.5
	Albedo	0.0579
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=414"
}

#1_"415 Palatia:Palatia:1896 CO:1954 MG:1959 OF:A899 TB" "Sol" #1=
#2_"*Палатия:415 Palatia:Palatia:1896 CO" "Sol" #2=
#3_"1896 CO:*Палатия:415 Palatia:Palatia" "Sol" #3=
".:Palatia:415 Palatia:1896 CO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38.17
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.667422158751
		SemiMajorAxis	2.792839131837
		Eccentricity	0.300893089701
		Inclination	8.171595552264
		AscendingNode	126.978437020634
		ArgOfPericenter	297.147313978486
		MeanAnomaly	228.09599430915
	}
	UniformRotation
	{
		Period	20.73
	}
	LunarLambert	0.5
	Albedo	0.0628
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=415"
}

#1_"416 Vaticana:Vaticana:1896 CS:1975 LE" "Sol" #1=
#2_"*Ватикана:416 Vaticana:Vaticana:1896 CS" "Sol" #2=
#3_"1896 CS:*Ватикана:416 Vaticana:Vaticana" "Sol" #3=
".:Vaticana:416 Vaticana:1896 CS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"416 vaticana.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	42.735
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.660334030472
		SemiMajorAxis	2.790010873149
		Eccentricity	0.21904864424
		Inclination	12.860260354629
		AscendingNode	58.130966355203
		ArgOfPericenter	198.301217518247
		MeanAnomaly	140.902870606983
	}
	UniformRotation
	{
		Period	5.372
	}
	LunarLambert	0.5
	Albedo	0.1689
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=416"
}

#1_"417 Suevia:Suevia:1896 CT:1943 MB:1945 WD:1948 LL:1948 MC:1952 HU1:1954 UH3" "Sol" #1=
#2_"*Суэвия:417 Suevia:Suevia:1896 CT" "Sol" #2=
#3_"1896 CT:*Суэвия:417 Suevia:Suevia" "Sol" #3=
".:Suevia:417 Suevia:1896 CT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"417 suevia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	27.437
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.68582820176
		SemiMajorAxis	2.800176713966
		Eccentricity	0.134843858009
		Inclination	6.648001297507
		AscendingNode	199.530510127387
		ArgOfPericenter	349.217872348339
		MeanAnomaly	137.86401865651
	}
	UniformRotation
	{
		Period	7.034
	}
	LunarLambert	0.5
	Albedo	0.072
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=417"
}

#1_"418 Alemannia:Alemannia:1896 CV" "Sol" #1=
#2_"*Алеманния:418 Alemannia:Alemannia:1896 CV" "Sol" #2=
#3_"1896 CV:*Алеманния:418 Alemannia:Alemannia" "Sol" #3=
".:Alemannia:418 Alemannia:1896 CV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	17.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.178832917195
		SemiMajorAxis	2.594365755378
		Eccentricity	0.117833799461
		Inclination	6.816435651585
		AscendingNode	248.978729269988
		ArgOfPericenter	126.405545405266
		MeanAnomaly	91.270880465867
	}
	UniformRotation
	{
		Period	4.671
	}
	LunarLambert	0.5
	Albedo	0.1878
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=418"
}

#1_"419 Aurelia:Aurelia:1896 CW" "Sol" #1=
#2_"*Аврелия:419 Aurelia:Aurelia:1896 CW" "Sol" #2=
#3_"1896 CW:*Аврелия:419 Aurelia:Aurelia" "Sol" #3=
".:Aurelia:419 Aurelia:1896 CW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"419 aurelia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	74.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.185021414354
		SemiMajorAxis	2.596926480712
		Eccentricity	0.25059659098
		Inclination	3.926184524534
		AscendingNode	229.12608080171
		ArgOfPericenter	44.399177331749
		MeanAnomaly	31.937689805973
	}
	UniformRotation
	{
		Period	16.784
	}
	LunarLambert	0.5
	Albedo	0.034
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=419"
}

#1_"420 Bertholda:Bertholda:1896 CY" "Sol" #1=
#2_"*Бертольда:420 Bertholda:Bertholda:1896 CY" "Sol" #2=
#3_"1896 CY:*Бертольда:420 Bertholda:Bertholda" "Sol" #3=
".:Bertholda:420 Bertholda:1896 CY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	70.625
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.309609802023
		SemiMajorAxis	3.414518998494
		Eccentricity	0.031305242847
		Inclination	6.689247451004
		AscendingNode	242.681591685157
		ArgOfPericenter	235.488204580468
		MeanAnomaly	126.871818377022
	}
	UniformRotation
	{
		Period	11.04
	}
	LunarLambert	0.5
	Albedo	0.042
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=420"
}

#1_"423 Diotima:Diotima:1896 DB:1951 UV:1975 LV" "Sol" #1=
#2_"*Диотима:423 Diotima:Diotima:1896 DB" "Sol" #2=
#3_"1896 DB:*Диотима:423 Diotima:Diotima" "Sol" #3=
".:Diotima:423 Diotima:1896 DB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"423 diotima.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	85.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.380531367535
		SemiMajorAxis	3.070515614363
		Eccentricity	0.037327481801
		Inclination	11.238225182228
		AscendingNode	69.382406732935
		ArgOfPericenter	198.497768040877
		MeanAnomaly	312.393671625145
	}
	UniformRotation
	{
		Period	4.775
	}
	LunarLambert	0.5
	Albedo	0.067
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=423"
}

#1_"424 Gratia:Gratia:1896 DF:1948 DB:1959 MA" "Sol" #1=
#2_"*Грация:424 Gratia:Gratia:1896 DF" "Sol" #2=
#3_"1896 DF:*Грация:424 Gratia:Gratia" "Sol" #3=
".:Gratia:424 Gratia:1896 DF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	43.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.622056035164
		SemiMajorAxis	2.774712576957
		Eccentricity	0.108349304523
		Inclination	8.209721696416
		AscendingNode	99.256655542219
		ArgOfPericenter	331.770259620197
		MeanAnomaly	222.375037284814
	}
	UniformRotation
	{
		Period	19.47
	}
	LunarLambert	0.5
	Albedo	0.0279
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=424"
}

#1_"425 Cornelia:Cornelia:1896 DC:1949 SG1:1951 BC:1952 HS1" "Sol" #1=
#2_"*Корнелия:425 Cornelia:Cornelia:1896 DC" "Sol" #2=
#3_"1896 DC:*Корнелия:425 Cornelia:Cornelia" "Sol" #3=
".:Cornelia:425 Cornelia:1896 DC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.925
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.90761008013
		SemiMajorAxis	2.887849558296
		Eccentricity	0.061523863239
		Inclination	4.04755825294
		AscendingNode	61.148683491312
		ArgOfPericenter	121.632830600857
		MeanAnomaly	304.68611459361
	}
	UniformRotation
	{
		Period	17.56
	}
	LunarLambert	0.5
	Albedo	0.0475
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=425"
}

#1_"426 Hippo:Hippo:1897 DH" "Sol" #1=
#2_"*Гиппон:426 Hippo:Hippo:1897 DH" "Sol" #2=
#3_"1897 DH:*Гиппон:426 Hippo:Hippo" "Sol" #3=
".:Hippo:426 Hippo:1897 DH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	63.55
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.913366775438
		SemiMajorAxis	2.890107442317
		Eccentricity	0.103576981994
		Inclination	19.478885582586
		AscendingNode	311.42933969717
		ArgOfPericenter	222.122238323589
		MeanAnomaly	127.532968008749
	}
	UniformRotation
	{
		Period	34.3
	}
	LunarLambert	0.5
	Albedo	0.0469
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=426"
}

#1_"427 Galene:Galene:1897 DJ:1971 BD4:1992 AQ3:A905 BC" "Sol" #1=
#2_"*Галена:427 Galene:Galene:1897 DJ" "Sol" #2=
#3_"1897 DJ:*Галена:427 Galene:Galene" "Sol" #3=
".:Galene:427 Galene:1897 DJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"427 galene.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	16.096
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.122544428467
		SemiMajorAxis	2.971563539564
		Eccentricity	0.120568162351
		Inclination	5.124377359745
		AscendingNode	297.437866490665
		ArgOfPericenter	12.459395868614
		MeanAnomaly	334.493332067875
	}
	UniformRotation
	{
		Period	3.705
	}
	LunarLambert	0.5
	Albedo	0.205
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=427"
}

#1_"428 Monachia:Monachia:1897 DK:1946 UL:1949 OE:1953 TN3:1974 XU" "Sol" #1=
#2_"*Монахия:428 Monachia:Monachia:1897 DK" "Sol" #2=
#3_"1897 DK:*Монахия:428 Monachia:Monachia" "Sol" #3=
".:Monachia:428 Monachia:1897 DK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"gaspra.jpg"
	Radius	8.825
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.504940808493
		SemiMajorAxis	2.307358039442
		Eccentricity	0.179027265015
		Inclination	6.199311850942
		AscendingNode	17.632046482099
		ArgOfPericenter	15.542210686049
		MeanAnomaly	158.828396018499
	}
	UniformRotation
	{
		Period	3.6338
	}
	LunarLambert	0.5
	Albedo	0.1142
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=428"
}

#1_"429 Lotis:Lotis:1897 DL:A905 SA" "Sol" #1=
#2_"*Лотида:429 Lotis:Lotis:1897 DL" "Sol" #2=
#3_"1897 DL:*Лотида:429 Lotis:Lotis" "Sol" #3=
".:Lotis:429 Lotis:1897 DL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.21124222491
		SemiMajorAxis	2.607762364588
		Eccentricity	0.123110053702
		Inclination	9.53239199863
		AscendingNode	219.987521788164
		ArgOfPericenter	167.961249342214
		MeanAnomaly	308.765849713275
	}
	UniformRotation
	{
		Period	13.577
	}
	LunarLambert	0.5
	Albedo	0.043
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=429"
}

#1_"430 Hybris:Hybris:1897 DM:1952 HO2" "Sol" #1=
#2_"*Гибрида:430 Hybris:Hybris:1897 DM" "Sol" #2=
#3_"1897 DM:*Гибрида:430 Hybris:Hybris" "Sol" #3=
".:Hybris:430 Hybris:1897 DM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.665
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.795141362977
		SemiMajorAxis	2.843558332487
		Eccentricity	0.255645410096
		Inclination	14.599962177763
		AscendingNode	249.448536195348
		ArgOfPericenter	179.065773583807
		MeanAnomaly	149.884589720382
	}
	UniformRotation
	{
		Period	7.205
	}
	LunarLambert	0.5
	Albedo	0.1206
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=430"
}

#1_"431 Nephele:Nephele:1897 DN:1933 KC:1949 YS:1955 DU:A906 HC" "Sol" #1=
#2_"*Нефела:431 Nephele:Nephele:1897 DN" "Sol" #2=
#3_"1897 DN:*Нефела:431 Nephele:Nephele" "Sol" #3=
".:Nephele:431 Nephele:1897 DN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	47.515
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.566971738714
		SemiMajorAxis	3.141042959479
		Eccentricity	0.171193751314
		Inclination	1.828112373069
		AscendingNode	117.27190098069
		ArgOfPericenter	214.515088276301
		MeanAnomaly	126.7022282486
	}
	UniformRotation
	{
		Period	18.821
	}
	LunarLambert	0.5
	Albedo	0.0636
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=431"
}

#1_"432 Pythia:Pythia:1897 DO:1936 PR" "Sol" #1=
#2_"*Пифия:432 Pythia:Pythia:1897 DO" "Sol" #2=
#3_"1897 DO:*Пифия:432 Pythia:Pythia" "Sol" #3=
".:Pythia:432 Pythia:1897 DO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	23.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.64652324868
		SemiMajorAxis	2.36908434558
		Eccentricity	0.146529477632
		Inclination	12.127369820741
		AscendingNode	88.809627481931
		ArgOfPericenter	173.818982147351
		MeanAnomaly	202.428820967461
	}
	UniformRotation
	{
		Period	8.252
	}
	LunarLambert	0.5
	Albedo	0.2338
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=432"
}

#1_"433 Eros:Eros:1898 DQ:1956 PC" "Sol" #1=
#2_"*Эрос:433 Eros:Eros:1898 DQ" "Sol" #2=
#3_"1898 DQ:*Эрос:433 Eros:Eros" "Sol" #3=
".:Eros:433 Eros:1898 DQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"433 eros.cmod"
	Orientation	[ 90 0 1 0 ]
	Radius	17.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.7604630749018
		SemiMajorAxis	1.457960681567809
		Eccentricity	0.2226338073109678
		Inclination	10.8289993701657
		AscendingNode	304.3345371635228
		ArgOfPericenter	178.7956772122569
		MeanAnomaly	231.4013672840452
	}
	UniformRotation
	{
		Period	5.270
		Inclination	78.70
		AscendingNode	107.23
		MeridianAngle	338.165
	}
	LunarLambert	0.5
	Albedo	0.25
	InfoURL	"https://en.wikipedia.org/wiki/433_Eros"
}

#1_"434 Hungaria:Hungaria:1898 DR" "Sol" #1=
#2_"*Венгрия:434 Hungaria:Hungaria:1898 DR" "Sol" #2=
#3_"1898 DR:Hungaria:*Венгрия:434 Hungaria" "Sol" #3=
".:Hungaria:434 Hungaria:1898 DR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"434 hungaria.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.467
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.711238597759
		SemiMajorAxis	1.94434364164
		Eccentricity	0.073516319454
		Inclination	22.509462368369
		AscendingNode	175.330011293546
		ArgOfPericenter	123.872028448176
		MeanAnomaly	293.752533856448
	}
	UniformRotation
	{
		Period	26.521
	}
	LunarLambert	0.5
	Albedo	0.428
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=434"
}

#1_"435 Ella:Ella:1898 DS:1947 KE" "Sol" #1=
#2_"*Элла:435 Ella:Ella:1898 DS" "Sol" #2=
#3_"1898 DS:*Элла:435 Ella:Ella" "Sol" #3=
".:Ella:435 Ella:1898 DS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"435 ella.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	17.396
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.83766737092
		SemiMajorAxis	2.451166156153
		Eccentricity	0.154087627892
		Inclination	1.81616496074
		AscendingNode	23.226728552581
		ArgOfPericenter	333.367322300597
		MeanAnomaly	111.637095859219
	}
	UniformRotation
	{
		Period	4.623
	}
	LunarLambert	0.5
	Albedo	0.118
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=435"
}

#1_"436 Patricia:Patricia:1898 DT:1938 XF:1972 TJ" "Sol" #1=
#2_"*Патриция:436 Patricia:Patricia:1898 DT" "Sol" #2=
#3_"1898 DT:*Патриция:436 Patricia:Patricia" "Sol" #3=
".:Patricia:436 Patricia:1898 DT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"436 patricia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	29.304
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.739716432728
		SemiMajorAxis	3.205689758544
		Eccentricity	0.064409692417
		Inclination	18.483001987289
		AscendingNode	351.387957822975
		ArgOfPericenter	40.797853340168
		MeanAnomaly	79.508412536071
	}
	UniformRotation
	{
		Period	16.133
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=436"
}

#1_"437 Rhodia:Rhodia:1898 DP" "Sol" #1=
#2_"*Родия:437 Rhodia:Rhodia:1898 DP" "Sol" #2=
#3_"1898 DP:*Родия:437 Rhodia:Rhodia" "Sol" #3=
".:Rhodia:437 Rhodia:1898 DP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.6865
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.688197594714
		SemiMajorAxis	2.387100215615
		Eccentricity	0.248054456959
		Inclination	7.344242576001
		AscendingNode	263.266743108318
		ArgOfPericenter	61.901762680657
		MeanAnomaly	194.915368625095
	}
	UniformRotation
	{
		Period	56
	}
	LunarLambert	0.5
	Albedo	0.677
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=437"
}

#1_"438 Zeuxo:Zeuxo:1898 DU:A902 UC:A912 BC" "Sol" #1=
#2_"*Зеуксо:438 Zeuxo:Zeuxo:1898 DU" "Sol" #2=
#3_"1898 DU:*Зеуксо:438 Zeuxo:Zeuxo" "Sol" #3=
".:Zeuxo:438 Zeuxo:1898 DU" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	30.57
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.080927290536
		SemiMajorAxis	2.553683692828
		Eccentricity	0.067561710206
		Inclination	7.372183100975
		AscendingNode	49.151390167297
		ArgOfPericenter	211.252292592023
		MeanAnomaly	298.712171688087
	}
	UniformRotation
	{
		Period	8.831
	}
	LunarLambert	0.5
	Albedo	0.0568
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=438"
}

#1_"439 Ohio:Ohio:1898 EB:1934 CO1:1936 QP1" "Sol" #1=
#2_"*Огайо:439 Ohio:Ohio:1898 EB" "Sol" #2=
#3_"1898 EB:*Огайо:439 Ohio:Ohio" "Sol" #3=
".:Ohio:439 Ohio:1898 EB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38.285
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.545967693662
		SemiMajorAxis	3.133137265275
		Eccentricity	0.062577600062
		Inclination	19.151738703346
		AscendingNode	201.560967135617
		ArgOfPericenter	241.457068770734
		MeanAnomaly	288.931996466084
	}
	UniformRotation
	{
		Period	19.2
	}
	LunarLambert	0.5
	Albedo	0.0352
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=439"
}

#1_"440 Theodora:Theodora:1898 EC" "Sol" #1=
#2_"*Феодора:440 Theodora:Theodora:1898 EC" "Sol" #2=
#3_"1898 EC:*Феодора:440 Theodora:Theodora" "Sol" #3=
".:Theodora:440 Theodora:1898 EC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"440 theodora.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.285529685119
		SemiMajorAxis	2.210029795128
		Eccentricity	0.107406264091
		Inclination	1.595959078062
		AscendingNode	292.135098215188
		ArgOfPericenter	179.028416459328
		MeanAnomaly	104.695885196095
	}
	UniformRotation
	{
		Period	4.828
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=440"
}

#1_"441 Bathilde:Bathilde:1898 ED" "Sol" #1=
#2_"*Батильда:441 Bathilde:Bathilde:1898 ED" "Sol" #2=
#3_"1898 ED:*Батильда:441 Bathilde:Bathilde" "Sol" #3=
".:Bathilde:441 Bathilde:1898 ED" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"441 bathilde.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	32.566
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.704475789166
		SemiMajorAxis	2.807600797202
		Eccentricity	0.078699589254
		Inclination	8.146477610054
		AscendingNode	253.602042631348
		ArgOfPericenter	201.364416870611
		MeanAnomaly	222.772056813176
	}
	UniformRotation
	{
		Period	10.446
	}
	LunarLambert	0.5
	Albedo	0.204
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=441"
}

#1_"442 Eichsfeldia:Eichsfeldia:1899 EE:A892 FA" "Sol" #1=
#2_"*Айхсфельдия:442 Eichsfeldia:Eichsfeldia:1899 EE" "Sol" #2=
#3_"1899 EE:*Айхсфельдия:442 Eichsfeldia:Eichsfeldia" "Sol" #3=
".:Eichsfeldia:442 Eichsfeldia:1899 EE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.0855
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.591579502731
		SemiMajorAxis	2.345226834048
		Eccentricity	0.07040736294
		Inclination	6.069088648222
		AscendingNode	134.938051472752
		ArgOfPericenter	84.913415315443
		MeanAnomaly	21.489688814559
	}
	UniformRotation
	{
		Period	11.871
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=442"
}

#1_"443 Photographica:Photographica:1899 EF:1930 YG:1930 YJ:1947 WC" "Sol" #1=
#2_"*Фотографика:443 Photographica:Photographica:1899 EF" "Sol" #2=
#3_"1899 EF:*Фотографика:443 Photographica:Photographica" "Sol" #3=
".:Photographica:443 Photographica:1899 EF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.297069216704
		SemiMajorAxis	2.215201524046
		Eccentricity	0.040214812488
		Inclination	4.235444236291
		AscendingNode	175.452071601174
		ArgOfPericenter	349.046143067881
		MeanAnomaly	30.063063212725
	}
	UniformRotation
	{
		Period	19.795
	}
	LunarLambert	0.5
	Albedo	0.1918
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=443"
}

#1_"444 Gyptis:Gyptis:1899 EL:1950 HB1:A899 PD" "Sol" #1=
#2_"*Гиптида:444 Gyptis:Gyptis:1899 EL" "Sol" #2=
#3_"1899 EL:*Гиптида:444 Gyptis:Gyptis" "Sol" #3=
".:Gyptis:444 Gyptis:1899 EL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	81.54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.607822280153
		SemiMajorAxis	2.769013110843
		Eccentricity	0.175624374736
		Inclination	10.277862515787
		AscendingNode	195.725722022464
		ArgOfPericenter	155.103993283579
		MeanAnomaly	243.462982109117
	}
	UniformRotation
	{
		Period	6.214
	}
	LunarLambert	0.5
	Albedo	0.049
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=444"
}

#1_"445 Edna:Edna:1899 EX:1978 PJ5:A918 CB" "Sol" #1=
#2_"*Эдна:445 Edna:Edna:1899 EX" "Sol" #2=
#3_"1899 EX:*Эдна:445 Edna:Edna" "Sol" #3=
".:Edna:445 Edna:1899 EX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	43.585
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.734076180741
		SemiMajorAxis	3.203589322538
		Eccentricity	0.19258269896
		Inclination	21.366935553276
		AscendingNode	292.351972354623
		ArgOfPericenter	80.841351245246
		MeanAnomaly	87.38023955064
	}
	UniformRotation
	{
		Period	19.97
	}
	LunarLambert	0.5
	Albedo	0.0447
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=445"
}

#1_"446 Aeternitas:Aeternitas:1899 ER" "Sol" #1=
#2_"*Этернитас:446 Aeternitas:Aeternitas:1899 ER" "Sol" #2=
#3_"1899 ER:*Этернитас:446 Aeternitas:Aeternitas" "Sol" #3=
".:Aeternitas:446 Aeternitas:1899 ER" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"446 aeternitas.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	26.781
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.652143693704
		SemiMajorAxis	2.786741032113
		Eccentricity	0.127088235752
		Inclination	10.626152516383
		AscendingNode	42.092543284121
		ArgOfPericenter	279.653487442439
		MeanAnomaly	316.132616422228
	}
	UniformRotation
	{
		Period	15.7413
	}
	LunarLambert	0.5
	Albedo	0.317
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=446"
}

#1_"447 Valentine:Valentine:1899 ES" "Sol" #1=
#2_"*Валентина:447 Valentine:Valentine:1899 ES" "Sol" #2=
#3_"1899 ES:*Валентина:447 Valentine:Valentine" "Sol" #3=
".:Valentine:447 Valentine:1899 ES" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	39.61
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.167923791829
		SemiMajorAxis	2.989087297702
		Eccentricity	0.042579561897
		Inclination	4.793713506998
		AscendingNode	71.913167041271
		ArgOfPericenter	323.854569584755
		MeanAnomaly	102.516850742774
	}
	UniformRotation
	{
		Period	9.651
	}
	LunarLambert	0.5
	Albedo	0.0714
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=447"
}

#1_"448 Natalie:Natalie:1899 ET:1949 UW:1962 BA" "Sol" #1=
#2_"*Наталия:448 Natalie:Natalie:1899 ET" "Sol" #2=
#3_"1899 ET:*Наталия:448 Natalie:Natalie" "Sol" #3=
".:Natalie:448 Natalie:1899 ET" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.88
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.547370392862
		SemiMajorAxis	3.133665536641
		Eccentricity	0.186862103971
		Inclination	12.726119641258
		AscendingNode	37.297673495575
		ArgOfPericenter	294.269404380901
		MeanAnomaly	281.405000085309
	}
	UniformRotation
	{
		Period	8.0646
	}
	LunarLambert	0.5
	Albedo	0.0588
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=448"
}

#1_"449 Hamburga:Hamburga:1899 EU:1947 OA:1948 TO:A901 EA" "Sol" #1=
#2_"*Гамбурга:449 Hamburga:Hamburga:1899 EU" "Sol" #2=
#3_"1899 EU:*Гамбурга:449 Hamburga:Hamburga" "Sol" #3=
".:Hamburga:449 Hamburga:1899 EU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	42.795
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.075611503688
		SemiMajorAxis	2.551465604305
		Eccentricity	0.173717049268
		Inclination	3.08527305801
		AscendingNode	85.94446246521
		ArgOfPericenter	47.41462235917
		MeanAnomaly	346.810781616313
	}
	UniformRotation
	{
		Period	18.263
	}
	LunarLambert	0.5
	Albedo	0.0393
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=449"
}

#1_"450 Brigitta:Brigitta:1899 EV:A907 GF" "Sol" #1=
#2_"*Бригитта:450 Brigitta:Brigitta:1899 EV" "Sol" #2=
#3_"1899 EV:*Бригитта:450 Brigitta:Brigitta" "Sol" #3=
".:450 Brigitta:Brigitta:1899 EV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"450 brigitta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	18.519
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.23829893406
		SemiMajorAxis	3.016162371929
		Eccentricity	0.09883718534
		Inclination	10.154121837336
		AscendingNode	14.470607710435
		ArgOfPericenter	356.080091501316
		MeanAnomaly	13.017185343838
	}
	UniformRotation
	{
		Period	10.7657
	}
	LunarLambert	0.5
	Albedo	0.094
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=450"
}

#1_"451 Patientia:Patientia:1899 EY:A902 MB" "Sol" #1=
#2_"*Пациенция:451 Patientia:Patientia:1899 EY" "Sol" #2=
#3_"1899 EY:*Пациенция:451 Patientia:Patientia" "Sol" #3=
".:Patientia:451 Patientia:1899 EY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	112.48
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.353438636591
		SemiMajorAxis	3.060199579498
		Eccentricity	0.076015121807
		Inclination	15.240432744329
		AscendingNode	89.258300059855
		ArgOfPericenter	337.195295761872
		MeanAnomaly	168.746154342614
	}
	UniformRotation
	{
		Period	9.727
	}
	LunarLambert	0.5
	Albedo	0.0764
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=451"
}

#1_"453 Tea:Tea:1900 FA:1969 QC:A901 QA" "Sol" #1=
#2_"*Тея:453 Tea:Tea:1900 FA" "Sol" #2=
#3_"1900 FA:*Тея:453 Tea:Tea" "Sol" #3=
".:Tea:453 Tea:1900 FA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"gaspra.jpg"
	Radius	10.465
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.225640462328
		SemiMajorAxis	2.183090990412
		Eccentricity	0.109181420157
		Inclination	5.550740309385
		AscendingNode	11.727007271331
		ArgOfPericenter	220.660892171814
		MeanAnomaly	135.136544070673
	}
	UniformRotation
	{
		Period	6.812
	}
	LunarLambert	0.5
	Albedo	0.1827
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=453"
}

#1_"454 Mathesis:Mathesis:1900 FC" "Sol" #1=
#2_"*Матезида:454 Mathesis:Mathesis:1900 FC" "Sol" #2=
#3_"1900 FC:*Матезида:454 Mathesis:Mathesis" "Sol" #3=
".:Mathesis:454 Mathesis:1900 FC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.261914351289
		SemiMajorAxis	2.628639382978
		Eccentricity	0.109585912029
		Inclination	6.291397547721
		AscendingNode	32.309829043725
		ArgOfPericenter	177.120530664736
		MeanAnomaly	319.517993133705
	}
	UniformRotation
	{
		Period	8.378
	}
	LunarLambert	0.5
	Albedo	0.0555
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=454"
}

#1_"455 Bruchsalia:Bruchsalia:1900 FG:1937 AA1:1959 ED1:A901 VD" "Sol" #1=
#2_"*Брухзалия:455 Bruchsalia:Bruchsalia:1900 FG" "Sol" #2=
#3_"1900 FG:*Брухзалия:455 Bruchsalia:Bruchsalia" "Sol" #3=
".:Bruchsalia:455 Bruchsalia:1900 FG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"455 bruchsalia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	44.396
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.332479411833
		SemiMajorAxis	2.657575044087
		Eccentricity	0.293221136455
		Inclination	12.014833594055
		AscendingNode	76.558574621184
		ArgOfPericenter	272.366687537949
		MeanAnomaly	84.471962008598
	}
	UniformRotation
	{
		Period	11.85
	}
	LunarLambert	0.5
	Albedo	0.034
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=455"
}

#1_"456 Abnoba:Abnoba:1900 FH:1952 YF" "Sol" #1=
#2_"*Абноба:456 Abnoba:Abnoba:1900 FH" "Sol" #2=
#3_"1900 FH:*Абноба:456 Abnoba:Abnoba" "Sol" #3=
".:Abnoba:456 Abnoba:1900 FH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	19.88
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.654572032617
		SemiMajorAxis	2.78771070166
		Eccentricity	0.179987383699
		Inclination	14.437233959455
		AscendingNode	229.31352779914
		ArgOfPericenter	6.658716956056
		MeanAnomaly	234.607442980296
	}
	UniformRotation
	{
		Period	18.281
	}
	LunarLambert	0.5
	Albedo	0.2335
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=456"
}

#1_"458 Hercynia:Hercynia:1900 FK:1947 XB:A902 CA:A915 PD" "Sol" #1=
#2_"*Герциния:458 Hercynia:Hercynia:1900 FK" "Sol" #2=
#3_"1900 FK:*Герциния:458 Hercynia:Hercynia" "Sol" #3=
".:Hercynia:458 Hercynia:1900 FK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	19.375
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.189190345788
		SemiMajorAxis	2.997281957752
		Eccentricity	0.23705839525
		Inclination	12.671307342103
		AscendingNode	134.534747966782
		ArgOfPericenter	276.108893887956
		MeanAnomaly	349.32172297567
	}
	UniformRotation
	{
		Period	22.3
	}
	LunarLambert	0.5
	Albedo	0.1654
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=458"
}

#1_"459 Signe:Signe:1900 FM:1934 VH:1938 SE1:A917 TF:A921 RD" "Sol" #1=
#2_"*Сигне:459 Signe:Signe:1900 FM" "Sol" #2=
#3_"1900 FM:*Сигне:459 Signe:Signe" "Sol" #3=
".:Signe:459 Signe:1900 FM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.66
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.245023672348
		SemiMajorAxis	2.621689629246
		Eccentricity	0.208447035403
		Inclination	10.296271793325
		AscendingNode	29.524245721702
		ArgOfPericenter	18.959686112056
		MeanAnomaly	311.36274094937
	}
	UniformRotation
	{
		Period	5.5362
	}
	LunarLambert	0.5
	Albedo	0.137
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=459"
}

#1_"460 Scania:Scania:1900 FN" "Sol" #1=
#2_"*Скания:460 Scania:Scania:1900 FN" "Sol" #2=
#3_"1900 FN:*Скания:460 Scania:Scania" "Sol" #3=
".:Scania:460 Scania:1900 FN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.89
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.476979344187
		SemiMajorAxis	2.716342897689
		Eccentricity	0.10607579593
		Inclination	4.636429395242
		AscendingNode	205.231739875078
		ArgOfPericenter	162.567412997102
		MeanAnomaly	185.395030146043
	}
	UniformRotation
	{
		Period	9.56
	}
	LunarLambert	0.5
	Albedo	0.2144
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=460"
}

#1_"462 Eriphyla:Eriphyla:1900 FQ:1927 CP:1946 DB:1948 OG:1951 EA3:1957 KB:1958 RR:1959 WB:A896 YA: #1=
#1_A907 BB" "Sol" #1=
#2_"*Эрифила:462 Eriphyla:Eriphyla:1900 FQ" "Sol" #2=
#3_"1900 FQ:*Эрифила:462 Eriphyla:Eriphyla" "Sol" #3=
".:Eriphyla:462 Eriphyla:1900 FQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"ida.jpg"
	Radius	17.815
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.869700212847
		SemiMajorAxis	2.872958477515
		Eccentricity	0.087052992287
		Inclination	3.192565500408
		AscendingNode	105.287035064731
		ArgOfPericenter	251.720301272096
		MeanAnomaly	178.98538848876
	}
	UniformRotation
	{
		Period	8.64
	}
	LunarLambert	0.5
	Albedo	0.2829
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=462"
}

#1_"463 Lola:Lola:1900 FS:1926 TC:1932 FG:1959 NR" "Sol" #1=
#2_"*Лола:463 Lola:Lola:1900 FS" "Sol" #2=
#3_"1900 FS:*Лола:463 Lola:Lola" "Sol" #3=
".:Lola:463 Lola:1900 FS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.985
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.713506302469
		SemiMajorAxis	2.398008079652
		Eccentricity	0.220762490656
		Inclination	13.543421954153
		AscendingNode	36.540677677563
		ArgOfPericenter	329.270870808381
		MeanAnomaly	276.024780576726
	}
	UniformRotation
	{
		Period	6.206
	}
	LunarLambert	0.5
	Albedo	0.0829
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=463"
}

#1_"464 Megaira:Megaira:1901 FV:1929 AH:A912 JB:A912 JC:A916 FD" "Sol" #1=
#2_"*Мегера:464 Megaira:Megaira:1901 FV" "Sol" #2=
#3_"1901 FV:*Мегера:464 Megaira:Megaira" "Sol" #3=
".:Megaira:464 Megaira:1901 FV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	37.02
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.687205235055
		SemiMajorAxis	2.800725282624
		Eccentricity	0.205034391716
		Inclination	10.169014200111
		AscendingNode	102.373795630015
		ArgOfPericenter	258.55162153198
		MeanAnomaly	192.468522556152
	}
	UniformRotation
	{
		Period	12.726
	}
	LunarLambert	0.5
	Albedo	0.0502
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=464"
}

#1_"465 Alekto:Alekto:1901 FW:1949 YE1:1949 YU:1968 PB:A907 EF:A916 YC" "Sol" #1=
#2_"*Алекто:465 Alekto:Alekto:1901 FW" "Sol" #2=
#3_"1901 FW:*Алекто:465 Alekto:Alekto" "Sol" #3=
".:Alekto:465 Alekto:1901 FW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.67
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.438968199375
		SemiMajorAxis	3.092707718468
		Eccentricity	0.208030367967
		Inclination	4.656440852705
		AscendingNode	300.665849904117
		ArgOfPericenter	283.992403038644
		MeanAnomaly	259.411808690003
	}
	UniformRotation
	{
		Period	10.938
	}
	LunarLambert	0.5
	Albedo	0.0433
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=465"
}

#1_"466 Tisiphone:Tisiphone:1901 FX:1953 NP" "Sol" #1=
#2_"*Тисифона:466 Tisiphone:Tisiphone:1901 FX" "Sol" #2=
#3_"1901 FX:*Тисифона:466 Tisiphone:Tisiphone" "Sol" #3=
".:Tisiphone:466 Tisiphone:1901 FX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	57.765
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.145314695487
		SemiMajorAxis	3.354985263295
		Eccentricity	0.09195402821
		Inclination	19.112716196892
		AscendingNode	290.887720219724
		ArgOfPericenter	249.389841639446
		MeanAnomaly	103.038299856566
	}
	UniformRotation
	{
		Period	8.824
	}
	LunarLambert	0.5
	Albedo	0.0634
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=466"
}

#1_"467 Laura:Laura:1901 FY:1954 OE:A924 RG" "Sol" #1=
#2_"*Лаура:467 Laura:Laura:1901 FY" "Sol" #2=
#3_"1901 FY:*Лаура:467 Laura:Laura" "Sol" #3=
".:Laura:467 Laura:1901 FY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.98
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.054381054442
		SemiMajorAxis	2.945143897519
		Eccentricity	0.109085409912
		Inclination	6.436620274611
		AscendingNode	322.487445208476
		ArgOfPericenter	91.317790817659
		MeanAnomaly	248.25998380816
	}
	UniformRotation
	{
		Period	36.8
	}
	LunarLambert	0.5
	Albedo	0.0633
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=467"
}

#1_"468 Lina:Lina:1901 FZ:A915 PA:A918 EB" "Sol" #1=
#2_"*Лина:468 Lina:Lina:1901 FZ" "Sol" #2=
#3_"1901 FZ:*Лина:468 Lina:Lina" "Sol" #3=
".:Lina:468 Lina:1901 FZ" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	34.67
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.543860064213
		SemiMajorAxis	3.132343425972
		Eccentricity	0.197625740079
		Inclination	0.437387432402
		AscendingNode	21.470837908396
		ArgOfPericenter	333.358070362578
		MeanAnomaly	281.709441026344
	}
	UniformRotation
	{
		Period	16.33
	}
	LunarLambert	0.5
	Albedo	0.043
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=468"
}

#1_"469 Argentina:Argentina:1901 GE:1941 FB1:1948 PG1:A907 FA" "Sol" #1=
#2_"*Аргентина:469 Argentina:Argentina:1901 GE" "Sol" #2=
#3_"1901 GE:*Аргентина:469 Argentina:Argentina" "Sol" #3=
".:Argentina:469 Argentina:Argentina:1901 GE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	62.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.669606450605
		SemiMajorAxis	3.179531566802
		Eccentricity	0.159084908971
		Inclination	11.596221718985
		AscendingNode	333.478513545102
		ArgOfPericenter	209.403265316437
		MeanAnomaly	49.060829308455
	}
	UniformRotation
	{
		Period	17.573
	}
	LunarLambert	0.5
	Albedo	0.0399
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=469"
}

#1_"470 Kilia:Kilia:1901 GJ:1932 TA:A902 RB" "Sol" #1=
#2_"*Килия:470 Kilia:Kilia:1901 GJ" "Sol" #2=
#3_"1901 GJ:*Килия:470 Kilia:Kilia" "Sol" #3=
".:Kilia:470 Kilia:1901 GJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.195
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.728761702322
		SemiMajorAxis	2.404571072031
		Eccentricity	0.094558797451
		Inclination	7.226875256583
		AscendingNode	173.246397160818
		ArgOfPericenter	47.500084782747
		MeanAnomaly	160.284597406793
	}
	UniformRotation
	{
		Period	290
	}
	LunarLambert	0.5
	Albedo	0.2379
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=470"
}

#1_"471 Papagena:Papagena:1901 GN:A911 MB" "Sol" #1=
#2_"*Папагена:471 Papagena:Papagena:1901 GN" "Sol" #2=
#3_"1901 GN:*Папагена:471 Papagena:Papagena" "Sol" #3=
".:Papagena:471 Papagena:1901 GN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"471 papagena.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	74.064
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.91295753387
		SemiMajorAxis	2.889946959214
		Eccentricity	0.231117840422
		Inclination	14.974806887981
		AscendingNode	83.963061027451
		ArgOfPericenter	314.339273109304
		MeanAnomaly	126.82677478373
	}
	UniformRotation
	{
		Period	7.113
	}
	LunarLambert	0.5
	Albedo	0.164
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=471"
}

#1_"472 Roma:Roma:1901 GP:1944 DO" "Sol" #1=
#2_"*Рим:472 Roma:Roma:1901 GP" "Sol" #2=
#3_"1901 GP:*Рим:472 Roma:Roma" "Sol" #3=
".:Roma:472 Roma:1901 GP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	23.635
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.058250157408
		SemiMajorAxis	2.544214604558
		Eccentricity	0.094226281905
		Inclination	15.804087736553
		AscendingNode	127.182421980675
		ArgOfPericenter	295.528948030557
		MeanAnomaly	228.364445454677
	}
	UniformRotation
	{
		Period	9.8007
	}
	LunarLambert	0.5
	Albedo	0.2138
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=472"
}

#1_"474 Prudentia:Prudentia:1901 GD:1929 NG:1933 OO:A902 NA:A910 RB" "Sol" #1=
#2_"*Пруденция:474 Prudentia:Prudentia:1901 GD" "Sol" #2=
#3_"1901 GD:*Пруденция:474 Prudentia:Prudentia" "Sol" #3=
".:Prudentia:474 Prudentia:1901 GD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"474 prudentia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	19.678
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.839898535529
		SemiMajorAxis	2.452116112617
		Eccentricity	0.211698219291
		Inclination	8.798712548403
		AscendingNode	161.84138309928
		ArgOfPericenter	155.784177188991
		MeanAnomaly	63.102156755765
	}
	UniformRotation
	{
		Period	8.572
	}
	LunarLambert	0.5
	Albedo	0.062
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=474"
}

#1_"476 Hedwig:Hedwig:1901 GQ:1974 PL" "Sol" #1=
#2_"*Гедвиг:476 Hedwig:Hedwig:1901 GQ" "Sol" #2=
#3_"1901 GQ:*Гедвиг:476 Hedwig:Hedwig" "Sol" #3=
".:Hedwig:476 Hedwig:1901 GQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58.38
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.312188731033
		SemiMajorAxis	2.64927091754
		Eccentricity	0.073909031108
		Inclination	10.937395509742
		AscendingNode	286.455804516777
		ArgOfPericenter	359.995836364924
		MeanAnomaly	140.523929721265
	}
	UniformRotation
	{
		Period	27.33
	}
	LunarLambert	0.5
	Albedo	0.0493
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=476"
}

#1_"477 Italia:Italia:1901 GR:A905 UK" "Sol" #1=
#2_"*Италия:477 Italia:Italia:1901 GR" "Sol" #2=
#3_"1901 GR:*Италия:477 Italia:Italia" "Sol" #3=
".:Italia:477 Italia:1901 GR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.255
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.752770491913
		SemiMajorAxis	2.414881745147
		Eccentricity	0.188361283662
		Inclination	5.287594531053
		AscendingNode	10.705750544123
		ArgOfPericenter	322.073493938178
		MeanAnomaly	67.135492284602
	}
	UniformRotation
	{
		Period	19.42
	}
	LunarLambert	0.5
	Albedo	0.2769
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=477"
}

#1_"478 Tergeste:Tergeste:1901 GU:1948 RU1" "Sol" #1=
#2_"*Тергест:478 Tergeste:Tergeste:1901 GU" "Sol" #2=
#3_"1901 GU:*Тергест:478 Tergeste:Tergeste" "Sol" #3=
".:Tergeste:478 Tergeste:Tergeste:1901 GU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	39.73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.239029602755
		SemiMajorAxis	3.016442840101
		Eccentricity	0.084022723679
		Inclination	13.183611040639
		AscendingNode	233.927388422621
		ArgOfPericenter	239.37703447273
		MeanAnomaly	123.95533774506
	}
	UniformRotation
	{
		Period	16.104
	}
	LunarLambert	0.5
	Albedo	0.1798
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=478"
}

#1_"479 Caprera:Caprera:1901 HJ:1956 EA1:1957 HD" "Sol" #1=
#2_"*Капрера:479 Caprera:Caprera:1901 HJ" "Sol" #2=
#3_"1901 HJ:*Капрера:479 Caprera:Caprera" "Sol" #3=
".:Caprera:479 Caprera:1901 HJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.49
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.493049225696
		SemiMajorAxis	2.7228391284
		Eccentricity	0.217480699353
		Inclination	8.682656756806
		AscendingNode	136.044705562054
		ArgOfPericenter	270.152102873803
		MeanAnomaly	69.310383351854
	}
	UniformRotation
	{
		Period	9.43
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=479"
}

#1_"480 Hansa:Hansa:1901 GL:A905 JA:A911 UJ " "Sol" #1=
#2_"*Ганза:480 Hansa:Hansa:1901 GL" "Sol" #2=
#3_"1901 GL:*Ганза:480 Hansa:Hansa" "Sol" #3=
".:Hansa:480 Hansa:1901 GL" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"480 hansa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	28.11
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.299237289799
		SemiMajorAxis	2.643963624288
		Eccentricity	0.044995349962
		Inclination	21.292289712828
		AscendingNode	237.244898452361
		ArgOfPericenter	214.558686565554
		MeanAnomaly	307.649453636451
	}
	UniformRotation
	{
		Period	16.19
	}
	LunarLambert	0.5
	Albedo	0.2485
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=480"
}

#1_"482 Petrina:Petrina:1902 HT:1949 HP1:1956 TK:1975 FY:1987 SJ12" "Sol" #1=
#2_"*Петрина:482 Petrina:Petrina:1902 HT" "Sol" #2=
#3_"1902 HT:*Петрина:482 Petrina:Petrina" "Sol" #3=
".:Petrina:482 Petrina:1902 HT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"482 petrina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	22.876
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.188912371022
		SemiMajorAxis	2.997174917779
		Eccentricity	0.100233500862
		Inclination	14.464467503731
		AscendingNode	179.448783971166
		ArgOfPericenter	87.280026668166
		MeanAnomaly	172.852988685991
	}
	UniformRotation
	{
		Period	11.7922
	}
	LunarLambert	0.5
	Albedo	0.246
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=482"
}

#1_"483 Seppina:Seppina:1902 HU:1942 OE:1955 QJ:A896 GA " "Sol" #1=
#2_"*Сеппина:483 Seppina:Seppina:1902 HU" "Sol" #2=
#3_"1902 HU:*Сеппина:483 Seppina:Seppina" "Sol" #3=
".:Seppina:483 Seppina:1902 HU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	34.685
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.332028858801
		SemiMajorAxis	3.422602439103
		Eccentricity	0.054052228693
		Inclination	18.745039792836
		AscendingNode	174.060964554526
		ArgOfPericenter	154.73841228672
		MeanAnomaly	122.377068589778
	}
	UniformRotation
	{
		Period	12.727
	}
	LunarLambert	0.5
	Albedo	0.1709
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=483"
}

#1_"484 Pittsburghia:Pittsburghia:1902 HX:1936 EB:1963 HB" "Sol" #1=
#2_"*Питтсбургия:484 Pittsburghia:Pittsburghia:1902 HX" "Sol" #2=
#3_"1902 HX:*Питтсбургия:484 Pittsburghia:Pittsburghia" "Sol" #3=
".:Pittsburghia:484 Pittsburghia:1902 HX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"484 pittsburghia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	15.03
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.358211022882
		SemiMajorAxis	2.668087296282
		Eccentricity	0.056970474286
		Inclination	12.512897032931
		AscendingNode	127.278748402163
		ArgOfPericenter	191.412545296589
		MeanAnomaly	209.021761830932
	}
	UniformRotation
	{
		Period	10.63
	}
	LunarLambert	0.5
	Albedo	0.222
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=484"
}

#1_"485 Genua:Genua:1902 HZ:1933 FZ1:1934 HA:1953 PP:1977 VY1:A904 SA" "Sol" #1=
#2_"*Генуя:485 Genua:Genua:1902 HZ" "Sol" #2=
#3_"1902 HZ:*Генуя:485 Genua:Genua" "Sol" #3=
".:Genua:485 Genua:1902 HZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	31.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.556655000948
		SemiMajorAxis	2.748476093713
		Eccentricity	0.192366868854
		Inclination	13.86002939399
		AscendingNode	193.464097260091
		ArgOfPericenter	272.766300486033
		MeanAnomaly	347.89312916139
	}
	UniformRotation
	{
		Period	17.59
	}
	LunarLambert	0.5
	Albedo	0.2072
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=485"
}

#1_"486 Cremona:Cremona:1902 JB:1949 MX:A902 MA:A913 MA" "Sol" #1=
#2_"*Кремона:486 Cremona:Cremona:1902 JB" "Sol" #2=
#3_"1902 JB:*Кремона:486 Cremona:Cremona" "Sol" #3=
".:Cremona:486 Cremona:1902 JB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"486 cremona.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	11.39
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.608812899016
		SemiMajorAxis	2.352722880609
		Eccentricity	0.161911159543
		Inclination	11.090498795594
		AscendingNode	94.257532202349
		ArgOfPericenter	124.645692392629
		MeanAnomaly	87.667386465522
	}
	UniformRotation
	{
		Period	65.15
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=486"
}

#1_"487 Venetia:Venetia:1902 JL" "Sol" #1=
#2_"*Венеция:487 Venetia:Venetia:1902 JL" "Sol" #2=
#3_"1902 JL:*Венеция:487 Venetia:Venetia" "Sol" #3=
".:Venetia:487 Venetia:1902 JL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	31.575
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.360160254334
		SemiMajorAxis	2.668882780492
		Eccentricity	0.088882148118
		Inclination	10.246279515365
		AscendingNode	114.828850595986
		ArgOfPericenter	280.776492260538
		MeanAnomaly	187.345358259386
	}
	UniformRotation
	{
		Period	13.28
	}
	LunarLambert	0.5
	Albedo	0.2457
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=487"
}

#1_"488 Kreusa:Kreusa:1902 JG:1947 KH:1977 YD:A901 CA:A905 XA" "Sol" #1=
#2_"*Креуса:488 Kreusa:Kreusa:1902 JG" "Sol" #2=
#3_"1902 JG:*Креуса:488 Kreusa:Kreusa" "Sol" #3=
".:Kreusa:488 Kreusa:1902 JG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	75.065
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.638864165213
		SemiMajorAxis	3.168027580187
		Eccentricity	0.159225078456
		Inclination	11.520941949614
		AscendingNode	84.250644812331
		ArgOfPericenter	71.1935698482
		MeanAnomaly	93.013777817924
	}
	UniformRotation
	{
		Period	19.26
	}
	LunarLambert	0.5
	Albedo	0.0589
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=488"
}

#1_"489 Comacina:Comacina:1902 JM:A911 DA" "Sol" #1=
#2_"*Комачина:489 Comacina:Comacina:1902 JM" "Sol" #2=
#3_"1902 JM:*Комачина:489 Comacina:Comacina" "Sol" #3=
".:Comacina:489 Comacina:1902 JM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"489 comacina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	69.695
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.59760911922
		SemiMajorAxis	3.152556732655
		Eccentricity	0.044604866669
		Inclination	12.999233252959
		AscendingNode	166.896148942654
		ArgOfPericenter	11.71677075626
		MeanAnomaly	177.044753461013
	}
	UniformRotation
	{
		Period	9.02
	}
	LunarLambert	0.5
	Albedo	0.0427
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=489"
}

#1_"490 Veritas:Veritas:1902 JP:1947 OG:A914 WA" "Sol" #1=
#2_"*Веритас:490 Veritas:Veritas:1902 JP" "Sol" #2=
#3_"1902 JP:*Веритас:490 Veritas:Veritas" "Sol" #3=
".:Veritas:490 Veritas:1902 JP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"490 veritas.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	59.402
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.650303131431
		SemiMajorAxis	3.172310560835
		Eccentricity	0.094813710891
		Inclination	9.279555902047
		AscendingNode	178.339711759381
		ArgOfPericenter	194.561899903921
		MeanAnomaly	286.284306626235
	}
	UniformRotation
	{
		Period	7.93
	}
	LunarLambert	0.5
	Albedo	0.059
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=490"
}

#1_"491 Carina:Carina:1902 JQ:1928 DA1:1930 QK:1931 UR:1942 WA:A894 GA" "Sol" #1=
#2_"*Карина:491 Carina:Carina:1902 JQ" "Sol" #2=
#3_"1902 JQ:*Карина:491 Carina:Carina" "Sol" #3=
".:Carina:491 Carina:1902 JQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	48.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.696882145622
		SemiMajorAxis	3.189720933111
		Eccentricity	0.087995582177
		Inclination	18.862297479424
		AscendingNode	175.434010728455
		ArgOfPericenter	233.663507576943
		MeanAnomaly	191.535512464458
	}
	UniformRotation
	{
		Period	14.87
	}
	LunarLambert	0.5
	Albedo	0.0743
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=491"
}

#1_"492 Gismonda:Gismonda:1902 JR:A913 RB" "Sol" #1=
#2_"*Гизмонда:492 Gismonda:Gismonda:1902 JR" "Sol" #2=
#3_"1902 JR:*Гизмонда:492 Gismonda:Gismonda" "Sol" #3=
".:Gismonda:492 Gismonda:1902 JR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	25.845
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.515970732852
		SemiMajorAxis	3.12182940714
		Eccentricity	0.174655070234
		Inclination	1.617611426405
		AscendingNode	46.299232034294
		ArgOfPericenter	296.131018253425
		MeanAnomaly	160.586390353412
	}
	UniformRotation
	{
		Period	6.488
	}
	LunarLambert	0.5
	Albedo	0.0795
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=492"
}

#1_"493 Griseldis:Griseldis:1902 JS:A915 BB" "Sol" #1=
#2_"*Гризельда:493 Griseldis:Griseldis:1902 JS" "Sol" #2=
#3_"1902 JS:*Гризельда:493 Griseldis:Griseldis" "Sol" #3=
".:Griseldis:493 Griseldis:1902 JS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.205
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.516395483662
		SemiMajorAxis	3.12198966694
		Eccentricity	0.173701322884
		Inclination	15.163426634479
		AscendingNode	357.368976620916
		ArgOfPericenter	47.580853382489
		MeanAnomaly	85.410663017365
	}
	UniformRotation
	{
		Period	51.94
	}
	LunarLambert	0.5
	Albedo	0.0622
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=493"
}

#1_"494 Virtus:Virtus:1902 JV:1950 BM" "Sol" #1=
#2_"*Виртус:494 Virtus:Virtus:1902 JV" "Sol" #2=
#3_"1902 JV:*Виртус:494 Virtus:Virtus" "Sol" #3=
".:Virtus:494 Virtus:1902 JV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	42.76
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.160451655359
		SemiMajorAxis	2.986205385509
		Eccentricity	0.06319383459
		Inclination	7.085615856716
		AscendingNode	38.222717165803
		ArgOfPericenter	218.168220883907
		MeanAnomaly	28.626723382234
	}
	UniformRotation
	{
		Period	5.57
	}
	LunarLambert	0.5
	Albedo	0.063
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=494"
}

#1_"495 Eulalia:Eulalia:1902 KG:1988 PA2:A906 XC:A916 GF" "Sol" #1=
#2_"*Эвлалия:495 Eulalia:Eulalia:1902 KG" "Sol" #2=
#3_"1902 KG:*Эвлалия:495 Eulalia:Eulalia" "Sol" #3=
".:Eulalia:495 Eulalia:1902 KG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"495 eulalia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	18.644
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.921909222584
		SemiMajorAxis	2.486907067801
		Eccentricity	0.130032100718
		Inclination	2.279216877092
		AscendingNode	186.489628752918
		ArgOfPericenter	207.07316867678
		MeanAnomaly	214.663782321765
	}
	UniformRotation
	{
		Period	28.967
	}
	LunarLambert	0.5
	Albedo	0.062
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=495"
}

#1_"496 Gryphia:Gryphia:1902 KH:1931 TB:1931 TN2:1933 FQ:1936 CB:1951 WS2" "Sol" #1=
#2_"*Грифия:496 Gryphia:Gryphia:1902 KH" "Sol" #2=
#3_"1902 KH:*Грифия:496 Gryphia:Gryphia" "Sol" #3=
".:Gryphia:496 Gryphia:1902 KH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"gaspra.jpg"
	Radius	7.735
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.260004669985
		SemiMajorAxis	2.198568560588
		Eccentricity	0.079225273132
		Inclination	3.791559344065
		AscendingNode	207.619460789039
		ArgOfPericenter	258.511651385262
		MeanAnomaly	85.984992528706
	}
	UniformRotation
	{
		Period	18
	}
	LunarLambert	0.5
	Albedo	0.1676
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=496"
}

#1_"497 Iva:Iva:1902 KJ:1947 BN:1950 TD3" "Sol" #1=
#2_"*Ива:497 Iva:Iva:1902 KJ" "Sol" #2=
#3_"1902 KJ:Iva:*Ива:497 Iva" "Sol" #3=
".:Iva:497 Iva:1902 KJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"497 iva.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	20.466
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.814193382514
		SemiMajorAxis	2.85108535662
		Eccentricity	0.300006607823
		Inclination	4.820290527948
		AscendingNode	6.325953980687
		ArgOfPericenter	3.614728996792
		MeanAnomaly	283.128695574925
	}
	UniformRotation
	{
		Period	4.62
	}
	LunarLambert	0.5
	Albedo	0.119
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=497"
}

#1_"498 Tokio:Tokio:1902 KU:1900 EB" "Sol" #1=
#2_"*Токио:498 Tokio:Tokio:1902 KU" "Sol" #2=
#3_"1902 KU:*Токио:498 Tokio:Tokio" "Sol" #3=
".:Tokio:498 Tokio:1902 KU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.915
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.314144289881
		SemiMajorAxis	2.650071812245
		Eccentricity	0.224757044702
		Inclination	9.501046582264
		AscendingNode	97.444151921763
		ArgOfPericenter	240.998423629879
		MeanAnomaly	41.750015960707
	}
	UniformRotation
	{
		Period	41.85
	}
	LunarLambert	0.5
	Albedo	0.0694
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=498"
}

#1_"499 Venusia:Venusia:1902 KX:1950 CE" "Sol" #1=
#2_"*Венузия:499 Venusia:Venusia:1902 KX" "Sol" #2=
#3_"1902 KX:*Венузия:499 Venusia:Venusia" "Sol" #3=
".:Venusia:499 Venusia:1902 KX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"499 venusia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	38.664
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	8.042754883101
		SemiMajorAxis	4.01418842073
		Eccentricity	0.214579109839
		Inclination	2.088812471651
		AscendingNode	256.324745146862
		ArgOfPericenter	175.274456603238
		MeanAnomaly	75.081568534642
	}
	UniformRotation
	{
		Period	13.48
	}
	LunarLambert	0.5
	Albedo	0.052
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=499"
}

#1_"500 Selinur:Selinur:1903 LA:1935 SJ2:1935 WD" "Sol" #1=
#2_"*Селинур:500 Selinur:Selinur:1903 LA" "Sol" #2=
#3_"1903 LA:*Селинур:500 Selinur:Selinur" "Sol" #3=
".:Selinur:500 Selinur:1903 LA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	21.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.222521620609
		SemiMajorAxis	2.612416710777
		Eccentricity	0.146041764629
		Inclination	9.772490196049
		AscendingNode	289.942370316141
		ArgOfPericenter	74.629056128807
		MeanAnomaly	263.013794760365
	}
	UniformRotation
	{
		Period	8.0111
	}
	LunarLambert	0.5
	Albedo	0.1804
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=500"
}

#1_"501 Urhixidur:Urhixidur:1903 LB:1943 FC:1949 FW:1951 RB2:1951 SE:1955 FB" "Sol" #1=
#2_"*Урхиксидур:501 Urhixidur:Urhixidur:1903 LB" "Sol" #2=
#3_"1903 LB:*Урхиксидур:501 Urhixidur:Urhixidur" "Sol" #3=
".:Urhixidur:501 Urhixidur:1903 LB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38.72
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.628972797741
		SemiMajorAxis	3.164321716438
		Eccentricity	0.140002896951
		Inclination	20.817084692703
		AscendingNode	357.379391807348
		ArgOfPericenter	353.367546216056
		MeanAnomaly	98.074856230726
	}
	UniformRotation
	{
		Period	13.1743
	}
	LunarLambert	0.5
	Albedo	0.0812
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=501"
}

#1_"502 Sigune:Sigune:1903 LC:1925 AD:1929 EK" "Sol" #1=
#2_"*Сигуна:502 Sigune:Sigune:1903 LC" "Sol" #2=
#3_"1903 LC:*Сигуна:502 Sigune:Sigune" "Sol" #3=
".:Sigune:502 Sigune:1903 LC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"502 sigune.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.902
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.677562189598
		SemiMajorAxis	2.38250899468
		Eccentricity	0.179543828491
		Inclination	25.032484787569
		AscendingNode	133.006893375095
		ArgOfPericenter	19.092892195335
		MeanAnomaly	110.728641884882
	}
	UniformRotation
	{
		Period	10.922
	}
	LunarLambert	0.5
	Albedo	0.178
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=502"
}

#1_"503 Evelyn:Evelyn:1903 LF:1948 BA:1948 DA:A899 GA" "Sol" #1=
#2_"*Эвелин:503 Evelyn:Evelyn:1903 LF" "Sol" #2=
#3_"1903 LF:*Эвелин:503 Evelyn:Evelyn" "Sol" #3=
".:Evelyn:503 Evelyn:1903 LF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.84
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.492203029222
		SemiMajorAxis	2.722497247852
		Eccentricity	0.175947734162
		Inclination	5.009944233534
		AscendingNode	68.950221193614
		ArgOfPericenter	42.265690654963
		MeanAnomaly	326.351995902159
	}
	UniformRotation
	{
		Period	38.7
	}
	LunarLambert	0.5
	Albedo	0.0585
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=503"
}

#1_"504 Cora:Cora:1902 LK:1947 OH" "Sol" #1=
#2_"*Кора:504 Cora:Cora:1902 LK" "Sol" #2=
#3_"1902 LK:*Кора:504 Cora:Cora" "Sol" #3=
".:Cora:504 Cora:1902 LK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	15.01
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.489395813792
		SemiMajorAxis	2.721362922081
		Eccentricity	0.217958903461
		Inclination	12.890091986008
		AscendingNode	104.645042204653
		ArgOfPericenter	247.917889287107
		MeanAnomaly	331.287541466612
	}
	UniformRotation
	{
		Period	7.588
	}
	LunarLambert	0.5
	Albedo	0.3407
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=504"
}

#1_"505 Cava:Cava:1902 LL:1947 WD:1947 XF:1963 NA:A904 AC" "Sol" #1=
#2_"*Кава:505 Cava:Cava:1902 LL" "Sol" #2=
#3_"1902 LL:*Кава:505 Cava:Cava" "Sol" #3=
".:Cava:505 Cava:1902 LL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"505 cava.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	57.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.395506034126
		SemiMajorAxis	2.683286952409
		Eccentricity	0.246201221502
		Inclination	9.841018043053
		AscendingNode	90.880252974398
		ArgOfPericenter	337.237647742296
		MeanAnomaly	84.855937678679
	}
	UniformRotation
	{
		Period	8.1789
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=505"
}

#1_"506 Marion:Marion:1903 LN:1948 PF1" "Sol" #1=
#2_"*Марион:506 Marion:Marion:1903 LN" "Sol" #2=
#3_"1903 LN:*Марион:506 Marion:Marion" "Sol" #3=
".:Marion:506 Marion:1903 LN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	52.97
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.297516067832
		SemiMajorAxis	3.038850863602
		Eccentricity	0.148461822454
		Inclination	17.009020564858
		AscendingNode	312.951548407325
		ArgOfPericenter	146.246279138322
		MeanAnomaly	66.343302656301
	}
	UniformRotation
	{
		Period	13.546
	}
	LunarLambert	0.5
	Albedo	0.0454
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=506"
}

#1_"507 Laodica:Laodica:1903 LO:1953 GK1:1958 AK:1974 YC:A896 YB:A912 VP" "Sol" #1=
#2_"*Лаодика:507 Laodica:Laodica:1903 LO" "Sol" #2=
#3_"1903 LO:*Лаодика:507 Laodica:Laodica" "Sol" #3=
".:Laodica:507 Laodica:1903 LO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	21.89
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.617518591245
		SemiMajorAxis	3.160027611751
		Eccentricity	0.09674105777
		Inclination	9.513271877772
		AscendingNode	293.610225135555
		ArgOfPericenter	100.958164718655
		MeanAnomaly	83.550627779596
	}
	UniformRotation
	{
		Period	6.737
	}
	LunarLambert	0.5
	Albedo	0.2112
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=507"
}

#1_"508 Princetonia:Princetonia:1903 LQ:1926 KA:A920 GF" "Sol" #1=
#2_"*Принстония:508 Princetonia:Princetonia:1903 LQ" "Sol" #2=
#3_"1903 LQ:*Принстония:508 Princetonia:Princetonia" "Sol" #3=
".:Princetonia:508 Princetonia:1903 LQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	71.175
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.627526307391
		SemiMajorAxis	3.163779597767
		Eccentricity	0.008613819306
		Inclination	13.330950401158
		AscendingNode	44.251142581837
		ArgOfPericenter	188.965934654568
		MeanAnomaly	286.036907212836
	}
	UniformRotation
	{
		Period	52.8
	}
	LunarLambert	0.5
	Albedo	0.0441
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=508"
}

#1_"509 Iolanda:Iolanda:1903 LR:A905 UB" "Sol" #1=
#2_"*Иоланда:509 Iolanda:Iolanda:1903 LR" "Sol" #2=
#3_"1903 LR:*Иоланда:509 Iolanda:Iolanda" "Sol" #3=
".:Iolanda:509 Iolanda:1903 LR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"509 iolanda.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	25.946
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.366452192553
		SemiMajorAxis	3.06515688688
		Eccentricity	0.094000283798
		Inclination	15.399288664154
		AscendingNode	217.573953641305
		ArgOfPericenter	158.077327236638
		MeanAnomaly	139.341738794475
	}
	UniformRotation
	{
		Period	12.306
	}
	LunarLambert	0.5
	Albedo	0.253
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=509"
}

#1_"510 Mabella:Mabella:1903 LT:1946 UO:A907 GO" "Sol" #1=
#2_"*Мабелла:510 Mabella:Mabella:1903 LT" "Sol" #2=
#3_"1903 LT:*Мабелла:510 Mabella:Mabella" "Sol" #3=
".:Mabella:510 Mabella:1903 LT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.72
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.215029019547
		SemiMajorAxis	2.609325415843
		Eccentricity	0.192106451657
		Inclination	9.524716560936
		AscendingNode	202.812378080134
		ArgOfPericenter	90.67329482577
		MeanAnomaly	130.213932507254
	}
	UniformRotation
	{
		Period	19.4
	}
	LunarLambert	0.5
	Albedo	0.0687
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=510"
}

#1_"511 Davida:Davida:1903 LU" "Sol" #1=
#2_"*Давида:511 Davida:Davida:1903 LU" "Sol" #2=
#3_"1903 LU:*Давида:511 Davida:Davida" "Sol" #3=
".:Davida:511 Davida:1903 LU" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"511 davida.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	178.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.632188969749
		SemiMajorAxis	3.165526913718
		Eccentricity	0.188375716391
		Inclination	15.941927378198
		AscendingNode	107.629345740772
		ArgOfPericenter	337.935911348735
		MeanAnomaly	53.159739217522
	}
	UniformRotation
	{
		Period	5.1297
	}
	LunarLambert	0.5
	Albedo	0.076
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=511"
}

#1_"512 Taurinensis:Taurinensis:1903 LV:A909 GE" "Sol" #1=
#2_"*Тауриненсида:512 Taurinensis:Taurinensis:1903 LV" "Sol" #2=
#3_"1903 LV:*Тауриненсида:512 Taurinensis:Taurinensis" "Sol" #3=
".:Taurinensis:512 Taurinensis:1903 LV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"512 taurinensis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	11.545
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.241105373874
		SemiMajorAxis	2.190063122906
		Eccentricity	0.253383040988
		Inclination	8.751927844674
		AscendingNode	107.103915368144
		ArgOfPericenter	249.105836743256
		MeanAnomaly	86.998224192444
	}
	UniformRotation
	{
		Period	5.585
	}
	LunarLambert	0.5
	Albedo	0.1772
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=512"
}

#1_"513 Centesima:Centesima:1903 LY:1916 Sav:1950 RM1:A914 WB" "Sol" #1=
#2_"*Центезима:513 Centesima:Centesima:1903 LY" "Sol" #2=
#3_"1903 LY:*Центезима:513 Centesima:Centesima" "Sol" #3=
".:Centesima:513 Centesima:1903 LY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"513 centesima.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	24.402
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.234952865088
		SemiMajorAxis	3.014877812164
		Eccentricity	0.080282899768
		Inclination	9.715819867848
		AscendingNode	184.515518310797
		ArgOfPericenter	225.579886026443
		MeanAnomaly	34.900482908384
	}
	UniformRotation
	{
		Period	5.23
	}
	LunarLambert	0.5
	Albedo	0.089
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=513"
}

#1_"514 Armida:Armida:1903 MB" "Sol" #1=
#2_"*Армида:514 Armida:Armida:1903 MB" "Sol" #2=
#3_"1903 MB:*Армида:514 Armida:Armida" "Sol" #3=
".:Armida:514 Armida:1903 MB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	53.085
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.319504261211
		SemiMajorAxis	3.0472538838
		Eccentricity	0.041863077325
		Inclination	3.876193738294
		AscendingNode	268.653794037854
		ArgOfPericenter	108.018481847695
		MeanAnomaly	300.562290387508
	}
	UniformRotation
	{
		Period	21.851
	}
	LunarLambert	0.5
	Albedo	0.0379
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=514"
}

#1_"515 Athalia:Athalia:1903 ME:1931 TQ:1937 WO:1937 WQ:1937 WR:1937 YH:1953 TD:1974 QA3:1977 CF" "Sol" #1=
#2_"*Аталия:515 Athalia:Athalia:1903 ME" "Sol" #2=
#3_"1903 ME:*Аталия:515 Athalia:Athalia" "Sol" #3=
".:Athalia:515 Athalia:1903 ME" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	19.11
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.522719320558
		SemiMajorAxis	3.124375183992
		Eccentricity	0.169881016276
		Inclination	2.038274077142
		AscendingNode	121.211783180844
		ArgOfPericenter	299.797279063155
		MeanAnomaly	0.971699351183
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=515"
}

#1_"516 Amherstia:Amherstia:1903 MG:1938 YO" "Sol" #1=
#2_"*Амхерстия:516 Amherstia:Amherstia:1903 MG" "Sol" #2=
#3_"1903 MG:*Амхерстия:516 Amherstia:Amherstia" "Sol" #3=
".:Amherstia:516 Amherstia:1903 MG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"516 amherstia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	32.572
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.388999648582
		SemiMajorAxis	2.68063836705
		Eccentricity	0.272803466218
		Inclination	12.96119966736
		AscendingNode	328.84485745785
		ArgOfPericenter	258.073188716021
		MeanAnomaly	251.574282758776
	}
	UniformRotation
	{
		Period	7.49
	}
	LunarLambert	0.5
	Albedo	0.202
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=516"
}

#1_"517 Edith:Edith:1903 MH:1953 VS:A905 BB:A909 XA" "Sol" #1=
#2_"*Эдит:517 Edith:Edith:1903 MH" "Sol" #2=
#3_"1903 MH:*Эдит:517 Edith:Edith" "Sol" #3=
".:Edith:517 Edith:1903 MH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	45.56
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.607289892251
		SemiMajorAxis	3.156190474063
		Eccentricity	0.180989215592
		Inclination	3.194684668383
		AscendingNode	274.503566320178
		ArgOfPericenter	139.603096566812
		MeanAnomaly	299.255021782337
	}
	UniformRotation
	{
		Period	9.2747
	}
	LunarLambert	0.5
	Albedo	0.0387
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=517"
}

#1_"518 Halawe:Halawe:1903 MO:1915 Sag:1930 FS:A907 VH" "Sol" #1=
#2_"*Халва:518 Halawe:Halawe:1903 MO" "Sol" #2=
#3_"1903 MO:*Халва:518 Halawe:Halawe" "Sol" #3=
".:Halawe:518 Halawe:1903 MO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"518 halawe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.078
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.029870053099
		SemiMajorAxis	2.532339289998
		Eccentricity	0.227938204964
		Inclination	6.727699571078
		AscendingNode	203.961702444882
		ArgOfPericenter	117.55532563152
		MeanAnomaly	234.42672833364
	}
	UniformRotation
	{
		Period	14.31
	}
	LunarLambert	0.5
	Albedo	0.246
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=518"
}

#1_"519 Sylvania:Sylvania:1903 MP:A909 CA:A911 HD" "Sol" #1=
#2_"*Сильвания:519 Sylvania:Sylvania:1903 MP" "Sol" #2=
#3_"1903 MP:*Сильвания:519 Sylvania:Sylvania" "Sol" #3=
".:Sylvania:519 Sylvania:1903 MP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"519 sylvania.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	20.039
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.659551999232
		SemiMajorAxis	2.789698744351
		Eccentricity	0.186171052062
		Inclination	11.019269432985
		AscendingNode	44.750608706923
		ArgOfPericenter	302.506138218594
		MeanAnomaly	336.867393473134
	}
	UniformRotation
	{
		Period	17.962
	}
	LunarLambert	0.5
	Albedo	0.246
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=519"
}

#1_"520 Franziska:Franziska:1903 MV:A924 WH" "Sol" #1=
#2_"*Франциска:520 Franziska:Franziska:1903 MV" "Sol" #2=
#3_"1903 MV:*Франциска:520 Franziska:Franziska" "Sol" #3=
".:Franziska:520 Franziska:1903 MV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"520 franziska.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	12.63
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.208750977011
		SemiMajorAxis	3.004809394758
		Eccentricity	0.110024226794
		Inclination	10.957543580157
		AscendingNode	34.308411087442
		ArgOfPericenter	22.265168184409
		MeanAnomaly	101.547040068439
	}
	UniformRotation
	{
		Period	16.507
	}
	LunarLambert	0.5
	Albedo	0.147
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=520"
}

#1_"521 Brixia:Brixia:1904 NB:1948 QU" "Sol" #1=
#2_"*Бриксия:521 Brixia:Brixia:1904 NB" "Sol" #2=
#3_"1904 NB:*Бриксия:521 Brixia:Brixia" "Sol" #3=
".:Brixia:521 Brixia:1904 NB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	57.825
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.532166923853
		SemiMajorAxis	2.73862013239
		Eccentricity	0.282874123691
		Inclination	10.598840887599
		AscendingNode	89.665945499943
		ArgOfPericenter	316.077188533553
		MeanAnomaly	178.37949525941
	}
	UniformRotation
	{
		Period	9.78
	}
	LunarLambert	0.5
	Albedo	0.0626
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=521"
}

#1_"522 Helga:Helga:1904 NC:1936 QP:A902 WB" "Sol" #1=
#2_"*Хельга:522 Helga:Helga:1904 NC" "Sol" #2=
#3_"1904 NC:*Хельга:522 Helga:Helga" "Sol" #3=
".:Helga:522 Helga:1904 NC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	50.61
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.956565838142
		SemiMajorAxis	3.644107093902
		Eccentricity	0.077795285705
		Inclination	4.43894439193
		AscendingNode	116.98890155901
		ArgOfPericenter	243.09641865714
		MeanAnomaly	118.699553783167
	}
	UniformRotation
	{
		Period	8.129
	}
	LunarLambert	0.5
	Albedo	0.0388
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=522"
}

#1_"523 Ada:Ada:1904 ND:1937 NB:1964 XN:A902 UD" "Sol" #1=
#2_"*Ада:523 Ada:Ada:1904 ND" "Sol" #2=
#3_"1904 ND:*Ада:523 Ada:Ada" "Sol" #3=
".:Ada:523 Ada:1904 ND" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"523 ada.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	15.945
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.118371757614
		SemiMajorAxis	2.969949622794
		Eccentricity	0.174400106772
		Inclination	4.295387041334
		AscendingNode	260.849976819368
		ArgOfPericenter	189.31029649442
		MeanAnomaly	276.216454175887
	}
	UniformRotation
	{
		Period	10.03
	}
	LunarLambert	0.5
	Albedo	0.2512
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=523"
}

#1_"524 Fidelio:Fidelio:1904 NN:1953 UT" "Sol" #1=
#2_"*Фиделия:524 Fidelio:Fidelio:1904 NN" "Sol" #2=
#3_"1904 NN:*Фиделия:524 Fidelio:Fidelio" "Sol" #3=
".:Fidelio:524 Fidelio:1904 NN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	35.865
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.280916476443
		SemiMajorAxis	2.636446937085
		Eccentricity	0.126961980773
		Inclination	8.230298273943
		AscendingNode	326.714276629414
		ArgOfPericenter	80.333883391113
		MeanAnomaly	57.072861984439
	}
	UniformRotation
	{
		Period	14.198
	}
	LunarLambert	0.5
	Albedo	0.0402
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=524"
}

#1_"526 Jena:Jena:1904 NQ:A901 TF" "Sol" #1=
#2_"*Йена:526 Jena:Jena:1904 NQ" "Sol" #2=
#3_"1904 NQ:*Йена:526 Jena:Jena" "Sol" #3=
".:Jena:526 Jena:1904 NQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"526 jena.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	22.42
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.511516853684
		SemiMajorAxis	3.120148696892
		Eccentricity	0.135004313347
		Inclination	2.173480177565
		AscendingNode	137.778928687773
		ArgOfPericenter	357.226952544443
		MeanAnomaly	67.755827699612
	}
	UniformRotation
	{
		Period	9.474
	}
	LunarLambert	0.5
	Albedo	0.077
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=526"
}

#1_"527 Euryanthe:Euryanthe:1904 NR:1948 EF:1977 FM:2000 WW197" "Sol" #1=
#2_"*Эврианта:527 Euryanthe:Euryanthe:1904 NR" "Sol" #2=
#3_"1904 NR:*Эврианта:527 Euryanthe:Euryanthe" "Sol" #3=
".:Euryanthe:527 Euryanthe:1904 NR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.455
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.499019373052
		SemiMajorAxis	2.725250579534
		Eccentricity	0.151153499526
		Inclination	9.676956050502
		AscendingNode	120.632578311371
		ArgOfPericenter	202.75069266191
		MeanAnomaly	114.831268007865
	}
	UniformRotation
	{
		Period	26.06
	}
	LunarLambert	0.5
	Albedo	0.0576
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=527"
}

#1_"528 Rezia:Rezia:1904 NS:A907 VB" "Sol" #1=
#2_"*Реция:528 Rezia:Rezia:1904 NS" "Sol" #2=
#3_"1904 NS:*Реция:528 Rezia:Rezia" "Sol" #3=
".:Rezia:528 Rezia:1904 NS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"528 rezia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	45.983
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.255078428263
		SemiMajorAxis	3.394817024403
		Eccentricity	0.018808260222
		Inclination	12.678684686313
		AscendingNode	49.745957332878
		ArgOfPericenter	332.144419403604
		MeanAnomaly	48.814066148953
	}
	UniformRotation
	{
		Period	7.337
	}
	LunarLambert	0.5
	Albedo	0.046
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=528"
}

#1_"529 Preziosa:Preziosa:1904 NT:1952 KC:A902 YC" "Sol" #1=
#2_"*Прециоза:529 Preziosa:Preziosa:1904 NT" "Sol" #2=
#3_"1904 NT:*Прециоза:529 Preziosa:Preziosa" "Sol" #3=
".:Preziosa:529 Preziosa:1904 NT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"529 preziosa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	16.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.234377296935
		SemiMajorAxis	3.014656823297
		Eccentricity	0.097013797557
		Inclination	11.027014538728
		AscendingNode	65.218361792895
		ArgOfPericenter	333.886229429716
		MeanAnomaly	185.630067669391
	}
	UniformRotation
	{
		Period	27
	}
	LunarLambert	0.5
	Albedo	0.1632
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=529"
}

#1_"530 Turandot:Turandot:1904 NV:1934 JK:1934 NE1:1949 DD:1966 DS:A911 QF" "Sol" #1=
#2_"*Турандот:530 Turandot:Turandot:1904 NV" "Sol" #2=
#3_"1904 NV:*Турандот:530 Turandot:Turandot" "Sol" #3=
".:Turandot:530 Turandot:1904 NV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	42.425
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.690568163914
		SemiMajorAxis	3.187363671579
		Eccentricity	0.219647434483
		Inclination	8.560162607624
		AscendingNode	129.174930791562
		ArgOfPericenter	200.21786470641
		MeanAnomaly	348.094562850107
	}
	UniformRotation
	{
		Period	19.947
	}
	LunarLambert	0.5
	Albedo	0.0472
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=530"
}

#1_"531 Zerlina:Zerlina:1904 NW:1955 HA" "Sol" #1=
#2_"*Церлина:531 Zerlina:Zerlina:1904 NW" "Sol" #2=
#3_"1904 NW:*Церлина:531 Zerlina:Zerlina" "Sol" #3=
".:Zerlina:531 Zerlina:1904 NW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"531 zerlina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.902
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.653080828639
		SemiMajorAxis	2.787115263131
		Eccentricity	0.197141929436
		Inclination	33.974235150732
		AscendingNode	197.761577713068
		ArgOfPericenter	57.538927988782
		MeanAnomaly	252.390582161571
	}
	UniformRotation
	{
		Period	16.706
	}
	LunarLambert	0.5
	Albedo	0.101
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=531"
}

#1_"532 Herculina:Herculina:1904 NY:1950 JP" "Sol" #1=
#2_"*Геркулина:532 Herculina:Herculina:1904 NY" "Sol" #2=
#3_"1904 NY:*Геркулина:532 Herculina:Herculina" "Sol" #3=
".:Herculina:532 Herculina:1904 NY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"532 herculina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.900 0.826 ]
	BlendTexture	true
	Radius	130
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.619439304648
		SemiMajorAxis	2.773665227713
		Eccentricity	0.17556481743
		Inclination	16.312129919375
		AscendingNode	107.540545693169
		ArgOfPericenter	76.175114174474
		MeanAnomaly	216.306329190501
	}
	UniformRotation
	{
		Period	9.405
		Inclination	80
		AscendingNode	19
	}
	LunarLambert	0.5
	Albedo	0.285
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=532"
}

#1_"533 Sara:Sara:1904 NZ:A901 VB:A911 UB" "Sol" #1=
#2_"*Сара:533 Sara:Sara:1904 NZ" "Sol" #2=
#3_"1904 NZ:*Сара:533 Sara:Sara" "Sol" #3=
".:Sara:533 Sara:1904 NZ" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	15.54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.140887120792
		SemiMajorAxis	2.978652984909
		Eccentricity	0.045749955733
		Inclination	6.558079636541
		AscendingNode	180.354150569185
		ArgOfPericenter	35.85802191118
		MeanAnomaly	175.085652422805
	}
	UniformRotation
	{
		Period	11.654
	}
	LunarLambert	0.5
	Albedo	0.2479
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=533"
}

#1_"534 Nassovia:Nassovia:1904 OA:1975 YG:A916 UQ" "Sol" #1=
#2_"*Нассовия:534 Nassovia:Nassovia:1904 OA" "Sol" #2=
#3_"1904 OA:*Нассовия:534 Nassovia:Nassovia" "Sol" #3=
".:Nassovia:534 Nassovia:1904 OA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"534 nassovia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	16.166
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.896423527134
		SemiMajorAxis	2.883459455726
		Eccentricity	0.055714141231
		Inclination	3.27527549435
		AscendingNode	94.20476493076
		ArgOfPericenter	338.600275945624
		MeanAnomaly	343.085240070155
	}
	UniformRotation
	{
		Period	9.382
	}
	LunarLambert	0.5
	Albedo	0.213
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=534"
}

#1_"535 Montague:Montague:1904 OC:1953 FV1:1959 VL:A903 BD" "Sol" #1=
#2_"*Монтегю:535 Montague:Montague:1904 OC" "Sol" #2=
#3_"1904 OC:*Монтегю:535 Montague:Montague" "Sol" #3=
".:Montague:535 Montague:1904 OC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	37.245
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.118574200625
		SemiMajorAxis	2.569364947326
		Eccentricity	0.024574283025
		Inclination	6.77790897298
		AscendingNode	84.820608289364
		ArgOfPericenter	64.285501227622
		MeanAnomaly	21.83309422562
	}
	UniformRotation
	{
		Period	10.2482
	}
	LunarLambert	0.5
	Albedo	0.0514
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=535"
}

#1_"536 Merapi:Merapi:1904 OF:1950 KE:1957 LP" "Sol" #1=
#2_"*Мерапи:536 Merapi:Merapi:1904 OF" "Sol" #2=
#3_"1904 OF:*Мерапи:536 Merapi:Merapi" "Sol" #3=
".:Merapi:536 Merapi:1904 OF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	75.71
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.539070025815
		SemiMajorAxis	3.496808565329
		Eccentricity	0.085473655272
		Inclination	19.428778582861
		AscendingNode	59.241592525909
		ArgOfPericenter	296.19574405494
		MeanAnomaly	211.631216243813
	}
	UniformRotation
	{
		Period	8.78
	}
	LunarLambert	0.5
	Albedo	0.0452
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=536"
}

#1_"537 Pauly:Pauly:1904 OG:1930 GN:A913 EF" "Sol" #1=
#2_"*Паули:537 Pauly:Pauly:1904 OG" "Sol" #2=
#3_"1904 OG:*Паули:537 Pauly:Pauly" "Sol" #3=
".:Pauly:537 Pauly:1904 OG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"537 pauly.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	20.366
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.417157219342
		SemiMajorAxis	3.084434071916
		Eccentricity	0.227708377419
		Inclination	9.901707546967
		AscendingNode	120.343302050703
		ArgOfPericenter	185.99970905607
		MeanAnomaly	188.899958924658
	}
	UniformRotation
	{
		Period	16.168
	}
	LunarLambert	0.5
	Albedo	0.322
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=537"
}

#1_"538 Friederike:Friederike:1904 OK" "Sol" #1=
#2_"*Фредерика:538 Friederike:Friederike:1904 OK" "Sol" #2=
#3_"1904 OK:*Фредерика:538 Friederike:Friederike" "Sol" #3=
".:Friederike:538 Friederike:1904 OK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.245
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.613618660329
		SemiMajorAxis	3.158564888121
		Eccentricity	0.168744410161
		Inclination	6.520315596247
		AscendingNode	141.175214761684
		ArgOfPericenter	227.887347557134
		MeanAnomaly	169.70030782122
	}
	UniformRotation
	{
		Period	46.728
	}
	LunarLambert	0.5
	Albedo	0.0641
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=538"
}

#1_"539 Pamina:Pamina:1904 OL:1959 XK" "Sol" #1=
#2_"*Памина:539 Pamina:Pamina:1904 OL" "Sol" #2=
#3_"1904 OL:*Памина:539 Pamina:Pamina" "Sol" #3=
".:Pamina:539 Pamina:1904 OL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.985
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.539933999029
		SemiMajorAxis	2.741748142724
		Eccentricity	0.21015924411
		Inclination	6.805770563734
		AscendingNode	274.568897932974
		ArgOfPericenter	96.991454062121
		MeanAnomaly	86.498108512011
	}
	UniformRotation
	{
		Period	13.903
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=539"
}

#1_"540 Rosamunde:Rosamunde:1904 ON" "Sol" #1=
#2_"*Розамунда:540 Rosamunde:Rosamunde:1904 ON" "Sol" #2=
#3_"1904 ON:*Розамунда:540 Rosamunde:Rosamunde" "Sol" #3=
".:Rosamunde:540 Rosamunde:1904 ON" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"540 rosamunde.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	9.576
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.304742790421
		SemiMajorAxis	2.218637287585
		Eccentricity	0.090041775503
		Inclination	5.581543006293
		AscendingNode	202.201673723117
		ArgOfPericenter	337.834192676175
		MeanAnomaly	266.092045824454
	}
	UniformRotation
	{
		Period	9.351
	}
	LunarLambert	0.5
	Albedo	0.331
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=540"
}

#1_"541 Deborah:Deborah:1904 OO:1957 WU1" "Sol" #1=
#2_"*Дебора:541 Deborah:Deborah:1904 OO" "Sol" #2=
#3_"1904 OO:*Дебора:541 Deborah:Deborah" "Sol" #3=
".:Deborah:541 Deborah:1904 OO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.505
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.721565274766
		SemiMajorAxis	2.814395950494
		Eccentricity	0.051878558224
		Inclination	6.007803905831
		AscendingNode	267.812165117014
		ArgOfPericenter	357.30157232537
		MeanAnomaly	182.911450927604
	}
	UniformRotation
	{
		Period	29.368
	}
	LunarLambert	0.5
	Albedo	0.0496
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=541"
}

#1_"542 Susanna:Susanna:1904 OQ:A921 BA" "Sol" #1=
#2_"*Сусанна:542 Susanna:Susanna:1904 OQ" "Sol" #2=
#3_"1904 OQ:*Сусанна:542 Susanna:Susanna" "Sol" #3=
".:Susanna:542 Susanna:1904 OQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	20.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.958921095847
		SemiMajorAxis	2.907943721362
		Eccentricity	0.138367629329
		Inclination	12.075700475861
		AscendingNode	153.020627424319
		ArgOfPericenter	215.532593232326
		MeanAnomaly	79.056815432389
	}
	UniformRotation
	{
		Period	10.069
	}
	LunarLambert	0.5
	Albedo	0.1843
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=542"
}

#1_"543 Charlotte:Charlotte:1904 OT:1958 XX" "Sol" #1=
#2_"*Шарлотта:543 Charlotte:Charlotte:1904 OT" "Sol" #2=
#3_"1904 OT:*Шарлотта:543 Charlotte:Charlotte" "Sol" #3=
".:Charlotte:543 Charlotte:1904 OT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"543 charlotte.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	22.806
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.344700351044
		SemiMajorAxis	3.056868614162
		Eccentricity	0.154930152357
		Inclination	8.479698294985
		AscendingNode	294.979697113991
		ArgOfPericenter	109.699226127268
		MeanAnomaly	180.411825165462
	}
	UniformRotation
	{
		Period	10.718
	}
	LunarLambert	0.5
	Albedo	0.144
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=543"
}

#1_"544 Jetta:Jetta:1904 OU:1937 UJ:1937 VS" "Sol" #1=
#2_"*Йетта:544 Jetta:Jetta:1904 OU" "Sol" #2=
#3_"1904 OU:*Йетта:544 Jetta:Jetta" "Sol" #3=
".:Jetta:544 Jetta:1904 OU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"544 jetta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.584
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.178203833186
		SemiMajorAxis	2.594105377262
		Eccentricity	0.152269907179
		Inclination	8.374981173477
		AscendingNode	298.354305692863
		ArgOfPericenter	342.900256849787
		MeanAnomaly	224.304042118996
	}
	UniformRotation
	{
		Period	7.745
	}
	LunarLambert	0.5
	Albedo	0.262
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=544"
}

#1_"545 Messalina:Messalina:1904 OY:1949 YH:1973 YO4" "Sol" #1=
#2_"*Мессалина:545 Messalina:Messalina:1904 OY" "Sol" #2=
#3_"1904 OY:*Мессалина:545 Messalina:Messalina" "Sol" #3=
".:Messalina:545 Messalina:1904 OY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	55.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.756309631984
		SemiMajorAxis	3.211865098728
		Eccentricity	0.167810152266
		Inclination	11.198058430426
		AscendingNode	333.656623044985
		ArgOfPericenter	329.499512938031
		MeanAnomaly	203.633891587745
	}
	UniformRotation
	{
		Period	7.2
	}
	LunarLambert	0.5
	Albedo	0.0415
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=545"
}

#1_"546 Herodias:Herodias:1904 PA2*" "Sol" #1=
#2_"*Геродиада:546 Herodias:Herodias:1904 PA2*" "Sol" #2=
#3_"1904 PA2*:*Геродиада:546 Herodias:Herodias" "Sol" #3=
".:Herodias:546 Herodias:1904 PA2*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.01
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.188146464876
		SemiMajorAxis	2.598219109188
		Eccentricity	0.116458100943
		Inclination	14.850793275672
		AscendingNode	21.804187102432
		ArgOfPericenter	108.787066162226
		MeanAnomaly	8.054393262173
	}
	UniformRotation
	{
		Period	10.77
	}
	LunarLambert	0.5
	Albedo	0.0534
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=546"
}

#1_"547 Praxedis:Praxedis:1904 PB" "Sol" #1=
#2_"*Пракседида:547 Praxedis:Praxedis:1904 PB" "Sol" #2=
#3_"1904 PB:*Пракседида:547 Praxedis:Praxedis" "Sol" #3=
".:Praxedis:547 Praxedis:1904 PB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.84
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.619020625394
		SemiMajorAxis	2.773497632535
		Eccentricity	0.236503286868
		Inclination	16.899530269893
		AscendingNode	193.217771668033
		ArgOfPericenter	195.264891390843
		MeanAnomaly	308.85418979898
	}
	UniformRotation
	{
		Period	9.105
	}
	LunarLambert	0.5
	Albedo	0.0566
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=547"
}

#1_"549 Jessonda:Jessonda:1904 PK" "Sol" #1=
#2_"*Джессонда:549 Jessonda:Jessonda:1904 PK" "Sol" #2=
#3_"1904 PK:*Джессонда:549 Jessonda:Jessonda" "Sol" #3=
".:Jessonda:549 Jessonda:1904 PK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.397105080809
		SemiMajorAxis	2.683937683854
		Eccentricity	0.257833772113
		Inclination	3.96195087096
		AscendingNode	291.471802887017
		ArgOfPericenter	158.288878546138
		MeanAnomaly	354.725774860174
	}
	UniformRotation
	{
		Period	2.971
	}
	LunarLambert	0.5
	Albedo	0.1971
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=549"
}

#1_"550 Senta:Senta:1904 PL:A900 YA:A903 NA" "Sol" #1=
#2_"*Сента:550 Senta:Senta:1904 PL" "Sol" #2=
#3_"1904 PL:*Сента:550 Senta:Senta" "Sol" #3=
".:Senta:550 Senta:1904 PL" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"550 senta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	18.717
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.164467255846
		SemiMajorAxis	2.588416539869
		Eccentricity	0.22247392845
		Inclination	10.108811245157
		AscendingNode	270.715666485674
		ArgOfPericenter	45.299905173416
		MeanAnomaly	235.394975476534
	}
	UniformRotation
	{
		Period	20.555
	}
	LunarLambert	0.5
	Albedo	0.225
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=550"
}

#1_"551 Ortrud:Ortrud:1904 PM:1962 DC:1978 AA:A906 EA" "Sol" #1=
#2_"*Ортруд:551 Ortrud:Ortrud:1904 PM" "Sol" #2=
#3_"1904 PM:*Ортруд:551 Ortrud:Ortrud" "Sol" #3=
".:Ortrud:551 Ortrud:1904 PM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	39.23
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.109618804486
		SemiMajorAxis	2.966562706541
		Eccentricity	0.12351825111
		Inclination	0.397503637751
		AscendingNode	6.005188243537
		ArgOfPericenter	68.068792627874
		MeanAnomaly	190.973939954445
	}
	UniformRotation
	{
		Period	13.05
	}
	LunarLambert	0.5
	Albedo	0.0426
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=551"
}

#1_"552 Sigelinde:Sigelinde:1904 PO:1941 MG" "Sol" #1=
#2_"*Зигелинда:552 Sigelinde:Sigelinde:1904 PO" "Sol" #2=
#3_"1904 PO:*Зигелинда:552 Sigelinde:Sigelinde" "Sol" #3=
".:Sigelinde:552 Sigelinde:1904 PO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38.78
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.595248116933
		SemiMajorAxis	3.15167019737
		Eccentricity	0.087913691375
		Inclination	7.695415432762
		AscendingNode	266.959895109732
		ArgOfPericenter	348.668813922296
		MeanAnomaly	49.096727701663
	}
	UniformRotation
	{
		Period	17.156
	}
	LunarLambert	0.5
	Albedo	0.051
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=552"
}

#1_"553 Kundry:Kundry:1904 PP:1932 CL:1957 UB" "Sol" #1=
#2_"*Кундри:553 Kundry:Kundry:1904 PP" "Sol" #2=
#3_"1904 PP:*Кундри:553 Kundry:Kundry" "Sol" #3=
".:Kundry:553 Kundry:1904 PP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"553 kundry.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	4.505
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.333199590911
		SemiMajorAxis	2.23135538378
		Eccentricity	0.109974778943
		Inclination	5.389041960342
		AscendingNode	72.400375501973
		ArgOfPericenter	354.683038579414
		MeanAnomaly	72.500133620526
	}
	UniformRotation
	{
		Period	12.605
	}
	LunarLambert	0.5
	Albedo	0.287
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=553"
}

#1_"554 Peraga:Peraga:1905 PS:A896 RB:A900 UC" "Sol" #1=
#2_"*Перага:554 Peraga:Peraga:1905 PS" "Sol" #2=
#3_"1905 PS:*Перага:554 Peraga:Peraga" "Sol" #3=
".:Peraga:554 Peraga:1905 PS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	47.935
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.661226198678
		SemiMajorAxis	2.375448245368
		Eccentricity	0.153260607121
		Inclination	2.935723252496
		AscendingNode	295.463253637697
		ArgOfPericenter	127.562027041431
		MeanAnomaly	53.861202444379
	}
	UniformRotation
	{
		Period	13.7128
	}
	LunarLambert	0.5
	Albedo	0.0496
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=554"
}

#1_"555 Norma:Norma:1905 PT:1928 FS:1939 BA:1950 CC:1954 UH2:1968 HE1" "Sol" #1=
#2_"*Норма:555 Norma:Norma:1905 PT" "Sol" #2=
#3_"1905 PT:*Норма:555 Norma:Norma" "Sol" #3=
".:Norma:555 Norma:1905 PT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	20.055
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.693803772459
		SemiMajorAxis	3.188571762319
		Eccentricity	0.149949421869
		Inclination	2.646079629597
		AscendingNode	130.436866821188
		ArgOfPericenter	356.277764887931
		MeanAnomaly	170.801757880895
	}
	UniformRotation
	{
		Period	19.55
	}
	LunarLambert	0.5
	Albedo	0.0632
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=555"
}

#1_"556 Phyllis:Phyllis:1905 PW:1950 QW" "Sol" #1=
#2_"*Филлида:556 Phyllis:Phyllis:1905 PW" "Sol" #2=
#3_"1905 PW:*Филлида:556 Phyllis:Phyllis" "Sol" #3=
".:Phyllis:556 Phyllis:1905 PW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"556 phyllis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	18.14
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.869035451476
		SemiMajorAxis	2.464504816422
		Eccentricity	0.103037482844
		Inclination	5.240968732042
		AscendingNode	286.137246492447
		ArgOfPericenter	177.334137859786
		MeanAnomaly	148.354442559912
	}
	UniformRotation
	{
		Period	4.293
	}
	LunarLambert	0.5
	Albedo	0.201
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=556"
}

#1_"558 Carmen:Carmen:1905 QB" "Sol" #1=
#2_"*Кармен:558 Carmen:Carmen:1905 QB" "Sol" #2=
#3_"1905 QB:*Кармен:558 Carmen:Carmen" "Sol" #3=
".:Carmen:558 Carmen:1905 QB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	29.655
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.955080253283
		SemiMajorAxis	2.906441997354
		Eccentricity	0.043707142834
		Inclination	8.375896819208
		AscendingNode	143.729460295483
		ArgOfPericenter	311.794510901542
		MeanAnomaly	97.478779254195
	}
	UniformRotation
	{
		Period	11.387
	}
	LunarLambert	0.5
	Albedo	0.1161
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=558"
}

#1_"559 Nanon:Nanon:1905 QD:1925 VH:1971 YL:A918 EE" "Sol" #1=
#2_"*Нанон:559 Nanon:Nanon:1905 QD" "Sol" #2=
#3_"1905 QD:*Нанон:559 Nanon:Nanon" "Sol" #3=
".:Nanon:559 Nanon:1905 QD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	39.91
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.462967884537
		SemiMajorAxis	2.710672436107
		Eccentricity	0.067065910678
		Inclination	9.305688342238
		AscendingNode	112.147150843589
		ArgOfPericenter	129.139431031518
		MeanAnomaly	156.251106024082
	}
	UniformRotation
	{
		Period	10.059
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=559"
}

#1_"560 Delila:Delila:1905 QF:1957 OS" "Sol" #1=
#2_"*Делила:560 Delila:Delila:1905 QF" "Sol" #2=
#3_"1905 QF:*Делила:560 Delila:Delila" "Sol" #3=
".:Delila:560 Delila:1905 QF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.62
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.559582455175
		SemiMajorAxis	2.749653152566
		Eccentricity	0.162108237038
		Inclination	8.470628858103
		AscendingNode	105.35145794549
		ArgOfPericenter	3.869926631378
		MeanAnomaly	57.764039167442
	}
	UniformRotation
	{
		Period	29.913
	}
	LunarLambert	0.5
	Albedo	0.0733
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=560"
}

#1_"561 Ingwelde:Ingwelde:1905 QG:1931 XR:1942 VM:1944 DB:1953 VP:1967 GP:1970 SX:1970 WQ:1972 BH" "Sol" #1=
#2_"*Ингвельда:561 Ingwelde:Ingwelde:1905 QG" "Sol" #2=
#3_"1905 QG:*Ингвельда:561 Ingwelde:Ingwelde" "Sol" #3=
".:Ingwelde:561 Ingwelde:1905 QG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	12.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.661543045243
		SemiMajorAxis	3.176516197858
		Eccentricity	0.116070020628
		Inclination	1.543676889906
		AscendingNode	159.493887825597
		ArgOfPericenter	315.538117259872
		MeanAnomaly	222.245644481807
	}
	UniformRotation
	{
		Period	12.012
	}
	LunarLambert	0.5
	Albedo	0.0966
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=561"
}

#1_"562 Salome:Salome:1905 QH" "Sol" #1=
#2_"*Саломея:562 Salome:Salome:1905 QH" "Sol" #2=
#3_"1905 QH:*Саломея:562 Salome:Salome" "Sol" #3=
".:Salome:562 Salome:1905 QH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"562 salome.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	16.326
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.246203340537
		SemiMajorAxis	3.019195797072
		Eccentricity	0.099811485793
		Inclination	11.103242411519
		AscendingNode	70.625005310225
		ArgOfPericenter	263.689834095912
		MeanAnomaly	201.087425822856
	}
	UniformRotation
	{
		Period	6.351
	}
	LunarLambert	0.5
	Albedo	0.158
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=562"
}

#1_"563 Suleika:Suleika:1905 QK" "Sol" #1=
#2_"*Зулейка:563 Suleika:Suleika:1905 QK" "Sol" #2=
#3_"1905 QK:*Зулейка:563 Suleika:Suleika" "Sol" #3=
".:Suleika:563 Suleika:1905 QK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	26.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.471960305273
		SemiMajorAxis	2.714312365004
		Eccentricity	0.233110467183
		Inclination	10.231603256619
		AscendingNode	85.341614421452
		ArgOfPericenter	336.71652346494
		MeanAnomaly	332.403621117263
	}
	UniformRotation
	{
		Period	5.69
	}
	LunarLambert	0.5
	Albedo	0.2477
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=563"
}

#1_"564 Dudu:Dudu:1905 QM" "Sol" #1=
#2_"*Дуду:564 Dudu:Dudu:1905 QM" "Sol" #2=
#3_"1905 QM:*Дуду:564 Dudu:Dudu" "Sol" #3=
".:Dudu:564 Dudu:1905 QM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"564 dudu.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	26.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.551686894936
		SemiMajorAxis	2.746477960859
		Eccentricity	0.27674859785
		Inclination	17.98896335751
		AscendingNode	70.771845047158
		ArgOfPericenter	215.071937934917
		MeanAnomaly	336.704800131108
	}
	UniformRotation
	{
		Period	8.882
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=564"
}

#1_"565 Marbachia:Marbachia:1905 QN:1947 LE:1949 WK:A912 DA" "Sol" #1=
#2_"*Марбахия:565 Marbachia:Marbachia:1905 QN" "Sol" #2=
#3_"1905 QN:*Марбахия:565 Marbachia:Marbachia" "Sol" #3=
".:Marbachia:565 Marbachia:1905 QN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"565 marbachia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.666
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.819359640487
		SemiMajorAxis	2.443364360493
		Eccentricity	0.130257810084
		Inclination	10.99496960329
		AscendingNode	225.85501996273
		ArgOfPericenter	291.726591267014
		MeanAnomaly	317.97043108926
	}
	UniformRotation
	{
		Period	4.587
	}
	LunarLambert	0.5
	Albedo	0.105
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=565"
}

#1_"566 Stereoskopia:Stereoskopia:1905 QO:1927 ED:1928 HC:A899 JB:A899 LB:A907 VL" "Sol" #1=
#2_"*Стереоскопия:566 Stereoskopia:Stereoskopia:1905 QO" "Sol" #2=
#3_"1905 QO:*Стереоскопия:566 Stereoskopia:Stereoskopia" "Sol" #3=
".:Stereoskopia:566 Stereoskopia:1905 QO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	84.08
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.229269365752
		SemiMajorAxis	3.38547236051
		Eccentricity	0.112936783391
		Inclination	4.895321105166
		AscendingNode	80.211153069672
		ArgOfPericenter	296.289244792565
		MeanAnomaly	84.632902820456
	}
	UniformRotation
	{
		Period	12.103
	}
	LunarLambert	0.5
	Albedo	0.0383
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=566"
}

#1_"567 Eleutheria:Eleutheria:1905 QP:1935 UJ:A907 TH:A907 VC:A909 AC:A913 WA" "Sol" #1=
#2_"*Елевтерия:567 Eleutheria:Eleutheria:1905 QP" "Sol" #2=
#3_"1905 QP:*Елевтерия:567 Eleutheria:Eleutheria" "Sol" #3=
".:Eleutheria:567 Eleutheria:1905 QP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"567 eleutheria.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	46.705
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.555071586164
		SemiMajorAxis	3.136565094687
		Eccentricity	0.092455770829
		Inclination	9.253387408616
		AscendingNode	58.345246400341
		ArgOfPericenter	133.198331316742
		MeanAnomaly	314.6667681896
	}
	UniformRotation
	{
		Period	7.717
	}
	LunarLambert	0.5
	Albedo	0.0439
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=567"
}

#1_"568 Cheruskia:Cheruskia:1905 QS:1956 DA:A891 XB" "Sol" #1=
#2_"*Херуския:568 Cheruskia:Cheruskia:1905 QS" "Sol" #2=
#3_"1905 QS:*Херуския:568 Cheruskia:Cheruskia" "Sol" #3=
".:Cheruskia:568 Cheruskia:1905 QS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	43.495
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.897706465556
		SemiMajorAxis	2.883963107609
		Eccentricity	0.167092271604
		Inclination	18.386858949299
		AscendingNode	249.886614331077
		ArgOfPericenter	174.613866431827
		MeanAnomaly	42.99754664494
	}
	UniformRotation
	{
		Period	13.209
	}
	LunarLambert	0.5
	Albedo	0.0535
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=568"
}

#1_"569 Misa:Misa:1905 QT:1949 WS" "Sol" #1=
#2_"*Миса:569 Misa:Misa:1905 QT" "Sol" #2=
#3_"1905 QT:*Миса:569 Misa:Misa" "Sol" #3=
".:Misa:569 Misa:1905 QT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.475
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.3318320353
		SemiMajorAxis	2.657310300445
		Eccentricity	0.180228411138
		Inclination	1.292972934011
		AscendingNode	301.807735968874
		ArgOfPericenter	143.085685362787
		MeanAnomaly	354.987800427857
	}
	UniformRotation
	{
		Period	13.52
	}
	LunarLambert	0.5
	Albedo	0.0297
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=569"
}

#1_"570 Kythera:Kythera:1905 QX:1952 BE:1994 PG40" "Sol" #1=
#2_"*Китера:570 Kythera:Kythera:1905 QX" "Sol" #2=
#3_"1905 QX:*Китера:570 Kythera:Kythera" "Sol" #3=
".:Kythera:570 Kythera:1905 QX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	51.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.317628633646
		SemiMajorAxis	3.41741137562
		Eccentricity	0.121329108122
		Inclination	1.786936288073
		AscendingNode	223.903227281264
		ArgOfPericenter	155.239036963406
		MeanAnomaly	32.550030105387
	}
	UniformRotation
	{
		Period	8.12
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=570"
}

#1_"572 Rebekka:Rebekka:1905 RB:A915 HA" "Sol" #1=
#2_"*Ребекка:572 Rebekka:Rebekka:1905 RB" "Sol" #2=
#3_"1905 RB:*Ребекка:572 Rebekka:Rebekka" "Sol" #3=
".:Rebekka:572 Rebekka:1905 RB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"572 rebekka.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	14.452
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.7207443401818
		SemiMajorAxis	2.401123058321326
		Eccentricity	0.1572518822914673
		Inclination	10.57480345632542
		AscendingNode	194.5764716012538
		ArgOfPericenter	192.2417606824398
		MeanAnomaly	113.6113293610839
	}
	UniformRotation
	{
		Period	5.6497
	}
	LunarLambert	0.5
	Albedo	0.089
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=572"
}

#1_"573 Recha:Recha:1905 RC:1926 RF:1956 HC" "Sol" #1=
#2_"*Реха:573 Recha:Recha:1905 RC" "Sol" #2=
#3_"1905 RC:*Реха:573 Recha:Recha" "Sol" #3=
".:Recha:573 Recha:1905 RC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"573 recha.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	23.791
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.231892446852
		SemiMajorAxis	3.01370267439
		Eccentricity	0.114437005188
		Inclination	9.833134213153
		AscendingNode	342.962125045178
		ArgOfPericenter	29.033713211669
		MeanAnomaly	302.456502013602
	}
	UniformRotation
	{
		Period	7.1663
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=573"
}

#1_"574 Reginhild:Reginhild:1905 RD:1947 BB:A912 YB:A922 TB" "Sol" #1=
#2_"*Регингильда:574 Reginhild:Reginhild:1905 RD" "Sol" #2=
#3_"1905 RD:*Регингильда:574 Reginhild:Reginhild" "Sol" #3=
".:Reginhild:574 Reginhild:1905 RD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.381518980404
		SemiMajorAxis	2.252868026798
		Eccentricity	0.239654232712
		Inclination	5.683860458065
		AscendingNode	336.812035105771
		ArgOfPericenter	76.82665707203
		MeanAnomaly	74.712759993947
	}
	UniformRotation
	{
		Period	14.339
	}
	LunarLambert	0.5
	Albedo	0.3819
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=574"
}

#1_"575 Renate:Renate:1905 RE:1981 EO1" "Sol" #1=
#2_"*Рената:575 Renate:Renate:1905 RE" "Sol" #2=
#3_"1905 RE:*Рената:575 Renate:Renate" "Sol" #3=
".:Renate:575 Renate:1905 RE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.63
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.082713891777
		SemiMajorAxis	2.554428961619
		Eccentricity	0.127881752445
		Inclination	15.011436550486
		AscendingNode	349.686194442574
		ArgOfPericenter	334.074048159024
		MeanAnomaly	295.573650473451
	}
	UniformRotation
	{
		Period	3.676
	}
	LunarLambert	0.5
	Albedo	0.1706
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=575"
}

#1_"576 Emanuela:Emanuela:1905 RF:1972 JG:A923 BA" "Sol" #1=
#2_"*Эмануэла:576 Emanuela:Emanuela:1905 RF" "Sol" #2=
#3_"1905 RF:*Эмануэла:576 Emanuela:Emanuela" "Sol" #3=
".:Emanuela:576 Emanuela:1905 RF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	42.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.156901120368
		SemiMajorAxis	2.984835499872
		Eccentricity	0.195719757021
		Inclination	10.228665244143
		AscendingNode	299.948103617141
		ArgOfPericenter	26.259703674236
		MeanAnomaly	73.855792587995
	}
	UniformRotation
	{
		Period	8.192
	}
	LunarLambert	0.5
	Albedo	0.0428
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=576"
}

#1_"577 Rhea:Rhea (asteroid):1905 RH:1943 QD:1949 SF1:1952 DC:A912 AC" "Sol" #1=
#2_"*Рея (астероид):577 Rhea:Rhea (asteroid):1905 RH" "Sol" #2=
#3_"1905 RH:*Рея (астероид):577 Rhea:Rhea (asteroid)" "Sol" #3=
".:Rhea (asteroid):577 Rhea:1905 RH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	19.765
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.490691332821
		SemiMajorAxis	3.112283988231
		Eccentricity	0.154682069704
		Inclination	5.296716426765
		AscendingNode	328.58664957913
		ArgOfPericenter	330.936203340377
		MeanAnomaly	357.368358132472
	}
	UniformRotation
	{
		Period	12.249
	}
	LunarLambert	0.5
	Albedo	0.1792
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=577"
}

#1_"578 Happelia:Happelia:1905 RZ:1958 HN:A899 KA" "Sol" #1=
#2_"*Гаппелия:578 Happelia:Happelia:1905 RZ" "Sol" #2=
#3_"1905 RZ:*Гаппелия:578 Happelia:Happelia" "Sol" #3=
".:Happelia:578 Happelia:1905 RZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"578 happelia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	34.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.559810858937
		SemiMajorAxis	2.749744977623
		Eccentricity	0.193893939207
		Inclination	6.152157298935
		AscendingNode	29.413087963826
		ArgOfPericenter	261.515106464885
		MeanAnomaly	70.654553555959
	}
	UniformRotation
	{
		Period	10.061
	}
	LunarLambert	0.5
	Albedo	0.0769
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=578"
}

#1_"579 Sidonia:Sidonia:1905 SD" "Sol" #1=
#2_"*Сидония:579 Sidonia:Sidonia:1905 SD" "Sol" #2=
#3_"1905 SD:*Сидония:579 Sidonia:Sidonia" "Sol" #3=
".:Sidonia:579 Sidonia:1905 SD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	42.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.227000872159
		SemiMajorAxis	3.01182393421
		Eccentricity	0.080766734497
		Inclination	11.00752311112
		AscendingNode	82.742677307911
		ArgOfPericenter	229.096381053869
		MeanAnomaly	47.580335905409
	}
	UniformRotation
	{
		Period	16.286
	}
	LunarLambert	0.5
	Albedo	0.1748
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=579"
}

#1_"580 Selene:Selene:1905 SE:1950 RQ1" "Sol" #1=
#2_"*Селена:580 Selene:Selene:1905 SE" "Sol" #2=
#3_"1905 SE:*Селена:580 Selene:Selene" "Sol" #3=
".:Selene:580 Selene:1905 SE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	22.895
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.807258418078
		SemiMajorAxis	3.230789280748
		Eccentricity	0.082951949625
		Inclination	3.661415681855
		AscendingNode	99.158431305094
		ArgOfPericenter	334.253443886992
		MeanAnomaly	303.70073739002
	}
	UniformRotation
	{
		Period	9.47
	}
	LunarLambert	0.5
	Albedo	0.1218
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=580"
}

#1_"581 Tauntonia:Tauntonia:1905 SH" "Sol" #1=
#2_"*Тонтония:581 Tauntonia:Tauntonia:1905 SH" "Sol" #2=
#3_"1905 SH:*Тонтония:581 Tauntonia:Tauntonia" "Sol" #3=
".:Tauntonia:581 Tauntonia:1905 SH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.83
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.754741626534
		SemiMajorAxis	3.211281802487
		Eccentricity	0.031376503008
		Inclination	21.889566246094
		AscendingNode	102.62226160323
		ArgOfPericenter	28.797350848974
		MeanAnomaly	281.681760398721
	}
	UniformRotation
	{
		Period	16.54
	}
	LunarLambert	0.5
	Albedo	0.0758
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=581"
}

#1_"582 Olympia:Olympia:1906 SO:1963 QE:1963 SD" "Sol" #1=
#2_"*Олимпия:582 Olympia:Olympia:1906 SO" "Sol" #2=
#3_"1906 SO:*Олимпия:582 Olympia:Olympia" "Sol" #3=
".:Olympia:582 Olympia:1906 SO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"582 olympia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	22.174
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.21521539226
		SemiMajorAxis	2.60940233164
		Eccentricity	0.22261283977
		Inclination	30.035327593736
		AscendingNode	155.710476125097
		ArgOfPericenter	310.455528244209
		MeanAnomaly	180.884648841006
	}
	UniformRotation
	{
		Period	36.312
	}
	LunarLambert	0.5
	Albedo	0.2128
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=582"
}

#1_"583 Klotilde:Klotilde:1905 SP:1950 RO:1954 KH:1955 QL:1957 YC:1962 WN" "Sol" #1=
#2_"*Клотильда:583 Klotilde:Klotilde:1905 SP" "Sol" #2=
#3_"1905 SP:*Клотильда:583 Klotilde:Klotilde" "Sol" #3=
".:Klotilde:583 Klotilde:Klotilde:1905 SP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.82
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.653985734375
		SemiMajorAxis	3.173688786782
		Eccentricity	0.162266853111
		Inclination	8.245973365828
		AscendingNode	257.943972730577
		ArgOfPericenter	252.504881589196
		MeanAnomaly	343.851451410467
	}
	UniformRotation
	{
		Period	9.2116
	}
	LunarLambert	0.5
	Albedo	0.066
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=583"
}

#1_"584 Semiramis:Semiramis:1906 SY:1948 TW:A913 AB" "Sol" #1=
#2_"*Семирамида:584 Semiramis:Semiramis:1906 SY" "Sol" #2=
#3_"1906 SY:*Семирамида:584 Semiramis:Semiramis" "Sol" #3=
".:Semiramis:584 Semiramis:1906 SY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"584 semiramis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.882 0.767 ]
	BlendTexture	true
	Radius	27.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.657162509322
		SemiMajorAxis	2.373690205883
		Eccentricity	0.233040127091
		Inclination	10.728282089254
		AscendingNode	282.234625583501
		ArgOfPericenter	84.819719112156
		MeanAnomaly	4.962054781568
	}
	UniformRotation
	{
		Period	5.068
		Inclination	129
		AscendingNode	196
	}
	LunarLambert	0.5
	Albedo	0.1987
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=584"
}

#1_"585 Bilkis:Bilkis:1906 TA" "Sol" #1=
#2_"*Билкис:585 Bilkis:Bilkis:1906 TA" "Sol" #2=
#3_"1906 TA:*Билкис:585 Bilkis:Bilkis" "Sol" #3=
".:Bilkis:585 Bilkis:1906 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.045
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.789007735575
		SemiMajorAxis	2.430402443239
		Eccentricity	0.128652842106
		Inclination	7.566073372285
		AscendingNode	180.300936892524
		ArgOfPericenter	329.171225976438
		MeanAnomaly	264.255948915331
	}
	UniformRotation
	{
		Period	8.5751
	}
	LunarLambert	0.5
	Albedo	0.0362
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=585"
}

#1_"586 Thekla:Thekla:1906 TC:A911 BB" "Sol" #1=
#2_"*Фёкла:586 Thekla:Thekla:1906 TC" "Sol" #2=
#3_"1906 TC:*Фёкла:586 Thekla:Thekla" "Sol" #3=
".:Thekla:586 Thekla:1906 TC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"586 thekla.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	47.602
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.308883491516
		SemiMajorAxis	3.04319649308
		Eccentricity	0.060159275499
		Inclination	1.625243568239
		AscendingNode	228.451864606765
		ArgOfPericenter	250.436286790425
		MeanAnomaly	207.393219767775
	}
	UniformRotation
	{
		Period	13.67
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=586"
}

#1_"588 Achilles:Achilles:1906 TG" "Sol" #1=
#2_"*Ахиллес:588 Achilles:Achilles:1906 TG" "Sol" #2=
#3_"1906 TG:*Ахиллес:588 Achilles:Achilles" "Sol" #3=
".:Achilles:588 Achilles:1906 TG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	67.735
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.867840956566
		SemiMajorAxis	5.202862439479
		Eccentricity	0.147661803422
		Inclination	10.315228901499
		AscendingNode	316.579720740196
		ArgOfPericenter	133.423616224521
		MeanAnomaly	105.500594025022
	}
	UniformRotation
	{
		Period	7.306
	}
	LunarLambert	0.5
	Albedo	0.0328
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=588"
}

#1_"589 Croatia:Croatia:1906 TM:1936 WM:1947 RA:1953 RF1:1953 VR1:1953 VU:A912 HH" "Sol" #1=
#2_"*Хорватия:589 Croatia:Croatia:1906 TM" "Sol" #2=
#3_"1906 TM:*Хорватия:589 Croatia:Croatia" "Sol" #3=
".:Croatia:589 Croatia:1906 TM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	43.77
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.548461787893
		SemiMajorAxis	3.134076536764
		Eccentricity	0.038816930183
		Inclination	10.814562289201
		AscendingNode	177.608499263082
		ArgOfPericenter	220.610109366531
		MeanAnomaly	347.662404379227
	}
	UniformRotation
	{
		Period	24.821
	}
	LunarLambert	0.5
	Albedo	0.0509
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=589"
}

#1_"590 Tomyris:Tomyris:1906 TO:1954 ME:1955 SJ" "Sol" #1=
#2_"*Томирис:590 Tomyris:Tomyris:1906 TO" "Sol" #2=
#3_"1906 TO:*Томирис:590 Tomyris:Tomyris" "Sol" #3=
".:Tomyris:590 Tomyris:1906 TO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"590 tomyris.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	15.288
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.199799337165
		SemiMajorAxis	3.00136574363
		Eccentricity	0.080481599568
		Inclination	11.176173234006
		AscendingNode	106.190560159213
		ArgOfPericenter	340.66047248151
		MeanAnomaly	51.765647140916
	}
	UniformRotation
	{
		Period	5.562
	}
	LunarLambert	0.5
	Albedo	0.187
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=590"
}

#1_"591 Irmgard:Irmgard:1906 TP:1954 EM:1955 ML1" "Sol" #1=
#2_"*Ирмгард:591 Irmgard:Irmgard:1906 TP" "Sol" #2=
#3_"1954 EM:*Ирмгард:591 Irmgard:Irmgard" "Sol" #3=
".:Irmgard:591 Irmgard:1906 TP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.93
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.384672552564
		SemiMajorAxis	2.678876190802
		Eccentricity	0.207527930686
		Inclination	12.490429131428
		AscendingNode	334.295727759528
		ArgOfPericenter	217.385934347805
		MeanAnomaly	268.372469309557
	}
	UniformRotation
	{
		Period	7.35
	}
	LunarLambert	0.5
	Albedo	0.0364
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=591"
}

#1_"593 Titania:Titania (asteroid):1906 TT:1930 SD1:1932 BR" "Sol" #1=
#2_"*Титания (астероид):593 Titania:Titania (asteroid):1906 TT" "Sol" #2=
#3_"1906 TT:*Титания (астероид):593 Titania:Titania (asteroid)" "Sol" #3=
".:Titania (asteroid):593 Titania:1906 TT" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	37.66
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.438455058098
		SemiMajorAxis	2.700737758918
		Eccentricity	0.214856183368
		Inclination	16.883188957571
		AscendingNode	76.007564795514
		ArgOfPericenter	31.025816509737
		MeanAnomaly	233.368836000532
	}
	UniformRotation
	{
		Period	9.899
	}
	LunarLambert	0.5
	Albedo	0.0604
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=593"
}

#1_"594 Mireille:Mireille:1906 TW" "Sol" #1=
#2_"*Мирайлль:594 Mireille:Mireille:1906 TW" "Sol" #2=
#3_"1906 TW:*Мирайлль:594 Mireille:Mireille" "Sol" #3=
".:Mireille:594 Mireille:1906 TW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.615
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.257784635678
		SemiMajorAxis	2.626941040232
		Eccentricity	0.353097905968
		Inclination	32.597113918389
		AscendingNode	155.129197849872
		ArgOfPericenter	76.789418650532
		MeanAnomaly	159.554281083198
	}
	UniformRotation
	{
		Period	4.966
	}
	LunarLambert	0.5
	Albedo	0.3255
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=594"
}

#1_"595 Polyxena:Polyxena:1906 TZ:2000 SV346:A908 TA:A911 FA" "Sol" #1=
#2_"*Поликсена:595 Polyxena:Polyxena:1906 TZ" "Sol" #2=
#3_"1906 TZ:*Поликсена:595 Polyxena:Polyxena" "Sol" #3=
".:Polyxena:595 Polyxena:1906 TZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"595 polyxena.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	45.324
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.74496401421
		SemiMajorAxis	3.207643345875
		Eccentricity	0.061941214139
		Inclination	17.828340219327
		AscendingNode	23.915133408393
		ArgOfPericenter	279.213063208624
		MeanAnomaly	252.260250316594
	}
	UniformRotation
	{
		Period	11.801
	}
	LunarLambert	0.5
	Albedo	0.145
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=595"
}

#1_"596 Scheila:Scheila:1906 UA:1949 WT" "Sol" #1=
#2_"*Шейла:596 Scheila:Scheila:1906 UA" "Sol" #2=
#3_"1906 UA:*Шейла:596 Scheila:Scheila" "Sol" #3=
".:Scheila:596 Scheila:1906 UA" "Sol" #4=
{
	Class	"asteroid"
	# Class	"comet"   # Комета главного пояса

	Mesh	"596 scheila.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"comet.dds"
	Radius	79.863
	OrbitColor	[ 0.611765 0.317647 0.12549 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	5.014308817911
		SemiMajorAxis	2.929556759715
		Eccentricity	0.164223326915
		Inclination	14.654678204473
		AscendingNode	70.639667001071
		ArgOfPericenter	175.152503212643
		MeanAnomaly	302.612402328388
	}
	UniformRotation
	{
		Period	15.848
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=596"
}

#1_"597 Bandusia:Bandusia:1906 UB:1938 YC:1950 KK:1958 HJ:A924 MA" "Sol" #1=
#2_"*Бандусия:597 Bandusia:Bandusia:1906 UB" "Sol" #2=
#3_"1906 UB:*Бандусия:597 Bandusia:Bandusia" "Sol" #3=
".:Bandusia:597 Bandusia:1906 UB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	18.03
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.365839664123
		SemiMajorAxis	2.671199880377
		Eccentricity	0.144496582522
		Inclination	12.803274040878
		AscendingNode	36.54766943459
		ArgOfPericenter	307.716227074665
		MeanAnomaly	201.735802409767
	}
	UniformRotation
	{
		Period	11.5
	}
	LunarLambert	0.5
	Albedo	0.2361
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=597"
}

#1_"598 Octavia:Octavia:1906 UC:A907 JB" "Sol" #1=
#2_"*Октавия:598 Octavia:Octavia:1906 UC" "Sol" #2=
#3_"1906 UC:*Октавия:598 Octavia:Octavia" "Sol" #3=
".:Octavia:598 Octavia:1906 UC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.165
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.592768652033
		SemiMajorAxis	2.762978962722
		Eccentricity	0.246929788363
		Inclination	12.22553533013
		AscendingNode	91.858998861717
		ArgOfPericenter	291.266416859802
		MeanAnomaly	35.715290536411
	}
	UniformRotation
	{
		Period	10.8903
	}
	LunarLambert	0.5
	Albedo	0.0521
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=598"
}

#1_"599 Luisa:Luisa:1906 UJ" "Sol" #1=
#2_"*Луиза:599 Luisa:Luisa:1906 UJ" "Sol" #2=
#3_"1906 UJ:*Луиза:599 Luisa:Luisa" "Sol" #3=
".:Luisa:599 Luisa:1906 UJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	32.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.622432240843
		SemiMajorAxis	2.774863137438
		Eccentricity	0.292096351078
		Inclination	16.652592534807
		AscendingNode	44.596019915579
		ArgOfPericenter	293.147114862322
		MeanAnomaly	105.398833451246
	}
	UniformRotation
	{
		Period	9.566
	}
	LunarLambert	0.5
	Albedo	0.1377
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=599"
}

#1_"600 Musa:Musa:1906 UM:1950 RC:1953 GC2" "Sol" #1=
#2_"*Муза:600 Musa:Musa:1906 UM" "Sol" #2=
#3_"1906 UM:*Муза:600 Musa:Musa" "Sol" #3=
".:Musa:600 Musa:1906 UM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"600 musa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	12.558
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.337756440212
		SemiMajorAxis	2.659732585179
		Eccentricity	0.055392699211
		Inclination	10.199660530267
		AscendingNode	139.301972169986
		ArgOfPericenter	114.576237032528
		MeanAnomaly	11.247252578757
	}
	UniformRotation
	{
		Period	5.8856
	}
	LunarLambert	0.5
	Albedo	0.227
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=600"
}

#1_"601 Nerthus:Nerthus:1906 UN:1934 NF1:1940 RB1" "Sol" #1=
#2_"*Нертуда:601 Nerthus:Nerthus:1906 UN" "Sol" #2=
#3_"1906 UN:*Нертуда:601 Nerthus:Nerthus" "Sol" #3=
".:Nerthus:601 Nerthus:1906 UN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"601 nerthus.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	37.768
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.568473682381
		SemiMajorAxis	3.141607893485
		Eccentricity	0.101252965589
		Inclination	16.105938770535
		AscendingNode	169.6210343
		ArgOfPericenter	158.27289139628
		MeanAnomaly	160.686224891484
	}
	UniformRotation
	{
		Period	13.59
	}
	LunarLambert	0.5
	Albedo	0.043
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=601"
}

#1_"602 Marianna:Marianna:1906 TE:1946 LC:1947 RF:A909 UD:A920 TC" "Sol" #1=
#2_"*Марианна:602 Marianna:Marianna:1906 TE" "Sol" #2=
#3_"1906 TE:*Марианна:602 Marianna:Marianna" "Sol" #3=
".:Marianna:602 Marianna:1906 TE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	62.36
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.427873855379
		SemiMajorAxis	3.088500641273
		Eccentricity	0.247797067858
		Inclination	15.106733467998
		AscendingNode	331.5065975246
		ArgOfPericenter	46.029132914931
		MeanAnomaly	126.488927844823
	}
	UniformRotation
	{
		Period	35.195
	}
	LunarLambert	0.5
	Albedo	0.0539
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=602"
}

#1_"603 Timandra:Timandra:1906 TJ:1967 EJ:1975 EA2:1977 RW7" "Sol" #1=
#2_"*Тимандра:603 Timandra:Timandra:1906 TJ" "Sol" #2=
#3_"1906 TJ:*Тимандра:603 Timandra:Timandra" "Sol" #3=
".:Timandra:603 Timandra:1906 TJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.865
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.043016416937
		SemiMajorAxis	2.537843682432
		Eccentricity	0.174513691458
		Inclination	8.026554955879
		AscendingNode	343.461580370822
		ArgOfPericenter	159.97952558707
		MeanAnomaly	300.69603146201
	}
	UniformRotation
	{
		Period	41.79
	}
	LunarLambert	0.5
	Albedo	0.1354
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=603"
}

#1_"604 Tekmessa:Tekmessa:1906 TK:A894 BA:A911 BC:A915 WG" "Sol" #1=
#2_"*Текмесса:604 Tekmessa:Tekmessa:1906 TK" "Sol" #2=
#3_"1906 TK:*Текмесса:604 Tekmessa:Tekmessa" "Sol" #3=
".:Tekmessa:604 Tekmessa:1906 TK" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32.58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.584713799896
		SemiMajorAxis	3.147713134871
		Eccentricity	0.199253005525
		Inclination	4.42120926259
		AscendingNode	12.180432006498
		ArgOfPericenter	28.876878767804
		MeanAnomaly	245.619444968564
	}
	UniformRotation
	{
		Period	5.5596
	}
	LunarLambert	0.5
	Albedo	0.087
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=604"
}

#1_"605 Juvisia:Juvisia:1906 UU:1931 PD:1931 RY:1939 BJ:1952 SE1" "Sol" #1=
#2_"*Ювизия:605 Juvisia:Juvisia:1906 UU" "Sol" #2=
#3_"1906 UU:*Ювизия:605 Juvisia:Juvisia" "Sol" #3=
".:Juvisia:605 Juvisia:1906 UU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.93
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.196285141673
		SemiMajorAxis	3.000013310112
		Eccentricity	0.139689292146
		Inclination	19.661873535917
		AscendingNode	342.852535904863
		ArgOfPericenter	14.676214571875
		MeanAnomaly	339.356525987751
	}
	UniformRotation
	{
		Period	15.93
	}
	LunarLambert	0.5
	Albedo	0.0397
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=605"
}

#1_"606 Brangane:Brangane:1906 VB" "Sol" #1=
#2_"*Брангена:606 Brangane:Brangane:1906 VB" "Sol" #2=
#3_"1906 VB:*Брангена:606 Brangane:Brangane" "Sol" #3=
".:Brangane:606 Brangane:1906 VB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"606 brangane.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	17.879
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.161681120289
		SemiMajorAxis	2.587261933003
		Eccentricity	0.219758574514
		Inclination	8.620594487521
		AscendingNode	318.715943247452
		ArgOfPericenter	57.375879520483
		MeanAnomaly	353.463600593242
	}
	UniformRotation
	{
		Period	12.295
	}
	LunarLambert	0.5
	Albedo	0.096
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=606"
}

#1_"607 Jenny:Jenny:1906 VC:1940 TH:1948 JD" "Sol" #1=
#2_"*Дженни:607 Jenny:Jenny:1906 VC" "Sol" #2=
#3_"1906 VC:*Дженни:607 Jenny:Jenny" "Sol" #3=
".:Jenny:607 Jenny:1906 VC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.39
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.821169754082
		SemiMajorAxis	2.853839079265
		Eccentricity	0.07375963527
		Inclination	10.109974314648
		AscendingNode	285.28127619795
		ArgOfPericenter	289.792507168713
		MeanAnomaly	314.317415426672
	}
	UniformRotation
	{
		Period	8.521
	}
	LunarLambert	0.5
	Albedo	0.0711
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=607"
}

#1_"608 Adolfine:Adolfine:1906 VD:1916 Sbu:1927 QE:1948 RR1:1953 VR:A911 QD" "Sol" #1=
#2_"*Адольфина:608 Adolfine:Adolfine:1906 VD" "Sol" #2=
#3_"1906 VD:*Адольфина:608 Adolfine:Adolfine" "Sol" #3=
".:Adolfine:608 Adolfine:1906 VD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"608 adolfine.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.182
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.254776830487
		SemiMajorAxis	3.022484270395
		Eccentricity	0.12470421948
		Inclination	9.379148724145
		AscendingNode	293.84867445263
		ArgOfPericenter	71.414189475722
		MeanAnomaly	34.555185006784
	}
	UniformRotation
	{
		Period	8.3458
	}
	LunarLambert	0.5
	Albedo	0.245
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=608"
}

#1_"609 Fulvia:Fulvia:1906 VF:1942 EK1:1942 FK:1948 LM:1969 FM:2002 LN60:A917 SR" "Sol" #1=
#2_"*Фульвия:609 Fulvia:Fulvia:1906 VF" "Sol" #2=
#3_"1906 VF:*Фульвия:609 Fulvia:Fulvia" "Sol" #3=
".:Fulvia:609 Fulvia:1906 VF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.085
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.422113269395
		SemiMajorAxis	3.086315043684
		Eccentricity	0.041306664336
		Inclination	4.188255703709
		AscendingNode	165.351218617299
		ArgOfPericenter	113.422223671108
		MeanAnomaly	65.375201630512
	}
	UniformRotation
	{
		Period	12
	}
	LunarLambert	0.5
	Albedo	0.0602
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=609"
}

#1_"611 Valeria:Valeria:1906 VL:A901 VA" "Sol" #1=
#2_"*Валерия:611 Valeria:Valeria:1906 VL" "Sol" #2=
#3_"1906 VL:*Валерия:611 Valeria:Valeria" "Sol" #3=
".:Valeria:611 Valeria:1906 VL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	28.485
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.142447627829
		SemiMajorAxis	2.979255730921
		Eccentricity	0.119197750926
		Inclination	13.441110674925
		AscendingNode	189.447367002425
		ArgOfPericenter	256.792318973581
		MeanAnomaly	317.061051285703
	}
	UniformRotation
	{
		Period	6.977
	}
	LunarLambert	0.5
	Albedo	0.1148
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=611"
}

#1_"612 Veronika:Veronika:1906 VN:1934 SF:1950 LN:1962 VB:1973 RE:1973 TQ:1973 UH3:1974 XS" "Sol" #1=
#2_"*Вероника:612 Veronika:Veronika:1906 VN" "Sol" #2=
#3_"1906 VN:*Вероника:612 Veronika:Veronika" "Sol" #3=
".:Veronika:612 Veronika:1906 VN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.87
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.624432163947
		SemiMajorAxis	3.16261981226
		Eccentricity	0.257682419455
		Inclination	20.813997069961
		AscendingNode	203.265492424165
		ArgOfPericenter	121.133837948341
		MeanAnomaly	158.534096782813
	}
	UniformRotation
	{
		Period	8.243
	}
	LunarLambert	0.5
	Albedo	0.0411
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=612"
}

#1_"613 Ginevra:Ginevra:1906 VP:1978 JB:A901 TD" "Sol" #1=
#2_"*Гвиневра:613 Ginevra:Ginevra:1906 VP" "Sol" #2=
#3_"1906 VP:*Гвиневра:613 Ginevra:Ginevra" "Sol" #3=
".:Ginevra:613 Ginevra:1906 VP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.02
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.991097315153
		SemiMajorAxis	2.920509054085
		Eccentricity	0.059395018469
		Inclination	7.666534525916
		AscendingNode	354.81325619296
		ArgOfPericenter	62.494751447541
		MeanAnomaly	216.11661502082
	}
	UniformRotation
	{
		Period	13.024
	}
	LunarLambert	0.5
	Albedo	0.0374
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=613"
}

#1_"614 Pia:Pia:1906 VQ:1928 XH:1963 QF:A919 RA" "Sol" #1=
#2_"*Пиа:614 Pia:Pia:1906 VQ" "Sol" #2=
#3_"1906 VQ:*Пиа:614 Pia:Pia" "Sol" #3=
".:Pia:614 Pia:1906 VQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"614 pia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	14.596
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.418309748361
		SemiMajorAxis	2.692559471873
		Eccentricity	0.111539393501
		Inclination	7.027666505739
		AscendingNode	217.302310598047
		ArgOfPericenter	208.886641541656
		MeanAnomaly	133.290299681928
	}
	UniformRotation
	{
		Period	4.572
	}
	LunarLambert	0.5
	Albedo	0.094
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=614"
}

#1_"615 Roswitha:Roswitha:1906 VR:A902 WF:A902 YA:A908 BA" "Sol" #1=
#2_"*Росвита:615 Roswitha:Roswitha:1906 VR" "Sol" #2=
#3_"1906 VR:*Росвита:615 Roswitha:Roswitha" "Sol" #3=
".:Roswitha:615 Roswitha:1906 VR" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.945
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.274827874946
		SemiMajorAxis	2.633946525103
		Eccentricity	0.109476449056
		Inclination	2.76090357546
		AscendingNode	13.497631850787
		ArgOfPericenter	246.68401339851
		MeanAnomaly	240.031989010474
	}
	UniformRotation
	{
		Period	4.422
	}
	LunarLambert	0.5
	Albedo	0.0553
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=615"
}

#1_"616 Elly:Elly:1906 VT:A908 DB" "Sol" #1=
#2_"*Элли:616 Elly:Elly:1906 VT" "Sol" #2=
#3_"1906 VT:*Элли:616 Elly:Elly" "Sol" #3=
".:Elly:616 Elly:1906 VT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"616 elly.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.585
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.07938999597
		SemiMajorAxis	2.553042333597
		Eccentricity	0.058897039395
		Inclination	14.959066086599
		AscendingNode	356.1074679089
		ArgOfPericenter	107.786705660749
		MeanAnomaly	354.950181797174
	}
	UniformRotation
	{
		Period	5.297
	}
	LunarLambert	0.5
	Albedo	0.211
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=616"
}

#1_"Patroclus-Menoetius" "Sol" #1=
#2_"*Патрокл-Менетий:Patroclus-Menoetius" "Sol" #2=
#3_"Patroclus-Menoetius:*Патрокл-Менетий" "Sol" #3=
".:Patroclus-Menoetius" "Sol" #4=
{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	294
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.91826662694
		SemiMajorAxis	5.217589767847
		Eccentricity	0.139284878993
		Inclination	22.049245950923
		AscendingNode	44.363959282959
		ArgOfPericenter	308.482775981466
		MeanAnomaly	70.608674103869
	}
	LunarLambert	0.5
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00617.html"
}

#1_"617 Patroclus:Patroclus:1906 VY:1941 XC:1962 NB" "Sol/Patroclus-Menoetius" #1=
#2_"*Патрокл:617 Patroclus:Patroclus:1906 VY" "Sol/Patroclus-Menoetius" #2=
#3_"1906 VY:*Патрокл:617 Patroclus:Patroclus" "Sol/Patroclus-Menoetius" #3=
".:Patroclus:617 Patroclus:1906 VY" "Sol/Patroclus-Menoetius" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	53
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	4.283
		SemiMajorAxis	300
		Eccentricity	0.02
		ArgOfPericenter	180
	}
	UniformRotation
	{
		Period	103.02
	}
	LunarLambert	0.5
	Albedo	0.047
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=617"
}

#1_"Menoetius:617 Patroclus I:Patroclus I:2001 617 I" "Sol/Patroclus-Menoetius" #1=
#2_"*Менетий:Menoetius:617 Patroclus I:*Патрокл I:Patroclus I:2001 617 I" "Sol/Patroclus-Menoetius" #2=
#3_"2001 617 I:*Менетий:Menoetius:617 Patroclus I:*Патрокл I:Patroclus I" "Sol/Patroclus-Menoetius" #3=
".:Menoetius:617 Patroclus I:Patroclus I:2001 617 I" "Sol/Patroclus-Menoetius" #4=

{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"menoetius-smooth.dds"
	Radius	49
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	4.283
		SemiMajorAxis	380
		Eccentricity	0.02
	}
	UniformRotation
	{
		Period	103.02
	}
	LunarLambert	0.5
	Albedo	0.047
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00617.html"
}

#1_"618 Elfriede:Elfriede:1906 VZ" "Sol" #1=
#2_"*Эльфрида:618 Elfriede:Elfriede:1906 VZ" "Sol" #2=
#3_"1906 VZ:*Эльфрида:618 Elfriede:Elfriede" "Sol" #3=
".:Elfriede:618 Elfriede:1906 VZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	60.145
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.695344607703
		SemiMajorAxis	3.189146989049
		Eccentricity	0.07370322422
		Inclination	17.038153465247
		AscendingNode	111.072984751322
		ArgOfPericenter	228.278053463801
		MeanAnomaly	37.978074838294
	}
	UniformRotation
	{
		Period	14.801
	}
	LunarLambert	0.5
	Albedo	0.0606
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=618"
}

#1_"620 Drakonia:Drakonia:1906 WE:1950 ET:1950 HS:1955 QE1" "Sol" #1=
#2_"*Дракония:620 Drakonia:Drakonia:1906 WE" "Sol" #2=
#3_"1906 WE:Drakonia:*Дракония:620 Drakonia" "Sol" #3=
".:Drakonia:620 Drakonia:1906 WE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"620 drakonia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.692
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.80109230295
		SemiMajorAxis	2.435567343749
		Eccentricity	0.135250384934
		Inclination	7.739185225431
		AscendingNode	0.016904884861
		ArgOfPericenter	336.453636142629
		MeanAnomaly	60.065530335919
	}
	UniformRotation
	{
		Period	5.487
	}
	LunarLambert	0.5
	Albedo	0.419
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=620"
}

#1_"621 Werdandi:Werdandi:1906 WJ:1952 BO" "Sol" #1=
#2_"*Верданди:621 Werdandi:Werdandi:1906 WJ" "Sol" #2=
#3_"1906 WJ:*Верданди:621 Werdandi:Werdandi" "Sol" #3=
".:Werdandi:621 Werdandi:1906 WJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"621 werdandi.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	14.863
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.529697297381
		SemiMajorAxis	3.127006403363
		Eccentricity	0.138733570192
		Inclination	2.314728336485
		AscendingNode	67.120349267847
		ArgOfPericenter	31.874526300086
		MeanAnomaly	193.02431987551
	}
	UniformRotation
	{
		Period	11.776
	}
	LunarLambert	0.5
	Albedo	0.127
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=621"
}

#1_"622 Esther:Esther:1906 WP:1947 QE:1952 BC:1994 EV9" "Sol" #1=
#2_"*Эстер:622 Esther:Esther:1906 WP" "Sol" #2=
#3_"1906 WP:Esther:*Эстер:622 Esther" "Sol" #3=
".:Esther:622 Esther:1906 WP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"622 esther.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	20
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.756558543343
		SemiMajorAxis	2.416506528403
		Eccentricity	0.242005279154
		Inclination	8.638354627364
		AscendingNode	142.016756758521
		ArgOfPericenter	256.847611723288
		MeanAnomaly	145.9770637305
	}
	UniformRotation
	{
		Period	47.5
	}
	LunarLambert	0.5
	Albedo	0.316
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=622"
}

#1_"623 Chimaera:Chimaera:1907 XJ" "Sol" #1=
#2_"*Химера:623 Chimaera:Chimaera:1907 XJ" "Sol" #2=
#3_"1907 XJ:*Химера:623 Chimaera:Chimaera" "Sol" #3=
".:Chimaera:623 Chimaera:1907 XJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.045
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.862649062675
		SemiMajorAxis	2.461792061211
		Eccentricity	0.112763101644
		Inclination	14.130165820482
		AscendingNode	308.353436392492
		ArgOfPericenter	124.73335778233
		MeanAnomaly	32.730346711373
	}
	UniformRotation
	{
		Period	14.635
	}
	LunarLambert	0.5
	Albedo	0.0372
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=623"
}

#1_"624 Hektor:Hektor:1907 XM:1948 VD" "Sol" #1=
#2_"*Гектор:624 Hektor:Hektor:1907 XM" "Sol" #2=
#3_"1907 XM:*Гектор:624 Hektor:Hektor" "Sol" #3=
".:Hektor:624 Hektor:1907 XM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"624 hektor.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.885 0.782 ]
	BlendTexture	true
	Radius	208
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.028762030161
		SemiMajorAxis	5.249788661969
		Eccentricity	0.024404703413
		Inclination	18.169013725832
		AscendingNode	342.809042997472
		ArgOfPericenter	182.146707721216
		MeanAnomaly	40.849551772658
	}
	UniformRotation
	{
		Period	6.924
	}
	LunarLambert	0.5
	Albedo	0.025
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=624"
}

#1_"Skamandrios:2006 624 I" "Sol/624 Hektor" #1=
#2_"*Скамандриос:Skamandrios:2006 624 I" "Sol/624 Hektor" #2=
#3_"2006 624 I:*Скамандриос:Skamandrios" "Sol/624 Hektor" #3=
".:Skamandrios:2006 624 I" "Sol/624 Hektor" #4=


{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.885 0.782 ]
	BlendTexture	true
	Radius	6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	2.965079
		SemiMajorAxis	957.5
		Eccentricity	0.31
	}
	LunarLambert	0.5
	Albedo	0.025
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00624.html"
}

#1_"625 Xenia:Xenia:1907 XN:1959 GV:1973 PA" "Sol" #1=
#2_"*Ксения:625 Xenia:Xenia:1907 XN" "Sol" #2=
#3_"1907 XN:*Ксения:625 Xenia:Xenia" "Sol" #3=
".:Xenia:625 Xenia:1907 XN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"625 xenia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	14.144
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.306107862997
		SemiMajorAxis	2.646779737853
		Eccentricity	0.226772192637
		Inclination	12.078223483822
		AscendingNode	127.552617418053
		ArgOfPericenter	200.599563441436
		MeanAnomaly	196.398713454247
	}
	UniformRotation
	{
		Period	21.017
	}
	LunarLambert	0.5
	Albedo	0.221
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=625"
}

#1_"626 Notburga:Notburga:1907 XO" "Sol" #1=
#2_"*Нортбурга:626 Notburga:Notburga:1907 XO" "Sol" #2=
#3_"1907 XO:*Нортбурга:626 Notburga:Notburga" "Sol" #3=
".:Notburga:626 Notburga:1907 XO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	50.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.129404996496
		SemiMajorAxis	2.573867490078
		Eccentricity	0.242559886947
		Inclination	25.369481123512
		AscendingNode	341.644687033108
		ArgOfPericenter	43.771025022456
		MeanAnomaly	133.726612294326
	}
	UniformRotation
	{
		Period	19.353
	}
	LunarLambert	0.5
	Albedo	0.0437
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=626"
}

#1_"627 Charis:Charis:1907 XS:1929 RJ1:1929 RN1:1932 CZ:1947 GK:1966 DR:A917 DE" "Sol" #1=
#2_"*Харида:627 Charis:Charis:1907 XS" "Sol" #2=
#3_"1907 XS:*Харида:627 Charis:Charis" "Sol" #3=
".:Charis:627 Charis:1907 XS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.255
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.937187745399
		SemiMajorAxis	2.899441117316
		Eccentricity	0.059584346607
		Inclination	6.47748691755
		AscendingNode	142.533025180816
		ArgOfPericenter	174.169456949555
		MeanAnomaly	122.15683211147
	}
	UniformRotation
	{
		Period	27.888
	}
	LunarLambert	0.5
	Albedo	0.0786
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=627"
}

#1_"628 Christine:Christine:1907 XT:1977 AT2" "Sol" #1=
#2_"*Кристина:628 Christine:Christine:1907 XT" "Sol" #2=
#3_"1907 XT:*Кристина:628 Christine:Christine" "Sol" #3=
".:Christine:628 Christine:1907 XT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"628 christine.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	24.12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.151779659319
		SemiMajorAxis	2.583156566075
		Eccentricity	0.042630271631
		Inclination	11.529319143449
		AscendingNode	112.142659726381
		ArgOfPericenter	206.712668286452
		MeanAnomaly	183.304101081284
	}
	UniformRotation
	{
		Period	16.1783
	}
	LunarLambert	0.5
	Albedo	0.12
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=628"
}

#1_"629 Bernardina:Bernardina:1907 XU:1929 AD:1949 UJ:1961 XY:1962 AC:1963 GE:A907 GB:A922 WA" "Sol" #1=
#2_"*Бернардина:629 Bernardina:Bernardina:1907 XU" "Sol" #2=
#3_"1907 XU:*Бернардина:629 Bernardina:Bernardina" "Sol" #3=
".:Bernardina:629 Bernardina:Bernardina:1907 XU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"629 bernardina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	17.544
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.561880284423
		SemiMajorAxis	3.139127505723
		Eccentricity	0.153864415432
		Inclination	9.25351387111
		AscendingNode	86.580384676784
		ArgOfPericenter	35.274510588379
		MeanAnomaly	186.189879908712
	}
	UniformRotation
	{
		Period	3.763
	}
	LunarLambert	0.5
	Albedo	0.14
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=629"
}

#1_"630 Euphemia:Euphemia:1907 XW:A924 DC" "Sol" #1=
#2_"*Эвфимия:630 Euphemia:Euphemia:1907 XW" "Sol" #2=
#3_"1907 XW:*Эвфимия:630 Euphemia:Euphemia" "Sol" #3=
".:Euphemia:630 Euphemia:1907 XW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.605
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.252285542879
		SemiMajorAxis	2.624678689404
		Eccentricity	0.110876021244
		Inclination	13.85603790062
		AscendingNode	105.431402578443
		ArgOfPericenter	39.952017970342
		MeanAnomaly	134.717343248216
	}
	UniformRotation
	{
		Period	350
	}
	LunarLambert	0.5
	Albedo	0.2375
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=630"
}

#1_"631 Philippina:Philippina:1907 YJ:1951 UB1:A907 GL" "Sol" #1=
#2_"*Филиппина:631 Philippina:Philippina:1907 YJ" "Sol" #2=
#3_"1907 YJ:*Филиппина:631 Philippina:Philippina" "Sol" #3=
".:Philippina:631 Philippina:1907 YJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"631 philippina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	25.246
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.666224347449
		SemiMajorAxis	2.792361289571
		Eccentricity	0.082312100257
		Inclination	18.918114886303
		AscendingNode	224.727766640831
		ArgOfPericenter	277.6099316131
		MeanAnomaly	91.252094395195
	}
	UniformRotation
	{
		Period	5.899
	}
	LunarLambert	0.5
	Albedo	0.229
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=631"
}

#1_"632 Pyrrha:Pyrrha:1907 YX:A911 FC" "Sol" #1=
#2_"*Пирра:632 Pyrrha:Pyrrha:1907 YX" "Sol" #2=
#3_"1907 YX:Pyrrha:*Пирра:632 Pyrrha" "Sol" #3=
".:Pyrrha:632 Pyrrha:1907 YX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"632 pyrrha.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.348795497488
		SemiMajorAxis	2.664243135196
		Eccentricity	0.189861185683
		Inclination	2.215437933997
		AscendingNode	356.507010413953
		ArgOfPericenter	252.79491898193
		MeanAnomaly	79.251070445628
	}
	UniformRotation
	{
		Period	4.1167
	}
	LunarLambert	0.5
	Albedo	0.195
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=632"
}

#1_"633 Zelima:Zelima:1907 ZM:1939 ND:A918 OA" "Sol" #1=
#2_"*Зелима:633 Zelima:Zelima:1907 ZM" "Sol" #2=
#3_"1907 ZM:*Зелима:633 Zelima:Zelima" "Sol" #3=
".:Zelima:633 Zelima:1907 ZM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	17.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.241705643859
		SemiMajorAxis	3.017469930817
		Eccentricity	0.084666806233
		Inclination	10.9164978568
		AscendingNode	147.384317745565
		ArgOfPericenter	186.995308347274
		MeanAnomaly	103.737538913863
	}
	UniformRotation
	{
		Period	11.724
	}
	LunarLambert	0.5
	Albedo	0.1918
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=633"
}

#1_"634 Ute:Ute:1907 ZN:1948 CB" "Sol" #1=
#2_"*Уте:634 Ute:Ute:1907 ZN" "Sol" #2=
#3_"1907 ZN:*Уте:634 Ute:Ute" "Sol" #3=
".:Ute:634 Ute:1907 ZN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.72
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.316990081867
		SemiMajorAxis	3.046293650663
		Eccentricity	0.185725079033
		Inclination	12.289069995701
		AscendingNode	133.448957259575
		ArgOfPericenter	220.540701462574
		MeanAnomaly	345.174328207293
	}
	UniformRotation
	{
		Period	11.7554
	}
	LunarLambert	0.5
	Albedo	0.053
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=634"
}

#1_"635 Vundtia:Vundtia:1907 ZS:1945 GF:1953 VV:A905 AC:A906 FC:A908 QA" "Sol" #1=
#2_"*Вундция:635 Vundtia:Vundtia:1907 ZS" "Sol" #2=
#3_"1907 ZS:*Вундция:635 Vundtia:Vundtia" "Sol" #3=
".:Vundtia:635 Vundtia:1907 ZS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	49.12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.570055040437
		SemiMajorAxis	3.142202643157
		Eccentricity	0.07646689625
		Inclination	11.028728769069
		AscendingNode	183.06042704
		ArgOfPericenter	223.713225535874
		MeanAnomaly	334.8147201255
	}
	UniformRotation
	{
		Period	11.79
	}
	LunarLambert	0.5
	Albedo	0.0456
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=635"
}

#1_"636 Erika:Erika:1907 XP:1954 UT1" "Sol" #1=
#2_"*Эрика:636 Erika:Erika:1907 XP" "Sol" #2=
#3_"1907 XP:*Эрика:636 Erika:Erika" "Sol" #3=
".:Erika:636 Erika:1907 XP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"636 erika.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	36.574
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.962624707774
		SemiMajorAxis	2.909391422678
		Eccentricity	0.172743742749
		Inclination	7.926578333545
		AscendingNode	34.688476252262
		ArgOfPericenter	297.5920800691
		MeanAnomaly	63.839777229073
	}
	UniformRotation
	{
		Period	14.603
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=636"
}

#1_"637 Chrysothemis:Chrysothemis:1907 YE:1930 GC:1955 UV:1975 JM" "Sol" #1=
#2_"*Хрисофемида:637 Chrysothemis:Chrysothemis:1907 YE" "Sol" #2=
#3_"1907 YE:*Хрисофемида:637 Chrysothemis:Chrysothemis" "Sol" #3=
".:Chrysothemis:637 Chrysothemis:1907 YE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	16.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.650897315264
		SemiMajorAxis	3.172532956291
		Eccentricity	0.1248573501
		Inclination	0.271531129782
		AscendingNode	353.422341890316
		ArgOfPericenter	172.500385020359
		MeanAnomaly	58.912941366114
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0633
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=637"
}

#1_"638 Moira:Moira:1907 ZQ:1917 Sdw:1944 QJ:1976 WA1:A893 EB:A906 BF" "Sol" #1=
#2_"*Мойра:638 Moira:Moira:1907 ZQ" "Sol" #2=
#3_"1907 ZQ:*Мойра:638 Moira:Moira" "Sol" #3=
".:Moira:638 Moira:1907 ZQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32.72
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.528114946824
		SemiMajorAxis	2.736987582923
		Eccentricity	0.159458148732
		Inclination	7.714187709873
		AscendingNode	103.228175054887
		ArgOfPericenter	128.355382556578
		MeanAnomaly	284.314985519403
	}
	UniformRotation
	{
		Period	9.875
	}
	LunarLambert	0.5
	Albedo	0.0496
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=638"
}

#1_"639 Latona:Latona:1907 ZT:A913 UB" "Sol" #1=
#2_"*Латона:639 Latona:Latona:1907 ZT" "Sol" #2=
#3_"1907 ZT:*Латона:639 Latona:Latona" "Sol" #3=
".:Latona:639 Latona:1907 ZT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"639 latona.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	39.254
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.255569245492
		SemiMajorAxis	3.022788121129
		Eccentricity	0.103689943436
		Inclination	8.563591410671
		AscendingNode	280.012155185039
		ArgOfPericenter	70.0369562837
		MeanAnomaly	141.732610957235
	}
	UniformRotation
	{
		Period	6.193
	}
	LunarLambert	0.5
	Albedo	0.123
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=639"
}

#1_"640 Brambilla:Brambilla:1907 ZW:A902 TD" "Sol" #1=
#2_"*Брамбилла:640 Brambilla:Brambilla:1907 ZW" "Sol" #2=
#3_"1907 ZW:*Брамбилла:640 Brambilla:Brambilla" "Sol" #3=
".:Brambilla:640 Brambilla:1907 ZW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.395
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.615707780393
		SemiMajorAxis	3.159348483928
		Eccentricity	0.080530112433
		Inclination	13.371882949254
		AscendingNode	234.936599761826
		ArgOfPericenter	31.668558799968
		MeanAnomaly	90.06548322832
	}
	UniformRotation
	{
		Period	7.768
	}
	LunarLambert	0.5
	Albedo	0.0686
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=640"
}

#1_"642 Clara:Clara:1907 ZY:1949 BS" "Sol" #1=
#2_"*Клара:642 Clara:Clara:1907 ZY" "Sol" #2=
#3_"1907 ZY:*Клара:642 Clara:Clara" "Sol" #3=
".:Clara:642 Clara:1907 ZY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.68
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.705155824032
		SemiMajorAxis	3.192808509872
		Eccentricity	0.121868683537
		Inclination	8.169065689277
		AscendingNode	5.906759603012
		ArgOfPericenter	117.865111757423
		MeanAnomaly	203.693960060344
	}
	UniformRotation
	{
		Period	8.2308
	}
	LunarLambert	0.5
	Albedo	0.1617
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=642"
}

#1_"643 Scheherezade:Scheherezade:1907 ZZ:1956 VG:A899 LC" "Sol" #1=
#2_"*Шехеризада:643 Scheherezade:Scheherezade:1907 ZZ" "Sol" #2=
#3_"1907 ZZ:*Шехеризада:643 Scheherezade:Scheherezade" "Sol" #3=
".:Scheherezade:643 Scheherezade:1907 ZZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	35.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.156857739445
		SemiMajorAxis	3.359185170669
		Eccentricity	0.058381553077
		Inclination	13.771821480025
		AscendingNode	252.203423678318
		ArgOfPericenter	230.621429792857
		MeanAnomaly	66.69807344728
	}
	UniformRotation
	{
		Period	14.161
	}
	LunarLambert	0.5
	Albedo	0.0446
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=643"
}

#1_"644 Cosima:Cosima:1907 AA" "Sol" #1=
#2_"*Козима:644 Cosima:Cosima:1907 AA" "Sol" #2=
#3_"1907 AA:*Козима:644 Cosima:Cosima" "Sol" #3=
".:Cosima:644 Cosima:1907 AA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"644 cosima.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.508
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.188016498352
		SemiMajorAxis	2.598165356968
		Eccentricity	0.156037383833
		Inclination	1.04082966755
		AscendingNode	109.972043553044
		ArgOfPericenter	268.827838852704
		MeanAnomaly	216.259462510496
	}
	UniformRotation
	{
		Period	7.556
	}
	LunarLambert	0.5
	Albedo	0.271
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=644"
}

#1_"645 Agrippina:Agrippina:1907 AG" "Sol" #1=
#2_"*Агриппина:645 Agrippina:Agrippina:1907 AG" "Sol" #2=
#3_"1907 AG:*Агриппина:645 Agrippina:Agrippina" "Sol" #3=
".:Agrippina:645 Agrippina:1907 AG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.758705023929
		SemiMajorAxis	3.212756079556
		Eccentricity	0.146180476142
		Inclination	7.042805362186
		AscendingNode	0.172461538409
		ArgOfPericenter	84.18411928064
		MeanAnomaly	219.830358197335
	}
	UniformRotation
	{
		Period	32.6
	}
	LunarLambert	0.5
	Albedo	0.2381
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=645"
}

#1_"648 Pippa:Pippa:1907 AE" "Sol" #1=
#2_"*Пиппа:648 Pippa:Pippa:1907 AE" "Sol" #2=
#3_"1907 AE:*Пиппа:648 Pippa:Pippa" "Sol" #3=
".:Pippa:648 Pippa:1907 AE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.135
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.748601261406
		SemiMajorAxis	3.208997083512
		Eccentricity	0.19438472269
		Inclination	9.80118419621
		AscendingNode	291.243761205007
		ArgOfPericenter	178.025294668228
		MeanAnomaly	225.017467603051
	}
	UniformRotation
	{
		Period	9.263
	}
	LunarLambert	0.5
	Albedo	0.0509
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=648"
}

#1_"650 Amalasuntha:Amalasuntha:1907 AM:1930 UK:1947 CB:1949 PM:1949 QT:1949 QY1" "Sol" #1=
#2_"*Амаласунта:650 Amalasuntha:Amalasuntha:1907 AM" "Sol" #2=
#3_"1907 AM:Amalasuntha:*Амаласунта:650 Amalasuntha" "Sol" #3=
".:Amalasuntha:650 Amalasuntha:1907 AM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"650 amalasuntha.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	9.304
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.857844671389
		SemiMajorAxis	2.45975030777
		Eccentricity	0.183245879897
		Inclination	2.558795666508
		AscendingNode	215.538765462461
		ArgOfPericenter	178.573174197487
		MeanAnomaly	135.599730327959
	}
	UniformRotation
	{
		Period	16.582
	}
	LunarLambert	0.5
	Albedo	0.027
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=650"
}

#1_"651 Antikleia:Antikleia:1907 AN:1957 JF1:A905 JB" "Sol" #1=
#2_"*Антиклея:651 Antikleia:Antikleia:1907 AN" "Sol" #2=
#3_"1907 AN:*Антиклея:651 Antikleia:Antikleia" "Sol" #3=
".:Antikleia:651 Antikleia:1907 AN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.52
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.253901989347
		SemiMajorAxis	3.022148795703
		Eccentricity	0.10053522466
		Inclination	10.758745740785
		AscendingNode	38.02914361455
		ArgOfPericenter	355.205670047236
		MeanAnomaly	139.794002427077
	}
	UniformRotation
	{
		Period	20.299
	}
	LunarLambert	0.5
	Albedo	0.1603
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=651"
}

#1_"652 Jubilatrix:Jubilatrix:1907 AU" "Sol" #1=
#2_"*Юбилатрикс:652 Jubilatrix:Jubilatrix:1907 AU" "Sol" #2=
#3_"1907 AU:*Юбилатрикс:652 Jubilatrix:Jubilatrix" "Sol" #3=
".:Jubilatrix:652 Jubilatrix:1907 AU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.088197939157
		SemiMajorAxis	2.556715916742
		Eccentricity	0.125740361578
		Inclination	15.746239915778
		AscendingNode	86.267140528758
		ArgOfPericenter	277.047491948595
		MeanAnomaly	119.075578378871
	}
	UniformRotation
	{
		Period	2.6627
	}
	LunarLambert	0.5
	Albedo	0.171
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=652"
}

#1_"653 Berenike:Berenike:1907 BK:1933 WT:1963 PE:A893 AA:A905 MA" "Sol" #1=
#2_"*Береника:653 Berenike:Berenike:1907 BK" "Sol" #2=
#3_"1907 BK:*Береника:653 Berenike:Berenike" "Sol" #3=
".:Berenike:653 Berenike:1907 BK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	19.61
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.234436764811
		SemiMajorAxis	3.014679656309
		Eccentricity	0.039679857366
		Inclination	11.290826927709
		AscendingNode	132.868891300565
		ArgOfPericenter	55.142622044816
		MeanAnomaly	43.870174082676
	}
	UniformRotation
	{
		Period	12.4886
	}
	LunarLambert	0.5
	Albedo	0.2444
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=653"
}

#1_"654 Zelinda:Zelinda:1908 BM:1965 QG" "Sol" #1=
#2_"*Зелинда:654 Zelinda:Zelinda:1908 BM" "Sol" #2=
#3_"1965 QG:*Зелинда:654 Zelinda:Zelinda" "Sol" #3=
".:Zelinda:654 Zelinda:1908 BM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	63.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.481584278496
		SemiMajorAxis	2.297095971678
		Eccentricity	0.23128298026
		Inclination	18.126805069868
		AscendingNode	278.478722296741
		ArgOfPericenter	213.979111194229
		MeanAnomaly	242.046261065006
	}
	UniformRotation
	{
		Period	31.735
	}
	LunarLambert	0.5
	Albedo	0.0425
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=654"
}

#1_"655 Briseis:Briseis:1907 BF:1950 CN:A909 DK" "Sol" #1=
#2_"*Брисеида:655 Briseis:Briseis:1907 BF" "Sol" #2=
#3_"1907 BF:*Брисеида:655 Briseis:Briseis" "Sol" #3=
".:Briseis:655 Briseis:1907 BF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	15.395
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.170457492478
		SemiMajorAxis	2.990064199842
		Eccentricity	0.087242178612
		Inclination	6.497469047345
		AscendingNode	130.068801624417
		ArgOfPericenter	278.554833432396
		MeanAnomaly	253.936941796404
	}
	UniformRotation
	{
		Period	160.66
	}
	LunarLambert	0.5
	Albedo	0.2693
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=655"
}

#1_"656 Beagle:Beagle:1908 BU:1917 Sed:1954 HJ" "Sol" #1=
#2_"*Бигль:656 Beagle:Beagle:1908 BU" "Sol" #2=
#3_"1908 BU:*Бигль:656 Beagle:Beagle" "Sol" #3=
".:Beagle:656 Beagle:1908 BU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	26.585
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.594443716489
		SemiMajorAxis	3.151368123706
		Eccentricity	0.135642911483
		Inclination	0.515154379584
		AscendingNode	184.339010851188
		ArgOfPericenter	330.883726800437
		MeanAnomaly	349.489612947555
	}
	UniformRotation
	{
		Period	7.035
	}
	LunarLambert	0.5
	Albedo	0.0625
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=656"
}

#1_"657 Gunlod:Gunlod:1908 BV:1927 SC:1929 AM:1936 YJ" "Sol" #1=
#2_"*Гунлёд:657 Gunlod:Gunlod:1908 BV" "Sol" #2=
#3_"1908 BV:*Гунлёд:657 Gunlod:Gunlod" "Sol" #3=
".:Gunlod:657 Gunlod:1908 BV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	21.26
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.220158780136
		SemiMajorAxis	2.611442048348
		Eccentricity	0.112098545464
		Inclination	10.230771999863
		AscendingNode	297.604786409005
		ArgOfPericenter	245.046213058143
		MeanAnomaly	67.112215102252
	}
	UniformRotation
	{
		Period	15.6652
	}
	LunarLambert	0.5
	Albedo	0.0415
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=657"
}

#1_"658 Asteria:Asteria:1908 BW:A906 UF:A918 EH" "Sol" #1=
#2_"*Астерия:658 Asteria:Asteria:1908 BW" "Sol" #2=
#3_"1908 BW:*Астерия:658 Asteria:Asteria" "Sol" #3=
".:Asteria:658 Asteria:1908 BW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"ida.jpg"
	Radius	11.475
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.819980279097
		SemiMajorAxis	2.853369662095
		Eccentricity	0.065484031832
		Inclination	1.506247639784
		AscendingNode	351.00743146973
		ArgOfPericenter	61.503605556703
		MeanAnomaly	116.45015156952
	}
	UniformRotation
	{
		Period	21.034
	}
	LunarLambert	0.5
	Albedo	0.204
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=658"
}

#1_"659 Nestor:Nestor:1908 CS:A914 WF" "Sol" #1=
#2_"*Нестор:659 Nestor:Nestor:1908 CS" "Sol" #2=
#3_"1908 CS:*Нестор:659 Nestor:Nestor" "Sol" #3=
".:Nestor:659 Nestor:1908 CS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	54.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.808621127416
		SemiMajorAxis	5.185540027884
		Eccentricity	0.115249610858
		Inclination	4.522796288284
		AscendingNode	350.866456542607
		ArgOfPericenter	341.644358020567
		MeanAnomaly	208.710577735476
	}
	UniformRotation
	{
		Period	15.98
	}
	LunarLambert	0.5
	Albedo	0.0378
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=659"
}

#1_"660 Crescentia:Crescentia:1908 CC:1961 CF" "Sol" #1=
#2_"*Кресцентия:660 Crescentia:Crescentia:1908 CC" "Sol" #2=
#3_"1908 CC:*Кресцентия:660 Crescentia:Crescentia" "Sol" #3=
".:Crescentia:660 Crescentia:1908 CC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"660 crescentia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	21.151
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.032963540352
		SemiMajorAxis	2.533635073286
		Eccentricity	0.108142269311
		Inclination	15.204754675781
		AscendingNode	156.982302467714
		ArgOfPericenter	106.154728454548
		MeanAnomaly	38.708812044385
	}
	UniformRotation
	{
		Period	7.9116
	}
	LunarLambert	0.5
	Albedo	0.332
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=660"
}

#1_"661 Cloelia:Cloelia:1908 CL:1929 CF:1930 KC:1936 RJ:1950 HM" "Sol" #1=
#2_"*Клелия:661 Cloelia:Cloelia:1908 CL" "Sol" #2=
#3_"1908 CL:*Клелия:661 Cloelia:Cloelia" "Sol" #3=
".:Cloelia:661 Cloelia:1908 CL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	24.025
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.240751732437
		SemiMajorAxis	3.017103830347
		Eccentricity	0.033853572938
		Inclination	9.231870444737
		AscendingNode	335.82678121304
		ArgOfPericenter	180.460585178496
		MeanAnomaly	136.45243798885
	}
	UniformRotation
	{
		Period	5.536
	}
	LunarLambert	0.5
	Albedo	0.1076
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=661"
}

#1_"662 Newtonia:Newtonia:1908 CW:1929 UE" "Sol" #1=
#2_"*Ньютония:662 Newtonia:Newtonia:1908 CW" "Sol" #2=
#3_"1908 CW:*Ньютония:662 Newtonia:Newtonia" "Sol" #3=
".:Newtonia:662 Newtonia:1908 CW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.079580409127
		SemiMajorAxis	2.553121778329
		Eccentricity	0.216652764874
		Inclination	4.120188150048
		AscendingNode	133.746835057833
		ArgOfPericenter	165.658174932278
		MeanAnomaly	339.711166665421
	}
	UniformRotation
	{
		Period	16.46
	}
	LunarLambert	0.5
	Albedo	0.1999
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=662"
}

#1_"663 Gerlinde:Gerlinde:1908 DG:1948 AB:1952 WF:1958 XP" "Sol" #1=
#2_"*Герлинда:663 Gerlinde:Gerlinde:1908 DG" "Sol" #2=
#3_"1908 DG:*Герлинда:663 Gerlinde:Gerlinde" "Sol" #3=
".:Gerlinde:663 Gerlinde:1908 DG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	50.44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.372890052599
		SemiMajorAxis	3.067607805662
		Eccentricity	0.146012087816
		Inclination	17.823161422813
		AscendingNode	232.884168687798
		ArgOfPericenter	310.752085944458
		MeanAnomaly	26.145391514655
	}
	UniformRotation
	{
		Period	10.251
	}
	LunarLambert	0.5
	Albedo	0.0359
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=663"
}

#1_"664 Judith:Judith:1908 DH:1951 AB1:1956 AH1" "Sol" #1=
#2_"*Юдифь:664 Judith:Judith:1908 DH" "Sol" #2=
#3_"1908 DH:*Юдифь:664 Judith:Judith" "Sol" #3=
".:Judith:664 Judith:1908 DH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.71417786159
		SemiMajorAxis	3.19617365915
		Eccentricity	0.229786850829
		Inclination	8.576748233775
		AscendingNode	170.955441037226
		ArgOfPericenter	102.03782431773
		MeanAnomaly	284.708810749431
	}
	UniformRotation
	{
		Period	10.9829
	}
	LunarLambert	0.5
	Albedo	0.0344
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=664"
}

#1_"665 Sabine:Sabine:1908 DK:1973 BD:A906 AA" "Sol" #1=
#2_"*Сабина:665 Sabine:Sabine:1908 DK" "Sol" #2=
#3_"1908 DK:*Сабина:665 Sabine:Sabine" "Sol" #3=
".:Sabine:665 Sabine:1908 DK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"665 sabine.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	25.545
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.578237145276
		SemiMajorAxis	3.14527903899
		Eccentricity	0.170998403164
		Inclination	14.740986309653
		AscendingNode	298.452935994657
		ArgOfPericenter	319.004885177177
		MeanAnomaly	43.823213294753
	}
	UniformRotation
	{
		Period	4.294
	}
	LunarLambert	0.5
	Albedo	0.3895
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=665"
}

#1_"666 Desdemona:Desdemona (asteroid):1908 DM" "Sol" #1=
#2_"*Дездемона (астероид):666 Desdemona:Desdemona (asteroid):1908 DM" "Sol" #2=
#3_"1908 DM:*Дездемона (астероид):666 Desdemona:Desdemona (asteroid)" "Sol" #3=
".:Desdemona (asteroid):666 Desdemona:1908 DM" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.52
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.17676973008
		SemiMajorAxis	2.593511752573
		Eccentricity	0.237600038298
		Inclination	7.58256359763
		AscendingNode	215.425798998404
		ArgOfPericenter	174.269146079148
		MeanAnomaly	120.867624158369
	}
	UniformRotation
	{
		Period	15.45
	}
	LunarLambert	0.5
	Albedo	0.1055
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=666"
}

#1_"667 Denise:Denise:1908 DN:1937 QA:1948 PH1:1957 BB1" "Sol" #1=
#2_"*Дениз:667 Denise:Denise:1908 DN" "Sol" #2=
#3_"1908 DN:*Дениз:667 Denise:Denise" "Sol" #3=
".:Denise:667 Denise:1908 DN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.674684674954
		SemiMajorAxis	3.181429872014
		Eccentricity	0.19165276635
		Inclination	25.404205285883
		AscendingNode	153.261002429607
		ArgOfPericenter	305.815917010399
		MeanAnomaly	101.662591916745
	}
	UniformRotation
	{
		Period	12.687
	}
	LunarLambert	0.5
	Albedo	0.0737
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=667"
}

#1_"668 Dora:Dora:1908 DO" "Sol" #1=
#2_"*Дора:668 Dora:Dora:1908 DO" "Sol" #2=
#3_"1908 DO:*Дора:668 Dora:Dora" "Sol" #3=
".:Dora:668 Dora:1908 DO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.42
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.668345401375
		SemiMajorAxis	2.793207412663
		Eccentricity	0.234999064937
		Inclination	6.843017467922
		AscendingNode	214.45797030993
		ArgOfPericenter	113.355830208037
		MeanAnomaly	255.983687655246
	}
	UniformRotation
	{
		Period	22.914
	}
	LunarLambert	0.5
	Albedo	0.0467
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=668"
}

#1_"669 Kypria:Kypria:1908 DQ:A906 BK" "Sol" #1=
#2_"*Киприя:669 Kypria:Kypria:1908 DQ" "Sol" #2=
#3_"1908 DQ:*Киприя:669 Kypria:Kypria" "Sol" #3=
".:Kypria:669 Kypria:1908 DQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"669 kypria.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	14.614
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.22536106329
		SemiMajorAxis	3.011193990579
		Eccentricity	0.079005933723
		Inclination	10.782864232079
		AscendingNode	170.803434491899
		ArgOfPericenter	114.313002842144
		MeanAnomaly	165.411888373677
	}
	UniformRotation
	{
		Period	14.283
	}
	LunarLambert	0.5
	Albedo	0.112
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=669"
}

#1_"670 Ottegebe:Ottegebe:1908 DR:A907 JD" "Sol" #1=
#2_"*Оттегебе:670 Ottegebe:Ottegebe:1908 DR" "Sol" #2=
#3_"1908 DR:*Оттегебе:670 Ottegebe:Ottegebe" "Sol" #3=
".:Ottegebe:670 Ottegebe:1908 DR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"670 ottegebe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	17.943
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.688975220665
		SemiMajorAxis	2.801430312773
		Eccentricity	0.194092604545
		Inclination	7.535583601591
		AscendingNode	174.694135004038
		ArgOfPericenter	195.397457562298
		MeanAnomaly	207.441617162622
	}
	UniformRotation
	{
		Period	10.045
	}
	LunarLambert	0.5
	Albedo	0.165
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=670"
}

#1_"671 Carnegia:Carnegia:1908 DV" "Sol" #1=
#2_"*Карнегия:671 Carnegia:Carnegia:1908 DV" "Sol" #2=
#3_"1908 DV:*Карнегия:671 Carnegia:Carnegia" "Sol" #3=
".:Carnegia:671 Carnegia:1908 DV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.36
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.435362354102
		SemiMajorAxis	3.091340662846
		Eccentricity	0.067807383302
		Inclination	8.029139250062
		AscendingNode	0.52593851917
		ArgOfPericenter	91.204191235739
		MeanAnomaly	100.497377247368
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0512
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=671"
}

#1_"673 Edda:Edda:1908 EA:1948 BF:1976 AK" "Sol" #1=
#2_"*Эдда:673 Edda:Edda:1908 EA" "Sol" #2=
#3_"1908 EA:*Эдда:673 Edda:Edda" "Sol" #3=
".:Edda:673 Edda:1908 EA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	18.765
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.721670835736
		SemiMajorAxis	2.814437898343
		Eccentricity	0.011914301856
		Inclination	2.87687925595
		AscendingNode	226.735165756929
		ArgOfPericenter	237.294928050336
		MeanAnomaly	72.744984619906
	}
	UniformRotation
	{
		Period	14.92
	}
	LunarLambert	0.5
	Albedo	0.1044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=673"
}

#1_"674 Rachele:Rachele:1908 EP:A901 KA:A924 DA" "Sol" #1=
#2_"*Рашель:674 Rachele:Rachele:1908 EP" "Sol" #2=
#3_"1908 EP:*Рашель:674 Rachele:Rachele" "Sol" #3=
".:Rachele:674 Rachele:1908 EP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	48.675
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.997531994638
		SemiMajorAxis	2.923018656394
		Eccentricity	0.196056189564
		Inclination	13.507879160812
		AscendingNode	58.177860555415
		ArgOfPericenter	42.232900617079
		MeanAnomaly	28.80239716268
	}
	UniformRotation
	{
		Period	30.982
	}
	LunarLambert	0.5
	Albedo	0.2007
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=674"
}

#1_"675 Ludmilla:Ludmilla:1908 DU:A910 CH" "Sol" #1=
#2_"*Людмила:675 Ludmilla:Ludmilla:1908 DU" "Sol" #2=
#3_"1908 DU:*Людмила:675 Ludmilla:Ludmilla" "Sol" #3=
".:Ludmilla:675 Ludmilla:1908 DU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"675 ludmilla.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.892 0.805 ]
	BlendTexture	true
	Radius	38
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.612343950462
		SemiMajorAxis	2.770824308809
		Eccentricity	0.200862834902
		Inclination	9.783481066911
		AscendingNode	263.270305415552
		ArgOfPericenter	152.085652500744
		MeanAnomaly	331.024565955427
	}
	UniformRotation
	{
		Period	7.717
		Inclination	126
		AscendingNode	110
	}
	LunarLambert	0.5
	Albedo	0.21
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=675"
}

#1_"676 Melitta:Melitta:1909 FN:A910 JD" "Sol" #1=
#2_"*Мелитта:676 Melitta:Melitta:1909 FN" "Sol" #2=
#3_"1909 FN:*Мелитта:676 Melitta:Melitta" "Sol" #3=
".:Melitta:676 Melitta:1909 FN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	39.995
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.354026403317
		SemiMajorAxis	3.060423566446
		Eccentricity	0.123971752602
		Inclination	12.864854641345
		AscendingNode	150.37959174716
		ArgOfPericenter	182.273732152148
		MeanAnomaly	101.710502297824
	}
	UniformRotation
	{
		Period	7.87
	}
	LunarLambert	0.5
	Albedo	0.0526
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=676"
}

#1_"677 Aaltje:Aaltje:1909 FR:A906 PA" "Sol" #1=
#2_"*Алтье:677 Aaltje:Aaltje:1909 FR" "Sol" #2=
#3_"1909 FR:*Алтье:677 Aaltje:Aaltje" "Sol" #3=
".:Aaltje:677 Aaltje:1909 FR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.075946110803
		SemiMajorAxis	2.953515132334
		Eccentricity	0.051106825368
		Inclination	8.488573003547
		AscendingNode	272.867489162233
		ArgOfPericenter	277.998781330821
		MeanAnomaly	231.294615076016
	}
	UniformRotation
	{
		Period	16.608
	}
	LunarLambert	0.5
	Albedo	0.2794
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=677"
}

#1_"678 Fredegundis:Fredegundis:1909 FS" "Sol" #1=
#2_"*Фредегонда:678 Fredegundis:Fredegundis:1909 FS" "Sol" #2=
#3_"1909 FS:*Фредегонда:678 Fredegundis:Fredegundis" "Sol" #3=
".:Fredegundis:678 Fredegundis:1909 FS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	20.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.129470898613
		SemiMajorAxis	2.573894874632
		Eccentricity	0.218398725525
		Inclination	6.083269646717
		AscendingNode	281.425754486487
		ArgOfPericenter	120.197621036528
		MeanAnomaly	290.575832624396
	}
	UniformRotation
	{
		Period	11.6162
	}
	LunarLambert	0.5
	Albedo	0.2494
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=678"
}

#1_"679 Pax:Pax:1909 FY:1973 QD" "Sol" #1=
#2_"*Пакс:679 Pax:Pax:1909 FY" "Sol" #2=
#3_"1909 FY:*Пакс:679 Pax:Pax" "Sol" #3=
".:Pax:679 Pax:1909 FY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"679 pax.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	31.954
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.158125259394
		SemiMajorAxis	2.585787968696
		Eccentricity	0.311541493935
		Inclination	24.388316499653
		AscendingNode	112.265551071927
		ArgOfPericenter	266.782232944304
		MeanAnomaly	251.167942701724
	}
	UniformRotation
	{
		Period	8.452
	}
	LunarLambert	0.5
	Albedo	0.11
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=679"
}

#1_"680 Genoveva:Genoveva:1909 GW:1932 KH:1933 UE:1933 VG:1954 HC" "Sol" #1=
#2_"*Геновева:680 Genoveva:Genoveva:1909 GW" "Sol" #2=
#3_"1909 GW:*Геновева:680 Genoveva:Genoveva" "Sol" #3=
".:Genoveva:680 Genoveva:1909 GW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	41.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.58057266573
		SemiMajorAxis	3.146156897093
		Eccentricity	0.293249356148
		Inclination	17.49369015883
		AscendingNode	38.055367587284
		ArgOfPericenter	245.617494965956
		MeanAnomaly	277.605129027398
	}
	UniformRotation
	{
		Period	11.089
	}
	LunarLambert	0.5
	Albedo	0.0474
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=680"
}

#1_"681 Gorgo:Gorgo:1909 GZ:1949 UO:1954 RD" "Sol" #1=
#2_"*Горгона:681 Gorgo:Gorgo:1909 GZ" "Sol" #2=
#3_"1909 GZ:Gorgo:*Горгона:681 Gorgo" "Sol" #3=
".:Gorgo:681 Gorgo:1909 GZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"681 gorgo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.195
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.471486273716
		SemiMajorAxis	3.105022425835
		Eccentricity	0.102944856921
		Inclination	12.580373723034
		AscendingNode	177.98447250482
		ArgOfPericenter	116.960876666857
		MeanAnomaly	181.968322299582
	}
	UniformRotation
	{
		Period	6.4606
	}
	LunarLambert	0.5
	Albedo	0.24
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=681"
}

#1_"682 Hagar:Hagar:1909 HA:1943 GK:1953 VU3:1975 VO5" "Sol" #1=
#2_"*Агарь:682 Hagar:Hagar:1909 HA" "Sol" #2=
#3_"1909 HA:Hagar:*Агарь:682 Hagar" "Sol" #3=
".:Hagar:682 Hagar:1909 HA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"682 hagar.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.629
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.322968460176
		SemiMajorAxis	2.653684227405
		Eccentricity	0.171825703191
		Inclination	11.507413013773
		AscendingNode	190.806707894967
		ArgOfPericenter	104.839149487935
		MeanAnomaly	312.209731523189
	}
	UniformRotation
	{
		Period	4.8503
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=682"
}

#1_"683 Lanzia:Lanzia:1909 HC:1954 TZ:A913 GC" "Sol" #1=
#2_"*Ланция:683 Lanzia:Lanzia:1909 HC" "Sol" #2=
#3_"1909 HC:*Ланция:683 Lanzia:Lanzia" "Sol" #3=
".:Lanzia:683 Lanzia:1909 HC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"683 lanzia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	41.52
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.501113583851
		SemiMajorAxis	3.116221167221
		Eccentricity	0.055575500068
		Inclination	18.504614081057
		AscendingNode	259.735005074638
		ArgOfPericenter	283.366335445876
		MeanAnomaly	171.741739570181
	}
	UniformRotation
	{
		Period	8.63
	}
	LunarLambert	0.5
	Albedo	0.053
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=683"
}

#1_"685 Hermia:Hermia:1909 HE" "Sol" #1=
#2_"*Гермия:685 Hermia:Hermia:1909 HE" "Sol" #2=
#3_"1909 HE:*Гермия:685 Hermia:Hermia" "Sol" #3=
".:Hermia:685 Hermia:1909 HE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"685 hermia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	5.475
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.346198057456
		SemiMajorAxis	2.237152692313
		Eccentricity	0.195897312307
		Inclination	3.645200885335
		AscendingNode	235.278905304207
		ArgOfPericenter	80.631882929979
		MeanAnomaly	187.466080842286
	}
	UniformRotation
	{
		Period	50.4
	}
	LunarLambert	0.5
	Albedo	0.2807
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=685"
}

#1_"686 Gersuind:Gersuind:1909 HF" "Sol" #1=
#2_"*Герзуйнд:686 Gersuind:Gersuind:1909 HF" "Sol" #2=
#3_"1909 HF:*Герзуйнд:686 Gersuind:Gersuind" "Sol" #3=
".:Gersuind:686 Gersuind:1909 HF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"686 gersuind.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	27.629
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.166292845908
		SemiMajorAxis	2.589172945918
		Eccentricity	0.268396672748
		Inclination	15.675369916656
		AscendingNode	243.362415814394
		ArgOfPericenter	88.346105897047
		MeanAnomaly	94.775902657915
	}
	UniformRotation
	{
		Period	6.3127
	}
	LunarLambert	0.5
	Albedo	0.078
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=686"
}

#1_"687 Tinette:Tinette:1909 HG" "Sol" #1=
#2_"*Тинетта:687 Tinette:Tinette:1909 HG" "Sol" #2=
#3_"1909 HG:Tinette:*Тинетта:687 Tinette" "Sol" #3=
".:Tinette:687 Tinette:1909 HG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"687 tinette.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	10.766
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.489412319748
		SemiMajorAxis	2.721369592418
		Eccentricity	0.272592080464
		Inclination	14.878315607713
		AscendingNode	334.346307456104
		ArgOfPericenter	52.91259866205
		MeanAnomaly	304.638336443247
	}
	UniformRotation
	{
		Period	7.4
	}
	LunarLambert	0.5
	Albedo	0.079
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=687"
}

#1_"688 Melanie:Melanie:1909 HH:1927 SR:1940 SJ:A917 KD" "Sol" #1=
#2_"*Мелани:688 Melanie:Melanie:1909 HH" "Sol" #2=
#3_"1909 HH:*Мелани:688 Melanie:Melanie" "Sol" #3=
".:Melanie:688 Melanie:1909 HH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.429922531421
		SemiMajorAxis	2.697275366958
		Eccentricity	0.13934567511
		Inclination	10.244531533163
		AscendingNode	170.917653098646
		ArgOfPericenter	139.62576278003
		MeanAnomaly	295.031434692792
	}
	UniformRotation
	{
		Period	18.87
	}
	LunarLambert	0.5
	Albedo	0.0599
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=688"
}

#1_"689 Zita:Zita:1909 HJ:1916 Scg" "Sol" #1=
#2_"*Зита:689 Zita:Zita:1909 HJ" "Sol" #2=
#3_"1909 HJ:*Зита:689 Zita:Zita" "Sol" #3=
".:Zita:689 Zita:1909 HJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"689 zita.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.523828770412
		SemiMajorAxis	2.31564010823
		Eccentricity	0.230233118006
		Inclination	5.744150617193
		AscendingNode	168.176312504788
		ArgOfPericenter	188.160476205737
		MeanAnomaly	309.457038871559
	}
	UniformRotation
	{
		Period	6.425
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=689"
}

#1_"690 Wratislavia:Wratislavia:1909 HZ:1942 XH:A902 LA" "Sol" #1=
#2_"*Вратиславия:690 Wratislavia:Wratislavia:1909 HZ" "Sol" #2=
#3_"1909 HZ:*Вратиславия:690 Wratislavia:Wratislavia" "Sol" #3=
".:Wratislavia:690 Wratislavia:1909 HZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"690 wratislavia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	67.325
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.580664315355
		SemiMajorAxis	3.146191343177
		Eccentricity	0.181987460018
		Inclination	11.264724577819
		AscendingNode	253.174427658529
		ArgOfPericenter	114.89032065616
		MeanAnomaly	307.430437160902
	}
	UniformRotation
	{
		Period	8.64
	}
	LunarLambert	0.5
	Albedo	0.0604
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=690"
}

#1_"691 Lehigh:Lehigh:1909 JG" "Sol" #1=
#2_"*Лихай:691 Lehigh:Lehigh:1909 JG" "Sol" #2=
#3_"1909 JG:*Лихай:691 Lehigh:Lehigh" "Sol" #3=
".:Lehigh:691 Lehigh:1909 JG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	43.84
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.236046352947
		SemiMajorAxis	3.015297633521
		Eccentricity	0.119649164421
		Inclination	13.019185171455
		AscendingNode	88.178605996169
		ArgOfPericenter	304.401123891108
		MeanAnomaly	76.35973509436
	}
	UniformRotation
	{
		Period	12.891
	}
	LunarLambert	0.5
	Albedo	0.0438
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=691"
}

#1_"692 Hippodamia:Hippodamia:1901 HD:1941 HK" "Sol" #1=
#2_"*Гипподамия:692 Hippodamia:Hippodamia:1901 HD" "Sol" #2=
#3_"1901 HD:*Гипподамия:692 Hippodamia:Hippodamia" "Sol" #3=
".:Hippodamia:692 Hippodamia:1901 HD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"692 hippodamia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	21.386
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.221792332059
		SemiMajorAxis	3.382762748187
		Eccentricity	0.170028783219
		Inclination	26.082977270808
		AscendingNode	63.489723920106
		ArgOfPericenter	54.237109429091
		MeanAnomaly	52.217013243389
	}
	UniformRotation
	{
		Period	8.98
	}
	LunarLambert	0.5
	Albedo	0.205
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=692"
}

#1_"693 Zerbinetta:Zerbinetta:1909 HN:1949 QB:1949 SW1:1952 DR3" "Sol" #1=
#2_"*Зербинетта:693 Zerbinetta:Zerbinetta:1909 HN" "Sol" #2=
#3_"1909 HN:*Зербинетта:693 Zerbinetta:Zerbinetta" "Sol" #3=
".:Zerbinetta:693 Zerbinetta:1909 HN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.83
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.052026675158
		SemiMajorAxis	2.944229242274
		Eccentricity	0.031517111774
		Inclination	14.193967526149
		AscendingNode	351.876077432856
		ArgOfPericenter	289.210576605296
		MeanAnomaly	23.326166501474
	}
	UniformRotation
	{
		Period	11.475
	}
	LunarLambert	0.5
	Albedo	0.0683
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=693"
}

#1_"694 Ekard:Ekard:1909 JA:1951 CD1" "Sol" #1=
#2_"*Экард:694 Ekard:Ekard:1909 JA" "Sol" #2=
#3_"1909 JA:*Экард:694 Ekard:Ekard" "Sol" #3=
".:Ekard:694 Ekard:1909 JA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"694 ekard.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	60.946
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.363183754989
		SemiMajorAxis	2.670116441038
		Eccentricity	0.3241060324
		Inclination	15.841014753681
		AscendingNode	230.364289903607
		ArgOfPericenter	110.916469634506
		MeanAnomaly	66.052416707256
	}
	UniformRotation
	{
		Period	5.925
	}
	LunarLambert	0.5
	Albedo	0.026
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=694"
}

#1_"695 Bella:Bella:1909 JB:1965 QF" "Sol" #1=
#2_"*Белла:695 Bella:Bella:1909 JB" "Sol" #2=
#3_"1909 JB:*Белла:695 Bella:Bella" "Sol" #3=
".:Bella:695 Bella:1909 JB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"695 bella.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	20.31
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.046710495022
		SemiMajorAxis	2.539389321413
		Eccentricity	0.159549540826
		Inclination	13.851947288377
		AscendingNode	275.713672332097
		ArgOfPericenter	79.158542459688
		MeanAnomaly	38.150271834723
	}
	UniformRotation
	{
		Period	14.222
	}
	LunarLambert	0.5
	Albedo	0.207
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=695"
}

#1_"696 Leonora:Leonora:1910 JJ:1916 Saw:1927 AC:1948 PO" "Sol" #1=
#2_"*Леонора:696 Leonora:Leonora:1910 JJ" "Sol" #2=
#3_"1910 JJ:*Леонора:696 Leonora:Leonora" "Sol" #3=
".:Leonora:696 Leonora:1910 JJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	37.88
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.641704219396
		SemiMajorAxis	3.169091224049
		Eccentricity	0.251233801641
		Inclination	13.037772584156
		AscendingNode	299.517745581304
		ArgOfPericenter	104.186043036548
		MeanAnomaly	202.792191470487
	}
	UniformRotation
	{
		Period	26.8964
	}
	LunarLambert	0.5
	Albedo	0.0773
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=696"
}

#1_"697 Galilea:Galilea:1910 JO:1945 GE:1979 FL2:A910 DA" "Sol" #1=
#2_"*Галилея:697 Galilea:Galilea:1910 JO" "Sol" #2=
#3_"1910 JO:*Галилея:697 Galilea:Galilea" "Sol" #3=
".:Galilea:697 Galilea:1910 JO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.07
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.888553701608
		SemiMajorAxis	2.88036898152
		Eccentricity	0.156616379359
		Inclination	15.141860513159
		AscendingNode	15.548067023589
		ArgOfPericenter	333.347759115448
		MeanAnomaly	301.557901367028
	}
	UniformRotation
	{
		Period	16.538
	}
	LunarLambert	0.5
	Albedo	0.0387
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=697"
}

#1_"698 Ernestina:Ernestina:1910 JX:A908 WB" "Sol" #1=
#2_"*Эрнестина:698 Ernestina:Ernestina:1910 JX" "Sol" #2=
#3_"1910 JX:*Эрнестина:698 Ernestina:Ernestina" "Sol" #3=
".:Ernestina:698 Ernestina:1910 JX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"698 ernestina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	13.518
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.857917983907
		SemiMajorAxis	2.868322529007
		Eccentricity	0.109043022772
		Inclination	11.529726443178
		AscendingNode	40.654029749917
		ArgOfPericenter	99.226738333084
		MeanAnomaly	223.449720226002
	}
	UniformRotation
	{
		Period	5.0363
	}
	LunarLambert	0.5
	Albedo	0.095
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=698"
}

#1_"699 Hela:Hela:1910 KD:1948 KD:1957 WX1:A902 WE:A923 TB" "Sol" #1=
#2_"*Хела:699 Hela:Hela:1910 KD" "Sol" #2=
#3_"1910 KD:*Хела:699 Hela:Hela" "Sol" #3=
".:Hela:699 Hela:1910 KD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"699 hela.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.517
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.22144844287
		SemiMajorAxis	2.611974051709
		Eccentricity	0.40977525061
		Inclination	15.296210392681
		AscendingNode	242.552864131314
		ArgOfPericenter	91.472227903333
		MeanAnomaly	270.539671002252
	}
	UniformRotation
	{
		Period	3.3962
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=699"
}

#1_"700 Auravictrix:Auravictrix:1910 KE:1951 VE:A893 FB" "Sol" #1=
#2_"*Ауравиктрикс:700 Auravictrix:Auravictrix:1910 KE" "Sol" #2=
#3_"1910 KE:*Ауравиктрикс:700 Auravictrix:Auravictrix" "Sol" #3=
".:Auravictrix:700 Auravictrix:1910 KE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"700 auravictrix.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	8.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.328776892363
		SemiMajorAxis	2.229381145391
		Eccentricity	0.10388586818
		Inclination	6.790396559239
		AscendingNode	96.847994724858
		ArgOfPericenter	101.961717437561
		MeanAnomaly	184.662431912091
	}
	UniformRotation
	{
		Period	6.075
	}
	LunarLambert	0.5
	Albedo	0.228
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=700"
}

#1_"701 Oriola:Oriola:1910 KN:1946 KB:1950 BN1:1958 TC1:A899 LD:A906 TB" "Sol" #1=
#2_"*Ориола:701 Oriola:Oriola:1910 KN" "Sol" #2=
#3_"1910 KN:*Ориола:701 Oriola:Oriola" "Sol" #3=
".:Oriola:701 Oriola:1910 KN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	20.09
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.234593943646
		SemiMajorAxis	3.014740005554
		Eccentricity	0.032660945098
		Inclination	7.141243900356
		AscendingNode	243.762345776326
		ArgOfPericenter	326.228622920316
		MeanAnomaly	60.802876621099
	}
	UniformRotation
	{
		Period	9.09
	}
	LunarLambert	0.5
	Albedo	0.2184
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=701"
}

#1_"702 Alauda:Alauda:1910 KQ" "Sol" #1=
#2_"*Алауда:702 Alauda:Alauda:1910 KQ" "Sol" #2=
#3_"1910 KQ:*Алауда:702 Alauda:Alauda" "Sol" #3=
".:Alauda:702 Alauda:1910 KQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	100.98
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.702351572886
		SemiMajorAxis	3.191762184894
		Eccentricity	0.019994547841
		Inclination	20.611410628414
		AscendingNode	289.932443563429
		ArgOfPericenter	351.32820476953
		MeanAnomaly	136.98940692165
	}
	UniformRotation
	{
		Period	8.354
	}
	LunarLambert	0.5
	Albedo	0.0587
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=702"
}

#1_"Pichi-unem:702 Alauda I:Alauda I:2007 702 I" "Sol/702 Alauda" #1=
#2_"*Пичи-унем:Pichi-unem:702 Alauda I:*Алауда I:Alauda I:2007 702 I" "Sol/702 Alauda" #2=
#3_"2007 702 I:*Пичи-унем:Pichi-unem:702 Alauda I:*Алауда I:Alauda I" "Sol/702 Alauda" #3=
".:Pichi-unem:702 Alauda I:*Алауда I:Alauda I:2007 702 I" "Sol/702 Alauda" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid.dds"
	Radius	1.755
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	4.914
		SemiMajorAxis	1227
		Eccentricity	0.003
	}
	LunarLambert	0.5
	Albedo	0.0587
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00702.html"
}

#1_"704 Interamnia:Interamnia:1910 KU:1952 MW" "Sol" #1=
#2_"*Интерамния:704 Interamnia:Interamnia:1910 KU" "Sol" #2=
#3_"1910 KU:*Интерамния:704 Interamnia:Interamnia" "Sol" #3=
".:Interamnia:704 Interamnia:1910 KU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	SemiAxes	[ 175.15 151.8 151.8 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.34592027982
		SemiMajorAxis	3.057333750327
		Eccentricity	0.154129777663
		Inclination	17.309122497215
		AscendingNode	280.303711958403
		ArgOfPericenter	95.350965380575
		MeanAnomaly	165.286412928062
	}
	UniformRotation
	{
		Period	8.727
	}
	LunarLambert	0.5
	Albedo	0.0742
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=704"
}

#1_"705 Erminia:Erminia:1910 KV:1948 HA:1951 AU:A895 TA:A905 VG" "Sol" #1=
#2_"*Эрминия:705 Erminia:Erminia:1910 KV" "Sol" #2=
#3_"1910 KV:*Эрминия:705 Erminia:Erminia" "Sol" #3=
".:Erminia:705 Erminia:1910 KV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	67.11
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.999030880354
		SemiMajorAxis	2.923603085126
		Eccentricity	0.048582171103
		Inclination	25.042448249897
		AscendingNode	2.895119643453
		ArgOfPericenter	100.858528613466
		MeanAnomaly	230.903365620267
	}
	UniformRotation
	{
		Period	53.96
	}
	LunarLambert	0.5
	Albedo	0.0432
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=705"
}

#1_"706 Hirundo:Hirundo:1910 KX:1948 AE:1957 DA:1977 QB:A924 WD" "Sol" #1=
#2_"*Гирундо:706 Hirundo:Hirundo:1910 KX" "Sol" #2=
#3_"1910 KX:*Гирундо:706 Hirundo:Hirundo" "Sol" #3=
".:Hirundo:706 Hirundo:1910 KX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"706 hirundo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	15.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.505394358386
		SemiMajorAxis	2.727824374794
		Eccentricity	0.19442058155
		Inclination	14.469752755786
		AscendingNode	325.511533683715
		ArgOfPericenter	29.897349891648
		MeanAnomaly	48.670598884013
	}
	UniformRotation
	{
		Period	22.027
	}
	LunarLambert	0.5
	Albedo	0.081
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=706"
}

#1_"708 Raphaela:Raphaela:1911 LJ:A892 XA:A907 EG" "Sol" #1=
#2_"*Рафаэла:708 Raphaela:Raphaela:1911 LJ" "Sol" #2=
#3_"1911 LJ:*Рафаэла:708 Raphaela:Raphaela" "Sol" #3=
".:Raphaela:708 Raphaela:1911 LJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"708 raphaela.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.715
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.360882472422
		SemiMajorAxis	2.669177488651
		Eccentricity	0.086880004627
		Inclination	3.491739308708
		AscendingNode	355.205453745698
		ArgOfPericenter	197.774584516075
		MeanAnomaly	232.8612801454
	}
	UniformRotation
	{
		Period	20.918
	}
	LunarLambert	0.5
	Albedo	0.2193
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=708"
}

#1_"709 Fringilla:Fringilla:1911 LK:1948 PK1:1956 CA:A906 DA" "Sol" #1=
#2_"*Фрингилла:709 Fringilla:Fringilla:1911 LK" "Sol" #2=
#3_"1911 LK:*Фрингилла:709 Fringilla:Fringilla" "Sol" #3=
".:Fringilla:709 Fringilla:1911 LK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	48.28
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.976199293
		SemiMajorAxis	2.914694503343
		Eccentricity	0.112366005065
		Inclination	16.294011619869
		AscendingNode	324.492909895561
		ArgOfPericenter	17.232742550224
		MeanAnomaly	98.32530417998
	}
	UniformRotation
	{
		Period	52.4
	}
	LunarLambert	0.5
	Albedo	0.0459
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=709"
}

#1_"710 Gertrud:Gertrud:1911 LM:1934 LF" "Sol" #1=
#2_"*Гертруд:710 Gertrud:Gertrud:1911 LM" "Sol" #2=
#3_"1911 LM:*Гертруд:710 Gertrud:Gertrud" "Sol" #3=
".:Gertrud:710 Gertrud:1911 LM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	13.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.52999460241
		SemiMajorAxis	3.127118485013
		Eccentricity	0.135317306157
		Inclination	1.75009985055
		AscendingNode	140.199371424087
		ArgOfPericenter	100.251865156031
		MeanAnomaly	195.570025424968
	}
	UniformRotation
	{
		Period	8.288
	}
	LunarLambert	0.5
	Albedo	0.0893
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=710"
}

#1_"712 Boliviana:Boliviana:1911 LO:1966 KD:1972 XL2" "Sol" #1=
#2_"*Боливиана:712 Boliviana:Boliviana:1911 LO" "Sol" #2=
#3_"1911 LO:*Боливиана:712 Boliviana:Boliviana" "Sol" #3=
".:Boliviana:712 Boliviana:1911 LO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	63.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.134586705659
		SemiMajorAxis	2.576020220723
		Eccentricity	0.186670873591
		Inclination	12.759203285391
		AscendingNode	230.862130364378
		ArgOfPericenter	181.839033627237
		MeanAnomaly	75.573983567638
	}
	UniformRotation
	{
		Period	11.743
	}
	LunarLambert	0.5
	Albedo	0.051
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=712"
}

#1_"713 Luscinia:Luscinia:1911 LS:1936 FM1:1951 NA:1955 FN1:A909 BA" "Sol" #1=
#2_"*Люциния:713 Luscinia:Luscinia:1911 LS" "Sol" #2=
#3_"1911 LS:*Люциния:713 Luscinia:Luscinia" "Sol" #3=
".:Luscinia:713 Luscinia:1911 LS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	52.76
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.23997554563
		SemiMajorAxis	3.389350300753
		Eccentricity	0.164732094796
		Inclination	10.359455306729
		AscendingNode	217.715132833049
		ArgOfPericenter	137.054177171981
		MeanAnomaly	39.345448480125
	}
	UniformRotation
	{
		Period	8.28
	}
	LunarLambert	0.5
	Albedo	0.041
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=713"
}

#1_"714 Ulula:Ulula:1911 LW" "Sol" #1=
#2_"*Улула:714 Ulula:Ulula:1911 LW" "Sol" #2=
#3_"1911 LW:*Улула:714 Ulula:Ulula" "Sol" #3=
".:Ulula:714 Ulula:1911 LW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"714 ulula.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	20.672
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.036072400129
		SemiMajorAxis	2.534936961994
		Eccentricity	0.056816565835
		Inclination	14.266989700223
		AscendingNode	233.912025163217
		ArgOfPericenter	232.617011023242
		MeanAnomaly	341.352210608
	}
	UniformRotation
	{
		Period	6.998
	}
	LunarLambert	0.5
	Albedo	0.26
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=714"
}

#1_"715 Transvaalia:Transvaalia:1911 LX:1961 GF:1973 AA:A915 FA:A916 NC:A920 HC" "Sol" #1=
#2_"*Трансваалия:715 Transvaalia:Transvaalia:1911 LX" "Sol" #2=
#3_"1911 LX:*Трансваалия:715 Transvaalia:Transvaalia" "Sol" #3=
".:Transvaalia:715 Transvaalia:1911 LX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.275
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.6037595637
		SemiMajorAxis	2.767385245844
		Eccentricity	0.083411039603
		Inclination	13.804803199447
		AscendingNode	46.189821046002
		ArgOfPericenter	299.072652909895
		MeanAnomaly	64.75271078751
	}
	UniformRotation
	{
		Period	11.8
	}
	LunarLambert	0.5
	Albedo	0.2606
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=715"
}

#1_"716 Berkeley:Berkeley:1911 MD:1947 CH:1952 FA:A906 OB" "Sol" #1=
#2_"*Беркли:716 Berkeley:Berkeley:1911 MD" "Sol" #2=
#3_"1911 MD:*Беркли:716 Berkeley:Berkeley" "Sol" #3=
".:Berkeley:716 Berkeley:1911 MD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.720313608602
		SemiMajorAxis	2.813898539199
		Eccentricity	0.084834761826
		Inclination	8.480666296984
		AscendingNode	145.988900890383
		ArgOfPericenter	57.273431391969
		MeanAnomaly	78.042572837622
	}
	UniformRotation
	{
		Period	15.55
	}
	LunarLambert	0.5
	Albedo	0.1801
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=716"
}

#1_"717 Wisibada:Wisibada:1911 MJ" "Sol" #1=
#2_"*Визибада:717 Wisibada:Wisibada:1911 MJ" "Sol" #2=
#3_"1911 MJ:*Визибада:717 Wisibada:Wisibada" "Sol" #3=
".:Wisibada:717 Wisibada:1911 MJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.52
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.567350018305
		SemiMajorAxis	3.141185248566
		Eccentricity	0.261352475304
		Inclination	1.646456894613
		AscendingNode	343.605044445787
		ArgOfPericenter	24.548420173745
		MeanAnomaly	156.235634599896
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0666
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=717"
}

#1_"718 Erida:Erida:1911 MS:1952 JK:1963 KL:1979 QG10:A902 YD:A904 JA:A920 GE" "Sol" #1=
#2_"*Эрида (астероид):718 Erida:Erida:1911 MS" "Sol" #2=
#3_"1911 MS:*Эрида (астероид):718 Erida:Erida" "Sol" #3=
".:Erida:718 Erida:1911 MS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"718 erida.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	35.456
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.338445513222
		SemiMajorAxis	3.054483204632
		Eccentricity	0.200677952831
		Inclination	6.927618132285
		AscendingNode	38.614722247971
		ArgOfPericenter	174.674421155475
		MeanAnomaly	254.126389003088
	}
	UniformRotation
	{
		Period	17.447
	}
	LunarLambert	0.5
	Albedo	0.042
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=718"
}

#1_"720 Bohlinia:Bohlinia:1911 MW:1948 DD:1951 XH1:A901 TE" "Sol" #1=
#2_"*Болиния:720 Bohlinia:Bohlinia:1911 MW" "Sol" #2=
#3_"1911 MW:*Болиния:720 Bohlinia:Bohlinia" "Sol" #3=
".:Bohlinia:720 Bohlinia:1911 MW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"720 bohlinia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	16.865
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.904624731821
		SemiMajorAxis	2.88667830101
		Eccentricity	0.016836503533
		Inclination	2.356120486779
		AscendingNode	35.708818188828
		ArgOfPericenter	118.631129419431
		MeanAnomaly	229.789760290993
	}
	UniformRotation
	{
		Period	8.919
	}
	LunarLambert	0.5
	Albedo	0.2029
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=720"
}

#1_"721 Tabora:Tabora:1911 MZ:1935 FX:1951 VH:A911 UH" "Sol" #1=
#2_"*Табора:721 Tabora:Tabora:1911 MZ" "Sol" #2=
#3_"1911 MZ:*Табора:721 Tabora:Tabora" "Sol" #3=
".:Tabora:721 Tabora:1911 MZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38.035
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.699575617347
		SemiMajorAxis	3.553797907981
		Eccentricity	0.11506022769
		Inclination	8.318426003128
		AscendingNode	38.4281396852
		ArgOfPericenter	353.240103445043
		MeanAnomaly	130.165280140823
	}
	UniformRotation
	{
		Period	7.982
	}
	LunarLambert	0.5
	Albedo	0.0604
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=721"
}

#1_"723 Hammonia:Hammonia:1911 NB:1949 YR:1955 FU1:A903 CA" "Sol" #1=
#2_"*Гаммония:723 Hammonia:Hammonia:1911 NB" "Sol" #2=
#3_"1911 NB:*Гаммония:723 Hammonia:Hammonia" "Sol" #3=
".:Hammonia:723 Hammonia:Hammonia:1911 NB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	17.84
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.18040070161
		SemiMajorAxis	2.993896396213
		Eccentricity	0.054074695731
		Inclination	4.995174853495
		AscendingNode	163.348981941124
		ArgOfPericenter	246.108556777546
		MeanAnomaly	317.243458259539
	}
	UniformRotation
	{
		Period	5.436
	}
	LunarLambert	0.5
	Albedo	0.1829
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=723"
}

#1_"725 Amanda:Amanda:1911 ND" "Sol" #1=
#2_"*Аманда:725 Amanda:Amanda:1911 ND" "Sol" #2=
#3_"1911 ND:*Аманда:725 Amanda:Amanda" "Sol" #3=
".:Amanda:725 Amanda:1911 ND" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"725 amanda.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	11.844
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.127976672858
		SemiMajorAxis	2.573273937618
		Eccentricity	0.219274958703
		Inclination	3.786583564203
		AscendingNode	68.816117540996
		ArgOfPericenter	322.768923048092
		MeanAnomaly	357.574212380974
	}
	UniformRotation
	{
		Period	3.749
	}
	LunarLambert	0.5
	Albedo	0.068
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=725"
}

#1_"726 Joella:Joella:1911 NM" "Sol" #1=
#2_"*Джоэлла:726 Joella:Joella:1911 NM" "Sol" #2=
#3_"1911 NM:*Джоэлла:726 Joella:Joella" "Sol" #3=
".:Joella:726 Joella:1911 NM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.01
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.111037893404
		SemiMajorAxis	2.566229649719
		Eccentricity	0.284181227415
		Inclination	15.408482844416
		AscendingNode	242.295669275508
		ArgOfPericenter	112.425256801942
		MeanAnomaly	60.298205041459
	}
	UniformRotation
	{
		Period	13.04
	}
	LunarLambert	0.5
	Albedo	0.0539
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=726"
}

#1_"727 Nipponia:Nipponia:1912 NT:1953 BE:A900 EA:A908 CC" "Sol" #1=
#2_"*Ниппония:727 Nipponia:Nipponia:1912 NT" "Sol" #2=
#3_"1912 NT:*Ниппония:727 Nipponia:Nipponia" "Sol" #3=
".:Nipponia:727 Nipponia:1912 NT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.085
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.11534865229
		SemiMajorAxis	2.56802327056
		Eccentricity	0.10489963365
		Inclination	15.062273791957
		AscendingNode	133.080425955245
		ArgOfPericenter	275.289115378863
		MeanAnomaly	66.689051257981
	}
	UniformRotation
	{
		Period	5.0687
	}
	LunarLambert	0.5
	Albedo	0.2423
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=727"
}

#1_"729 Watsonia:Watsonia:1912 OD:1944 DP" "Sol" #1=
#2_"*Ватсония:729 Watsonia:Watsonia:1912 OD" "Sol" #2=
#3_"1912 OD:*Ватсония:729 Watsonia:Watsonia" "Sol" #3=
".:Watsonia:729 Watsonia:1912 OD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	24.575
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.586256231864
		SemiMajorAxis	2.760366459402
		Eccentricity	0.096535124049
		Inclination	18.042421924149
		AscendingNode	124.398219643278
		ArgOfPericenter	88.322246878048
		MeanAnomaly	94.112851979081
	}
	UniformRotation
	{
		Period	25.23
	}
	LunarLambert	0.5
	Albedo	0.1381
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=729"
}

#1_"731 Sorga:Sorga:1912 OQ:1940 WP" "Sol" #1=
#2_"*Сорга:731 Sorga:Sorga:1912 OQ" "Sol" #2=
#3_"1912 OQ:*Сорга:731 Sorga:Sorga" "Sol" #3=
".:Sorga:731 Sorga:1912 OQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"731 sorga.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	17.298
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.173968610239
		SemiMajorAxis	2.991417694471
		Eccentricity	0.138709090093
		Inclination	10.679944894144
		AscendingNode	46.220208682079
		ArgOfPericenter	288.305354136186
		MeanAnomaly	179.704323650338
	}
	UniformRotation
	{
		Period	8.184
	}
	LunarLambert	0.5
	Albedo	0.209
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=731"
}

#1_"732 Tjilaki:Tjilaki:1912 OR:1958 FC" "Sol" #1=
#2_"*Тьилаки:732 Tjilaki:Tjilaki:1912 OR" "Sol" #2=
#3_"1912 OR:*Тьилаки:732 Tjilaki:Tjilaki" "Sol" #3=
".:Tjilaki:732 Tjilaki:1912 OR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"732 tjilaki.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	14.896
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.849027892199
		SemiMajorAxis	2.456001177321
		Eccentricity	0.04448029563
		Inclination	10.98945308204
		AscendingNode	173.380644871336
		ArgOfPericenter	64.082103541721
		MeanAnomaly	208.616009394803
	}
	UniformRotation
	{
		Period	12.34
	}
	LunarLambert	0.5
	Albedo	0.138
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=732"
}

#1_"733 Mocia:Mocia:1912 PF:1987 QE4:A909 DG:A909 GD" "Sol" #1=
#2_"*Моция:733 Mocia:Mocia:1912 PF" "Sol" #2=
#3_"1912 PF:*Моция:733 Mocia:Mocia" "Sol" #3=
".:Mocia:733 Mocia:1912 PF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	44.355
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.280024934965
		SemiMajorAxis	3.403837175895
		Eccentricity	0.061822584897
		Inclination	20.278843987411
		AscendingNode	341.021186736437
		ArgOfPericenter	191.042291322961
		MeanAnomaly	323.179458281048
	}
	UniformRotation
	{
		Period	11.374
	}
	LunarLambert	0.5
	Albedo	0.0539
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=733"
}

#1_"734 Benda:Benda:1912 PH" "Sol" #1=
#2_"*Бенда:734 Benda:Benda:1912 PH" "Sol" #2=
#3_"1912 PH:*Бенда:734 Benda:Benda" "Sol" #3=
".:Benda:734 Benda:1912 PH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	35.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.595979606867
		SemiMajorAxis	3.151944878641
		Eccentricity	0.098634928411
		Inclination	5.801029679498
		AscendingNode	3.180816160719
		ArgOfPericenter	67.847426509334
		MeanAnomaly	57.250885396156
	}
	UniformRotation
	{
		Period	7.11
	}
	LunarLambert	0.5
	Albedo	0.0464
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=734"
}

#1_"735 Marghanna:Marghanna:1912 PY:1952 OH:1952 OJ:1952 QA:1952 QB" "Sol" #1=
#2_"*Марганна:735 Marghanna:Marghanna:1912 PY" "Sol" #2=
#3_"1912 PY:*Марганна:735 Marghanna:Marghanna" "Sol" #3=
".:Marghanna:735 Marghanna:1912 PY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	37.16
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.50426575409
		SemiMajorAxis	2.727368807888
		Eccentricity	0.322596986644
		Inclination	16.884683430086
		AscendingNode	42.984979731995
		ArgOfPericenter	310.044107507734
		MeanAnomaly	268.971496213747
	}
	UniformRotation
	{
		Period	15.95
	}
	LunarLambert	0.5
	Albedo	0.0484
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=735"
}

#1_"736 Harvard:Harvard:1912 PZ:1937 FC:1947 HB" "Sol" #1=
#2_"*Гарвард:736 Harvard:Harvard:1912 PZ" "Sol" #2=
#3_"1912 PZ:*Гарвард:736 Harvard:Harvard" "Sol" #3=
".:Harvard:736 Harvard:1912 PZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.269788058998
		SemiMajorAxis	2.202965017969
		Eccentricity	0.164835089496
		Inclination	4.375243301054
		AscendingNode	135.939475359482
		ArgOfPericenter	200.528242352968
		MeanAnomaly	145.475944182984
	}
	UniformRotation
	{
		Period	6.7
	}
	LunarLambert	0.5
	Albedo	0.1406
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=736"
}

#1_"737 Arequipa:Arequipa:1912 QB:1961 JH" "Sol" #1=
#2_"*Арекипа:737 Arequipa:Arequipa:1912 QB" "Sol" #2=
#3_"1912 QB:*Арекипа:737 Arequipa:Arequipa" "Sol" #3=
".:Arequipa:737 Arequipa:1912 QB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	22.035
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.168766979728
		SemiMajorAxis	2.590197890112
		Eccentricity	0.24450849011
		Inclination	12.367156261696
		AscendingNode	184.674324558797
		ArgOfPericenter	134.343713504964
		MeanAnomaly	242.954782201343
	}
	UniformRotation
	{
		Period	14.13
	}
	LunarLambert	0.5
	Albedo	0.2723
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=737"
}

#1_"738 Alagasta:Alagasta:1913 QO:1950 BX1:A908 CA" "Sol" #1=
#2_"*Алагаста:738 Alagasta:Alagasta:1913 QO" "Sol" #2=
#3_"1913 QO:*Алагаста:738 Alagasta:Alagasta" "Sol" #3=
".:Alagasta:738 Alagasta:1913 QO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.395
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.288447937792
		SemiMajorAxis	3.035381997285
		Eccentricity	0.055078475144
		Inclination	3.534543831596
		AscendingNode	132.115409072295
		ArgOfPericenter	41.301242956969
		MeanAnomaly	35.285780246451
	}
	UniformRotation
	{
		Period	17.83
	}
	LunarLambert	0.5
	Albedo	0.0398
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=738"
}

#1_"739 Mandeville:Mandeville:1913 QR:1963 HE" "Sol" #1=
#2_"*Мандевиль:739 Mandeville:Mandeville:1913 QR" "Sol" #2=
#3_"1913 QR:*Мандевиль:739 Mandeville:Mandeville" "Sol" #3=
".:Mandeville:739 Mandeville:1913 QR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	53.765
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.531517328924
		SemiMajorAxis	2.73835844208
		Eccentricity	0.143087217688
		Inclination	20.660524538334
		AscendingNode	136.615077453821
		ArgOfPericenter	45.411651001682
		MeanAnomaly	146.248264603805
	}
	UniformRotation
	{
		Period	11.931
	}
	LunarLambert	0.5
	Albedo	0.0608
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=739"
}


#1_"740 Cantabia:Cantabia:1913 QS:1936 OF:1950 CF" "Sol" #1=
#2_"*Кантабия:740 Cantabia:Cantabia:1913 QS" "Sol" #2=
#3_"1913 QS:*Кантабия:740 Cantabia:Cantabia" "Sol" #3=
".:Cantabia:740 Cantabia:1913 QS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	45.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.328962344457
		SemiMajorAxis	3.050864827672
		Eccentricity	0.110730883997
		Inclination	10.847142167651
		AscendingNode	116.09835994551
		ArgOfPericenter	47.636629864601
		MeanAnomaly	23.173773606066
	}
	UniformRotation
	{
		Period	64.453
	}
	LunarLambert	0.5
	Albedo	0.0552
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=740"
}

#1_"741 Botolphia:Botolphia:1913 QT:1973 GN:A909 HA" "Sol" #1=
#2_"*Ботольфия:741 Botolphia:Botolphia:1913 QT" "Sol" #2=
#3_"1913 QT:*Ботольфия:741 Botolphia:Botolphia" "Sol" #3=
".:Botolphia:741 Botolphia:1913 QT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.82
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.483061025356
		SemiMajorAxis	2.718802322855
		Eccentricity	0.070289028202
		Inclination	8.414810698716
		AscendingNode	100.783419676005
		ArgOfPericenter	63.008833660904
		MeanAnomaly	236.286995056336
	}
	UniformRotation
	{
		Period	23.93
	}
	LunarLambert	0.5
	Albedo	0.1391
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=741"
}

#1_"742 Edisona:Edisona:1913 QU" "Sol" #1=
#2_"*Эдисона:742 Edisona:Edisona:1913 QU" "Sol" #2=
#3_"1913 QU:*Эдисона:742 Edisona:Edisona" "Sol" #3=
".:Edisona:742 Edisona:1913 QU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"742 edisona.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	23.544
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.226126824025
		SemiMajorAxis	3.011488170927
		Eccentricity	0.118810156233
		Inclination	11.217650983638
		AscendingNode	64.227378083145
		ArgOfPericenter	284.458137438805
		MeanAnomaly	311.856058989875
	}
	UniformRotation
	{
		Period	18.52
	}
	LunarLambert	0.5
	Albedo	0.121
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=742"
}

#1_"743 Eugenisis:Eugenisis:1913 QV:A908 AJ" "Sol" #1=
#2_"*Евгенида:743 Eugenisis:Eugenisis:1913 QV" "Sol" #2=
#3_"1913 QV:*Евгенида:743 Eugenisis:Eugenisis" "Sol" #3=
".:Eugenisis:743 Eugenisis:1913 QV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.585
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.667241262706
		SemiMajorAxis	2.792766969689
		Eccentricity	0.056965027862
		Inclination	4.827859898118
		AscendingNode	229.133665180704
		ArgOfPericenter	186.655216268852
		MeanAnomaly	22.022299488558
	}
	UniformRotation
	{
		Period	10.23
	}
	LunarLambert	0.5
	Albedo	0.0625
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=743"
}

#1_"744 Aguntina:Aguntina:1913 QW:1930 DZ:1950 TL4" "Sol" #1=
#2_"*Агунтина:744 Aguntina:Aguntina:1913 QW" "Sol" #2=
#3_"1913 QW:*Агунтина:744 Aguntina:Aguntina" "Sol" #3=
".:Aguntina:744 Aguntina:1913 QW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"744 aguntina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	29.318
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.652730368694
		SemiMajorAxis	3.17321899578
		Eccentricity	0.119252537553
		Inclination	7.715308524012
		AscendingNode	142.664834138882
		ArgOfPericenter	28.66959130561
		MeanAnomaly	342.466276367846
	}
	UniformRotation
	{
		Period	17.47
	}
	LunarLambert	0.5
	Albedo	0.031
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=744"
}

#1_"746 Marlu:Marlu:1913 QY:1926 WA:1975 XN" "Sol" #1=
#2_"*Марлу:746 Marlu:Marlu:1913 QY" "Sol" #2=
#3_"1913 QY:*Марлу:746 Marlu:Marlu" "Sol" #3=
".:Marlu:746 Marlu:1913 QY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"746 marlu.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	37.137
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.475867302477
		SemiMajorAxis	3.106679669366
		Eccentricity	0.239164871059
		Inclination	17.507399682676
		AscendingNode	2.007305860938
		ArgOfPericenter	307.166231494112
		MeanAnomaly	60.169206451253
	}
	UniformRotation
	{
		Period	7.787
	}
	LunarLambert	0.5
	Albedo	0.032
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=746"
}

#1_"747 Winchester:Winchester:1913 QZ" "Sol" #1=
#2_"*Уинчестер:747 Winchester:Winchester:1913 QZ" "Sol" #2=
#3_"1913 QZ:*Уинчестер:747 Winchester:Winchester" "Sol" #3=
".:Winchester:747 Winchester:1913 QZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"747 winchester.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	85.855
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.199332926917
		SemiMajorAxis	3.001186263798
		Eccentricity	0.340370569379
		Inclination	18.166943340024
		AscendingNode	130.082650474463
		ArgOfPericenter	275.453695632112
		MeanAnomaly	305.330079962454
	}
	UniformRotation
	{
		Period	9.4146
	}
	LunarLambert	0.5
	Albedo	0.0503
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=747"
}

#1_"748 Simeisa:Simeisa:1913 RD:1925 QG:1936 BG:1941 SU:1942 XU:1944 DC:1951 CX:1957 UL1:1963 MC" "Sol" #1=
#2_"*Симеиза:748 Simeisa:Simeisa:1913 RD" "Sol" #2=
#3_"1913 RD:*Симеиза:748 Simeisa:Simeisa" "Sol" #3=
".:Simeisa:748 Simeisa:Simeisa:1913 RD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	51.485
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.843029880334
		SemiMajorAxis	3.947454306376
		Eccentricity	0.187925717307
		Inclination	2.257564198851
		AscendingNode	265.510646460391
		ArgOfPericenter	178.273375834557
		MeanAnomaly	71.808308960728
	}
	UniformRotation
	{
		Period	11.919
	}
	LunarLambert	0.5
	Albedo	0.0415
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=748"
}

#1_"749 Malzovia:Malzovia:1913 RF:1950 JO:1968 XA" "Sol" #1=
#2_"*Мальцовия:749 Malzovia:Malzovia:1913 RF" "Sol" #2=
#3_"1913 RF:Malzovia:*Мальцовия:749 Malzovia" "Sol" #3=
".:Malzovia:749 Malzovia:1913 RF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"749 malzovia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.532
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.360713280136
		SemiMajorAxis	2.243617609057
		Eccentricity	0.173350706683
		Inclination	5.394108757406
		AscendingNode	109.781081308467
		ArgOfPericenter	128.890700874961
		MeanAnomaly	297.32326731988
	}
	UniformRotation
	{
		Period	5.9279
	}
	LunarLambert	0.5
	Albedo	0.27
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=749"
}

#1_"750 Oskar:Oskar:1913 RG:1928 FN:1932 JB:1940 LN:1953 VE:1970 ER2:1970 FH:1972 TY1:1977 FD:1978 BA" "Sol" #1=
#2_"*Оскар:750 Oskar:Oskar:1913 RG" "Sol" #2=
#3_"1913 RG:*Оскар:750 Oskar:Oskar" "Sol" #3=
".:Oskar:750 Oskar:1913 RG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.285
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.820953949496
		SemiMajorAxis	2.444044266239
		Eccentricity	0.128848489331
		Inclination	3.950974663834
		AscendingNode	69.737666733968
		ArgOfPericenter	72.389262643237
		MeanAnomaly	279.02820225173
	}
	UniformRotation
	{
		Period	6.2584
	}
	LunarLambert	0.5
	Albedo	0.0587
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=750"
}

#1_"751 Faina:Faina:1913 RK" "Sol" #1=
#2_"*Фаина:751 Faina:Faina:1913 RK" "Sol" #2=
#3_"1913 RK:*Фаина:751 Faina:Faina" "Sol" #3=
".:Faina:751 Faina:1913 RK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	55.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.071631475464
		SemiMajorAxis	2.549804248929
		Eccentricity	0.153053825669
		Inclination	15.607795034095
		AscendingNode	78.865081939392
		ArgOfPericenter	302.703691610444
		MeanAnomaly	169.034451273287
	}
	UniformRotation
	{
		Period	23.678
	}
	LunarLambert	0.5
	Albedo	0.0497
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=751"
}

#1_"752 Sulamitis:Sulamitis:1913 RL:1936 FH1" "Sol" #1=
#2_"*Суламита:752 Sulamitis:Sulamitis:1913 RL" "Sol" #2=
#3_"1913 RL:*Суламита:752 Sulamitis:Sulamitis" "Sol" #3=
".:Sulamitis:752 Sulamitis:1913 RL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.385
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.865565993134
		SemiMajorAxis	2.463031275136
		Eccentricity	0.073462880451
		Inclination	5.959186465859
		AscendingNode	85.17075452807
		ArgOfPericenter	23.461859861979
		MeanAnomaly	204.311792354449
	}
	UniformRotation
	{
		Period	27.367
	}
	LunarLambert	0.5
	Albedo	0.0409
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=752"
}

#1_"753 Tiflis:Tiflis:1913 RM:A907 VK:A909 DD" "Sol" #1=
#2_"*Тифлис:753 Tiflis:Tiflis:1913 RM" "Sol" #2=
#3_"1913 RM:*Тифлис:753 Tiflis:Tiflis" "Sol" #3=
".:Tiflis:753 Tiflis:1913 RM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"753 tiflis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.461
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.553064634592
		SemiMajorAxis	2.328430451627
		Eccentricity	0.221952939182
		Inclination	10.091908209799
		AscendingNode	61.422282685586
		ArgOfPericenter	202.909472647507
		MeanAnomaly	180.514223184917
	}
	UniformRotation
	{
		Period	9.85
	}
	LunarLambert	0.5
	Albedo	0.333
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=753"
}

#1_"754 Malabar:Malabar:1906 UT:A901 TC:A909 DC" "Sol" #1=
#2_"*Малабар:754 Malabar:Malabar:1906 UT" "Sol" #2=
#3_"1906 UT:*Малабар:754 Malabar:Malabar" "Sol" #3=
".:Malabar:754 Malabar:1906 UT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	43.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.164909650102
		SemiMajorAxis	2.98792494713
		Eccentricity	0.047959375936
		Inclination	24.561821534813
		AscendingNode	180.047920978368
		ArgOfPericenter	301.94353005546
		MeanAnomaly	212.501400349624
	}
	UniformRotation
	{
		Period	11.74
	}
	LunarLambert	0.5
	Albedo	0.0485
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=754"
}

#1_"755 Quintilla:Quintilla:1908 CZ:1933 UF" "Sol" #1=
#2_"*Квинтилла:755 Quintilla:Quintilla:1908 CZ" "Sol" #2=
#3_"1908 CZ:*Квинтилла:755 Quintilla:Quintilla" "Sol" #3=
".:Quintilla:755 Quintilla:1908 CZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	18.02
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.677509987689
		SemiMajorAxis	3.182485764884
		Eccentricity	0.138357082612
		Inclination	3.240721529804
		AscendingNode	176.707807992002
		ArgOfPericenter	43.229081702826
		MeanAnomaly	307.467189442784
	}
	UniformRotation
	{
		Period	4.552
	}
	LunarLambert	0.5
	Albedo	0.1621
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=755"
}

#1_"756 Lilliana:Lilliana:1908 DC:1949 HJ1:1966 FE" "Sol" #1=
#2_"*Лиллиана:756 Lilliana:Lilliana:1908 DC" "Sol" #2=
#3_"1908 DC:*Лиллиана:756 Lilliana:Lilliana" "Sol" #3=
".:Lilliana:756 Lilliana:1908 DC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"756 lilliana.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	32.418
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.711963356187
		SemiMajorAxis	3.195347830103
		Eccentricity	0.148336968345
		Inclination	20.354616231146
		AscendingNode	208.083680324681
		ArgOfPericenter	5.268975790156
		MeanAnomaly	177.538401981511
	}
	UniformRotation
	{
		Period	7.834
	}
	LunarLambert	0.5
	Albedo	0.057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=756"
}

#1_"757 Portlandia:Portlandia:1908 EJ:1931 CF:A912 YA" "Sol" #1=
#2_"*Портландия:757 Portlandia:Portlandia:1908 EJ" "Sol" #2=
#3_"1908 EJ:*Портландия:757 Portlandia:Portlandia" "Sol" #3=
".:Portlandia:757 Portlandia:1908 EJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"757 portlandia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	16.447
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.655536785919
		SemiMajorAxis	2.372986700607
		Eccentricity	0.108508976451
		Inclination	8.166608798401
		AscendingNode	22.535162865245
		ArgOfPericenter	44.070492645397
		MeanAnomaly	331.87561541567
	}
	UniformRotation
	{
		Period	6.5837
	}
	LunarLambert	0.5
	Albedo	0.217
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=757"
}

#1_"758 Mancunia:Mancunia:1912 PE:1938 AG:A914 WC" "Sol" #1=
#2_"*Манкуния:758 Mancunia:Mancunia:1912 PE" "Sol" #2=
#3_"1912 PE:*Манкуния:758 Mancunia:Mancunia" "Sol" #3=
".:Mancunia:758 Mancunia:1912 PE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"758 mancunia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	44.492
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.691031816224
		SemiMajorAxis	3.187536801153
		Eccentricity	0.1513963738
		Inclination	5.61116993144
		AscendingNode	106.198145918466
		ArgOfPericenter	315.093005277605
		MeanAnomaly	157.010088200837
	}
	UniformRotation
	{
		Period	12.7253
	}
	LunarLambert	0.5
	Albedo	0.121
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=758"
}

#1_"759 Vinifera:Vinifera:1913 SJ" "Sol" #1=
#2_"*Винифера:759 Vinifera:Vinifera:1913 SJ" "Sol" #2=
#3_"1913 SJ:*Винифера:759 Vinifera:Vinifera" "Sol" #3=
".:Vinifera:759 Vinifera:1913 SJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.555
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.236428028746
		SemiMajorAxis	2.618149370752
		Eccentricity	0.206404688597
		Inclination	19.909900242409
		AscendingNode	318.425823236654
		ArgOfPericenter	1.09475575552
		MeanAnomaly	333.954743658013
	}
	UniformRotation
	{
		Period	14.229
	}
	LunarLambert	0.5
	Albedo	0.0548
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=759"
}

#1_"760 Massinga:Massinga:1913 SL:1941 SL2" "Sol" #1=
#2_"*Массинга:760 Massinga:Massinga:1913 SL" "Sol" #2=
#3_"1913 SL:*Массинга:760 Massinga:Massinga" "Sol" #3=
".:Massinga:760 Massinga:1913 SL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	35.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.593495492171
		SemiMajorAxis	3.151012021775
		Eccentricity	0.23170779533
		Inclination	12.533288703646
		AscendingNode	331.66563897315
		ArgOfPericenter	200.741364962859
		MeanAnomaly	183.78424023097
	}
	UniformRotation
	{
		Period	10.72
	}
	LunarLambert	0.5
	Albedo	0.2276
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=760"
}

#1_"762 Pulcova:Pulcova:1913 SQ:1952 QM1" "Sol" #1=
#2_"*Пулкова:762 Pulcova:Pulcova:1913 SQ" "Sol" #2=
#3_"1913 SQ:*Пулкова:762 Pulcova:Pulcova" "Sol" #3=
".:Pulcova:762 Pulcova:1913 SQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"762 pulcova.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	70.86
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.605697187917
		SemiMajorAxis	3.155592785893
		Eccentricity	0.103020550481
		Inclination	13.08898537378
		AscendingNode	305.763869397181
		ArgOfPericenter	189.28319934112
		MeanAnomaly	243.31884149816
	}
	UniformRotation
	{
		Period	5.839
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=762"
}

#1_"2000 762 I" "Sol/762 Pulcova" #1=
#2_"2000 762 I" "Sol/762 Pulcova" #2=
#3_"2000 762 I" "Sol/762 Pulcova" #3=
".:2000 762 I" "Sol/762 Pulcova" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	4.438
		SemiMajorAxis	703
		Eccentricity	0.03
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-00762.html"
}

#1_"764 Gedania:Gedania:1913 SU:A902 WD:A908 YE:A918 TA" "Sol" #1=
#2_"*Гедания:764 Gedania:Gedania:1913 SU" "Sol" #2=
#3_"1913 SU:*Гедания:764 Gedania:Gedania" "Sol" #3=
".:Gedania:764 Gedania:1913 SU" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.14
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.703655194041
		SemiMajorAxis	3.192248614646
		Eccentricity	0.099515694885
		Inclination	10.031935610311
		AscendingNode	259.010619371062
		ArgOfPericenter	155.711584211464
		MeanAnomaly	258.171960505122
	}
	UniformRotation
	{
		Period	24.9751
	}
	LunarLambert	0.5
	Albedo	0.084
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=764"
}

#1_"766 Moguntia:Moguntia:1913 SW:A908 WE" "Sol" #1=
#2_"*Могунтия:766 Moguntia:Moguntia:1913 SW" "Sol" #2=
#3_"1913 SW:*Могунтия:766 Moguntia:Moguntia" "Sol" #3=
".:Moguntia:766 Moguntia:1913 SW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	15.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.25520885152
		SemiMajorAxis	3.022649930318
		Eccentricity	0.095714085012
		Inclination	10.079365898354
		AscendingNode	7.875769656033
		ArgOfPericenter	72.631755800322
		MeanAnomaly	40.967731263322
	}
	UniformRotation
	{
		Period	4.8164
	}
	LunarLambert	0.5
	Albedo	0.1572
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=766"
}

#1_"767 Bondia:Bondia:1913 SX:1929 OA:1933 FO1:1938 DQ2:1957 UR:1958 XA1:1959 AD:A902 SA" "Sol" #1=
#2_"*Бондия:767 Bondia:Bondia:1913 SX" "Sol" #2=
#3_"1913 SX:*Бондия:767 Bondia:Bondia" "Sol" #3=
".:Bondia:767 Bondia:1913 SX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	21.5195
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.544462093537
		SemiMajorAxis	3.132570190771
		Eccentricity	0.177240267576
		Inclination	2.412728401139
		AscendingNode	79.570151931582
		ArgOfPericenter	268.142273971167
		MeanAnomaly	140.881460700885
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.095
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=767"
}

#1_"769 Tatjana:Tatjana:1913 TA:1955 BA:1963 KK" "Sol" #1=
#2_"*Татьяна:769 Tatjana:Tatjana:1913 TA" "Sol" #2=
#3_"1913 TA:*Татьяна:769 Tatjana:Tatjana" "Sol" #3=
".:Tatjana:769 Tatjana:1913 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"769 tatjana.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	48.36
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.644649487612
		SemiMajorAxis	3.170194083676
		Eccentricity	0.185507692377
		Inclination	7.36810301745
		AscendingNode	38.497891003348
		ArgOfPericenter	254.031840851392
		MeanAnomaly	346.043590059122
	}
	UniformRotation
	{
		Period	35.08
	}
	LunarLambert	0.5
	Albedo	0.052
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=769"
}

#1_"770 Bali:Bali:1913 TE:A903 UA:A905 JC:A908 FB:A913 YB:A916 QC" "Sol" #1=
#2_"*Бали:770 Bali:Bali:1913 TE" "Sol" #2=
#3_"1913 TE:*Бали:770 Bali:Bali" "Sol" #3=
".:Bali:770 Bali:1913 TE" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"770 bali.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	8.194
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.309569058483
		SemiMajorAxis	2.220796837133
		Eccentricity	0.150739185056
		Inclination	4.385075858134
		AscendingNode	44.708151675496
		ArgOfPericenter	17.933661473193
		MeanAnomaly	181.460287316802
	}
	UniformRotation
	{
		Period	5.819
	}
	LunarLambert	0.5
	Albedo	0.272
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=770"
}

#1_"771 Libera:Libera:1913 TO:1958 HA" "Sol" #1=
#2_"*Либера:771 Libera:Libera:1913 TO" "Sol" #2=
#3_"1913 TO:*Либера:771 Libera:Libera" "Sol" #3=
".:Libera:771 Libera:1913 TO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"771 libera.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	14.661
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.314917373613
		SemiMajorAxis	2.650388393563
		Eccentricity	0.248535047538
		Inclination	14.938674561136
		AscendingNode	218.213045490504
		ArgOfPericenter	227.353045956431
		MeanAnomaly	131.128347597695
	}
	UniformRotation
	{
		Period	5.892
	}
	LunarLambert	0.5
	Albedo	0.123
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=771"
}

#1_"772 Tanete:Tanete:1913 TR:1936 NG:A902 WA:A907 VG:A910 JB" "Sol" #1=
#2_"*Танета:772 Tanete:Tanete:1913 TR" "Sol" #2=
#3_"1913 TR:*Танета:772 Tanete:Tanete" "Sol" #3=
".:Tanete:772 Tanete:1913 TR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58.83
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.19650099159
		SemiMajorAxis	3.000096388455
		Eccentricity	0.091842757168
		Inclination	28.855219547154
		AscendingNode	63.851814678272
		ArgOfPericenter	145.898950350885
		MeanAnomaly	50.103153288814
	}
	UniformRotation
	{
		Period	11.8
	}
	LunarLambert	0.5
	Albedo	0.0594
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=772"
}

#1_"773 Irmintraud:Irmintraud:1913 TV:1946 SO:A910 CG" "Sol" #1=
#2_"*Ирминтрауд:773 Irmintraud:Irmintraud:1913 TV" "Sol" #2=
#3_"1913 TV:*Ирминтрауд:773 Irmintraud:Irmintraud" "Sol" #3=
".:Irmintraud:773 Irmintraud:1913 TV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	47.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.828768474586
		SemiMajorAxis	2.856836945501
		Eccentricity	0.080882540784
		Inclination	16.688820204554
		AscendingNode	322.410326345331
		ArgOfPericenter	332.163662855367
		MeanAnomaly	97.480529523701
	}
	UniformRotation
	{
		Period	6.7514
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=773"
}

#1_"774 Armor:Armor:1913 TW:1955 SW2:A896 RA:A908 YH:A910 CJ" "Sol" #1=
#2_"*Армор:774 Armor:Armor:1913 TW" "Sol" #2=
#3_"1913 TW:*Армор:774 Armor:Armor" "Sol" #3=
".:Armor:774 Armor:1913 TW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	25.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.313230400569
		SemiMajorAxis	3.044857444178
		Eccentricity	0.169904958643
		Inclination	5.561846242272
		AscendingNode	250.290578422261
		ArgOfPericenter	28.657084823475
		MeanAnomaly	129.106138165458
	}
	UniformRotation
	{
		Period	25.107
	}
	LunarLambert	0.5
	Albedo	0.2529
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=774"
}

#1_"775 Lumiere:Lumiere:1914 TX:A917 SB" "Sol" #1=
#2_"*Люмьер:775 Lumiere:Lumiere:1914 TX" "Sol" #2=
#3_"1914 TX:*Люмьер:775 Lumiere:Lumiere" "Sol" #3=
".:Lumiere:775 Lumiere:1914 TX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"775 lumiere.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	15.979
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.228707899222
		SemiMajorAxis	3.012479630188
		Eccentricity	0.071255831089
		Inclination	9.28832846852
		AscendingNode	297.745319897465
		ArgOfPericenter	167.206414375989
		MeanAnomaly	310.655690168468
	}
	UniformRotation
	{
		Period	6.103
	}
	LunarLambert	0.5
	Albedo	0.111
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=775"
}

#1_"776 Berbericia:Berbericia:1914 TY:1977 PN2:1999 BO16:A910 GA:A911 MA" "Sol" #1=
#2_"*Бербериция:776 Berbericia:Berbericia:1914 TY" "Sol" #2=
#3_"1914 TY:*Бербериция:776 Berbericia:Berbericia" "Sol" #3=
".:Berbericia:776 Berbericia:1914 TY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"776 berbericia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	75.856
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.022824069852
		SemiMajorAxis	2.93287245215
		Eccentricity	0.163843615949
		Inclination	18.233144495087
		AscendingNode	79.772356131872
		ArgOfPericenter	307.294939655395
		MeanAnomaly	117.613442043613
	}
	UniformRotation
	{
		Period	7.668
	}
	LunarLambert	0.5
	Albedo	0.065
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=776"
}

#1_"777 Gutemberga:Gutemberga:1914 TZ:1926 EF:A924 YB" "Sol" #1=
#2_"*Гутенберга:777 Gutemberga:Gutemberga:1914 TZ" "Sol" #2=
#3_"1914 TZ:*Гутенберга:777 Gutemberga:Gutemberga" "Sol" #3=
".:Gutemberga:777 Gutemberga:1914 TZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.791164690108
		SemiMajorAxis	3.224817502486
		Eccentricity	0.108089962238
		Inclination	12.938277098854
		AscendingNode	283.315037373534
		ArgOfPericenter	263.101956490688
		MeanAnomaly	100.04104096318
	}
	UniformRotation
	{
		Period	12.88
	}
	LunarLambert	0.5
	Albedo	0.0494
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=777"
}

#1_"778 Theobalda:Theobalda:1914 UA:1940 PG:1948 CA:A923 RQ" "Sol" #1=
#2_"*Теобальда:778 Theobalda:Theobalda:1914 UA" "Sol" #2=
#3_"1914 UA:*Теобальда:778 Theobalda:Theobalda" "Sol" #3=
".:Theobalda:778 Theobalda:1914 UA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32.03
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.692503352087
		SemiMajorAxis	3.188086247223
		Eccentricity	0.249942727811
		Inclination	13.687619889895
		AscendingNode	321.709647416
		ArgOfPericenter	134.289990568661
		MeanAnomaly	280.380037872219
	}
	UniformRotation
	{
		Period	11.659
	}
	LunarLambert	0.5
	Albedo	0.0589
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=778"
}

#1_"779 Nina:Nina:1914 UB:A908 YB:A912 TE" "Sol" #1=
#2_"*Нина:779 Nina:Nina:1914 UB" "Sol" #2=
#3_"1914 UB:*Нина:779 Nina:Nina" "Sol" #3=
".:Nina:779 Nina:1914 UB" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	38.31
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.349240081883
		SemiMajorAxis	2.664424712024
		Eccentricity	0.226598065998
		Inclination	14.579309640543
		AscendingNode	283.75773903668
		ArgOfPericenter	49.298743923749
		MeanAnomaly	207.822591591076
	}
	UniformRotation
	{
		Period	11.186
	}
	LunarLambert	0.5
	Albedo	0.144
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=779"
}

#1_"780 Armenia:Armenia:1914 UC:A909 DE" "Sol" #1=
#2_"*Армения:780 Armenia:Armenia:1914 UC" "Sol" #2=
#3_"1914 UC:*Армения:780 Armenia:Armenia" "Sol" #3=
".:Armenia:780 Armenia:1914 UC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	47.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.492172941038
		SemiMajorAxis	3.112843842221
		Eccentricity	0.097131262774
		Inclination	19.086218029646
		AscendingNode	144.859434800929
		ArgOfPericenter	214.705763132176
		MeanAnomaly	238.51421049609
	}
	UniformRotation
	{
		Period	19.891
	}
	LunarLambert	0.5
	Albedo	0.0498
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=780"
}

#1_"781 Kartvelia:Kartvelia:1914 UF:A908 AH" "Sol" #1=
#2_"*Картвелия:781 Kartvelia:Kartvelia:1914 UF" "Sol" #2=
#3_"1914 UF:*Картвелия:781 Kartvelia:Kartvelia" "Sol" #3=
".:Kartvelia:781 Kartvelia:1914 UF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.01
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.773814846316
		SemiMajorAxis	3.21837342694
		Eccentricity	0.115602758236
		Inclination	19.150437030629
		AscendingNode	138.1121714
		ArgOfPericenter	156.245355179988
		MeanAnomaly	319.886443404421
	}
	UniformRotation
	{
		Period	19.06
	}
	LunarLambert	0.5
	Albedo	0.0704
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=781"
}

#1_"782 Montefiore:Montefiore:1914 UK:A911 KA" "Sol" #1=
#2_"*Монтефиоре:782 Montefiore:Montefiore:1914 UK" "Sol" #2=
#3_"1914 UK:*Монтефиоре:782 Montefiore:Montefiore" "Sol" #3=
".:Montefiore:782 Montefiore:1914 UK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.218775156067
		SemiMajorAxis	2.179992296279
		Eccentricity	0.038510113382
		Inclination	5.26043550184
		AscendingNode	80.504223332763
		ArgOfPericenter	81.546822999086
		MeanAnomaly	127.456831750598
	}
	UniformRotation
	{
		Period	4.0728
	}
	LunarLambert	0.5
	Albedo	0.2919
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=782"
}

#1_"783 Nora:Nora:1914 UL:A911 QG" "Sol" #1=
#2_"*Нора:783 Nora:Nora:1914 UL" "Sol" #2=
#3_"1914 UL:*Нора:783 Nora:Nora" "Sol" #3=
".:Nora:783 Nora:1914 UL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.01
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.584599583881
		SemiMajorAxis	2.342187354311
		Eccentricity	0.229862362132
		Inclination	9.342105944884
		AscendingNode	142.130130359907
		ArgOfPericenter	154.817407504549
		MeanAnomaly	306.938748842638
	}
	UniformRotation
	{
		Period	34.4
	}
	LunarLambert	0.5
	Albedo	0.0635
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=783"
}

#1_"784 Pickeringia:Pickeringia:1914 UM" "Sol" #1=
#2_"*Пикерингия:784 Pickeringia:Pickeringia:1914 UM" "Sol" #2=
#3_"1914 UM:*Пикерингия:784 Pickeringia:Pickeringia" "Sol" #3=
".:Pickeringia:784 Pickeringia:1914 UM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"784 pickeringia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	37.798
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.451214604182
		SemiMajorAxis	3.097348347647
		Eccentricity	0.241780067314
		Inclination	12.28812158032
		AscendingNode	14.947957121513
		ArgOfPericenter	238.33429741532
		MeanAnomaly	95.167576165898
	}
	UniformRotation
	{
		Period	13.17
	}
	LunarLambert	0.5
	Albedo	0.086
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=784"
}

#1_"785 Zwetana:Zwetana:1914 UN:1929 YB:1931 MC:1953 UF1:1972 CD:A904 VA" "Sol" #1=
#2_"*Цветана:785 Zwetana:Zwetana:1914 UN" "Sol" #2=
#3_"1914 UN:*Цветана:785 Zwetana:Zwetana" "Sol" #3=
".:Zwetana:785 Zwetana:1914 UN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	24.27
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.119165829726
		SemiMajorAxis	2.569610999254
		Eccentricity	0.210277831711
		Inclination	12.766127123354
		AscendingNode	71.893454267135
		ArgOfPericenter	131.557039888915
		MeanAnomaly	124.630794347436
	}
	UniformRotation
	{
		Period	8.8882
	}
	LunarLambert	0.5
	Albedo	0.1245
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=785"
}

#1_"786 Bredichina:Bredichina:1914 UO" "Sol" #1=
#2_"*Бредихина:786 Bredichina:Bredichina:1914 UO" "Sol" #2=
#3_"1914 UO:*Бредихина:786 Bredichina:Bredichina" "Sol" #3=
".:Bredichina:786 Bredichina:1914 UO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	45.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.666350804328
		SemiMajorAxis	3.178314266432
		Eccentricity	0.161897554762
		Inclination	14.529703375922
		AscendingNode	89.872543127165
		ArgOfPericenter	133.060953983567
		MeanAnomaly	279.906699443912
	}
	UniformRotation
	{
		Period	18.61
	}
	LunarLambert	0.5
	Albedo	0.073
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=786"
}

#1_"787 Moskva:Moskva:1914 UQ:1934 FD:1970 CT:A910 JC" "Sol" #1=
#2_"*Москва:787 Moskva:Moskva:1914 UQ" "Sol" #2=
#3_"1914 UQ:*Москва:787 Moskva:Moskva" "Sol" #3=
".:Moskva:787 Moskva:1914 UQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"787 moskva.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.964
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.045478896557
		SemiMajorAxis	2.538874060659
		Eccentricity	0.130125398239
		Inclination	14.851514911658
		AscendingNode	183.887667966764
		ArgOfPericenter	126.082738141419
		MeanAnomaly	116.047451329256
	}
	UniformRotation
	{
		Period	6.056
	}
	LunarLambert	0.5
	Albedo	0.19
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=787"
}

#1_"788 Hohensteina:Hohensteina:1914 UR:1927 SS:1933 WU" "Sol" #1=
#2_"*Гогенштейна:788 Hohensteina:Hohensteina:1914 UR" "Sol" #2=
#3_"1914 UR:*Гогенштейна:788 Hohensteina:Hohensteina" "Sol" #3=
".:Hohensteina:788 Hohensteina:1914 UR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	51.84
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.528373102012
		SemiMajorAxis	3.126507167756
		Eccentricity	0.132551936414
		Inclination	14.33491867674
		AscendingNode	177.842276865928
		ArgOfPericenter	48.455032342989
		MeanAnomaly	65.467010287841
	}
	UniformRotation
	{
		Period	37.176
	}
	LunarLambert	0.5
	Albedo	0.0787
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=788"
}

#1_"789 Lena:Lena:1914 UU:1970 CE" "Sol" #1=
#2_"*Лена:789 Lena:Lena:1914 UU:1970 CE" "Sol" #2=
#3_"1914 UU:Lena:*Лена:789 Lena:1970 CE" "Sol" #3=
".:Lena:789 Lena:1914 UU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"789 lena.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	11.242
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.402606546319
		SemiMajorAxis	2.686175900897
		Eccentricity	0.147235015139
		Inclination	10.78077309641
		AscendingNode	232.623650562457
		ArgOfPericenter	44.005925924953
		MeanAnomaly	110.024039008829
	}
	UniformRotation
	{
		Period	5.848
	}
	LunarLambert	0.5
	Albedo	0.153
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=789"
}

#1_"790 Pretoria:Pretoria:1912 NW:1970 HN" "Sol" #1=
#2_"*Претория:790 Pretoria:Pretoria:1912 NW" "Sol" #2=
#3_"1912 NW:*Претория:790 Pretoria:Pretoria" "Sol" #3=
".:Pretoria:790 Pretoria:1912 NW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	85.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.302011433827
		SemiMajorAxis	3.411777150898
		Eccentricity	0.151079596087
		Inclination	20.525188398137
		AscendingNode	252.052847861592
		ArgOfPericenter	38.726405572843
		MeanAnomaly	353.205906758649
	}
	UniformRotation
	{
		Period	10.37
	}
	LunarLambert	0.5
	Albedo	0.0384
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=790"
}

#1_"791 Ani:Ani:1914 UV:1949 WH:1964 PO:1975 XM" "Sol" #1=
#2_"*Ани:791 Ani:Ani:1914 UV" "Sol" #2=
#3_"1914 UV:*Ани:791 Ani:Ani" "Sol" #3=
".:Ani:791 Ani:1914 UV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	51.76
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.509833509372
		SemiMajorAxis	3.119513354318
		Eccentricity	0.196617024475
		Inclination	16.387232946003
		AscendingNode	130.022553920751
		ArgOfPericenter	201.606722111753
		MeanAnomaly	35.338343771803
	}
	UniformRotation
	{
		Period	16.72
	}
	LunarLambert	0.5
	Albedo	0.0329
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=791"
}

#1_"792 Metcalfia:Metcalfia:1907 ZC" "Sol" #1=
#2_"*Меткалфия:792 Metcalfia:Metcalfia:1907 ZC" "Sol" #2=
#3_"1907 ZC:*Меткалфия:792 Metcalfia:Metcalfia" "Sol" #3=
".:Metcalfia:792 Metcalfia:1907 ZC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"792 metcalfia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	30.902
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.249300489505
		SemiMajorAxis	2.623450217038
		Eccentricity	0.12995473856
		Inclination	8.615795441982
		AscendingNode	265.138691853272
		ArgOfPericenter	227.577851524291
		MeanAnomaly	175.965247529923
	}
	UniformRotation
	{
		Period	9.17
	}
	LunarLambert	0.5
	Albedo	0.024
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=792"
}

#1_"793 Arizona:Arizona:1907 ZD" "Sol" #1=
#2_"*Аризона:793 Arizona:Arizona:1907 ZD" "Sol" #2=
#3_"1907 ZD:*Аризона:793 Arizona:Arizona" "Sol" #3=
".:Arizona:793 Arizona:1907 ZD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.475
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.67175004553
		SemiMajorAxis	2.794565313007
		Eccentricity	0.125032531554
		Inclination	15.78894524657
		AscendingNode	36.064118839541
		ArgOfPericenter	309.134823569435
		MeanAnomaly	241.682350307339
	}
	UniformRotation
	{
		Period	7.399
	}
	LunarLambert	0.5
	Albedo	0.1659
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=793"
}

#1_"794 Irenaea:Irenaea:1914 VB:1930 KH:1936 QK:1947 QD:1953 TT2" "Sol" #1=
#2_"*Иренея:794 Irenaea:Irenaea:1914 VB" "Sol" #2=
#3_"1914 VB:*Иренея:794 Irenaea:Irenaea" "Sol" #3=
".:Irenaea:794 Irenaea:1914 VB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.536773181922
		SemiMajorAxis	3.129673411326
		Eccentricity	0.296141725199
		Inclination	5.418284356252
		AscendingNode	160.453506370355
		ArgOfPericenter	131.612540849182
		MeanAnomaly	34.469611215546
	}
	UniformRotation
	{
		Period	9.14
	}
	LunarLambert	0.5
	Albedo	0.0502
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=794"
}

#1_"795 Fini:Fini:1914 VE:1940 GY:1946 UR:1951 UR:1958 JC" "Sol" #1=
#2_"*Фини:795 Fini:Fini:1914 VE" "Sol" #2=
#3_"1914 VE:*Фини:795 Fini:Fini" "Sol" #3=
".:Fini:795 Fini:1914 VE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	37.33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.558712754762
		SemiMajorAxis	2.749303493281
		Eccentricity	0.102180031605
		Inclination	19.058323159878
		AscendingNode	17.394769921105
		ArgOfPericenter	190.815436002233
		MeanAnomaly	133.434710354124
	}
	UniformRotation
	{
		Period	9.292
	}
	LunarLambert	0.5
	Albedo	0.0418
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=795"
}

#1_"796 Sarita:Sarita:1914 VH:1930 HR:1960 HE" "Sol" #1=
#2_"*Сарита:796 Sarita:Sarita:1914 VH" "Sol" #2=
#3_"1914 VH:*Сарита:796 Sarita:Sarita" "Sol" #3=
".:Sarita:796 Sarita:1914 VH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	22.48
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.277948491259
		SemiMajorAxis	2.635228219871
		Eccentricity	0.319489434471
		Inclination	19.04430642344
		AscendingNode	33.204865828407
		ArgOfPericenter	329.704700679089
		MeanAnomaly	162.551694612976
	}
	UniformRotation
	{
		Period	8.1755
	}
	LunarLambert	0.5
	Albedo	0.1966
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=796"
}

#1_"797 Montana:Montana:1914 VR:1953 JG:1957 MG:A898 WA" "Sol" #1=
#2_"*Монтана:797 Montana:Montana:1914 VR" "Sol" #2=
#3_"1914 VR:Montana:*Монтана:797 Montana" "Sol" #3=
".:Montana:797 Montana:1914 VR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"797 montana.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.598
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.035814297431
		SemiMajorAxis	2.53482888976
		Eccentricity	0.061363487605
		Inclination	4.5102335084
		AscendingNode	238.349891164539
		ArgOfPericenter	355.401379626509
		MeanAnomaly	277.77217724295
	}
	UniformRotation
	{
		Period	4.5463
	}
	LunarLambert	0.5
	Albedo	0.287
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=797"
}

#1_"798 Ruth:Ruth:1914 VT:1945 VJ:1955 SN:A880 JA:A917 KA" "Sol" #1=
#2_"*Руфь:798 Ruth:Ruth:1914 VT" "Sol" #2=
#3_"1914 VT:*Руфь:798 Ruth:Ruth" "Sol" #3=
".:Ruth:798 Ruth:1914 VT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"798 ruth.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	21.595
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.236993049125
		SemiMajorAxis	3.015661073737
		Eccentricity	0.037902999033
		Inclination	9.223633333521
		AscendingNode	214.446684105016
		ArgOfPericenter	40.782786077485
		MeanAnomaly	215.225296068972
	}
	UniformRotation
	{
		Period	8.55
	}
	LunarLambert	0.5
	Albedo	0.1587
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=798"
}

#1_"799 Gudula:Gudula:1915 WO:1935 BC:1948 KB:1952 HL4:A907 FB" "Sol" #1=
#2_"*Гудула:799 Gudula:Gudula:1915 WO" "Sol" #2=
#3_"1915 WO:*Гудула:799 Gudula:Gudula" "Sol" #3=
".:Gudula:799 Gudula:1915 WO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	21.815
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.051197745173
		SemiMajorAxis	2.541266198986
		Eccentricity	0.021369355669
		Inclination	5.282130345044
		AscendingNode	164.882526035582
		ArgOfPericenter	235.774205601907
		MeanAnomaly	348.601640216767
	}
	UniformRotation
	{
		Period	14.814
	}
	LunarLambert	0.5
	Albedo	0.0704
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=799"
}

#1_"800 Kressmannia:Kressmannia:1915 WP:A905 CF:A912 GC" "Sol" #1=
#2_"*Крессмания:800 Kressmannia:Kressmannia:1915 WP" "Sol" #2=
#3_"1915 WP:*Крессмания:800 Kressmannia:Kressmannia" "Sol" #3=
".:Kressmannia:800 Kressmannia:1915 WP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"800 kressmannia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	7.7145
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.249146550013
		SemiMajorAxis	2.19368398828
		Eccentricity	0.201351555142
		Inclination	4.264381699622
		AscendingNode	325.200680100823
		ArgOfPericenter	347.387188100964
		MeanAnomaly	194.870775684307
	}
	UniformRotation
	{
		Period	4.464
	}
	LunarLambert	0.5
	Albedo	0.243
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=800"
}

#1_"801 Helwerthia:Helwerthia:1915 WQ:1925 RG:1970 GS1:A924 OD" "Sol" #1=
#2_"*Гельверция:801 Helwerthia:Helwerthia:1915 WQ" "Sol" #2=
#3_"1915 WQ:*Гельверция:801 Helwerthia:Helwerthia" "Sol" #3=
".:Helwerthia:801 Helwerthia:1915 WQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.615
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.202177614395
		SemiMajorAxis	2.604018918326
		Eccentricity	0.078104044139
		Inclination	14.12447749887
		AscendingNode	185.991387768812
		ArgOfPericenter	335.701170832433
		MeanAnomaly	266.366060595317
	}
	UniformRotation
	{
		Period	23.93
	}
	LunarLambert	0.5
	Albedo	0.0384
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=801"
}

#1_"802 Epyaxa:Epyaxa:1915 WR:1930 YK:1931 AX:1970 AM1:1972 XW:1977 FG3" "Sol" #1=
#2_"*Эпиакса:802 Epyaxa:Epyaxa:1915 WR" "Sol" #2=
#3_"1915 WR:Epyaxa:*Эпиакса:802 Epyaxa" "Sol" #3=
".:Epyaxa:802 Epyaxa:1915 WR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"802 epyaxa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	3.712
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.25403801019
		SemiMajorAxis	2.195885105232
		Eccentricity	0.079023629403
		Inclination	5.202747013455
		AscendingNode	7.832275257748
		ArgOfPericenter	115.684918487742
		MeanAnomaly	161.447684784847
	}
	UniformRotation
	{
		Period	4.392
	}
	LunarLambert	0.5
	Albedo	0.292
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=802"
}

#1_"803 Picka:Picka:1915 WS:1952 YH:1984 EC2:A899 NE:A915 FD" "Sol" #1=
#2_"*Пика:803 Picka:Picka:1915 WS" "Sol" #2=
#3_"1915 WS:*Пика:803 Picka:Picka" "Sol" #3=
".:Picka:803 Picka:1915 WS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"803 picka.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	23.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.721590265994
		SemiMajorAxis	3.198937102779
		Eccentricity	0.064838045007
		Inclination	8.67254208171
		AscendingNode	250.985702120908
		ArgOfPericenter	61.414168899633
		MeanAnomaly	351.446822760548
	}
	UniformRotation
	{
		Period	5.0742
	}
	LunarLambert	0.5
	Albedo	0.1181
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=803"
}

#1_"804 Hispania:Hispania:1915 WT:1953 FU1:A903 WA " "Sol" #1=
#2_"*Испания:804 Hispania:Hispania:1915 WT" "Sol" #2=
#3_"1915 WT:*Испания:804 Hispania:Hispania" "Sol" #3=
".:Hispania:804 Hispania:1915 WT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	78.79
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.793354828888
		SemiMajorAxis	2.842852002334
		Eccentricity	0.138125281242
		Inclination	15.376676942327
		AscendingNode	347.636895970783
		ArgOfPericenter	343.831975491351
		MeanAnomaly	154.918899389618
	}
	UniformRotation
	{
		Period	14.845
	}
	LunarLambert	0.5
	Albedo	0.052
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=804"
}

#1_"805 Hormuthia:Hormuthia:1915 WW:1928 QG:1950 FU:1950 GD:A911 UA:A917 UG" "Sol" #1=
#2_"*Гормуция:805 Hormuthia:Hormuthia:1915 WW" "Sol" #2=
#3_"1915 WW:*Гормуция:805 Hormuthia:Hormuthia" "Sol" #3=
".:Hormuthia:805 Hormuthia:1915 WW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.47
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.708668877502
		SemiMajorAxis	3.194119062005
		Eccentricity	0.187094315995
		Inclination	15.726643893013
		AscendingNode	166.444953324089
		ArgOfPericenter	132.53617432032
		MeanAnomaly	28.599299445367
	}
	UniformRotation
	{
		Period	9.51
	}
	LunarLambert	0.5
	Albedo	0.0465
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=805"
}

#1_"806 Gyldenia:Gyldenia:1915 WX:1950 LT" "Sol" #1=
#2_"*Гульдения:806 Gyldenia:Gyldenia:1915 WX" "Sol" #2=
#3_"1915 WX:*Гульдения:806 Gyldenia:Gyldenia" "Sol" #3=
".:Gyldenia:806 Gyldenia:1915 WX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.315
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.753004683396
		SemiMajorAxis	3.210635599769
		Eccentricity	0.075039856433
		Inclination	14.236473984666
		AscendingNode	44.002826598377
		ArgOfPericenter	119.04060723131
		MeanAnomaly	143.929216915715
	}
	UniformRotation
	{
		Period	16.846
	}
	LunarLambert	0.5
	Albedo	0.0259
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=806"
}

#1_"807 Ceraskia:Ceraskia:1915 WY:1974 QB3:A909 BK:A917 QA" "Sol" #1=
#2_"*Цераския:807 Ceraskia:Ceraskia:1915 WY" "Sol" #2=
#3_"1915 WY:*Цераския:807 Ceraskia:Ceraskia" "Sol" #3=
".:Ceraskia:807 Ceraskia:1915 WY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"807 ceraskia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.62
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.23843803862
		SemiMajorAxis	3.016215768408
		Eccentricity	0.06652805281
		Inclination	11.319884097861
		AscendingNode	132.221137396695
		ArgOfPericenter	337.658816824475
		MeanAnomaly	74.886557581038
	}
	UniformRotation
	{
		Period	7.4
	}
	LunarLambert	0.5
	Albedo	0.207
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=807"
}

#1_"808 Merxia:Merxia:1901 GY" "Sol" #1=
#2_"*Мерксия:808 Merxia:Merxia:1901 GY" "Sol" #2=
#3_"1901 GY:*Мерксия:808 Merxia:Merxia" "Sol" #3=
".:Merxia:808 Merxia:1901 GY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"808 merxia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	15.462
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.552056811499
		SemiMajorAxis	2.746626763409
		Eccentricity	0.126427212028
		Inclination	4.723252992162
		AscendingNode	181.066145126342
		ArgOfPericenter	274.237914152066
		MeanAnomaly	241.269809702213
	}
	UniformRotation
	{
		Period	30.631
	}
	LunarLambert	0.5
	Albedo	0.213
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=808"
}

#1_"810 Atossa:Atossa:1915 XQ:1931 PF:1934 NB:1947 PA" "Sol" #1=
#2_"*Атосса:810 Atossa:Atossa:1915 XQ" "Sol" #2=
#3_"1915 XQ:*Атосса:810 Atossa:Atossa" "Sol" #3=
".:Atossa:810 Atossa:1915 XQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"810 atossa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	4.052
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.215862112509
		SemiMajorAxis	2.17867681229
		Eccentricity	0.180996691722
		Inclination	2.612304910214
		AscendingNode	152.7185594491
		ArgOfPericenter	195.57798289148
		MeanAnomaly	6.973851582596
	}
	UniformRotation
	{
		Period	4.385
	}
	LunarLambert	0.5
	Albedo	0.224
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=810"
}

#1_"812 Adele:Adele:1915 XV:A902 UE" "Sol" #1=
#2_"*Адель:812 Adele:Adele:1915 XV" "Sol" #2=
#3_"1915 XV:*Адель:812 Adele:Adele" "Sol" #3=
".:Adele:812 Adele:1915 XV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"812 adele.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.178
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.336452870462
		SemiMajorAxis	2.659199695167
		Eccentricity	0.166929405589
		Inclination	13.322288808181
		AscendingNode	7.343840341091
		ArgOfPericenter	352.592657352482
		MeanAnomaly	358.307445618805
	}
	UniformRotation
	{
		Period	5.8587
	}
	LunarLambert	0.5
	Albedo	0.291
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=812"
}

#1_"813 Baumeia:Baumeia:1915 YR:1945 WC:1974 QR2:1974 QY2:A907 GH" "Sol" #1=
#2_"*Баумея:813 Baumeia:Baumeia:1915 YR" "Sol" #2=
#3_"1915 YR:*Баумея:813 Baumeia:Baumeia" "Sol" #3=
".:Baumeia:813 Baumeia:1915 YR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.314922928102
		SemiMajorAxis	2.22319123816
		Eccentricity	0.025899607038
		Inclination	6.295449659292
		AscendingNode	51.976587239796
		ArgOfPericenter	314.698806153539
		MeanAnomaly	352.61362940765
	}
	UniformRotation
	{
		Period	10.544
	}
	LunarLambert	0.5
	Albedo	0.2027
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=813"
}

#1_"814 Tauris:Tauris:1916 YT:1927 BA:A907 JE" "Sol" #1=
#2_"*Таврида:814 Tauris:Tauris:1916 YT" "Sol" #2=
#3_"1916 YT:*Таврида:814 Tauris:Tauris" "Sol" #3=
".:Tauris:814 Tauris:1916 YT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	54.78
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.600439990294
		SemiMajorAxis	3.153619535174
		Eccentricity	0.308080767728
		Inclination	21.825687023933
		AscendingNode	88.798370245371
		ArgOfPericenter	296.803364366559
		MeanAnomaly	254.921128310303
	}
	UniformRotation
	{
		Period	35.8
	}
	LunarLambert	0.5
	Albedo	0.047
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=814"
}

#1_"815 Coppelia:Coppelia:1916 YU:1953 VP1" "Sol" #1=
#2_"*Коппелия:815 Coppelia:Coppelia:1916 YU" "Sol" #2=
#3_"1916 YU:*Коппелия:815 Coppelia:Coppelia" "Sol" #3=
".:Coppelia:815 Coppelia:1916 YU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.55
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.333679715494
		SemiMajorAxis	2.658065871545
		Eccentricity	0.075261729907
		Inclination	13.861749097495
		AscendingNode	57.119185527759
		ArgOfPericenter	59.46925405034
		MeanAnomaly	298.242268117093
	}
	UniformRotation
	{
		Period	4.421
	}
	LunarLambert	0.5
	Albedo	0.2089
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=815"
}

#1_"816 Juliana:Juliana:1916 YV" "Sol" #1=
#2_"*Юлиана:816 Juliana:Juliana:1916 YV" "Sol" #2=
#3_"1916 YV:*Юлиана:816 Juliana:Juliana" "Sol" #3=
".:Juliana:816 Juliana:1916 YV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"816 juliana.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	25.372
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.207326409481
		SemiMajorAxis	3.004261502815
		Eccentricity	0.110577396928
		Inclination	14.331689062347
		AscendingNode	127.872819154567
		ArgOfPericenter	21.329243395531
		MeanAnomaly	350.029006429369
	}
	UniformRotation
	{
		Period	10.557
	}
	LunarLambert	0.5
	Albedo	0.043
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=816"
}

#1_"817 Annika:Annika:1916 YW" "Sol" #1=
#2_"*Анника:817 Annika:Annika:1916 YW" "Sol" #2=
#3_"1916 YW:*Анника:817 Annika:Annika" "Sol" #3=
".:Annika:817 Annika:1916 YW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.025
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.170124640786
		SemiMajorAxis	2.590760233841
		Eccentricity	0.178442261096
		Inclination	11.339404447198
		AscendingNode	125.632167203758
		ArgOfPericenter	284.538135958769
		MeanAnomaly	308.870596413656
	}
	UniformRotation
	{
		Period	10.56
	}
	LunarLambert	0.5
	Albedo	0.174
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=817"
}

#1_"818 Kapteynia:Kapteynia:1916 YZ:1929 JC" "Sol" #1=
#2_"*Каптения:818 Kapteynia:Kapteynia:1916 YZ" "Sol" #2=
#3_"1916 YZ:*Каптения:818 Kapteynia:Kapteynia" "Sol" #3=
".:Kapteynia:818 Kapteynia:1916 YZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	24.725
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.643940579872
		SemiMajorAxis	3.169928649755
		Eccentricity	0.094910786666
		Inclination	15.663493213295
		AscendingNode	70.832466134651
		ArgOfPericenter	293.267761632854
		MeanAnomaly	293.432918912425
	}
	UniformRotation
	{
		Period	16.35
	}
	LunarLambert	0.5
	Albedo	0.1655
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=818"
}

#1_"819 Barnardiana:Barnardiana:1916 ZA:1930 QX:1955 EB:A904 SC" "Sol" #1=
#2_"*Барнардиана:819 Barnardiana:Barnardiana:1916 ZA" "Sol" #2=
#3_"1916 ZA:*Барнардиана:819 Barnardiana:Barnardiana" "Sol" #3=
".:Barnardiana:819 Barnardiana:1916 ZA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"819 barnardiana.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.458
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.25795179002
		SemiMajorAxis	2.197645479871
		Eccentricity	0.142121163139
		Inclination	4.898323864914
		AscendingNode	333.164997691997
		ArgOfPericenter	306.452470708736
		MeanAnomaly	61.923199401166
	}
	UniformRotation
	{
		Period	66.7
	}
	LunarLambert	0.5
	Albedo	0.277
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=819"
}

#1_"820 Adriana:Adriana:1916 ZB:1934 NA1:1934 PV:1935 SE:1975 YP" "Sol" #1=
#2_"*Адриана:820 Adriana:Adriana:1916 ZB" "Sol" #2=
#3_"1916 ZB:*Адриана:820 Adriana:Adriana" "Sol" #3=
".:Adriana:820 Adriana:1916 ZB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.325
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.553465907374
		SemiMajorAxis	3.135960654987
		Eccentricity	0.048832887372
		Inclination	5.939309452202
		AscendingNode	118.529243117405
		ArgOfPericenter	189.88489289293
		MeanAnomaly	181.184672862445
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0204
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=820"
}

#New3
#1_"822 Lalage:Lalage:1916 ZD:1943 EJ1" "Sol" #1=
#2_"*Лалаж:822 Lalage:Lalage:1916 ZD" "Sol" #2=
#3_"1916 ZD:*Лалаж:822 Lalage:Lalage" "Sol" #3=
".:Lalage:822 Lalage:1916 ZD" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"822 lalage.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.122
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.387701226193
		SemiMajorAxis	2.255613054205
		Eccentricity	0.154470767202
		Inclination	0.716185773891
		AscendingNode	210.083176507238
		ArgOfPericenter	247.082021841003
		MeanAnomaly	51.509507373091
	}
	UniformRotation
	{
		Period	3.345
	}
	LunarLambert	0.5
	Albedo	0.349
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=822"
}


#1_"823 Sisigambis:Sisigambis:1916 ZG:1937 QE:1939 FA1:1969 FN:2005 AR82:A913 JB" "Sol" #1=
#2_"*Сизигамбида:823 Sisigambis:Sisigambis:1916 ZG" "Sol" #2=
#3_"1916 ZG:*Сизигамбида:823 Sisigambis:Sisigambis" "Sol" #3=
".:Sisigambis:823 Sisigambis:1916 ZG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"gaspra.jpg"
	Radius	8.315
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.311400577624
		SemiMajorAxis	2.221616089183
		Eccentricity	0.090166538471
		Inclination	3.646048130654
		AscendingNode	255.063744177695
		ArgOfPericenter	218.858518848192
		MeanAnomaly	357.709411610004
	}
	UniformRotation
	{
		Period	146
	}
	LunarLambert	0.5
	Albedo	0.1793
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=823"
}

#1_"824 Anastasia:Anastasia:1916 ZH:1948 BB:1950 RR1:A913 TB" "Sol" #1=
#2_"*Анастасия:824 Anastasia:Anastasia:1916 ZH" "Sol" #2=
#3_"1916 ZH:*Анастасия:824 Anastasia:Anastasia" "Sol" #3=
".:Anastasia:824 Anastasia:1916 ZH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	17.07
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.666851626199
		SemiMajorAxis	2.792611534669
		Eccentricity	0.136674282822
		Inclination	8.126062164764
		AscendingNode	141.404306210579
		ArgOfPericenter	142.11476396053
		MeanAnomaly	318.40169615197
	}
	UniformRotation
	{
		Period	250
	}
	LunarLambert	0.5
	Albedo	0.1039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=824"
}

#1_"825 Tanina:Tanina:1916 ZL:A904 UB" "Sol" #1=
#2_"*Танина:825 Tanina:Tanina:1916 ZL" "Sol" #2=
#3_"1916 ZL:*Танина:825 Tanina:Tanina" "Sol" #3=
".:Tanina:825 Tanina:1916 ZL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"825 tanina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	6.712
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.320558065468
		SemiMajorAxis	2.225710038047
		Eccentricity	0.075390006869
		Inclination	3.400198156145
		AscendingNode	101.431353444133
		ArgOfPericenter	111.577703249133
		MeanAnomaly	239.324496655361
	}
	UniformRotation
	{
		Period	6.94
	}
	LunarLambert	0.5
	Albedo	0.275
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=825"
}

#1_"826 Henrika:Henrika:1916 ZO:1930 MG:1934 HE:1935 SW1:1948 PJ1:1957 QC:1962 UK:1962 VC" "Sol" #1=
#2_"*Генрика:826 Henrika:Henrika:1916 ZO" "Sol" #2=
#3_"1916 ZO:*Генрика:826 Henrika:Henrika" "Sol" #3=
".:Henrika:826 Henrika:1916 ZO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.467160596686
		SemiMajorAxis	2.712369855226
		Eccentricity	0.204916418791
		Inclination	7.10505978359
		AscendingNode	230.247408916988
		ArgOfPericenter	36.898971350435
		MeanAnomaly	330.522242589111
	}
	UniformRotation
	{
		Period	5.9846
	}
	LunarLambert	0.5
	Albedo	0.1435
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=826"
}

#1_"828 Lindemannia:Lindemannia:1916 ZX:A905 UJ" "Sol" #1=
#2_"*Линдеманния:828 Lindemannia:Lindemannia:1916 ZX" "Sol" #2=
#3_"1916 ZX:*Линдеманния:828 Lindemannia:Lindemannia" "Sol" #3=
".:Lindemannia:828 Lindemannia:1916 ZX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.946
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	5.712733476189
		SemiMajorAxis	3.195635033857
		Eccentricity	0.029045828663
		Inclination	1.128620247295
		AscendingNode	1.932738538168
		ArgOfPericenter	289.969011953021
		MeanAnomaly	256.394101700904
	}
	UniformRotation
	{
		Period	20.52
	}
	LunarLambert	0.5
	Albedo	0.057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=828"
}

#1_"829 Academia:Academia:1916 ZY:1958 XU:A914 DA" "Sol" #1=
#2_"*Академия:829 Academia:Academia:1916 ZY" "Sol" #2=
#3_"1916 ZY:*Академия:829 Academia:Academia" "Sol" #3=
".:Academia:829 Academia:1916 ZY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"829 academia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	21.342
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.142527683433
		SemiMajorAxis	2.579317539703
		Eccentricity	0.100256261053
		Inclination	8.283988048643
		AscendingNode	352.5102551895
		ArgOfPericenter	41.341296478112
		MeanAnomaly	210.466958163705
	}
	UniformRotation
	{
		Period	7.891
	}
	LunarLambert	0.5
	Albedo	0.054
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=829"
}

#1_"830 Petropolitana:Petropolitana:1916 ZZ:1917 Sgb:1933 RK:1949 KW" "Sol" #1=
#2_"*Петрополитана:830 Petropolitana:Petropolitana:1916 ZZ" "Sol" #2=
#3_"1916 ZZ:*Петрополитана:830 Petropolitana:Petropolitana" "Sol" #3=
".:Petropolitana:830 Petropolitana:1916 ZZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"830 petropolitana.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	20.664
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.754691819348
		SemiMajorAxis	3.211263273403
		Eccentricity	0.061644564702
		Inclination	3.816971063264
		AscendingNode	340.757182186826
		ArgOfPericenter	85.90969544029
		MeanAnomaly	319.764525012048
	}
	UniformRotation
	{
		Period	39
	}
	LunarLambert	0.5
	Albedo	0.215
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=830"
}

#1_"832 Karin:Karin:1916 AB:1955 SD3:A902 WH" "Sol" #1=
#2_"*Карин:832 Karin:Karin:1916 AB" "Sol" #2=
#3_"1916 AB:*Карин:832 Karin:Karin" "Sol" #3=
".:Karin:832 Karin:1916 AB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"832 karin.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	7.906
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.856111752385
		SemiMajorAxis	2.867611500718
		Eccentricity	0.07845899819
		Inclination	1.003685831715
		AscendingNode	254.307655378414
		ArgOfPericenter	121.290935818959
		MeanAnomaly	119.748439739147
	}
	UniformRotation
	{
		Period	18.348
	}
	LunarLambert	0.5
	Albedo	0.221
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=832"
}

#1_"834 Burnhamia:Burnhamia:1916 AD:1959 CA:1972 JE:A905 UM" "Sol" #1=
#2_"*Бурнхамия:834 Burnhamia:Burnhamia:1916 AD" "Sol" #2=
#3_"1916 AD:*Бурнхамия:834 Burnhamia:Burnhamia" "Sol" #3=
".:Burnhamia:834 Burnhamia:1916 AD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.325
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.691616785128
		SemiMajorAxis	3.187755224107
		Eccentricity	0.203746945871
		Inclination	3.95642796269
		AscendingNode	182.959404102502
		ArgOfPericenter	90.184177824964
		MeanAnomaly	222.104881242948
	}
	UniformRotation
	{
		Period	13.875
	}
	LunarLambert	0.5
	Albedo	0.0698
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=834"
}

#1_"835 Olivia:Olivia:1916 AE:1964 BA:1979 ST" "Sol" #1=
#2_"*Оливия:835 Olivia:Olivia:1916 AE" "Sol" #2=
#3_"1916 AE:*Оливия:835 Olivia:Olivia" "Sol" #3=
".:Olivia:835 Olivia:1916 AE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.825
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.772557826659
		SemiMajorAxis	3.217906294367
		Eccentricity	0.090204351518
		Inclination	3.706479876733
		AscendingNode	309.2149347537
		ArgOfPericenter	62.200240442082
		MeanAnomaly	25.255583411521
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0242
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=835"
}

#1_"838 Seraphina:Seraphina:1916 AH" "Sol" #1=
#2_"*Серафина:838 Seraphina:Seraphina:1916 AH" "Sol" #2=
#3_"1916 AH:*Серафина:838 Seraphina:Seraphina" "Sol" #3=
".:Seraphina:838 Seraphina:1916 AH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.905
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.934057736085
		SemiMajorAxis	2.898215556349
		Eccentricity	0.134694457
		Inclination	10.414384592367
		AscendingNode	240.125576137238
		ArgOfPericenter	116.653826313336
		MeanAnomaly	336.356305597729
	}
	UniformRotation
	{
		Period	15.67
	}
	LunarLambert	0.5
	Albedo	0.0455
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=838"
}

#1_"839 Valborg:Valborg:1916 AJ:1948 CF:1952 BW1:1954 UH1" "Sol" #1=
#2_"*Вальборг:839 Valborg:Valborg:1916 AJ" "Sol" #2=
#3_"1916 AJ:*Вальборг:839 Valborg:Valborg" "Sol" #3=
".:Valborg:839 Valborg:1916 AJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.195
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.227657505936
		SemiMajorAxis	2.614534616528
		Eccentricity	0.152709310369
		Inclination	12.608805448554
		AscendingNode	338.229285433346
		ArgOfPericenter	338.911331555736
		MeanAnomaly	124.035053580305
	}
	UniformRotation
	{
		Period	10.366
	}
	LunarLambert	0.5
	Albedo	0.3534
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=839"
}

#1_"842 Kerstin:Kerstin:1916 AM" "Sol" #1=
#2_"*Керстин:842 Kerstin:Kerstin:1916 AM" "Sol" #2=
#3_"1916 AM:*Керстин:842 Kerstin:Kerstin" "Sol" #3=
".:Kerstin:842 Kerstin:1916 AM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.816236896541
		SemiMajorAxis	3.234118459551
		Eccentricity	0.122000560549
		Inclination	14.549422315992
		AscendingNode	5.674060121164
		ArgOfPericenter	351.553963432745
		MeanAnomaly	12.798414401591
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0552
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=842"
}

#1_"844 Leontina:Leontina:1916 AP:1935 BN:1953 FL1:A902 EC" "Sol" #1=
#2_"*Леонтина:844 Leontina:Leontina:1916 AP" "Sol" #2=
#3_"1916 AP:Leontina:*Леонтина:844 Leontina" "Sol" #3=
".:Leontina:844 Leontina:1916 AP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"844 leontina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	21.077
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.73767186717
		SemiMajorAxis	3.204928439626
		Eccentricity	0.068651599942
		Inclination	8.779311546079
		AscendingNode	348.734495259108
		ArgOfPericenter	351.997206955255
		MeanAnomaly	247.036331229868
	}
	UniformRotation
	{
		Period	6.7859
	}
	LunarLambert	0.5
	Albedo	0.173
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=844"
}

#1_"845 Naema:Naema:1916 AS" "Sol" #1=
#2_"*Наэма:845 Naema:Naema:1916 AS" "Sol" #2=
#3_"1916 AS:*Наэма:845 Naema:Naema" "Sol" #3=
".:Naema:845 Naema:1916 AS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.18
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.035826072558
		SemiMajorAxis	2.937931595783
		Eccentricity	0.069060910904
		Inclination	12.611264754689
		AscendingNode	43.161765553475
		ArgOfPericenter	295.614559003234
		MeanAnomaly	233.418589810299
	}
	UniformRotation
	{
		Period	20.892
	}
	LunarLambert	0.5
	Albedo	0.0788
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=845"
}

#1_"846 Lipperta:Lipperta:1916 AT:1933 XF:1943 QF:1949 UB1:A912 AD" "Sol" #1=
#2_"*Липперта:846 Lipperta:Lipperta:1916 AT" "Sol" #2=
#3_"1916 AT:*Липперта:846 Lipperta:Lipperta" "Sol" #3=
".:Lipperta:846 Lipperta:1916 AT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	26.205
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.530201812781
		SemiMajorAxis	3.127196600501
		Eccentricity	0.182724208266
		Inclination	0.264220994969
		AscendingNode	261.510350231254
		ArgOfPericenter	129.200978307909
		MeanAnomaly	280.599088268388
	}
	UniformRotation
	{
		Period	1641
	}
	LunarLambert	0.5
	Albedo	0.0506
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=846"
}

#1_"847 Agnia:Agnia:1915 XX:A906 SF:A908 AG:A916 YA" "Sol" #1=
#2_"*Агния:847 Agnia:Agnia:1915 XX" "Sol" #2=
#3_"1915 XX:*Агния:847 Agnia:Agnia" "Sol" #3=
".:Agnia:847 Agnia:1915 XX" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"847 agnia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	12.466
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.647239092092
		SemiMajorAxis	2.784782041709
		Eccentricity	0.094100742351
		Inclination	2.482788957581
		AscendingNode	271.067469140451
		ArgOfPericenter	130.643698014324
		MeanAnomaly	80.273097087513
	}
	UniformRotation
	{
		Period	14.827
	}
	LunarLambert	0.5
	Albedo	0.152
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=847"
}

#1_"849 Ara:Ara:1912 NY:1915 Sai:1935 FU:1960 WN" "Sol" #1=
#2_"*Ара:849 Ara:Ara:1912 NY" "Sol" #2=
#3_"1912 NY:*Ара:849 Ara:Ara" "Sol" #3=
".:Ara:849 Ara:1912 NY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"849 ara.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	40.378
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.583926956157
		SemiMajorAxis	3.147417468686
		Eccentricity	0.199920949374
		Inclination	19.530638188463
		AscendingNode	228.367738564886
		ArgOfPericenter	63.272820199731
		MeanAnomaly	146.653972368497
	}
	UniformRotation
	{
		Period	4.116
	}
	LunarLambert	0.5
	Albedo	0.186
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=849"
}

#1_"850 Altona:Altona:1916 S24:A923 RP" "Sol" #1=
#2_"*Альтона:850 Altona:Altona:1916 S24" "Sol" #2=
#3_"1916 S24:*Альтона:850 Altona:Altona" "Sol" #3=
".:Altona:850 Altona:1916 S24" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.197118076378
		SemiMajorAxis	3.000333891499
		Eccentricity	0.124504186775
		Inclination	15.543181043801
		AscendingNode	121.155909046967
		ArgOfPericenter	134.365725762874
		MeanAnomaly	300.062757838359
	}
	UniformRotation
	{
		Period	11.197
	}
	LunarLambert	0.5
	Albedo	0.039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=850"
}

#1_"851 Zeissia:Zeissia:1916 S26:1950 NS1:1950 PA1" "Sol" #1=
#2_"*Цейссия:851 Zeissia:Zeissia:1916 S26" "Sol" #2=
#3_"1916 S26:*Цейссия:851 Zeissia:Zeissia" "Sol" #3=
".:Zeissia:851 Zeissia:1916 S26" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"gaspra.jpg"
	Radius	6.13
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.325853875394
		SemiMajorAxis	2.228075866565
		Eccentricity	0.089939470719
		Inclination	2.391707210748
		AscendingNode	141.205639935245
		ArgOfPericenter	7.600372624889
		MeanAnomaly	283.396869483976
	}
	UniformRotation
	{
		Period	9.34
	}
	LunarLambert	0.5
	Albedo	0.2646
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=851"
}

#1_"852 Wladilena:Wladilena:1916 S27:A913 SB:A924 WJ" "Sol" #1=
#2_"*Владилена:852 Wladilena:Wladilena:1916 S27" "Sol" #2=
#3_"1916 S27:*Владилена:852 Wladilena:Wladilena" "Sol" #3=
".:Wladilena:852 Wladilena:1916 S27" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"852 wladilena.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.27
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.630693431382
		SemiMajorAxis	2.362223132758
		Eccentricity	0.275042919849
		Inclination	23.017571116028
		AscendingNode	27.308004152624
		ArgOfPericenter	282.371824685876
		MeanAnomaly	344.650626710332
	}
	UniformRotation
	{
		Period	4.6134
	}
	LunarLambert	0.5
	Albedo	0.225
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=852"
}

#1_"853 Nansenia:Nansenia:1916 S28:1930 FY:1930 GJ:1952 SR" "Sol" #1=
#2_"*Нансения:853 Nansenia:Nansenia:1916 S28" "Sol" #2=
#3_"1916 S28:*Нансения:853 Nansenia:Nansenia" "Sol" #3=
".:Nansenia:853 Nansenia:1916 S28" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.516154031943
		SemiMajorAxis	2.312276647498
		Eccentricity	0.105176367928
		Inclination	9.216571017128
		AscendingNode	182.869385216332
		ArgOfPericenter	59.919286004538
		MeanAnomaly	348.714659693389
	}
	UniformRotation
	{
		Period	7.931
	}
	LunarLambert	0.5
	Albedo	0.0511
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=853"
}

#1_"856 Backlunda:Backlunda:1916 S30:1955 PB:1955 QO1:1958 LA:1959 SQ:1962 MA:A908 CB" "Sol" #1=
#2_"*Баклунда:856 Backlunda:Backlunda:1916 S30" "Sol" #2=
#3_"1916 S30:Backlunda:*Баклунда:856 Backlunda" "Sol" #3=
".:Backlunda:856 Backlunda:1916 S30" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"856 backlunda.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	22.724
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.801616542072
		SemiMajorAxis	2.435791277684
		Eccentricity	0.118546217672
		Inclination	14.318763635293
		AscendingNode	125.573307941365
		ArgOfPericenter	73.07119861998
		MeanAnomaly	186.482632615188
	}
	UniformRotation
	{
		Period	12.08
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=856"
}

#1_"857 Glasenappia:Glasenappia:1916 S33:1953 YC:1958 HK:A906 FF:A913 MF" "Sol" #1=
#2_"*Глазенаппия:857 Glasenappia:Glasenappia:1916 S33" "Sol" #2=
#3_"1916 S33:*Глазенаппия:857 Glasenappia:Glasenappia" "Sol" #3=
".:Glasenappia:857 Glasenappia:1916 S33" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"857 glasenappia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.248
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.24129704195
		SemiMajorAxis	2.190149464036
		Eccentricity	0.088903434162
		Inclination	5.301086362416
		AscendingNode	82.96709932264
		ArgOfPericenter	238.641069647666
		MeanAnomaly	50.740163871764
	}
	UniformRotation
	{
		Period	8.2
	}
	LunarLambert	0.5
	Albedo	0.271
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=857"
}

#1_"858 El Djezair:El Djezair:1916 a:A908 UC:A911 HE" "Sol" #1=
#2_"*Эль Дьезар:858 El Djezair:El Djezair:1916 a" "Sol" #2=
#3_"1916 a:*Эль Дьезар:858 El Djezair:El Djezair" "Sol" #3=
".:El Djezair:858 El Djezair:1916 a" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.2595
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.712134616367
		SemiMajorAxis	2.810647130116
		Eccentricity	0.101542433236
		Inclination	8.873652628705
		AscendingNode	67.207684570155
		ArgOfPericenter	178.95906843899
		MeanAnomaly	336.930845122965
	}
	UniformRotation
	{
		Period	22.31
	}
	LunarLambert	0.5
	Albedo	0.375
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=858"
}

#1_"859 Bouzareah:Bouzareah:1916 c:1928 YA:A916 UN" "Sol" #1=
#2_"*Бузареа:859 Bouzareah:Bouzareah:1916 c" "Sol" #2=
#3_"1916 c:*Бузареа:859 Bouzareah:Bouzareah" "Sol" #3=
".:Bouzareah:859 Bouzareah:1916 c" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.985
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.796535635474
		SemiMajorAxis	3.226811072967
		Eccentricity	0.105803554325
		Inclination	13.510359468387
		AscendingNode	35.815920980771
		ArgOfPericenter	18.22620746967
		MeanAnomaly	339.765659639088
	}
	UniformRotation
	{
		Period	23.2
	}
	LunarLambert	0.5
	Albedo	0.0467
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=859"
}

#1_"860 Ursina:Ursina:1917 BD:1959 CU:A903 BB" "Sol" #1=
#2_"*Урсина:860 Ursina:Ursina:1917 BD" "Sol" #2=
#3_"1917 BD:*Урсина:860 Ursina:Ursina" "Sol" #3=
".:Ursina:860 Ursina:1917 BD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.66
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.677916250451
		SemiMajorAxis	2.797023788416
		Eccentricity	0.106235213563
		Inclination	13.321396445267
		AscendingNode	309.458420133061
		ArgOfPericenter	20.095111273729
		MeanAnomaly	123.003240069938
	}
	UniformRotation
	{
		Period	9.386
	}
	LunarLambert	0.5
	Albedo	0.1618
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=860"
}

#1_"861 Aida:Aida:1917 BE:1939 BL:1947 OF:1950 BW1:A906 BG:A918 GA" "Sol" #1=
#2_"*Аида:861 Aida:Aida:1917 BE" "Sol" #2=
#3_"1917 BE:*Аида:861 Aida:Aida" "Sol" #3=
".:Aida:861 Aida:1917 BE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.425
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.564668542778
		SemiMajorAxis	3.140176547522
		Eccentricity	0.102627241691
		Inclination	8.049450360825
		AscendingNode	115.038086266879
		ArgOfPericenter	194.106917706698
		MeanAnomaly	18.14764653261
	}
	UniformRotation
	{
		Period	10.95
	}
	LunarLambert	0.5
	Albedo	0.0571
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=861"
}

#1_"862 Franzia:Franzia:1917 BF:1948 TT1:1949 YT:A903 BA" "Sol" #1=
#2_"*Франция:862 Franzia:Franzia:1917 BF" "Sol" #2=
#3_"1917 BF:*Франция:862 Franzia:Franzia" "Sol" #3=
".:Franzia:862 Franzia:1917 BF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.63
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.692928675837
		SemiMajorAxis	2.803004753936
		Eccentricity	0.079808405693
		Inclination	13.89957035382
		AscendingNode	300.147030657962
		ArgOfPericenter	120.697245537902
		MeanAnomaly	354.190095086625
	}
	UniformRotation
	{
		Period	7.52
	}
	LunarLambert	0.5
	Albedo	0.1368
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=862"
}

#1_"863 Benkoela:Benkoela:1917 BH:1927 WD" "Sol" #1=
#2_"*Бенкоэла:863 Benkoela:Benkoela:1917 BH" "Sol" #2=
#3_"1917 BH:*Бенкоэла:863 Benkoela:Benkoela" "Sol" #3=
".:Benkoela:863 Benkoela:1917 BH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.53
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.731540583449
		SemiMajorAxis	3.202644838959
		Eccentricity	0.030151979332
		Inclination	25.42049187652
		AscendingNode	116.959953586517
		ArgOfPericenter	94.4643111634
		MeanAnomaly	310.873504525264
	}
	UniformRotation
	{
		Period	7.03
	}
	LunarLambert	0.5
	Albedo	0.5952
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=863"
}

#1_"865 Zubaida:Zubaida:1917 BO:1936 FK1:1970 GQ1:A908 WF" "Sol" #1=
#2_"*Зубаида:865 Zubaida:Zubaida:1917 BO" "Sol" #2=
#3_"1917 BO:*Зубаида:865 Zubaida:Zubaida" "Sol" #3=
".:Zubaida:865 Zubaida:1917 BO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.885
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.758234941595
		SemiMajorAxis	2.417225400217
		Eccentricity	0.194448053748
		Inclination	13.341121643737
		AscendingNode	177.073225098475
		ArgOfPericenter	301.561623897213
		MeanAnomaly	27.762105925749
	}
	UniformRotation
	{
		Period	11.3533
	}
	LunarLambert	0.5
	Albedo	0.0972
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=865"
}

#1_"866 Fatme:Fatme:1917 BQ:1950 DF1" "Sol" #1=
#2_"*Фатме:866 Fatme:Fatme:1917 BQ" "Sol" #2=
#3_"1917 BQ:*Фатме:866 Fatme:Fatme" "Sol" #3=
".:Fatme:866 Fatme:1917 BQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	44.155
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.520157274009
		SemiMajorAxis	3.123408822647
		Eccentricity	0.055353083523
		Inclination	8.648945944448
		AscendingNode	91.293779146576
		ArgOfPericenter	259.220066265863
		MeanAnomaly	41.641533898678
	}
	UniformRotation
	{
		Period	20.03
	}
	LunarLambert	0.5
	Albedo	0.0473
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=866"
}

#1_"867 Kovacia:Kovacia:1917 BS:1942 XF:1958 WA" "Sol" #1=
#2_"*Ковация:867 Kovacia:Kovacia:1917 BS" "Sol" #2=
#3_"1917 BS:*Ковация:867 Kovacia:Kovacia" "Sol" #3=
".:Kovacia:867 Kovacia:1917 BS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"867 kovacia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	12.056
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.366190376845
		SemiMajorAxis	3.065057191871
		Eccentricity	0.129164095529
		Inclination	5.976067966866
		AscendingNode	46.844955835725
		ArgOfPericenter	69.88318663787
		MeanAnomaly	106.861291021309
	}
	UniformRotation
	{
		Period	8.6772
	}
	LunarLambert	0.5
	Albedo	0.092
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=867"
}

#1_"868 Lova:Lova:1917 BU:1925 FB:1957 EO" "Sol" #1=
#2_"*Лова:868 Lova:Lova:1917 BU" "Sol" #2=
#3_"1917 BU:*Лова:868 Lova:Lova" "Sol" #3=
".:Lova:868 Lova:1917 BU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.441828643161
		SemiMajorAxis	2.70210610513
		Eccentricity	0.149487673545
		Inclination	5.838271782357
		AscendingNode	115.797305796705
		ArgOfPericenter	287.215966048082
		MeanAnomaly	140.278841418536
	}
	UniformRotation
	{
		Period	41.3
	}
	LunarLambert	0.5
	Albedo	0.0524
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=868"
}

#1_"869 Mellena:Mellena:1917 BV:1931 RC:1944 OB:1952 DL2" "Sol" #1=
#2_"*Меллена:869 Mellena:Mellena:1917 BV" "Sol" #2=
#3_"1917 BV:*Меллена:869 Mellena:Mellena" "Sol" #3=
".:Mellena:869 Mellena:1917 BV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.26
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.411551239188
		SemiMajorAxis	2.689812972048
		Eccentricity	0.219500605001
		Inclination	7.837155837771
		AscendingNode	154.923777110272
		ArgOfPericenter	107.287122583293
		MeanAnomaly	3.209121442972
	}
	UniformRotation
	{
		Period	6.5155
	}
	LunarLambert	0.5
	Albedo	0.0565
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=869"
}

#1_"870 Manto:Manto:1917 BX:1935 NB:1935 QV:1953 UE1:A907 TF:A914 UC" "Sol" #1=
#2_"*Манто:870 Manto:Manto:1917 BX" "Sol" #2=
#3_"1917 BX:Manto:*Манто:870 Manto" "Sol" #3=
".:Manto:870 Manto:1917 BX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"870 manto.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.842
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.538304968962
		SemiMajorAxis	2.321977676126
		Eccentricity	0.264513905466
		Inclination	6.191138794426
		AscendingNode	120.808477006921
		ArgOfPericenter	197.00788085826
		MeanAnomaly	9.437707399147
	}
	UniformRotation
	{
		Period	122.3
	}
	LunarLambert	0.5
	Albedo	0.216
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=870"
}

#1_"872 Holda:Holda:1917 BZ:1948 EE:1949 OD1:A900 SA:A913 NA:A916 AB" "Sol" #1=
#2_"*Хольда:872 Holda:Holda:1917 BZ" "Sol" #2=
#3_"1917 BZ:*Хольда:872 Holda:Holda" "Sol" #3=
".:Holda:872 Holda:1917 BZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"872 holda.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	17.216
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.512794816297
		SemiMajorAxis	2.730810665658
		Eccentricity	0.080285035404
		Inclination	7.36911342246
		AscendingNode	194.79373476831
		ArgOfPericenter	18.184638031026
		MeanAnomaly	236.581909063697
	}
	UniformRotation
	{
		Period	5.945
	}
	LunarLambert	0.5
	Albedo	0.165
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=872"
}

#1_"873 Mechthild:Mechthild:1917 CA1*" "Sol" #1=
#2_"*Мечтилд:873 Mechthild:Mechthild:1917 CA1*" "Sol" #2=
#3_"1917 CA1*:*Мечтилд:873 Mechthild:Mechthild" "Sol" #3=
".:Mechthild:873 Mechthild:1917 CA1*" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"873 mechthild.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	17.236
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.258179896172
		SemiMajorAxis	2.627103614597
		Eccentricity	0.148214391091
		Inclination	5.274026036125
		AscendingNode	150.046430320661
		ArgOfPericenter	110.100065269362
		MeanAnomaly	305.281962399051
	}
	UniformRotation
	{
		Period	11.006
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=873"
}

#1_"874 Rotraut:Rotraut:1917 CC:1976 WJ" "Sol" #1=
#2_"*Ротраут:874 Rotraut:Rotraut:1917 CC" "Sol" #2=
#3_"1917 CC:*Ротраут:874 Rotraut:Rotraut" "Sol" #3=
".:Rotraut:874 Rotraut:1917 CC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"874 rotraut.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	29.144
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.59903646123
		SemiMajorAxis	3.153092626386
		Eccentricity	0.079021852709
		Inclination	11.147318591681
		AscendingNode	190.690509279221
		ArgOfPericenter	11.422441630012
		MeanAnomaly	177.741219841583
	}
	UniformRotation
	{
		Period	14.586
	}
	LunarLambert	0.5
	Albedo	0.054
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=874"
}

#1_"875 Nymphe:Nymphe:1917 CF:1926 RL:1970 GC1:1971 UK4:A917 KF" "Sol" #1=
#2_"*Нимфея:875 Nymphe:Nymphe:1917 CF" "Sol" #2=
#3_"1917 CF:*Нимфея:875 Nymphe:Nymphe" "Sol" #3=
".:Nymphe:875 Nymphe:1917 CF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"875 nymphe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.054
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.078087049755
		SemiMajorAxis	2.552498681409
		Eccentricity	0.151351218633
		Inclination	14.574559517617
		AscendingNode	196.099718105212
		ArgOfPericenter	117.482978663363
		MeanAnomaly	258.247328198322
	}
	UniformRotation
	{
		Period	12.618
	}
	LunarLambert	0.5
	Albedo	0.223
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=875"
}

#1_"876 Scott:Scott:1917 CH:1936 DR:1952 BQ" "Sol" #1=
#2_"*Скотт:876 Scott:Scott:1917 CH" "Sol" #2=
#3_"1917 CH:*Скотт:876 Scott:Scott" "Sol" #3=
".:Scott:876 Scott:1917 CH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.224658898611
		SemiMajorAxis	3.010924229135
		Eccentricity	0.112133562499
		Inclination	11.359315402909
		AscendingNode	150.965194778408
		ArgOfPericenter	211.721665807188
		MeanAnomaly	157.565133104218
	}
	UniformRotation
	{
		Period	14
	}
	LunarLambert	0.5
	Albedo	0.1626
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=876"
}

#1_"877 Walkure:Walkure:1915 S7:A909 GC" "Sol" #1=
#2_"*Валькирия:877 Walkure:Walkure:1915 S7" "Sol" #2=
#3_"1915 S7:*Валькирия:877 Walkure:Walkure" "Sol" #3=
".:Walkure:877 Walkure:1915 S7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"877 walkure.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	19.205
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.924666889612
		SemiMajorAxis	2.488072700453
		Eccentricity	0.159414117935
		Inclination	4.25605795151
		AscendingNode	116.405005470722
		ArgOfPericenter	276.236004891989
		MeanAnomaly	79.595923089905
	}
	UniformRotation
	{
		Period	17.424
	}
	LunarLambert	0.5
	Albedo	0.0623
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=877"
}

#1_"881 Athene:Athene:1917 CL" "Sol" #1=
#2_"*Афина:881 Athene:Athene:1917 CL" "Sol" #2=
#3_"1917 CL:Athene:*Афина:881 Athene" "Sol" #3=
".:Athene:881 Athene:1917 CL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"881 athene.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.076
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.222957662278
		SemiMajorAxis	2.612596556383
		Eccentricity	0.206607340294
		Inclination	14.184674078821
		AscendingNode	277.124499178035
		ArgOfPericenter	41.19369885132
		MeanAnomaly	201.445167958634
	}
	UniformRotation
	{
		Period	13.895
	}
	LunarLambert	0.5
	Albedo	0.237
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=881"
}

#1_"882 Swetlana:Swetlana:1917 CM:1967 TQ" "Sol" #1=
#2_"*Светлана:882 Swetlana:Swetlana:1917 CM" "Sol" #2=
#3_"1917 CM:*Светлана:882 Swetlana:Swetlana" "Sol" #3=
".:Swetlana:882 Swetlana:1917 CM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	21.22
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.522733708957
		SemiMajorAxis	3.124380610634954
		Eccentricity	0.2659696769796295
		Inclination	6.124648363898906
		AscendingNode	256.3254492593988
		ArgOfPericenter	126.7187001185251
		MeanAnomaly	154.4692148013134
	}
	UniformRotation
	{
		Period	20
	}
	LunarLambert	0.5
	Albedo	0.062
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=882"
}

#1_"884 Priamus:Priamus:1917 CQ:1929 XX:1938 KE" "Sol" #1=
#2_"*Приам:884 Priamus:Priamus:1917 CQ" "Sol" #2=
#3_"1917 CQ:*Приам:884 Priamus:Priamus" "Sol" #3=
".:Priamus:884 Priamus:1917 CQ" "Sol" #4=
{
	Class	"asteroid" # New - троянский астероид Юпитера L5

	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	50.5465
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	11.796994412513
		SemiMajorAxis	5.182135696259
		Eccentricity	0.121554313105
		Inclination	8.913900969278
		AscendingNode	301.55775880579
		ArgOfPericenter	335.630741164936
		MeanAnomaly	207.452673435222
	}
	UniformRotation
	{
		Period	6.8605
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=884"
}

#1_"885 Ulrike:Ulrike:1917 CX:1933 QQ:1934 XL:A906 SE" "Sol" #1=
#2_"*Ульрика:885 Ulrike:Ulrike:1917 CX" "Sol" #2=
#3_"1917 CX:*Ульрика:885 Ulrike:Ulrike" "Sol" #3=
".:Ulrike:885 Ulrike:1917 CX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"885 ulrike.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	15.268
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.441925641475
		SemiMajorAxis	3.093828724631
		Eccentricity	0.187506699584
		Inclination	3.304232867864
		AscendingNode	149.052013158749
		ArgOfPericenter	204.521123163203
		MeanAnomaly	315.345122738937
	}
	UniformRotation
	{
		Period	4.9
	}
	LunarLambert	0.5
	Albedo	0.109
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=885"
}

#1_"886 Washingtonia:Washingtonia:1917 b:1945 WA:1952 BN:A910 LA:A916 NA:A917 UD" "Sol" #1=
#2_"*Вашингтония:886 Washingtonia:Washingtonia:1917 b" "Sol" #2=
#3_"1917 b:*Вашингтония:886 Washingtonia:Washingtonia" "Sol" #3=
".:Washingtonia:886 Washingtonia:1917 b" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	45.28
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.676221050584
		SemiMajorAxis	3.182004077287
		Eccentricity	0.265282813954
		Inclination	16.801681021074
		AscendingNode	59.381745178954
		ArgOfPericenter	301.295592302812
		MeanAnomaly	113.471166964267
	}
	UniformRotation
	{
		Period	9.001
	}
	LunarLambert	0.5
	Albedo	0.0713
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=886"
}

#1_"887 Alinda:Alinda:1918 DB" "Sol" #1=
#2_"*Алинда:887 Alinda:Alinda:1918 DB" "Sol" #2=
#3_"1918 DB:*Алинда:887 Alinda:Alinda" "Sol" #3=
".:Alinda:887 Alinda:1918 DB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.901884092099
		SemiMajorAxis	2.478434474103
		Eccentricity	0.56745853157
		Inclination	9.359372430223
		AscendingNode	110.552154392264
		ArgOfPericenter	350.338396572435
		MeanAnomaly	149.366711977212
	}
	UniformRotation
	{
		Period	73.97
	}
	LunarLambert	0.5
	Albedo	0.31
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=887"
}

#1_"888 Parysatis:Parysatis:1918 DC:A906 JA:A908 YL:A915 JD" "Sol" #1=
#2_"*Парисатида:888 Parysatis:Parysatis:1918 DC" "Sol" #2=
#3_"1918 DC:*Парисатида:888 Parysatis:Parysatis" "Sol" #3=
".:Parysatis:888 Parysatis:1918 DC" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	22.325
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.463066248288
		SemiMajorAxis	2.710712264749
		Eccentricity	0.192039731509
		Inclination	13.847271236063
		AscendingNode	124.157934931529
		ArgOfPericenter	297.37929903135
		MeanAnomaly	293.158387222036
	}
	UniformRotation
	{
		Period	5.9314
	}
	LunarLambert	0.5
	Albedo	0.1392
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=888"
}

#1_"889 Erynia:Erynia:1918 DG:1929 BG:A912 PA" "Sol" #1=
#2_"*Эриния:889 Erynia:Erynia:1918 DG" "Sol" #2=
#3_"1918 DG:*Эриния:889 Erynia:Erynia" "Sol" #3=
".:Erynia:889 Erynia:1918 DG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"889 erynia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.341
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.826988271976
		SemiMajorAxis	2.446616795209
		Eccentricity	0.203795304519
		Inclination	8.100074447353
		AscendingNode	132.712003659704
		ArgOfPericenter	277.725368602184
		MeanAnomaly	239.944430337123
	}
	UniformRotation
	{
		Period	9.89
	}
	LunarLambert	0.5
	Albedo	0.23
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=889"
}

#1_"890 Waltraut:Waltraut:1918 DK:A908 GA" "Sol" #1=
#2_"*Вальтраут:890 Waltraut:Waltraut:1918 DK" "Sol" #2=
#3_"1918 DK:*Вальтраут:890 Waltraut:Waltraut" "Sol" #3=
".:Waltraut:890 Waltraut:1918 DK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"890 waltraut.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	14.188
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.255762589618
		SemiMajorAxis	3.022862256422
		Eccentricity	0.059163245375
		Inclination	10.871322118766
		AscendingNode	160.683554237658
		ArgOfPericenter	90.529189452977
		MeanAnomaly	61.725161364751
	}
	UniformRotation
	{
		Period	12.581
	}
	LunarLambert	0.5
	Albedo	0.121
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=890"
}

#1_"891 Gunhild:Gunhild:1918 DQ:1977 FH:1999 CF154:A915 VE" "Sol" #1=
#2_"*Гунхильд:891 Gunhild:Gunhild:1918 DQ" "Sol" #2=
#3_"1918 DQ:*Гунхильд:891 Gunhild:Gunhild" "Sol" #3=
".:Gunhild:891 Gunhild:1918 DQ:1977 FH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.975
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.834624363148
		SemiMajorAxis	2.859146152552
		Eccentricity	0.03042153928
		Inclination	13.557846016501
		AscendingNode	105.87437927205
		ArgOfPericenter	295.014006966022
		MeanAnomaly	182.364109873696
	}
	UniformRotation
	{
		Period	7.93
	}
	LunarLambert	0.5
	Albedo	0.0718
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=891"
}

#1_"892 Seeligeria:Seeligeria:1918 DR:1952 HY" "Sol" #1=
#2_"*Зеелигерия:892 Seeligeria:Seeligeria:1918 DR" "Sol" #2=
#3_"1918 DR:*Зеелигерия:892 Seeligeria:Seeligeria" "Sol" #3=
".:Seeligeria:892 Seeligeria:1918 DR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38.01
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.798174855016
		SemiMajorAxis	3.227419390628
		Eccentricity	0.101254232445
		Inclination	21.319464912118
		AscendingNode	175.952653989641
		ArgOfPericenter	287.717873733578
		MeanAnomaly	341.322151435729
	}
	UniformRotation
	{
		Period	41.4
	}
	LunarLambert	0.5
	Albedo	0.0485
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=892"
}

#1_"893 Leopoldina:Leopoldina:1918 DS:1935 OL" "Sol" #1=
#2_"*Леопольдина:893 Leopoldina:Leopoldina:1918 DS" "Sol" #2=
#3_"1918 DS:*Леопольдина:893 Leopoldina:Leopoldina" "Sol" #3=
".:Leopoldina:893 Leopoldina:1918 DS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38.07
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.327617764681
		SemiMajorAxis	3.050351619107
		Eccentricity	0.150001927771
		Inclination	17.019589450166
		AscendingNode	145.05491226518
		ArgOfPericenter	223.201287997568
		MeanAnomaly	281.095406102649
	}
	UniformRotation
	{
		Period	14.115
	}
	LunarLambert	0.5
	Albedo	0.0497
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=893"
}

#1_"894 Erda:Erda:1918 DT:1973 QB:A907 JC:A912 HD" "Sol" #1=
#2_"*Эрда:894 Erda:Erda:1918 DT" "Sol" #2=
#3_"1918 DT:*Эрда:894 Erda:Erda" "Sol" #3=
".:Erda:894 Erda:1918 DT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	18.27
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.507054626953
		SemiMajorAxis	3.118464382554
		Eccentricity	0.113041082707
		Inclination	12.694837955749
		AscendingNode	190.796757362481
		ArgOfPericenter	114.232345709732
		MeanAnomaly	154.661939189896
	}
	UniformRotation
	{
		Period	4.6897
	}
	LunarLambert	0.5
	Albedo	0.23
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=894"
}

#1_"895 Helio:Helio:1918 DU:A906 MB" "Sol" #1=
#2_"*Гелио:895 Helio:Helio:1918 DU" "Sol" #2=
#3_"1918 DU:*Гелио:895 Helio:Helio" "Sol" #3=
".:Helio:895 Helio:1918 DU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	70.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.726519581209
		SemiMajorAxis	3.200774156848
		Eccentricity	0.146110680106
		Inclination	26.08577426567
		AscendingNode	264.707931447142
		ArgOfPericenter	178.111047422318
		MeanAnomaly	137.998891022437
	}
	UniformRotation
	{
		Period	9.3959
	}
	LunarLambert	0.5
	Albedo	0.042
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=895"
}

#1_"896 Sphinx:Sphinx:1918 DV" "Sol" #1=
#2_"*Сфинкс:896 Sphinx:Sphinx:1918 DV" "Sol" #2=
#3_"1918 DV:*Сфинкс:896 Sphinx:Sphinx" "Sol" #3=
".:Sphinx:896 Sphinx:1918 DV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.535
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.455131138623
		SemiMajorAxis	2.285445602839
		Eccentricity	0.163183909543
		Inclination	8.18784525368
		AscendingNode	254.208522869947
		ArgOfPericenter	2.045765399145
		MeanAnomaly	1.109446367517
	}
	UniformRotation
	{
		Period	26.27
	}
	LunarLambert	0.5
	Albedo	0.1971
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=896"
}

#1_"897 Lysistrata:Lysistrata:1918 DZ:1950 KJ:1970 KA" "Sol" #1=
#2_"*Лисистрата:897 Lysistrata:Lysistrata:1918 DZ" "Sol" #2=
#3_"1918 DZ:*Лисистрата:897 Lysistrata:Lysistrata" "Sol" #3=
".:Lysistrata:897 Lysistrata:1950 KJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.955
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.050889670657
		SemiMajorAxis	2.541137363133
		Eccentricity	0.094196054828
		Inclination	14.32787837274
		AscendingNode	257.987727961569
		ArgOfPericenter	24.516046899313
		MeanAnomaly	301.879633637176
	}
	UniformRotation
	{
		Period	11.26
	}
	LunarLambert	0.5
	Albedo	0.2619
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=897"
}

#1_"898 Hildegard:Hildegard:1918 EA:1936 PA" "Sol" #1=
#2_"*Хильдегард:898 Hildegard:Hildegard:1918 EA" "Sol" #2=
#3_"1918 EA:Hildegard:*Хильдегард:898 Hildegard" "Sol" #3=
".:Hildegard:898 Hildegard:1918 EA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"898 hildegard.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.846
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.513203012694
		SemiMajorAxis	2.730975336749
		Eccentricity	0.371158887057
		Inclination	10.085924792108
		AscendingNode	241.563654557474
		ArgOfPericenter	49.749158335799
		MeanAnomaly	315.593950978252
	}
	UniformRotation
	{
		Period	24.855
	}
	LunarLambert	0.5
	Albedo	0.205
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=898"
}

#1_"899 Jokaste:Jokaste:1918 EB:1953 TL2" "Sol" #1=
#2_"*Джокаста:899 Jokaste:Jokaste:1918 EB" "Sol" #2=
#3_"1918 EB:*Джокаста:899 Jokaste:Jokaste" "Sol" #3=
".:Jokaste:899 Jokaste:1918 EB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.845
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.965329609473
		SemiMajorAxis	2.910448511557
		Eccentricity	0.198651772201
		Inclination	12.459069250004
		AscendingNode	252.544804976233
		ArgOfPericenter	127.739947600087
		MeanAnomaly	110.491711670576
	}
	UniformRotation
	{
		Period	6.245
	}
	LunarLambert	0.5
	Albedo	0.2026
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=899"
}

#1_"900 Rosalinde:Rosalinde:1918 EC" "Sol" #1=
#2_"*Розалинда (астероид):900 Rosalinde:Rosalinde:1918 EC" "Sol" #2=
#3_"1918 EC:*Розалинда (астероид):900 Rosalinde:Rosalinde" "Sol" #3=
".:Rosalinde:900 Rosalinde:1918 EC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"900 rosalinde.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	9.809
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.888975514223
		SemiMajorAxis	2.472965196516
		Eccentricity	0.162938371119
		Inclination	11.562785669578
		AscendingNode	182.301268188445
		ArgOfPericenter	122.131523509866
		MeanAnomaly	286.318709053307
	}
	UniformRotation
	{
		Period	16.648
	}
	LunarLambert	0.5
	Albedo	0.085
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=900"
}

#1_"903 Nealley:Nealley:1918 EM:1927 DB:1930 SC1:1935 QO:1936 TJ:1941 QG:1947 QC:1951 GE1:1951 JE: #1=
#1_1952 KK:1952 MO:1960 WU:A918 WC:A924 SD" "Sol" #1=
#2_"*Нилли:903 Nealley:Nealley:1918 EM" "Sol" #2=
#3_"1918 EM:*Нилли:903 Nealley:Nealley" "Sol" #3=
".:Nealley:903 Nealley:1918 EM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.715
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.832330221944
		SemiMajorAxis	3.240081507341
		Eccentricity	0.043882017402
		Inclination	11.778569873255
		AscendingNode	159.40241115009
		ArgOfPericenter	236.25111229179
		MeanAnomaly	127.077824501199
	}
	UniformRotation
	{
		Period	21.6
	}
	LunarLambert	0.5
	Albedo	0.0528
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=903"
}

#1_"904 Rockefellia:Rockefellia:1918 EO:1949 UK:1961 AK:A913 UD:A916 KC" "Sol" #1=
#2_"*Рокфеллия:904 Rockefellia:Rockefellia:1918 EO" "Sol" #2=
#3_"1918 EO:*Рокфеллия:904 Rockefellia:Rockefellia" "Sol" #3=
".:Rockefellia:904 Rockefellia:1918 EO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.375
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.178268269456
		SemiMajorAxis	2.993074745612
		Eccentricity	0.089125254347
		Inclination	15.160240964885
		AscendingNode	198.154662336135
		ArgOfPericenter	251.274432223806
		MeanAnomaly	157.889350997293
	}
	UniformRotation
	{
		Period	5.82
	}
	LunarLambert	0.5
	Albedo	0.0561
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=904"
}

#1_"905 Universitas:Universitas:1918 ES:1961 WE" "Sol" #1=
#2_"*Университас:905 Universitas:Universitas:1918 ES" "Sol" #2=
#3_"1918 ES:*Университас:905 Universitas:Universitas" "Sol" #3=
".:Universitas:905 Universitas:1918 ES" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"gaspra.jpg"
	Radius	6.035
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.299153809159
		SemiMajorAxis	2.216135142281
		Eccentricity	0.152767071552
		Inclination	5.323585837108
		AscendingNode	37.226726603835
		ArgOfPericenter	343.122732510611
		MeanAnomaly	61.262396942435
	}
	UniformRotation
	{
		Period	14.238
	}
	LunarLambert	0.5
	Albedo	0.280
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=905"
}

#1_"907 Rhoda:Rhoda:1918 EU:A901 BA:A913 SC" "Sol" #1=
#2_"*Рода:907 Rhoda:Rhoda:1918 EU" "Sol" #2=
#3_"1918 EU:*Рода:907 Rhoda:Rhoda" "Sol" #3=
".:Rhoda:907 Rhoda:1918 EU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.687289573873
		SemiMajorAxis	2.800758878927
		Eccentricity	0.160837787119
		Inclination	19.559182620256
		AscendingNode	43.130706093907
		ArgOfPericenter	87.562873168827
		MeanAnomaly	123.938154849892
	}
	UniformRotation
	{
		Period	22.44
	}
	LunarLambert	0.5
	Albedo	0.056
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=907"
}

#1_"908 Buda:Buda:1918 EX:1963 ME" "Sol" #1=
#2_"*Буда:908 Buda:Buda:1918 EX" "Sol" #2=
#3_"1918 EX:*Буда:908 Buda:Buda" "Sol" #3=
".:Buda:908 Buda:1918 EX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"908 buda.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	15.374
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.890611491385
		SemiMajorAxis	2.473658683523
		Eccentricity	0.146787325309
		Inclination	13.40705783933
		AscendingNode	85.606733794667
		ArgOfPericenter	23.570127877721
		MeanAnomaly	210.502325797203
	}
	UniformRotation
	{
		Period	14.572
	}
	LunarLambert	0.5
	Albedo	0.087
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=908"
}

#1_"909 Ulla:Ulla:1919 FA:1936 SJ:1949 OF1:1949 PW:1966 BU:1966 DM:A912 CA" "Sol" #1=
#2_"*Улла:909 Ulla:Ulla:1919 FA" "Sol" #2=
#3_"1919 FA:*Улла:909 Ulla:Ulla" "Sol" #3=
".:Ulla:909 Ulla:1919 FA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58.22
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.674840653404
		SemiMajorAxis	3.545045389209
		Eccentricity	0.090334112735
		Inclination	18.790462221758
		AscendingNode	146.372769123536
		ArgOfPericenter	233.709230619267
		MeanAnomaly	244.016601611361
	}
	UniformRotation
	{
		Period	8.73
	}
	LunarLambert	0.5
	Albedo	0.0343
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=909"
}

#1_"910 Anneliese:Anneliese:1919 FB:1946 SJ:1975 AH:A924 BD" "Sol" #1=
#2_"*Аннализа:910 Anneliese:Anneliese:1919 FB" "Sol" #2=
#3_"1919 FB:*Аннализа:910 Anneliese:Anneliese" "Sol" #3=
".:Anneliese:910 Anneliese:1919 FB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.535
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.005467924946
		SemiMajorAxis	2.926112281724
		Eccentricity	0.152962877295
		Inclination	9.208951397293
		AscendingNode	49.955712500883
		ArgOfPericenter	208.121811921676
		MeanAnomaly	307.59561957226
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0605
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=910"
}

#1_"911 Agamemnon:Agamemnon:1919 FD:1937 QD" "Sol" #1=
#2_"*Агамемнон:911 Agamemnon:Agamemnon:1919 FD" "Sol" #2=
#3_"1919 FD:*Агамемнон:911 Agamemnon:Agamemnon" "Sol" #3=
".:Agamemnon:911 Agamemnon:1919 FD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	83.33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.103348676278
		SemiMajorAxis	5.2714678438
		Eccentricity	0.06655487655
		Inclination	21.764736448615
		AscendingNode	338.031627478576
		ArgOfPericenter	81.724228013429
		MeanAnomaly	137.394154302528
	}
	UniformRotation
	{
		Period	6.592
	}
	LunarLambert	0.5
	Albedo	0.0444
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=911"
}

#1_"912 Maritima:Maritima:1919 FJ:1930 GA:1930 MO:A911 WB" "Sol" #1=
#2_"*Маритима:912 Maritima:Maritima:1919 FJ" "Sol" #2=
#3_"1919 FJ:*Маритима:912 Maritima:Maritima" "Sol" #3=
".:Maritima:912 Maritima:1919 FJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	41.585
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.549666412876
		SemiMajorAxis	3.134530146003
		Eccentricity	0.175675632252
		Inclination	18.340644890325
		AscendingNode	34.051083849735
		ArgOfPericenter	88.772411170407
		MeanAnomaly	175.828870195741
	}
	UniformRotation
	{
		Period	1332
	}
	LunarLambert	0.5
	Albedo	0.1115
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=912"
}

#1_"914 Palisana:Palisana:1919 FN:A904 PB:A916 WC" "Sol" #1=
#2_"*Пализана:914 Palisana:Palisana:1919 FN" "Sol" #2=
#3_"1919 FN:*Пализана:914 Palisana:Palisana" "Sol" #3=
".:Palisana:914 Palisana:1919 FN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38.305
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.852401065602
		SemiMajorAxis	2.457435878671
		Eccentricity	0.214573276963
		Inclination	25.20623378173
		AscendingNode	255.806082581504
		ArgOfPericenter	49.17961166908
		MeanAnomaly	277.671308184298
	}
	UniformRotation
	{
		Period	15.922
	}
	LunarLambert	0.5
	Albedo	0.0943
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=914"
}

#1_"915 Cosette:Cosette:1918 b:1933 FB2" "Sol" #1=
#2_"*Козетта:915 Cosette:Cosette:1918 b" "Sol" #2=
#3_"1918 b:*Козетта:915 Cosette:Cosette" "Sol" #3=
".:Cosette:915 Cosette:1918 b" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"915 cosette.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	5.8495
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.324882660807
		SemiMajorAxis	2.227642084205
		Eccentricity	0.139237698473
		Inclination	5.545708030443
		AscendingNode	9.351950298265
		ArgOfPericenter	39.473519609947
		MeanAnomaly	41.231228964157
	}
	UniformRotation
	{
		Period	4.445
	}
	LunarLambert	0.5
	Albedo	0.255
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=915"
}

#1_"916 America:America:1915 S1" "Sol" #1=
#2_"*Америка:916 America:America:1915 S1" "Sol" #2=
#3_"1915 S1:*Америка:916 America:America" "Sol" #3=
".:America:916 America:1915 S1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.615
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.639072093661
		SemiMajorAxis	2.365855986095
		Eccentricity	0.235650265844
		Inclination	11.094829957641
		AscendingNode	329.806771477039
		ArgOfPericenter	41.664028524455
		MeanAnomaly	83.187111921546
	}
	UniformRotation
	{
		Period	38
	}
	LunarLambert	0.5
	Albedo	0.053
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=916"
}

#1_"917 Lyka:Lyka:1915 S4:1950 BS:1951 JJ" "Sol" #1=
#2_"*Лика:917 Lyka:Lyka:1915 S4" "Sol" #2=
#3_"1915 S4:*Лика:917 Lyka:Lyka" "Sol" #3=
".:Lyka:917 Lyka:1915 S4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.674134762774
		SemiMajorAxis	2.381028458798
		Eccentricity	0.201492081062
		Inclination	5.134090160883
		AscendingNode	343.455767060335
		ArgOfPericenter	359.437378088089
		MeanAnomaly	6.048064101786
	}
	UniformRotation
	{
		Period	7.92
	}
	LunarLambert	0.5
	Albedo	0.0891
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=917"
}

#1_"918 Itha:Itha:1919 FR:1943 PB:A907 CA" "Sol" #1=
#2_"*Ита:918 Itha:Itha:1919 FR" "Sol" #2=
#3_"1919 FR:*Ита:918 Itha:Itha" "Sol" #3=
".:Itha:918 Itha:1919 FR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"918 itha.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.78
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.848330121451
		SemiMajorAxis	2.864547230452
		Eccentricity	0.189532754852
		Inclination	12.066504528875
		AscendingNode	330.468475368099
		ArgOfPericenter	15.79121792425
		MeanAnomaly	69.82877244471
	}
	UniformRotation
	{
		Period	3.4739
	}
	LunarLambert	0.5
	Albedo	0.224
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=918"
}

#1_"919 Ilsebill:Ilsebill:1918 EQ:1935 JG:1950 RP:1950 SE:1950 TN:1972 MA" "Sol" #1=
#2_"*Ильзебилл:919 Ilsebill:Ilsebill:1918 EQ" "Sol" #2=
#3_"1918 EQ:*Ильзебилл:919 Ilsebill:Ilsebill" "Sol" #3=
".:Ilsebill:919 Ilsebill:1918 EQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.825
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.617120931949
		SemiMajorAxis	2.772737131277
		Eccentricity	0.084696712584
		Inclination	8.157465573218
		AscendingNode	229.887534953592
		ArgOfPericenter	154.078767369467
		MeanAnomaly	309.925254857629
	}
	UniformRotation
	{
		Period	5.0325
	}
	LunarLambert	0.5
	Albedo	0.0698
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=919"
}

#1_"920 Rogeria:Rogeria:1919 FT:1973 QC" "Sol" #1=
#2_"*Рогерия:920 Rogeria:Rogeria:1919 FT" "Sol" #2=
#3_"1919 FT:*Рогерия:920 Rogeria:Rogeria" "Sol" #3=
".:Rogeria:920 Rogeria:1919 FT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"920 rogeria.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	13.328
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.245231066186
		SemiMajorAxis	2.621775018302
		Eccentricity	0.106736566133
		Inclination	11.580779672912
		AscendingNode	192.837348360552
		ArgOfPericenter	268.864616299546
		MeanAnomaly	57.940526495405
	}
	UniformRotation
	{
		Period	8.09
	}
	LunarLambert	0.5
	Albedo	0.076
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=920"
}

#1_"921 Jovita:Jovita:1919 FV:1976 WM" "Sol" #1=
#2_"*Иовита:921 Jovita:Jovita:1919 FV" "Sol" #2=
#3_"1919 FV:*Иовита:921 Jovita:Jovita" "Sol" #3=
".:Jovita:921 Jovita:1919 FV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.24
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.647364223494
		SemiMajorAxis	3.17121045029
		Eccentricity	0.183002920155
		Inclination	16.333295113986
		AscendingNode	204.930000439427
		ArgOfPericenter	70.832902212709
		MeanAnomaly	342.146441271686
	}
	UniformRotation
	{
		Period	15.64
	}
	LunarLambert	0.5
	Albedo	0.0297
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=921"
}

#1_"923 Herluga:Herluga:1919 GB:A915 VD" "Sol" #1=
#2_"*Герлуга:923 Herluga:Herluga:1919 GB" "Sol" #2=
#3_"1919 GB:*Герлуга:923 Herluga:Herluga" "Sol" #3=
".:Herluga:923 Herluga:1919 GB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.224987213758
		SemiMajorAxis	2.61343356447
		Eccentricity	0.197001135087
		Inclination	14.478044868723
		AscendingNode	197.62742253398
		ArgOfPericenter	201.27386725439
		MeanAnomaly	161.971836896863
	}
	UniformRotation
	{
		Period	19.746
	}
	LunarLambert	0.5
	Albedo	0.0421
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=923"
}

#1_"924 Toni:Toni:1919 GC:A906 BA:A914 UD" "Sol" #1=
#2_"*Тони:924 Toni:Toni:1919 GC" "Sol" #2=
#3_"1919 GC:*Тони:924 Toni:Toni" "Sol" #3=
".:Toni:924 Toni:1919 GC" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	42.745
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.035203037532
		SemiMajorAxis	2.937689269167
		Eccentricity	0.157174151657
		Inclination	8.994535966315
		AscendingNode	150.49290276077
		ArgOfPericenter	218.981999374865
		MeanAnomaly	325.500752763576
	}
	UniformRotation
	{
		Period	21.1
	}
	LunarLambert	0.5
	Albedo	0.0432
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=924"
}

#1_"925 Alphonsina:Alphonsina:1920 GM:A902 ED" "Sol" #1=
#2_"*Альфонсина:925 Alphonsina:Alphonsina:1920 GM" "Sol" #2=
#3_"1920 GM:*Альфонсина:925 Alphonsina:Alphonsina" "Sol" #3=
".:Alphonsina:925 Alphonsina:1920 GM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"925 alphonsina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	28.752
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.439072108518
		SemiMajorAxis	2.700988064146
		Eccentricity	0.078898075515
		Inclination	21.078195183975
		AscendingNode	299.608638974719
		ArgOfPericenter	201.087257302108
		MeanAnomaly	118.340479644309
	}
	UniformRotation
	{
		Period	7.88
	}
	LunarLambert	0.5
	Albedo	0.248
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=925"
}

#1_"926 Imhilde:Imhilde:1920 GN:1931 GB:1964 WB" "Sol" #1=
#2_"*Имхильда:926 Imhilde:Imhilde:1920 GN" "Sol" #2=
#3_"1920 GN:*Имхильда:926 Imhilde:Imhilde" "Sol" #3=
".:Imhilde:926 Imhilde:1920 GN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.24
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.153143577807
		SemiMajorAxis	2.983385403048
		Eccentricity	0.181135214548
		Inclination	16.32781878296
		AscendingNode	49.022621976104
		ArgOfPericenter	174.047549747442
		MeanAnomaly	74.265690368184
	}
	UniformRotation
	{
		Period	26.8
	}
	LunarLambert	0.5
	Albedo	0.057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=926"
}

#1_"927 Ratisbona:Ratisbona:1920 GO:1958 VD:1958 XQ" "Sol" #1=
#2_"*Ратисбона:927 Ratisbona:Ratisbona:1920 GO" "Sol" #2=
#3_"1920 GO:*Ратисбона:927 Ratisbona:Ratisbona" "Sol" #3=
".:Ratisbona:927 Ratisbona:1920 GO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.792909975258
		SemiMajorAxis	3.225465379467
		Eccentricity	0.086034407329
		Inclination	14.58089673165
		AscendingNode	7.797891577868
		ArgOfPericenter	169.597722577712
		MeanAnomaly	109.336160681819
	}
	UniformRotation
	{
		Period	12.994
	}
	LunarLambert	0.5
	Albedo	0.0591
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=927"
}

#1_"928 Hildrun:Hildrun:1920 GP:1959 EE1" "Sol" #1=
#2_"*Хильдрун:928 Hildrun:Hildrun:1920 GP" "Sol" #2=
#3_"1920 GP:*Хильдрун:928 Hildrun:Hildrun" "Sol" #3=
".:Hildrun:928 Hildrun:1920 GP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"928 hildrun.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	31.408
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.548592545014
		SemiMajorAxis	3.134125775781
		Eccentricity	0.149926027544
		Inclination	17.657342180782
		AscendingNode	129.86029578478
		ArgOfPericenter	21.849221500974
		MeanAnomaly	14.095076709851
	}
	UniformRotation
	{
		Period	14.13
	}
	LunarLambert	0.5
	Albedo	0.053
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=928"
}

#1_"930 Westphalia:Westphalia:1920 GS:A916 DD" "Sol" #1=
#2_"*Вестфалия:930 Westphalia:Westphalia:1920 GS" "Sol" #2=
#3_"1920 GS:*Вестфалия:930 Westphalia:Westphalia" "Sol" #3=
".:Westphalia:930 Westphalia:1920 GS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.24
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.791597486625
		SemiMajorAxis	2.431509755221
		Eccentricity	0.142937800622
		Inclination	15.334604129785
		AscendingNode	340.994565550545
		ArgOfPericenter	330.275044195798
		MeanAnomaly	232.068833443443
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0366
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=930"
}

#1_"931 Whittemora:Whittemora:1920 GU:A904 HB " "Sol" #1=
#2_"*Уайтмора:931 Whittemora:Whittemora:1920 GU" "Sol" #2=
#3_"1920 GU:*Уайтмора:931 Whittemora:Whittemora" "Sol" #3=
".:Whittemora:931 Whittemora:1920 GU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	22.635
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.658093942771
		SemiMajorAxis	3.175225943885
		Eccentricity	0.226695091525
		Inclination	11.474242058263
		AscendingNode	111.379285410885
		ArgOfPericenter	314.935908143788
		MeanAnomaly	352.210358436907
	}
	UniformRotation
	{
		Period	19.199
	}
	LunarLambert	0.5
	Albedo	0.1704
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=931"
}

#1_"933 Susi:Susi:1927 CH:1938 DD1:1938 ET" "Sol" #1=
#2_"*Сюзи:933 Susi:Susi:1927 CH" "Sol" #2=
#3_"1927 CH:*Сюзи:933 Susi:Susi" "Sol" #3=
".:Susi:933 Susi:1927 CH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.91
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.643790844803
		SemiMajorAxis	2.36790073341
		Eccentricity	0.165686830146
		Inclination	5.539284555195
		AscendingNode	141.483552594996
		ArgOfPericenter	12.996023409297
		MeanAnomaly	26.620570164584
	}
	UniformRotation
	{
		Period	4.6222
	}
	LunarLambert	0.5
	Albedo	0.0707
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=933"
}

#1_"934 Thuringia:Thuringia:1920 HK:1952 OP:1974 HP3" "Sol" #1=
#2_"*Тюрингия:934 Thuringia:Thuringia:1920 HK" "Sol" #2=
#3_"1920 HK:*Тюрингия:934 Thuringia:Thuringia" "Sol" #3=
".:Thuringia:934 Thuringia:1920 HK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"934 thuringia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	26.857
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.551731076733
		SemiMajorAxis	2.74649573363
		Eccentricity	0.21907158894
		Inclination	14.074340176492
		AscendingNode	325.515280489852
		ArgOfPericenter	64.421420370968
		MeanAnomaly	200.751372120919
	}
	UniformRotation
	{
		Period	8.166
	}
	LunarLambert	0.5
	Albedo	0.047
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=934"
}

#1_"935 Clivia:Clivia:1920 HM:1950 UB" "Sol" #1=
#2_"*Кливия:935 Clivia:Clivia:1920 HM" "Sol" #2=
#3_"1920 HM:*Кливия:935 Clivia:Clivia" "Sol" #3=
".:Clivia:935 Clivia:1920 HM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"gaspra.jpg"
	Radius	3.935
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.30429868109
		SemiMajorAxis	2.21843851476
		Eccentricity	0.146532519712
		Inclination	4.025396138136
		AscendingNode	346.507029576696
		ArgOfPericenter	58.098041187903
		MeanAnomaly	139.864565728406
	}
	UniformRotation
	{
		Period	3.6222
	}
	LunarLambert	0.5
	Albedo	0.1974
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=935"
}

#1_"936 Kunigunde:Kunigunde:1920 HN:1930 KD:1930 KR:1931 TO2:1942 RD1:1984 BK7:A913 HA:A921 WD" "Sol" #1=
#2_"*Кунигунда:936 Kunigunde:Kunigunde:1920 HN" "Sol" #2=
#3_"1920 HN:*Кунигунда:936 Kunigunde:Kunigunde" "Sol" #3=
".:Kunigunde:936 Kunigunde:1920 HN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"936 kunigunde.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	21.6135
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.542163256269
		SemiMajorAxis	3.131704249621
		Eccentricity	0.177644790138
		Inclination	2.368902713225
		AscendingNode	62.188196401242
		ArgOfPericenter	254.45083578158
		MeanAnomaly	12.05440616024
	}
	UniformRotation
	{
		Period	8.8
	}
	LunarLambert	0.5
	Albedo	0.065
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=936"
}

#1_"938 Chlosinde:Chlosinde:1920 HQ:1948 RJ" "Sol" #1=
#2_"*Хлосинда:938 Chlosinde:Chlosinde:1920 HQ" "Sol" #2=
#3_"1920 HQ:*Хлосинда:938 Chlosinde:Chlosinde" "Sol" #3=
".:Chlosinde:938 Chlosinde:1920 HQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	16.733
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.589133313567
		SemiMajorAxis	3.149373563386
		Eccentricity	0.19501233684
		Inclination	2.669283731541
		AscendingNode	119.069711813777
		ArgOfPericenter	226.314755008692
		MeanAnomaly	272.692704831681
	}
	UniformRotation
	{
		Period	19.204
	}
	LunarLambert	0.5
	Albedo	0.046
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=938"
}

#1_"940 Kordula:Kordula:1920 HT:1947 BG:1947 EB:1954 DB:1963 PC" "Sol" #1=
#2_"*Кордула:940 Kordula:Kordula:1920 HT" "Sol" #2=
#3_"1920 HT:*Кордула:940 Kordula:Kordula" "Sol" #3=
".:Kordula:940 Kordula:1920 HT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	43.605
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.15699657311
		SemiMajorAxis	3.359235668965
		Eccentricity	0.176592483789
		Inclination	6.213426676308
		AscendingNode	67.146687773963
		ArgOfPericenter	279.452825572926
		MeanAnomaly	86.439048499845
	}
	UniformRotation
	{
		Period	15.57
	}
	LunarLambert	0.5
	Albedo	0.0352
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=940"
}

#1_"943 Begonia:Begonia:1920 HX:1944 DM:1947 RC:1977 FU" "Sol" #1=
#2_"*Бегония:943 Begonia:Begonia:1920 HX" "Sol" #2=
#3_"1920 HX:*Бегония:943 Begonia:Begonia" "Sol" #3=
".:Begonia:943 Begonia:1920 HX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"943 begonia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	35.286
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.502543370263
		SemiMajorAxis	3.116761098835
		Eccentricity	0.212075335045
		Inclination	12.110374530796
		AscendingNode	113.856009092625
		ArgOfPericenter	4.650425668578
		MeanAnomaly	311.675805355349
	}
	UniformRotation
	{
		Period	15.66
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=943"
}

#1_"944 Hidalgo:Hidalgo:1920 HZ" "Sol" #1=
#2_"*Идальго:944 Hidalgo:Hidalgo:1920 HZ" "Sol" #2=
#3_"1920 HZ:*Идальго:944 Hidalgo:Hidalgo" "Sol" #3=
".:Hidalgo:944 Hidalgo:1920 HZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"944 hidalgo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	19
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	13.739778443768
		SemiMajorAxis	5.736509075001
		Eccentricity	0.661566644171
		Inclination	42.524542158253
		AscendingNode	21.476151931062
		ArgOfPericenter	56.732593409771
		MeanAnomaly	258.359031756844
	}
	UniformRotation
	{
		Period	10.063
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=944"
}

#1_"945 Barcelona:Barcelona:1921 JB" "Sol" #1=
#2_"*Барселона:945 Barcelona:Barcelona:1921 JB" "Sol" #2=
#3_"1921 JB:*Барселона:945 Barcelona:Barcelona" "Sol" #3=
".:Barcelona:945 Barcelona:1921 JB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.735
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.277565789525
		SemiMajorAxis	2.635071053969
		Eccentricity	0.163454580696
		Inclination	32.900625930527
		AscendingNode	318.305536351442
		ArgOfPericenter	162.310186611204
		MeanAnomaly	336.866736728662
	}
	UniformRotation
	{
		Period	7.36
	}
	LunarLambert	0.5
	Albedo	0.2416
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=945"
}

#1_"946 Poesia:Poesia:1921 JC:1959 AA:A911 KB" "Sol" #1=
#2_"*Поэзия:946 Poesia:Poesia:1921 JC" "Sol" #2=
#3_"1921 JC:*Поэзия:946 Poesia:Poesia" "Sol" #3=
".:Poesia:946 Poesia:1921 JC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	21.875
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.508542511164
		SemiMajorAxis	3.119026050612
		Eccentricity	0.144351706768
		Inclination	1.431524129929
		AscendingNode	69.67386210387
		ArgOfPericenter	38.687007578127
		MeanAnomaly	31.166900806652
	}
	UniformRotation
	{
		Period	108.5
	}
	LunarLambert	0.5
	Albedo	0.0627
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=946"
}

#1_"947 Monterosa:Monterosa:1921 JD:1940 GA1:1958 FF:A906 YK:A910 UA:A919 SF:A919 UD" "Sol" #1=
#2_"*Монтероса:947 Monterosa:Monterosa:1921 JD" "Sol" #2=
#3_"1921 JD:*Монтероса:947 Monterosa:Monterosa" "Sol" #3=
".:Monterosa:947 Monterosa:1921 JD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.565350266959
		SemiMajorAxis	2.751971513983
		Eccentricity	0.25004957883
		Inclination	6.706783892216
		AscendingNode	48.356440507317
		ArgOfPericenter	338.216538265282
		MeanAnomaly	291.890313657434
	}
	UniformRotation
	{
		Period	5.164
	}
	LunarLambert	0.5
	Albedo	0.2937
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=947"
}

#1_"949 Hel:Hel:1921 JK:1952 DN:1954 SN1" "Sol" #1=
#2_"*Хель:949 Hel:Hel:1921 JK" "Sol" #2=
#3_"1921 JK:*Хель:949 Hel:Hel" "Sol" #3=
".:Hel:949 Hel:1921 JK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.585
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.204793742935
		SemiMajorAxis	3.003287310058
		Eccentricity	0.192555125632
		Inclination	10.702227344888
		AscendingNode	321.206694083141
		ArgOfPericenter	249.093062654883
		MeanAnomaly	340.103731611398
	}
	UniformRotation
	{
		Period	10.862
	}
	LunarLambert	0.5
	Albedo	0.0487
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=949"
}

#1_"950 Ahrensa:Ahrensa:1921 JP:1955 SU2:1974 VG3:A904 RF" "Sol" #1=
#2_"*Аренса:950 Ahrensa:Ahrensa:1921 JP" "Sol" #2=
#3_"1921 JP:*Аренса:950 Ahrensa:Ahrensa" "Sol" #3=
".:Ahrensa:950 Ahrensa:1921 JP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.515
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.652353571856
		SemiMajorAxis	2.371608914563
		Eccentricity	0.158453097115
		Inclination	23.473939307504
		AscendingNode	181.813987604396
		ArgOfPericenter	348.353247324259
		MeanAnomaly	250.960360879865
	}
	UniformRotation
	{
		Period	202
	}
	LunarLambert	0.5
	Albedo	0.1793
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=950"
}

#1_"951 Gaspra:Gaspra:1916 S45:1955 MG1:A913 YA" "Sol" #1=
#2_"*Гаспра:951 Gaspra:Gaspra:1916 S45" "Sol" #2=
#3_"1916 S45:*Гаспра:951 Gaspra:Gaspra" "Sol" #3=
".:Gaspra:951 Gaspra:1916 S45" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"951 gaspra.cmod"
	MeshCenter	[ 1.540 -0.064 -0.118 ]
	Texture	"gaspra.jpg"
	Radius	9.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2448558.5  # 1991 Oct 29
		Period	3.2846479784353
		SemiMajorAxis	2.209634387508869
		Eccentricity	0.1738754270123919
		Inclination	4.097577988971894
		AscendingNode	253.4454444531708
		ArgOfPericenter	129.0460702731027
		MeanAnomaly	280.6191587386546
	}
	UniformRotation
	{
		Period	7.042073
		Inclination	69.28
		AscendingNode	109.59
		MeridianAngle	58.865
	}
	LunarLambert	0.5
	Albedo	0.22
	InfoURL	"https://en.wikipedia.org/wiki/951_Gaspra"
}

AltSurface "Limit of knowledge" "Sol/951 Gaspra"
{
	Texture	"gaspra-lok.jpg"
	Color	[ 0.85 0.71 0.56 ]
	BlendTexture	true
	LunarLambert	0.5
}

AltSurface "Geology" "Sol/951 Gaspra"
{
	Texture	"gaspra-geol.jpg"
	LunarLambert	0.5
}

#1_"952 Caia:Caia:1916 S61:1973 WH:A908 EB:A919 GB:A921 RA" "Sol" #1=
#2_"*Гаия:952 Caia:Caia:1916 S61" "Sol" #2=
#3_"1916 S61:*Гаия:952 Caia:Caia" "Sol" #3=
".:Caia:952 Caia:1916 S61" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.165373970736
		SemiMajorAxis	2.988104018919
		Eccentricity	0.246695225933
		Inclination	10.03383703389
		AscendingNode	18.599239207403
		ArgOfPericenter	354.635346960629
		MeanAnomaly	9.404935934932
	}
	UniformRotation
	{
		Period	7.51
	}
	LunarLambert	0.5
	Albedo	0.0554
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=952"
}

#1_"953 Painleva:Painleva:1921 JT:A913 UE" "Sol" #1=
#2_"*Пенлева:953 Painleva:Painleva:1921 JT" "Sol" #2=
#3_"1921 JT:*Пенлева:953 Painleva:Painleva" "Sol" #3=
".:Painleva:953 Painleva:1921 JT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.165
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.65175622249
		SemiMajorAxis	2.786586293854
		Eccentricity	0.19015173397
		Inclination	8.665824650086
		AscendingNode	36.438851752053
		ArgOfPericenter	260.067177994615
		MeanAnomaly	339.490390806347
	}
	UniformRotation
	{
		Period	7.389
	}
	LunarLambert	0.5
	Albedo	0.167
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=953"
}

#1_"954 Li:Li:1921 JU:1943 PE:1952 BE2:A905 UN:A920 GC" "Sol" #1=
#2_"*Ли:954 Li:Li:1921 JU" "Sol" #2=
#3_"1921 JU:*Ли:954 Li:Li" "Sol" #3=
".:Li:954 Li:1921 JU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	29.015
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.537266366862
		SemiMajorAxis	3.129859257826
		Eccentricity	0.172082334966
		Inclination	1.16921033708
		AscendingNode	163.243844182877
		ArgOfPericenter	151.604158331868
		MeanAnomaly	287.601620581105
	}
	UniformRotation
	{
		Period	7.207
	}
	LunarLambert	0.5
	Albedo	0.0555
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=954"
}

#1_"955 Alstede:Alstede:1921 JV:1946 OF:1955 TY:1966 DF" "Sol" #1=
#2_"*Альстеда:955 Alstede:Alstede:1921 JV" "Sol" #2=
#3_"1921 JV:*Альстеда:955 Alstede:Alstede" "Sol" #3=
".:Alstede:955 Alstede:1921 JV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"955 alstede.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.665
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.182928301751
		SemiMajorAxis	2.596060517361
		Eccentricity	0.287305669697
		Inclination	10.688211975098
		AscendingNode	351.481202746707
		ArgOfPericenter	282.462317267206
		MeanAnomaly	28.515365072981
	}
	UniformRotation
	{
		Period	5.19
	}
	LunarLambert	0.5
	Albedo	0.2135
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=955"
}

#1_"957 Camelia:Camelia:1921 JX:1932 AG:1958 BM" "Sol" #1=
#2_"*Камелия:957 Camelia:Camelia" "Sol" #2=
#3_"1921 JX:*Камелия:957 Camelia" "Sol" #3=
".:Camelia:957 Camelia:1921 JX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.865
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.988744267304
		SemiMajorAxis	2.919591067892
		Eccentricity	0.082448148255
		Inclination	14.792935124581
		AscendingNode	232.894319922012
		ArgOfPericenter	222.698235787485
		MeanAnomaly	166.106122993846
	}
	UniformRotation
	{
		Period	150
	}
	LunarLambert	0.5
	Albedo	0.0429
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=957"
}

#1_"958 Asplinda:Asplinda:1921 KC" "Sol" #1=
#2_"*Асплинда:958 Asplinda:Asplinda:1921 KC" "Sol" #2=
#3_"1921 KC:*Асплинда:958 Asplinda:Asplinda" "Sol" #3=
".:Asplinda:958 Asplinda:1921 KC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"958 asplinda.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	22.558
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.966315734822
		SemiMajorAxis	3.988713795481
		Eccentricity	0.186746786073
		Inclination	5.629856363699
		AscendingNode	343.152044185377
		ArgOfPericenter	92.882202570949
		MeanAnomaly	265.099035840709
	}
	UniformRotation
	{
		Period	25.3
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=958"
}

#1_"959 Arne:Arne:1921 KF:1927 YD:1952 DD2:1960 OF:A916 YB" "Sol" #1=
#2_"*Арне:959 Arne:Arne:1921 KF" "Sol" #2=
#3_"1921 KF:*Арне:959 Arne:Arne" "Sol" #3=
".:Arne:959 Arne:1921 KF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.71
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.682145680102
		SemiMajorAxis	3.18421786437
		Eccentricity	0.218141189613
		Inclination	4.492220423639
		AscendingNode	58.62910435345
		ArgOfPericenter	333.89881471041
		MeanAnomaly	98.614203343624
	}
	UniformRotation
	{
		Period	123.7
	}
	LunarLambert	0.5
	Albedo	0.0446
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=959"
}

#1_"961 Gunnie:Gunnie:1921 KM:1930 XT:1968 HO" "Sol" #1=
#2_"*Гунни:961 Gunnie:Gunnie:1921 KM" "Sol" #2=
#3_"1921 KM:*Гунни:961 Gunnie:Gunnie" "Sol" #3=
".:Gunnie:961 Gunnie:1921 KM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.91
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.417681554898
		SemiMajorAxis	2.692304247826
		Eccentricity	0.092581675338
		Inclination	10.987253982717
		AscendingNode	26.683050333583
		ArgOfPericenter	284.174011994939
		MeanAnomaly	97.165941246661
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0373
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=961"
}

#1_"965 Angelica:Angelica:1921 KT:1977 PM2" "Sol" #1=
#2_"*Анжелика:965 Angelica:Angelica:1921 KT" "Sol" #2=
#3_"1921 KT:*Анжелика:965 Angelica:Angelica" "Sol" #3=
".:Angelica:965 Angelica:1921 KT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.815
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.598094990725
		SemiMajorAxis	3.152739157603
		Eccentricity	0.283370996736
		Inclination	21.462130130091
		AscendingNode	41.488502347936
		ArgOfPericenter	46.799027484538
		MeanAnomaly	170.789275277512
	}
	UniformRotation
	{
		Period	17.772
	}
	LunarLambert	0.5
	Albedo	0.0739
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=965"
}

#1_"966 Muschi:Muschi:1921 KU" "Sol" #1=
#2_"*Муски:966 Muschi:Muschi:1921 KU" "Sol" #2=
#3_"1921 KU:*Муски:966 Muschi:Muschi" "Sol" #3=
".:Muschi:966 Muschi:1921 KU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	11.715
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.482107964351
		SemiMajorAxis	2.718416979555
		Eccentricity	0.131328724694
		Inclination	14.408333187579
		AscendingNode	72.444744428446
		ArgOfPericenter	178.42015052882
		MeanAnomaly	83.571634307986
	}
	UniformRotation
	{
		Period	5.355
	}
	LunarLambert	0.5
	Albedo	0.3497
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=966"
}

#1_"967 Helionape:Helionape:1921 KV:A922 AB" "Sol" #1=
#2_"*Гелионапе:967 Helionape:Helionape:1921 KV" "Sol" #2=
#3_"1921 KV:*Гелионапе:967 Helionape:Helionape" "Sol" #3=
".:Helionape:967 Helionape:1921 KV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"gaspra.jpg"
	Radius	5.985
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.319197131478
		SemiMajorAxis	2.225101856865
		Eccentricity	0.168809002665
		Inclination	5.414989142738
		AscendingNode	82.428116711708
		ArgOfPericenter	231.566268472856
		MeanAnomaly	101.138168175435
	}
	UniformRotation
	{
		Period	3.234
	}
	LunarLambert	0.5
	Albedo	0.1782
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=967"
}

#1_"968 Petunia:Petunia:1921 KW:1935 QK1:1948 KC" "Sol" #1=
#2_"*Петуния:968 Petunia:Petunia:1921 KW" "Sol" #2=
#3_"1921 KW:*Петуния:968 Petunia:Petunia" "Sol" #3=
".:Petunia:968 Petunia:1921 KW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"968 petunia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	12.211
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.8517813079135
		SemiMajorAxis	2.865906449520422
		Eccentricity	0.1379284281555813
		Inclination	11.59232473120878
		AscendingNode	208.9085131592233
		ArgOfPericenter	297.9483563612096
		MeanAnomaly	329.0330345778076
	}
	UniformRotation
	{
		Period	61.28
	}
	LunarLambert	0.5
	Albedo	0.233
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=968"
}

#1_"969 Leocadia:Leocadia:1921 KZ:1940 RV:1944 SB:1948 UG:1963 PA" "Sol" #1=
#2_"*Леокадия:969 Leocadia:Leocadia:1921 KZ" "Sol" #2=
#3_"1921 KZ:*Леокадия:969 Leocadia:Leocadia" "Sol" #3=
".:Leocadia:969 Leocadia:1921 KZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.755
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.865332121649
		SemiMajorAxis	2.462931929859
		Eccentricity	0.204202262608
		Inclination	2.295676876221
		AscendingNode	287.967517635819
		ArgOfPericenter	90.969440800447
		MeanAnomaly	49.688207937287
	}
	UniformRotation
	{
		Period	6.87
	}
	LunarLambert	0.5
	Albedo	0.0435
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=969"
}

#1_"971 Alsatia:Alsatia:1921 LF:1961 AA:A908 UE" "Sol" #1=
#2_"*Альсатия:971 Alsatia:Alsatia:1921 LF" "Sol" #2=
#3_"1921 LF:*Альсатия:971 Alsatia:Alsatia" "Sol" #3=
".:Alsatia:971 Alsatia:1921 LF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.875
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.294071709107
		SemiMajorAxis	2.641845365792
		Eccentricity	0.160636800733
		Inclination	13.774461850159
		AscendingNode	83.573934346776
		ArgOfPericenter	5.975708329134
		MeanAnomaly	217.312142241332
	}
	UniformRotation
	{
		Period	9.614
	}
	LunarLambert	0.5
	Albedo	0.0415
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=971"
}

#1_"972 Cohnia:Cohnia:1922 LK:1926 XC:A906 BB:A912 EA:A917 DC" "Sol" #1=
#2_"*Кония:972 Cohnia:Cohnia:1922 LK" "Sol" #2=
#3_"1922 LK:*Кония:972 Cohnia:Cohnia" "Sol" #3=
".:Cohnia:972 Cohnia:1922 LK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	37.825
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.342023575277
		SemiMajorAxis	3.055847885284
		Eccentricity	0.234871686217
		Inclination	8.371416549448
		AscendingNode	281.531420648646
		ArgOfPericenter	93.940873428495
		MeanAnomaly	183.421881647744
	}
	UniformRotation
	{
		Period	18.472
	}
	LunarLambert	0.5
	Albedo	0.0489
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=972"
}

#1_"973 Aralia:Aralia:1922 LR:1954 SE" "Sol" #1=
#2_"*Аралия:973 Aralia:Aralia:1922 LR" "Sol" #2=
#3_"1922 LR:*Аралия:973 Aralia:Aralia" "Sol" #3=
".:Aralia:973 Aralia:1922 LR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.756485094327
		SemiMajorAxis	3.211930367224
		Eccentricity	0.112232384861
		Inclination	15.829065888211
		AscendingNode	348.459540343956
		ArgOfPericenter	88.782819581951
		MeanAnomaly	80.125632631002
	}
	UniformRotation
	{
		Period	7.29
	}
	LunarLambert	0.5
	Albedo	0.0959
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=973"
}

#1_"974 Lioba:Lioba:1922 LS:1930 DA1:A906 FG:A916 UO" "Sol" #1=
#2_"*Лиоба:974 Lioba:Lioba:1922 LS" "Sol" #2=
#3_"1922 LS:*Лиоба:974 Lioba:Lioba" "Sol" #3=
".:Lioba:974 Lioba:1922 LS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.195
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.034161043461
		SemiMajorAxis	2.534136587986
		Eccentricity	0.111030672996
		Inclination	5.457020418099
		AscendingNode	86.701480701062
		ArgOfPericenter	302.623777219623
		MeanAnomaly	118.588523240274
	}
	UniformRotation
	{
		Period	38.7
	}
	LunarLambert	0.5
	Albedo	0.3965
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=974"
}

#1_"975 Perseverantia:Perseverantia:1922 LT:1950 CK:A912 CB" "Sol" #1=
#2_"*Персеверанция:975 Perseverantia:Perseverantia:1922 LT" "Sol" #2=
#3_"1922 LT:*Персеверанция:975 Perseverantia:Perseverantia" "Sol" #3=
".:Perseverantia:975 Perseverantia:1922 LT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"ida.jpg"
	Radius	13.245
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.772114947932
		SemiMajorAxis	2.834447795343
		Eccentricity	0.031070314376
		Inclination	2.559414351169
		AscendingNode	38.72069556236
		ArgOfPericenter	55.90772502793
		MeanAnomaly	242.078448877243
	}
	UniformRotation
	{
		Period	7.267
	}
	LunarLambert	0.5
	Albedo	0.1726
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=975"
}

#1_"976 Benjamina:Benjamina:1922 LU:A910 AB" "Sol" #1=
#2_"*Бенджамина:976 Benjamina:Benjamina:1922 LU" "Sol" #2=
#3_"1922 LU:*Бенджамина:976 Benjamina:Benjamina" "Sol" #3=
".:Benjamina:976 Benjamina:1922 LU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.726006672883
		SemiMajorAxis	3.200583031075
		Eccentricity	0.101219001011
		Inclination	7.71182447535
		AscendingNode	243.791855693375
		ArgOfPericenter	318.614980841506
		MeanAnomaly	60.449400419892
	}
	UniformRotation
	{
		Period	9.746
	}
	LunarLambert	0.5
	Albedo	0.0559
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=976"
}

#1_"977 Philippa:Philippa:1922 LV:A914 YA:A919 XA" "Sol" #1=
#2_"*Филиппа:977 Philippa:Philippa:1922 LV" "Sol" #2=
#3_"1922 LV:*Филиппа:977 Philippa:Philippa" "Sol" #3=
".:Philippa:977 Philippa:1922 LV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32.835
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.510662548657
		SemiMajorAxis	3.119826265681
		Eccentricity	0.02820687035
		Inclination	15.174166458116
		AscendingNode	75.811861988293
		ArgOfPericenter	74.432138285252
		MeanAnomaly	355.38899544653
	}
	UniformRotation
	{
		Period	15.405
	}
	LunarLambert	0.5
	Albedo	0.0555
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=977"
}

#1_"978 Aidamina:Aidamina:1922 LY:1929 YA:1946 QD:1966 BD:A906 VB:A923 YA" "Sol" #1=
#2_"*Айдамина:978 Aidamina:Aidamina:1922 LY" "Sol" #2=
#3_"1922 LY:*Айдамина:978 Aidamina:Aidamina" "Sol" #3=
".:Aidamina:978 Aidamina:1922 LY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	39.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.723036614514
		SemiMajorAxis	3.199476181697
		Eccentricity	0.234467433041
		Inclination	21.641035942893
		AscendingNode	216.637712792264
		ArgOfPericenter	133.036236918506
		MeanAnomaly	341.344893538356
	}
	UniformRotation
	{
		Period	10.099
	}
	LunarLambert	0.5
	Albedo	0.0365
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=978"
}

#1_"979 Ilsewa:Ilsewa:1922 MC:1932 EG1:1951 TW:1966 HO:A916 KD:A923 XB" "Sol" #1=
#2_"*Ильсева:979 Ilsewa:Ilsewa:1922 MC" "Sol" #2=
#3_"1922 MC:*Ильсева:979 Ilsewa:Ilsewa" "Sol" #3=
".:Ilsewa:979 Ilsewa:1922 MC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"979 ilsewa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	17.87
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.631889467252
		SemiMajorAxis	3.165414690729
		Eccentricity	0.134323567522
		Inclination	10.079577896959
		AscendingNode	231.09270121842
		ArgOfPericenter	113.58540759306
		MeanAnomaly	134.035687037843
	}
	UniformRotation
	{
		Period	42.61
	}
	LunarLambert	0.5
	Albedo	0.166
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=979"
}

#1_"980 Anacostia:Anacostia:1921 W19:A917 YC" "Sol" #1=
#2_"*Анакостия:980 Anacostia:Anacostia:1921 W19" "Sol" #2=
#3_"1921 W19:*Анакостия:980 Anacostia:Anacostia" "Sol" #3=
".:Anacostia:980 Anacostia:1921 W19" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	43.095
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.534599112504
		SemiMajorAxis	2.739599832285
		Eccentricity	0.202422693801
		Inclination	15.906112403033
		AscendingNode	285.824172741573
		ArgOfPericenter	70.20306659454
		MeanAnomaly	186.984344050348
	}
	UniformRotation
	{
		Period	20.117
	}
	LunarLambert	0.5
	Albedo	0.1723
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=980"
}

#1_"981 Martina:Martina:1917 S92:1928 TG:1942 EY:1949 MF:1953 FG:1959 GF:1959 JF:1966 QA:A906 SD" "Sol" #1=
#2_"*Мартина:981 Martina:Martina:1917 S92" "Sol" #2=
#3_"1917 S92:*Мартина:981 Martina:Martina" "Sol" #3=
".:Martina:981 Martina:1917 S92" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	16.2725
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.445310837551
		SemiMajorAxis	3.095111619942
		Eccentricity	0.20382985756
		Inclination	2.065679077734
		AscendingNode	46.088734576013
		ArgOfPericenter	298.646824132622
		MeanAnomaly	306.669862311924
	}
	UniformRotation
	{
		Period	11.267
	}
	LunarLambert	0.5
	Albedo	0.106
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=981"
}

#1_"982 Franklina:Franklina:1922 MD:1928 QF:1938 HG" "Sol" #1=
#2_"*Франклина:982 Franklina:Franklina:1922 MD" "Sol" #2=
#3_"1922 MD:*Франклина:982 Franklina:Franklina" "Sol" #3=
".:Franklina:982 Franklina:1922 MD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	16.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.373481097416
		SemiMajorAxis	3.067832769686
		Eccentricity	0.234206643807
		Inclination	13.646903173283
		AscendingNode	299.20366502
		ArgOfPericenter	351.2842663442
		MeanAnomaly	27.83417690765
	}
	UniformRotation
	{
		Period	16
	}
	LunarLambert	0.5
	Albedo	0.1838
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=982"
}

#1_"983 Gunila:Gunila:1922 ME:1934 SE:1940 TF:1944 LA:1949 JB:1955 HV" "Sol" #1=
#2_"*Гунила:983 Gunila:Gunila:1922 ME" "Sol" #2=
#3_"1922 ME:*Гунила:983 Gunila:Gunila" "Sol" #3=
".:Gunila:983 Gunila:1922 ME" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.935
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.612450306122
		SemiMajorAxis	3.158126614603
		Eccentricity	0.094584076409
		Inclination	14.871285521435
		AscendingNode	250.895232134807
		ArgOfPericenter	348.449179838876
		MeanAnomaly	218.331276597615
	}
	UniformRotation
	{
		Period	8.37
	}
	LunarLambert	0.5
	Albedo	0.0477
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=983"
}

#1_"984 Gretia:Gretia:1922 MH:1973 LC:A910 BA:A915 DA" "Sol" #1=
#2_"*Гретия:984 Gretia:Gretia:1922 MH" "Sol" #2=
#3_"1922 MH:*Гретия:984 Gretia:Gretia" "Sol" #3=
".:Gretia:984 Gretia:1922 MH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"984 gretia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	16.224
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.690598059492
		SemiMajorAxis	2.802076652676
		Eccentricity	0.197541692456
		Inclination	9.093712430886
		AscendingNode	314.219275255543
		ArgOfPericenter	55.6755418802
		MeanAnomaly	215.0521227089
	}
	UniformRotation
	{
		Period	5.778
	}
	LunarLambert	0.5
	Albedo	0.421
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=984"
}

#1_"986 Amelia:Amelia:1922 MQ:1935 BK:1966 VA:A915 JC" "Sol" #1=
#2_"*Амелия:986 Amelia:Amelia:1922 MQ" "Sol" #2=
#3_"1922 MQ:*Амелия:986 Amelia:Amelia" "Sol" #3=
".:Amelia:986 Amelia:1922 MQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"986 amelia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	24.338
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.544360718675
		SemiMajorAxis	3.132532006744
		Eccentricity	0.202028442418
		Inclination	14.813745173706
		AscendingNode	92.608009962406
		ArgOfPericenter	265.88529191216
		MeanAnomaly	215.03065238835
	}
	UniformRotation
	{
		Period	9.52
	}
	LunarLambert	0.5
	Albedo	0.218
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=986"
}

#1_"987 Wallia:Wallia:1922 MR:A899 PJ" "Sol" #1=
#2_"*Валлия:987 Wallia:Wallia:1922 MR" "Sol" #2=
#3_"1922 MR:*Валлия:987 Wallia:Wallia" "Sol" #3=
".:Wallia:987 Wallia:1922 MR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	21.835
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.564031778848
		SemiMajorAxis	3.139936989762
		Eccentricity	0.234830260717
		Inclination	8.908982669359
		AscendingNode	322.681447979714
		ArgOfPericenter	16.261721897087
		MeanAnomaly	215.822017132341
	}
	UniformRotation
	{
		Period	10.0813
	}
	LunarLambert	0.5
	Albedo	0.1765
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=987"
}

#1_"988 Appella:Appella:1922 MT:1955 QJ1" "Sol" #1=
#2_"*Аппелла:988 Appella:Appella:1922 MT" "Sol" #2=
#3_"1922 MT:*Аппелла:988 Appella:Appella" "Sol" #3=
".:Appella:988 Appella:1922 MT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	12.955
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.568315602027
		SemiMajorAxis	3.141548436278
		Eccentricity	0.2355080125
		Inclination	1.575102209598
		AscendingNode	41.728645495032
		ArgOfPericenter	337.399721014627
		MeanAnomaly	166.794732364194
	}
	UniformRotation
	{
		Period	120
	}
	LunarLambert	0.5
	Albedo	0.0871
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=988"
}

#1_"989 Schwassmannia:Schwassmannia:1922 MW:1935 UE:1935 UF" "Sol" #1=
#2_"*Швассмания:989 Schwassmannia:Schwassmannia:1922 MW" "Sol" #2=
#3_"1922 MW:*Швассмания:989 Schwassmannia:Schwassmannia" "Sol" #3=
".:Schwassmannia:989 Schwassmannia:1922 MW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.43
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.339230111277
		SemiMajorAxis	2.660334947115
		Eccentricity	0.25053227471
		Inclination	14.694229479043
		AscendingNode	243.438773606855
		ArgOfPericenter	165.982031664535
		MeanAnomaly	79.838487649748
	}
	UniformRotation
	{
		Period	107.85
	}
	LunarLambert	0.5
	Albedo	0.2035
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=989"
}

#1_"990 Yerkes:Yerkes:1922 MZ:1961 VB1:A913 UA" "Sol" #1=
#2_"*Йеркс:990 Yerkes:Yerkes:1922 MZ" "Sol" #2=
#3_"1922 MZ:*Йеркс:990 Yerkes:Yerkes" "Sol" #3=
".:Yerkes:990 Yerkes:1922 MZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	9.23
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.364345781791
		SemiMajorAxis	2.670590499941
		Eccentricity	0.214805060323
		Inclination	8.779384523308
		AscendingNode	354.01020776616
		ArgOfPericenter	8.963347345362
		MeanAnomaly	82.09674038071
	}
	UniformRotation
	{
		Period	24.56
	}
	LunarLambert	0.5
	Albedo	0.1303
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=990"
}

#1_"991 McDonalda:McDonalda:1922 NB:1949 PF:1950 WG:1953 GT1:1975 EE6" "Sol" #1=
#2_"*МакДональда:991 McDonalda:McDonalda:1922 NB" "Sol" #2=
#3_"1922 NB:*МакДональда:991 McDonalda:McDonalda" "Sol" #3=
".:McDonalda:991 McDonalda:1922 NB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	15.705
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.567239267661
		SemiMajorAxis	3.141143590274
		Eccentricity	0.157499797824
		Inclination	2.069758941295
		AscendingNode	63.257485137546
		ArgOfPericenter	254.720964871669
		MeanAnomaly	245.193603547145
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0638
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=991"
}

#1_"992 Swasey:Swasey:1922 ND:1969 TA4" "Sol" #1=
#2_"*Свази:992 Swasey:Swasey:1922 ND" "Sol" #2=
#3_"1922 ND:*Свази:992 Swasey:Swasey" "Sol" #3=
".:Swasey:992 Swasey:1922 ND" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	13.665
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.267982027154
		SemiMajorAxis	3.027545798541
		Eccentricity	0.084877494256
		Inclination	10.843754290467
		AscendingNode	212.263728754112
		ArgOfPericenter	344.963472817456
		MeanAnomaly	21.294606936399
	}
	UniformRotation
	{
		Period	13.308
	}
	LunarLambert	0.5
	Albedo	0.1132
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=992"
}

#1_"994 Otthild:Otthild:1923 NL:1960 KC:1967 CM:1967 EK1" "Sol" #1=
#2_"*Оттхильда:994 Otthild:Otthild:1923 NL" "Sol" #2=
#3_"1923 NL:*Оттхильда:994 Otthild:Otthild" "Sol" #3=
".:Otthild:994 Otthild:1923 NL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"994 otthild.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.393
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.026733042761
		SemiMajorAxis	2.531024937354
		Eccentricity	0.114948005372
		Inclination	15.396204244078
		AscendingNode	2.39858814648
		ArgOfPericenter	342.047084504444
		MeanAnomaly	124.807703897736
	}
	UniformRotation
	{
		Period	5.95
	}
	LunarLambert	0.5
	Albedo	0.31
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=994"
}

#1_"995 Sternberga:Sternberga:1923 NP:A903 XA" "Sol" #1=
#2_"*Штернберга:995 Sternberga:Sternberga:1923 NP" "Sol" #2=
#3_"1923 NP:*Штернберга:995 Sternberga:Sternberga" "Sol" #3=
".:Sternberga:995 Sternberga:1923 NP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	15.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.232821251905
		SemiMajorAxis	2.61666314684
		Eccentricity	0.167316411555
		Inclination	13.045060400451
		AscendingNode	221.790011402652
		ArgOfPericenter	122.332710996568
		MeanAnomaly	166.267832864127
	}
	UniformRotation
	{
		Period	14.612
	}
	LunarLambert	0.5
	Albedo	0.1341
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=995"
}

#1_"996 Hilaritas:Hilaritas:1923 NM:1977 CG:A915 WH" "Sol" #1=
#2_"*Хиларитада:996 Hilaritas:Hilaritas:1923 NM" "Sol" #2=
#3_"1923 NM:*Хиларитада:996 Hilaritas:Hilaritas" "Sol" #3=
".:Hilaritas:996 Hilaritas:1923 NM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"996 hilaritas.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	14.564
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.432622853464
		SemiMajorAxis	3.09030185553
		Eccentricity	0.140948571731
		Inclination	0.660732294442
		AscendingNode	347.413404257989
		ArgOfPericenter	147.689649261158
		MeanAnomaly	344.433494731358
	}
	UniformRotation
	{
		Period	10.05
	}
	LunarLambert	0.5
	Albedo	0.12
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=996"
}

#1_"997 Priska:Priska:1923 NR:1959 WA:1967 RN" "Sol" #1=
#2_"*Приска:997 Priska:Priska:1923 NR" "Sol" #2=
#3_"1923 NR:*Приска:997 Priska:Priska" "Sol" #3=
".:Priska:997 Priska:1923 NR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.359804239951
		SemiMajorAxis	2.66873749935
		Eccentricity	0.183003078905
		Inclination	10.505376752989
		AscendingNode	247.117506241372
		ArgOfPericenter	51.655350436667
		MeanAnomaly	340.627526357739
	}
	UniformRotation
	{
		Period	16.22
	}
	LunarLambert	0.5
	Albedo	0.0801
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=997"
}

#1_"998 Bodea:Bodea:1923 NU:1967 PA" "Sol" #1=
#2_"*Бодея:998 Bodea:Bodea:1923 NU" "Sol" #2=
#3_"1923 NU:*Бодея:998 Bodea:Bodea" "Sol" #3=
".:Bodea:998 Bodea:1923 NU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"998 bodea.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	13.972
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.506502012839
		SemiMajorAxis	3.118255760902
		Eccentricity	0.212116530742
		Inclination	15.504901318444
		AscendingNode	301.20338161428
		ArgOfPericenter	72.372815365709
		MeanAnomaly	162.594840270761
	}
	UniformRotation
	{
		Period	8.574
	}
	LunarLambert	0.5
	Albedo	0.036
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=998"
}

#1_"999 Zachia:Zachia:1923 NW:1939 HA:1940 RH:1957 SH:1972 CG:A915 VC" "Sol" #1=
#2_"*Цахия:999 Zachia:Zachia:1923 NW" "Sol" #2=
#3_"1923 NW:*Цахия:999 Zachia:Zachia" "Sol" #3=
".:Zachia:999 Zachia:1923 NW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.220167189278
		SemiMajorAxis	2.611445517409
		Eccentricity	0.216719866762
		Inclination	9.759522899163
		AscendingNode	214.978897419191
		ArgOfPericenter	128.072662024825
		MeanAnomaly	211.851769955131
	}
	UniformRotation
	{
		Period	22.77
	}
	LunarLambert	0.5
	Albedo	0.1994
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=999"
}

#1_"1000 Piazzia:Piazzia:1923 NZ:1951 OB:1967 ED" "Sol" #1=
#2_"*Пиацция:1000 Piazzia:Piazzia:1923 NZ" "Sol" #2=
#3_"1923 NZ:*Пиацция:1000 Piazzia:Piazzia" "Sol" #3=
".:Piazzia:1000 Piazzia:1923 NZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	23.89
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.652355275068
		SemiMajorAxis	3.173078619088
		Eccentricity	0.257166315673
		Inclination	20.570512529934
		AscendingNode	323.768374218647
		ArgOfPericenter	280.873169031653
		MeanAnomaly	68.653885878222
	}
	UniformRotation
	{
		Period	9.47
	}
	LunarLambert	0.5
	Albedo	0.1119
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1000"
}

#1_"1001 Gaussia:Gaussia:1923 OA:A907 XC:A911 MD" "Sol" #1=
#2_"*Гауссия:1001 Gaussia:Gaussia:1923 OA" "Sol" #2=
#3_"1923 OA:*Гауссия:1001 Gaussia:Gaussia" "Sol" #3=
".:Gaussia:1001 Gaussia:1923 OA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	37.335
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.750297748539
		SemiMajorAxis	3.20962839703
		Eccentricity	0.127106938021
		Inclination	9.295461427805
		AscendingNode	259.353034282929
		ArgOfPericenter	142.193874603936
		MeanAnomaly	309.883062233792
	}
	UniformRotation
	{
		Period	9.17
	}
	LunarLambert	0.5
	Albedo	0.0392
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1001"
}

#1_"1002 Olbersia:Olbersia:1923 OB:1956 UR" "Sol" #1=
#2_"*Ольберсия:1002 Olbersia:Olbersia:1923 OB" "Sol" #2=
#3_"1923 OB:*Ольберсия:1002 Olbersia:Olbersia" "Sol" #3=
".:Olbersia:1002 Olbersia:1923 OB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1002 olbersia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	11.469
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.651076587462
		SemiMajorAxis	2.786314868371
		Eccentricity	0.15388992736
		Inclination	10.768336677917
		AscendingNode	343.76025587817
		ArgOfPericenter	355.634054431038
		MeanAnomaly	212.565615746976
	}
	UniformRotation
	{
		Period	10.244
	}
	LunarLambert	0.5
	Albedo	0.147
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1002"
}

#1_"1004 Belopolskya:Belopolskya:1923 OS:1936 WB:1937 YB:1938 AA:1963 DC:1974 WK:2004 SU12:A917 TA" "Sol" #1=
#2_"*Белопольския:1004 Belopolskya:Belopolskya:1923 OS" "Sol" #2=
#3_"1923 OS:*Белопольския:1004 Belopolskya:Belopolskya" "Sol" #3=
".:Belopolskya:1004 Belopolskya:1923 OS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	35.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.269986882288
		SemiMajorAxis	3.400209058058
		Eccentricity	0.087261049522
		Inclination	2.978689459379
		AscendingNode	153.543970184
		ArgOfPericenter	215.604954753237
		MeanAnomaly	196.409809182939
	}
	UniformRotation
	{
		Period	9.44
	}
	LunarLambert	0.5
	Albedo	0.0348
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1004"
}

#1_"1005 Arago:Arago:1923 OT" "Sol" #1=
#2_"*Араго:1005 Arago:Arago:1923 OT" "Sol" #2=
#3_"1923 OT:*Араго:1005 Arago:Arago" "Sol" #3=
".:Arago:1005 Arago:1923 OT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.91
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.637971522499
		SemiMajorAxis	3.167693234916
		Eccentricity	0.113380857041
		Inclination	19.068029944672
		AscendingNode	349.243592203459
		ArgOfPericenter	60.028254164951
		MeanAnomaly	32.488980536942
	}
	UniformRotation
	{
		Period	8.7819
	}
	LunarLambert	0.5
	Albedo	0.0697
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1005"
}

#1_"1006 Lagrangea:Lagrangea:1923 OU" "Sol" #1=
#2_"*Лагранжея:1006 Lagrangea:Lagrangea:1923 OU" "Sol" #2=
#3_"1923 OU:*Лагранжея:1006 Lagrangea:Lagrangea" "Sol" #3=
".:Lagrangea:1006 Lagrangea:1923 OU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.78
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.592456121073
		SemiMajorAxis	3.150621666911
		Eccentricity	0.353843198129
		Inclination	10.917464644038
		AscendingNode	294.781879643288
		ArgOfPericenter	86.157783061153
		MeanAnomaly	106.309588846641
	}
	UniformRotation
	{
		Period	32.79
	}
	LunarLambert	0.5
	Albedo	0.067
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1006"
}

#1_"1008 La Paz:La Paz:1923 PD:1950 UN:1970 JA" "Sol" #1=
#2_"*Ла-Пас:1008 La Paz:La Paz:1923 PD" "Sol" #2=
#3_"1923 PD:*Ла-Пас:1008 La Paz:La Paz" "Sol" #3=
".:La Paz:1008 La Paz:1923 PD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.32
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.438549753548
		SemiMajorAxis	3.092549091907
		Eccentricity	0.078834574325
		Inclination	8.935365990158
		AscendingNode	20.566169947865
		ArgOfPericenter	15.14774061526
		MeanAnomaly	249.386315862551
	}
	UniformRotation
	{
		Period	8.998
	}
	LunarLambert	0.5
	Albedo	0.0819
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1008"
}

#1_"1010 Marlene:Marlene:1923 PF:1937 NB1:1950 CJ:1950 EY:A903 UD:A908 VA" "Sol" #1=
#2_"*Марлен:1010 Marlene:Marlene:1923 PF" "Sol" #2=
#3_"1923 PF:*Марлен:1010 Marlene:Marlene" "Sol" #3=
".:Marlene:1010 Marlene:1923 PF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1010 marlene.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	23.438
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.02160763477
		SemiMajorAxis	2.932398908063
		Eccentricity	0.100640580631
		Inclination	3.910751700897
		AscendingNode	98.922372077055
		ArgOfPericenter	278.222011631225
		MeanAnomaly	71.257985287138
	}
	UniformRotation
	{
		Period	31.06
	}
	LunarLambert	0.5
	Albedo	0.047
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1010"
}

#1_"1012 Sarema:Sarema:1924 PM:1942 VC1:1954 XL:1954 YF:A907 VQ:A907 WA" "Sol" #1=
#2_"*Сарема:1012 Sarema:Sarema:1924 PM" "Sol" #2=
#3_"1924 PM:*Сарема:1012 Sarema:Sarema" "Sol" #3=
".:Sarema:1012 Sarema:1924 PM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1012 sarema.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	10.452
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.903810310271
		SemiMajorAxis	2.479250082273
		Eccentricity	0.135248152026
		Inclination	4.032621684668
		AscendingNode	73.198271108762
		ArgOfPericenter	24.755619703441
		MeanAnomaly	103.16549451817
	}
	UniformRotation
	{
		Period	10.32
	}
	LunarLambert	0.5
	Albedo	0.049
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1012"
}

#1_"1013 Tombecka:Tombecka:1924 PQ:1953 TP3:1962 VK:A905 UG:A907 GW" "Sol" #1=
#2_"*Томбецка:1013 Tombecka:Tombecka:1924 PQ" "Sol" #2=
#3_"1924 PQ:*Томбецка:1013 Tombecka:Tombecka" "Sol" #3=
".:Tombecka:1013 Tombecka:1924 PQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	15.965
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.398086951866
		SemiMajorAxis	2.684337216822
		Eccentricity	0.208207262514
		Inclination	11.898656952965
		AscendingNode	27.255597921128
		ArgOfPericenter	100.009746679558
		MeanAnomaly	230.900184534791
	}
	UniformRotation
	{
		Period	6.053
	}
	LunarLambert	0.5
	Albedo	0.1552
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1013"
}

#1_"1015 Christa:Christa:1924 QF:A916 UE" "Sol" #1=
#2_"*Криста:1015 Christa:Christa:1924 QF" "Sol" #2=
#3_"1924 QF:*Криста:1015 Christa:Christa" "Sol" #3=
".:Christa:1015 Christa:1924 QF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	48.47
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.741753996227
		SemiMajorAxis	3.206448380231
		Eccentricity	0.083005545995
		Inclination	9.462232066322
		AscendingNode	120.448736141666
		ArgOfPericenter	284.232859659082
		MeanAnomaly	28.6855829428
	}
	UniformRotation
	{
		Period	11.23
	}
	LunarLambert	0.5
	Albedo	0.0459
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1015"
}

#1_"1017 Jacqueline:Jacqueline:1924 QL:1929 LG:1953 AC:A924 ED" "Sol" #1=
#2_"*Жаклин:1017 Jacqueline:Jacqueline:1924 QL" "Sol" #2=
#3_"1924 QL:*Жаклин:1017 Jacqueline:Jacqueline" "Sol" #3=
".:Jacqueline:1017 Jacqueline:1924 QL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1017 jacqueline.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	20.076
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.205086508748
		SemiMajorAxis	2.605220508385
		Eccentricity	0.07854199278
		Inclination	7.929492370636
		AscendingNode	119.002320849695
		ArgOfPericenter	68.890618287969
		MeanAnomaly	183.283257771432
	}
	UniformRotation
	{
		Period	7.87
	}
	LunarLambert	0.5
	Albedo	0.052
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1017"
}

#1_"1018 Arnolda:Arnolda:1924 QM:1926 VK:1952 BV1" "Sol" #1=
#2_"*Арнольда:1018 Arnolda:Arnolda:1924 QM" "Sol" #2=
#3_"1924 QM:*Арнольда:1018 Arnolda:Arnolda" "Sol" #3=
".:Arnolda:1018 Arnolda:1924 QM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.049483206864
		SemiMajorAxis	2.54054914263
		Eccentricity	0.246244563803
		Inclination	7.646686931384
		AscendingNode	359.696867047943
		ArgOfPericenter	343.02488939754
		MeanAnomaly	320.914958494777
	}
	UniformRotation
	{
		Period	14.617
	}
	LunarLambert	0.5
	Albedo	0.3701
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1018"
}

#1_"1019 Strackea:Strackea:1924 QN" "Sol" #1=
#2_"*Стракея:1019 Strackea:Strackea:1924 QN" "Sol" #2=
#3_"1924 QN:*Стракея:1019 Strackea:Strackea" "Sol" #3=
".:Strackea:1019 Strackea:1924 QN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	4.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.643081306118
		SemiMajorAxis	1.911619918938
		Eccentricity	0.071281052136
		Inclination	26.981199700528
		AscendingNode	144.42487521699
		ArgOfPericenter	122.091753412858
		MeanAnomaly	17.640560226915
	}
	UniformRotation
	{
		Period	4.044
	}
	LunarLambert	0.5
	Albedo	0.2236
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1019"
}

#1_"1021 Flammario:Flammario:1924 RG:1977 UM:A910 CE" "Sol" #1=
#2_"*Фламмарион:1021 Flammario:Flammario:1924 RG" "Sol" #2=
#3_"1924 RG:*Фламмарион:1021 Flammario:Flammario" "Sol" #3=
".:Flammario:1021 Flammario:1924 RG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1021 flammario.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	50.382
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.527968918735
		SemiMajorAxis	2.736928738832
		Eccentricity	0.285272172036
		Inclination	15.870692291584
		AscendingNode	115.451266906827
		ArgOfPericenter	287.117512008442
		MeanAnomaly	109.364766769394
	}
	UniformRotation
	{
		Period	12.16
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1021"
}

#1_"1022 Olympiada:Olympiada:1924 RT:1928 FQ:1948 QO:1957 OC:1961 JF:1962 QK:A910 NA" "Sol" #1=
#2_"*Олимпиада:1022 Olympiada:Olympiada:1924 RT" "Sol" #2=
#3_"1924 RT:*Олимпиада:1022 Olympiada:Olympiada" "Sol" #3=
".:Olympiada:1022 Olympiada:1924 RT" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"1022 olympiada.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	17.148
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.697985831455
		SemiMajorAxis	2.80501809323
		Eccentricity	0.174426919795
		Inclination	21.054167061388
		AscendingNode	112.013868346263
		ArgOfPericenter	124.980931859052
		MeanAnomaly	118.381810530007
	}
	UniformRotation
	{
		Period	3.822
	}
	LunarLambert	0.5
	Albedo	0.125
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1022"
}

#1_"1023 Thomana:Thomana:1924 RU:1936 RG" "Sol" #1=
#2_"*Томана:1023 Thomana:Thomana:1924 RU" "Sol" #2=
#3_"1924 RU:*Томана:1023 Thomana:Thomana" "Sol" #3=
".:Thomana:1023 Thomana:1924 RU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1023 thomana.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	29.135
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.640625536622
		SemiMajorAxis	3.168687261827
		Eccentricity	0.102538936862
		Inclination	10.076195311294
		AscendingNode	194.323164474109
		ArgOfPericenter	194.335268623663
		MeanAnomaly	292.031119709925
	}
	UniformRotation
	{
		Period	17.56
	}
	LunarLambert	0.5
	Albedo	0.0649
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1023"
}

#1_"1024 Hale:Hale:A923 YO13" "Sol" #1=
#2_"*Хейл:1024 Hale:Hale:1923 YO13" "Sol" #2=
#3_"1923 YO13:*Хейл:1024 Hale:Hale" "Sol" #3=
".:Hale:1024 Hale:1923 YO13" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.68
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.852110292186
		SemiMajorAxis	2.86603600022
		Eccentricity	0.225289014138
		Inclination	16.088403759033
		AscendingNode	58.873192486386
		ArgOfPericenter	308.003762319629
		MeanAnomaly	289.837344952972
	}
	UniformRotation
	{
		Period	16
	}
	LunarLambert	0.5
	Albedo	0.0594
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1024"
}

#1_"1027 Aesculapia:Aesculapia:A923 YO11:1942 DH:1977 LP1:A899 PE:A908 AE" "Sol" #1=
#2_"*Эскулапия:1027 Aesculapia:Aesculapia:1923 YO11" "Sol" #2=
#3_"1923 YO11:*Эскулапия:1027 Aesculapia:Aesculapia" "Sol" #3=
".:Aesculapia:1027 Aesculapia:1923 YO11" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	16.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.604064288368
		SemiMajorAxis	3.154979955046
		Eccentricity	0.131533872277
		Inclination	1.253666010565
		AscendingNode	29.361750168377
		ArgOfPericenter	132.306250734173
		MeanAnomaly	340.639791825591
	}
	UniformRotation
	{
		Period	6.83
	}
	LunarLambert	0.5
	Albedo	0.0981
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1027"
}

#1_"1028 Lydina:Lydina:1923 PG:A907 JF:A914 JA" "Sol" #1=
#2_"*Лидина:1028 Lydina:Lydina:1923 PG" "Sol" #2=
#3_"1923 PG:*Лидина:1028 Lydina:Lydina" "Sol" #3=
".:Lydina:1028 Lydina:1923 PG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	35.69
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.284927670417
		SemiMajorAxis	3.405608500346
		Eccentricity	0.107156584533
		Inclination	9.395753188113
		AscendingNode	62.859354586376
		ArgOfPericenter	24.855215813036
		MeanAnomaly	158.540259322182
	}
	UniformRotation
	{
		Period	11.68
	}
	LunarLambert	0.5
	Albedo	0.0586
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1028"
}

#1_"1029 La Plata:La Plata:1924 RK:1938 DR2:1969 OU:A916 UL:A916 UR" "Sol" #1=
#2_"*Ла-Плата:1029 La Plata:La Plata:1924 RK" "Sol" #2=
#3_"1924 RK:*Ла-Плата:1029 La Plata:La Plata" "Sol" #3=
".:La Plata:1029 La Plata:1924 RK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"ida.jpg"
	Radius	10.39
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.912302838539
		SemiMajorAxis	2.889690212737
		Eccentricity	0.026924601407
		Inclination	2.427698032942
		AscendingNode	29.912038379987
		ArgOfPericenter	145.8206820734
		MeanAnomaly	203.836654960184
	}
	UniformRotation
	{
		Period	15.31
	}
	LunarLambert	0.5
	Albedo	0.1819
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1029"
}

#1_"1030 Vitja:Vitja:1924 RQ:1961 AF:1964 TB" "Sol" #1=
#2_"*Витя:1030 Vitja:Vitja:1924 RQ" "Sol" #2=
#3_"1924 RQ:*Витя:1030 Vitja:Vitja" "Sol" #3=
".:Vitja:1030 Vitja:1924 RQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.858
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.515350757313
		SemiMajorAxis	3.121595481058
		Eccentricity	0.123398992786
		Inclination	14.785696963788
		AscendingNode	187.871087454153
		ArgOfPericenter	6.479266373857
		MeanAnomaly	3.039538585148
	}
	UniformRotation
	{
		Period	5.7014
	}
	LunarLambert	0.5
	Albedo	0.031
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1030"
}

#1_"1031 Arctica:Arctica:1924 RR:A910 VB:A913 JA" "Sol" #1=
#2_"*Арктика:1031 Arctica:Arctica:1924 RR" "Sol" #2=
#3_"1924 RR:*Арктика:1031 Arctica:Arctica" "Sol" #3=
".:Arctica:1031 Arctica:1924 RR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	37.735
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.322083398639
		SemiMajorAxis	3.048238769008
		Eccentricity	0.056489133486
		Inclination	17.631979467673
		AscendingNode	218.940602001985
		ArgOfPericenter	306.612429900757
		MeanAnomaly	95.142198194101
	}
	UniformRotation
	{
		Period	51
	}
	LunarLambert	0.5
	Albedo	0.0465
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1031"
}

#1_"1032 Pafuri:Pafuri:1924 SA:1937 XB:1947 SA:1961 AQ:1965 YJ:A917 CC" "Sol" #1=
#2_"*Пафури:1032 Pafuri:Pafuri:1924 SA" "Sol" #2=
#3_"1924 SA:*Пафури:1032 Pafuri:Pafuri" "Sol" #3=
".:Pafuri:1032 Pafuri:1924 SA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.335
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.531577052324
		SemiMajorAxis	3.127715022352
		Eccentricity	0.143284881698
		Inclination	9.478186741536
		AscendingNode	76.359552167177
		ArgOfPericenter	189.878650210264
		MeanAnomaly	102.789555771092
	}
	UniformRotation
	{
		Period	24
	}
	LunarLambert	0.5
	Albedo	0.0591
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1032"
}

#1_"1033 Simona:Simona:1924 SM:1937 CG" "Sol" #1=
#2_"*Симона:1033 Simona:Simona:1924 SM" "Sol" #2=
#3_"1924 SM:*Симона:1033 Simona:Simona" "Sol" #3=
".:Simona:1033 Simona:Simona:1924 SM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	12.38
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.210246546907
		SemiMajorAxis	3.005384540632
		Eccentricity	0.116000530601
		Inclination	10.647367094265
		AscendingNode	188.993831752862
		ArgOfPericenter	218.57618894147
		MeanAnomaly	77.972374574732
	}
	UniformRotation
	{
		Period	10.07
	}
	LunarLambert	0.5
	Albedo	0.1147
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1033"
}

#1_"1034 Mozartia:Mozartia:1924 SS:1971 DD2:1999 DK7" "Sol" #1=
#2_"*Моцартия:1034 Mozartia:Mozartia:1924 SS" "Sol" #2=
#3_"1924 SS:*Моцартия:1034 Mozartia:Mozartia" "Sol" #3=
".:Mozartia:1034 Mozartia:1924 SS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.04
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.470159938474
		SemiMajorAxis	2.292068149794
		Eccentricity	0.264469368967
		Inclination	3.977312156793
		AscendingNode	304.612394573162
		ArgOfPericenter	18.625499219128
		MeanAnomaly	19.245400632613
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.3567
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1034"
}

#1_"1035 Amata:Amata:1924 SW:1935 SU:1969 TJ4:A913 UC" "Sol" #1=
#2_"*Амата:1035 Amata:Amata:1924 SW" "Sol" #2=
#3_"1924 SW:*Амата:1035 Amata:Amata" "Sol" #3=
".:Amata:1035 Amata:1924 SW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1035 amata.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	28.032
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.579166264425
		SemiMajorAxis	3.145628284075
		Eccentricity	0.195258395993
		Inclination	18.031091178771
		AscendingNode	2.014288562369
		ArgOfPericenter	323.496650407243
		MeanAnomaly	102.133856672035
	}
	UniformRotation
	{
		Period	9.081
	}
	LunarLambert	0.5
	Albedo	0.038
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1035"
}

#1_"1036 Ganymed:Ganymed:1924 TD:1952 BF:1954 HH" "Sol" #1=
#2_"*Ганимед (астероид):1036 Ganymed:Ganymed:1924 TD" "Sol" #2=
#3_"1924 TD:*Ганимед (астероид):1036 Ganymed:Ganymed" "Sol" #3=
".:Ganymed:1036 Ganymed:1924 TD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1036 ganymed.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.896 0.789 ]
	BlendTexture	true
	Radius	18.838
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.345053157336
		SemiMajorAxis	2.662714446064
		Eccentricity	0.533887112349
		Inclination	26.693644721759
		AscendingNode	215.557735119554
		ArgOfPericenter	132.492780504521
		MeanAnomaly	271.077642701501
	}
	UniformRotation
	{
		Period	10.297
		Inclination	166
		AscendingNode	298
	}
	LunarLambert	0.5
	Albedo	0.238
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1036"
}

#1_"1038 Tuckia:Tuckia:1924 TK:1932 VA" "Sol" #1=
#2_"*Такия:1038 Tuckia:Tuckia:1924 TK" "Sol" #2=
#3_"1924 TK:*Такия:1038 Tuckia:Tuckia" "Sol" #3=
".:Tuckia:1038 Tuckia:1924 TK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.933128131585
		SemiMajorAxis	3.977628124375
		Eccentricity	0.220185920369
		Inclination	9.187515289769
		AscendingNode	57.774046983062
		ArgOfPericenter	305.255793902797
		MeanAnomaly	216.513831898565
	}
	UniformRotation
	{
		Period	23.2
	}
	LunarLambert	0.5
	Albedo	0.0244
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1038"
}

#1_"1039 Sonneberga:Sonneberga:1924 TL:1942 XG:1984 OK" "Sol" #1=
#2_"*Зоннеберга:1039 Sonneberga:Sonneberga:1924 TL" "Sol" #2=
#3_"1924 TL:*Зоннеберга:1039 Sonneberga:Sonneberga" "Sol" #3=
".:Sonneberga:1039 Sonneberga:1924 TL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.387918097637
		SemiMajorAxis	2.680197968132
		Eccentricity	0.05900660875
		Inclination	4.554813510989
		AscendingNode	221.748442512692
		ArgOfPericenter	326.920994118796
		MeanAnomaly	57.30673930124
	}
	UniformRotation
	{
		Period	34.2
	}
	LunarLambert	0.5
	Albedo	0.0476
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1039"
}

#1_"1040 Klumpkea:Klumpkea:1925 BD:1930 DC1:1936 BB" "Sol" #1=
#2_"*Клампкея:1040 Klumpkea:Klumpkea:1925 BD" "Sol" #2=
#3_"1925 BD:*Клампкея:1040 Klumpkea:Klumpkea" "Sol" #3=
".:Klumpkea:1040 Klumpkea:1925 BD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1040 klumpkea.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	11.17
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.487840128323
		SemiMajorAxis	3.111206464383
		Eccentricity	0.193134645292
		Inclination	16.693762931001
		AscendingNode	280.186273255794
		ArgOfPericenter	158.08498775218
		MeanAnomaly	148.683059814916
	}
	UniformRotation
	{
		Period	59.2
	}
	LunarLambert	0.5
	Albedo	0.245
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1040"
}

#1_"1041 Asta:Asta:1925 FA:1938 SJ1:1949 UQ:1949 UX:1951 CQ1:1956 AT:A906 VA:A917 YB" "Sol" #1=
#2_"*Аста:1041 Asta:Asta:1925 FA" "Sol" #2=
#3_"1925 FA:*Аста:1041 Asta:Asta" "Sol" #3=
".:Asta:1041 Asta:1925 FA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.635
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.390851697155
		SemiMajorAxis	3.074440705202
		Eccentricity	0.140137424334
		Inclination	13.90026853456
		AscendingNode	60.255762643319
		ArgOfPericenter	342.891840003458
		MeanAnomaly	21.984105996571
	}
	UniformRotation
	{
		Period	7.554
	}
	LunarLambert	0.5
	Albedo	0.0591
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1041"
}

#1_"1042 Amazone:Amazone:1925 HA" "Sol" #1=
#2_"*Амазона:1042 Amazone:Amazone:1925 HA" "Sol" #2=
#3_"1925 HA:*Амазона:1042 Amazone:Amazone" "Sol" #3=
".:Amazone:1042 Amazone:1925 HA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.82
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.813770111154
		SemiMajorAxis	3.233203957576
		Eccentricity	0.091965280124
		Inclination	20.683179993919
		AscendingNode	52.549122231987
		ArgOfPericenter	295.614481595266
		MeanAnomaly	52.40865128333
	}
	UniformRotation
	{
		Period	540
	}
	LunarLambert	0.5
	Albedo	0.0392
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1042"
}

#1_"1043 Beate:Beate:1925 HB" "Sol" #1=
#2_"*Беата:1043 Beate:Beate:1925 HB" "Sol" #2=
#3_"1925 HB:*Беата:1043 Beate:Beate" "Sol" #3=
".:Beate:1043 Beate:1925 HB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	15.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.436058964445
		SemiMajorAxis	3.091604786775
		Eccentricity	0.042471518961
		Inclination	8.934980032283
		AscendingNode	159.338769339787
		ArgOfPericenter	155.711666254789
		MeanAnomaly	72.777541864358
	}
	UniformRotation
	{
		Period	44.3
	}
	LunarLambert	0.5
	Albedo	0.2147
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1043"
}

#1_"1044 Teutonia:Teutonia:1924 RO:1925 XF:1929 RP:1949 KX:1954 UY1:1958 RG:1958 UP:A907 EE" "Sol" #1=
#2_"*Тевтония:1044 Teutonia:Teutonia:1924 RO" "Sol" #2=
#3_"1924 RO:*Тевтония:1044 Teutonia:Teutonia" "Sol" #3=
".:Teutonia:1044 Teutonia:1924 RO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"vesta.dds"
	Color	[ 1.000 0.951 0.842 ]
	BlendTexture	true
	Radius	7.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.133635250317
		SemiMajorAxis	2.575625007951
		Eccentricity	0.143626814549
		Inclination	4.251210309905
		AscendingNode	59.970732463682
		ArgOfPericenter	228.441634152044
		MeanAnomaly	268.930953390639
	}
	UniformRotation
	{
		Period	3.153
	}
	LunarLambert	0.5
	Albedo	0.334
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1044"
}

#1_"1048 Feodosia:Feodosia:1924 TP:1942 XP:1942 XZ:1959 SK" "Sol" #1=
#2_"*Феодосия:1048 Feodosia:Feodosia:1924 TP" "Sol" #2=
#3_"1924 TP:*Феодосия:1048 Feodosia:Feodosia" "Sol" #3=
".:Feodosia:1048 Feodosia:1924 TP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	35.08
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.513165962995
		SemiMajorAxis	2.730960390682
		Eccentricity	0.181426617042
		Inclination	15.806157153062
		AscendingNode	52.810534664614
		ArgOfPericenter	183.575218458891
		MeanAnomaly	177.531837625666
	}
	UniformRotation
	{
		Period	10.46
	}
	LunarLambert	0.5
	Albedo	0.0452
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1048"
}

#1_"1049 Gotho:Gotho:1925 RB:A906 DD" "Sol" #1=
#2_"*Готхо:1049 Gotho:Gotho:1925 RB" "Sol" #2=
#3_"1925 RB:*Готхо:1049 Gotho:Gotho" "Sol" #3=
".:Gotho:1049 Gotho:1925 RB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.345
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.453818499556
		SemiMajorAxis	3.098334614583
		Eccentricity	0.133747546802
		Inclination	15.102591410995
		AscendingNode	342.867019099384
		ArgOfPericenter	41.613325700108
		MeanAnomaly	113.504087170929
	}
	UniformRotation
	{
		Period	8.47
	}
	LunarLambert	0.5
	Albedo	0.0109
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1049"
}

#1_"1050 Meta:Meta:1925 RC:A908 SE" "Sol" #1=
#2_"*Мета:1050 Meta:Meta:1925 RC" "Sol" #2=
#3_"1925 RC:Meta:*Мета:1050 Meta" "Sol" #3=
".:Meta:1050 Meta:1925 RC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1050 meta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.386
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.259742087423
		SemiMajorAxis	2.627746109353
		Eccentricity	0.17604539506
		Inclination	12.504691658055
		AscendingNode	342.411083128334
		ArgOfPericenter	66.044087319344
		MeanAnomaly	140.712041171924
	}
	UniformRotation
	{
		Period	6.142
	}
	LunarLambert	0.5
	Albedo	0.364
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1050"
}

#1_"1051 Merope:Merope (asteroid):1925 SA:1926 XA:1931 TM3:1936 OG:A908 TE" "Sol" #1=
#2_"*Меропа (астероид):1051 Merope:Merope (asteroid):1925 SA" "Sol" #2=
#3_"1925 SA:*Меропа (астероид):1051 Merope:Merope (asteroid)" "Sol" #3=
".:Merope (asteroid):1051 Merope:1925 SA" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.605
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.773648695427
		SemiMajorAxis	3.218311684032
		Eccentricity	0.097495672034
		Inclination	23.483069659043
		AscendingNode	180.732683481029
		ArgOfPericenter	152.433242179774
		MeanAnomaly	180.727117348577
	}
	UniformRotation
	{
		Period	27.2
	}
	LunarLambert	0.5
	Albedo	0.0429
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1051"
}

#1_"1054 Forsytia:Forsytia:1925 WD:1962 DD:A907 EA" "Sol" #1=
#2_"*Форсайтия:1054 Forsytia:Forsytia:1925 WD" "Sol" #2=
#3_"1925 WD:*Форсайтия:1054 Forsytia:Forsytia" "Sol" #3=
".:Forsytia:1054 Forsytia:1925 WD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.735
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.994908774416
		SemiMajorAxis	2.921995699113
		Eccentricity	0.136610598401
		Inclination	10.849787140861
		AscendingNode	85.950368078515
		ArgOfPericenter	293.798474754636
		MeanAnomaly	327.971320245356
	}
	UniformRotation
	{
		Period	7.65
	}
	LunarLambert	0.5
	Albedo	0.0648
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1054"
}

#1_"1056 Azalea:Azalea:1924 QD:1925 NA:1929 WX" "Sol" #1=
#2_"*Азалия:1056 Azalea:Azalea:1924 QD" "Sol" #2=
#3_"1924 QD:*Азалия:1056 Azalea:Azalea" "Sol" #3=
".:Azalea:1056 Azalea:1924 QD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1056 azalea.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.934
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.330001247713
		SemiMajorAxis	2.229927770077
		Eccentricity	0.178591303171
		Inclination	5.427058573323
		AscendingNode	104.179938538084
		ArgOfPericenter	212.499490036699
		MeanAnomaly	349.355561386143
	}
	UniformRotation
	{
		Period	11.893
	}
	LunarLambert	0.5
	Albedo	0.292
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1056"
}

#1_"1057 Wanda:Wanda:1925 QB:1937 AF:1950 QY:1965 WG" "Sol" #1=
#2_"*Ванда:1057 Wanda:Wanda:1925 QB:1937 AF" "Sol" #2=
#3_"1925 QB:*Ванда:1057 Wanda:Wanda:1937 AF" "Sol" #3=
".:Wanda:1057 Wanda:1925 QB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.921447044864
		SemiMajorAxis	2.893275188825
		Eccentricity	0.246707225968
		Inclination	3.518564304252
		AscendingNode	258.81704211441
		ArgOfPericenter	112.242767474221
		MeanAnomaly	25.66432270715
	}
	UniformRotation
	{
		Period	28.8
	}
	LunarLambert	0.5
	Albedo	0.0446
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1057"
}

#1_"1061 Paeonia:Paeonia:1925 TB:1925 XB:1936 SM:1942 XD" "Sol" #1=
#2_"*Пиония:1061 Paeonia:Paeonia:1925 TB" "Sol" #2=
#3_"1925 TB:Paeonia:*Пиония:1061 Paeonia" "Sol" #3=
".:Paeonia:1061 Paeonia:1925 TB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1061 paeonia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	11.546
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.537640039439
		SemiMajorAxis	3.130000064901
		Eccentricity	0.213895641771
		Inclination	2.497237724468
		AscendingNode	90.960451497322
		ArgOfPericenter	305.98983115857
		MeanAnomaly	178.467733081871
	}
	UniformRotation
	{
		Period	7.9971
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1061"
}

#1_"1062 Ljuba:Ljuba:1925 TD:1943 EH1:1976 MM:A904 TB:A914 SD:A917 GB:A924 ND" "Sol" #1=
#2_"*Люба:1062 Ljuba:Ljuba:1925 TD" "Sol" #2=
#3_"1925 TD:*Люба:1062 Ljuba:Ljuba" "Sol" #3=
".:Ljuba:1062 Ljuba:1925 TD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.55
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.210688259921
		SemiMajorAxis	3.005554398072
		Eccentricity	0.066791839342
		Inclination	5.602736726013
		AscendingNode	341.463003716754
		ArgOfPericenter	101.830461732721
		MeanAnomaly	351.610458890348
	}
	UniformRotation
	{
		Period	33.8
	}
	LunarLambert	0.5
	Albedo	0.0668
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1062"
}

#1_"1063 Aquilegia:Aquilegia:1925 XA:1948 EP:1956 SK:A906 KA:A910 NC:A920 GB:A923 CA" "Sol" #1=
#2_"*Аквилегия:1063 Aquilegia:Aquilegia:1925 XA" "Sol" #2=
#3_"1925 XA:*Аквилегия:1063 Aquilegia:Aquilegia" "Sol" #3=
".:Aquilegia:1063 Aquilegia:1925 XA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.875
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.520704629762
		SemiMajorAxis	2.314271245883
		Eccentricity	0.039751966413
		Inclination	5.973148891066
		AscendingNode	95.342428035172
		ArgOfPericenter	106.790839608303
		MeanAnomaly	324.175227935727
	}
	UniformRotation
	{
		Period	5.792
	}
	LunarLambert	0.5
	Albedo	0.1572
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1063"
}

#1_"1064 Aethusa:Aethusa:1926 PA:1962 HF" "Sol" #1=
#2_"*Этуса:1064 Aethusa:Aethusa:1926 PA" "Sol" #2=
#3_"1926 PA:*Этуса:1064 Aethusa:Aethusa" "Sol" #3=
".:Aethusa:1064 Aethusa:1926 PA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.05412017247
		SemiMajorAxis	2.542488187077
		Eccentricity	0.176788939969
		Inclination	9.500957887074
		AscendingNode	280.585679468778
		ArgOfPericenter	20.626241597056
		MeanAnomaly	282.406669438279
	}
	UniformRotation
	{
		Period	8.621
	}
	LunarLambert	0.5
	Albedo	0.3202
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1064"
}

#1_"1069 Planckia:Planckia:1927 BC:1952 QY:1975 VG8" "Sol" #1=
#2_"*Планкия:1069 Planckia:Planckia:1927 BC" "Sol" #2=
#3_"1927 BC:*Планкия:1069 Planckia:Planckia" "Sol" #3=
".:Planckia:1069 Planckia:1927 BC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	19.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.526738982694
		SemiMajorAxis	3.125891032605
		Eccentricity	0.11029061171
		Inclination	13.572052381323
		AscendingNode	142.434046611068
		ArgOfPericenter	32.834130990276
		MeanAnomaly	257.189729423342
	}
	UniformRotation
	{
		Period	8.665
	}
	LunarLambert	0.5
	Albedo	0.2158
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1069"
}

#1_"1070 Tunica:Tunica:1926 RB:A903 SA" "Sol" #1=
#2_"*Туника:1070 Tunica:Tunica:1926 RB" "Sol" #2=
#3_"1926 RB:*Туника:1070 Tunica:Tunica" "Sol" #3=
".:Tunica:1070 Tunica:1926 RB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.195
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.808895125656
		SemiMajorAxis	3.231396292246
		Eccentricity	0.079222792788
		Inclination	16.967006222441
		AscendingNode	165.406894165729
		ArgOfPericenter	185.812135174034
		MeanAnomaly	94.425606678779
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0768
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1070"
}

#1_"1071 Brita:Brita:1924 RE:1927 YB:1947 BE:1948 HB:1948 JG:1952 FJ:A910 EB:A917 SP" "Sol" #1=
#2_"*Брита:1071 Brita:Brita:1924 RE" "Sol" #2=
#3_"1924 RE:*Брита:1071 Brita:Brita" "Sol" #3=
".:Brita:1071 Brita:1924 RE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.145
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.689802318945
		SemiMajorAxis	2.801759736577
		Eccentricity	0.109646728816
		Inclination	5.371159448392
		AscendingNode	52.585280228104
		ArgOfPericenter	27.013033643934
		MeanAnomaly	210.209097914254
	}
	UniformRotation
	{
		Period	5.8169
	}
	LunarLambert	0.5
	Albedo	0.0637
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1071"
}

#1_"1072 Malva:Malva:1926 TA:1949 UU" "Sol" #1=
#2_"*Мальва:1072 Malva:Malva:1926 TA" "Sol" #2=
#3_"1926 TA:*Мальва:1072 Malva:Malva" "Sol" #3=
".:Malva:1072 Malva:1926 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.525
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.626306906999
		SemiMajorAxis	3.163322552259
		Eccentricity	0.241999853503
		Inclination	8.025117396192
		AscendingNode	37.09860869447
		ArgOfPericenter	26.084276800824
		MeanAnomaly	180.073368054413
	}
	UniformRotation
	{
		Period	10.08
	}
	LunarLambert	0.5
	Albedo	0.0549
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1072"
}

#1_"1073 Gellivara:Gellivara:1923 OW:1929 UJ:1932 EP:1951 QL" "Sol" #1=
#2_"*Гелливара:1073 Gellivara:Gellivara:1923 OW" "Sol" #2=
#3_"1923 OW:*Гелливара:1073 Gellivara:Gellivara" "Sol" #3=
".:Gellivara:1073 Gellivara:1923 OW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	17.865
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.662303515845
		SemiMajorAxis	3.176800642468
		Eccentricity	0.193977100125
		Inclination	1.606907655479
		AscendingNode	39.516865718786
		ArgOfPericenter	289.133410778278
		MeanAnomaly	74.28778816161
	}
	UniformRotation
	{
		Period	11.32
	}
	LunarLambert	0.5
	Albedo	0.0241
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1073"
}

#1_"1074 Beljawskya:Beljawskya:1925 BE:1949 KC1:A912 VN:A914 BB:A917 QB:A923 TA" "Sol" #1=
#2_"*Белявския:1074 Beljawskya:Beljawskya:1925 BE" "Sol" #2=
#3_"1925 BE:*Белявския:1074 Beljawskya:Beljawskya" "Sol" #3=
".:Beljawskya:1074 Beljawskya:1925 BE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	23.91
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.608766515135
		SemiMajorAxis	3.156744550232
		Eccentricity	0.177151469984
		Inclination	0.801657988509
		AscendingNode	38.117734322822
		ArgOfPericenter	23.550019197696
		MeanAnomaly	54.61362274857
	}
	UniformRotation
	{
		Period	6.284
	}
	LunarLambert	0.5
	Albedo	0.0772
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1074"
}

#1_"1075 Helina:Helina:1926 SC:1930 KV:1965 CB:A906 YG:A916 WH" "Sol" #1=
#2_"*Гелина:1075 Helina:Helina:1926 SC" "Sol" #2=
#3_"1926 SC:*Гелина:1075 Helina:Helina" "Sol" #3=
".:Helina:1075 Helina:1926 SC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1075 helina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.099
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.230422359123
		SemiMajorAxis	3.013138109417
		Eccentricity	0.11376292587
		Inclination	11.52227099857
		AscendingNode	100.823622126757
		ArgOfPericenter	250.863547580717
		MeanAnomaly	327.781225702846
	}
	UniformRotation
	{
		Period	44.9
	}
	LunarLambert	0.5
	Albedo	0.129
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1075"
}

#1_"1076 Viola:Viola:1926 TE" "Sol" #1=
#2_"*Виола:1076 Viola:Viola:1926 TE" "Sol" #2=
#3_"1926 TE:*Виола:1076 Viola:Viola" "Sol" #3=
".:Viola:1076 Viola:1926 TE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.315
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.891825398454
		SemiMajorAxis	2.474173193156
		Eccentricity	0.145036513665
		Inclination	3.319514937276
		AscendingNode	143.710446304114
		ArgOfPericenter	303.94621119364
		MeanAnomaly	177.511854694282
	}
	UniformRotation
	{
		Period	7.336
	}
	LunarLambert	0.5
	Albedo	0.0415
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1076"
}

#1_"1077 Campanula:Campanula:1926 TK:1957 AJ:1972 CB" "Sol" #1=
#2_"*Кампанула:1077 Campanula:Campanula:1926 TK" "Sol" #2=
#3_"1926 TK:Campanula:*Кампанула:1077 Campanula" "Sol" #3=
".:Campanula:1077 Campanula:1926 TK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1077 campanula.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.854
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.701786013988
		SemiMajorAxis	2.392959813682
		Eccentricity	0.197571033608
		Inclination	5.399266590269
		AscendingNode	346.220237799988
		ArgOfPericenter	13.472734564847
		MeanAnomaly	165.268429960514
	}
	UniformRotation
	{
		Period	3.8508
	}
	LunarLambert	0.5
	Albedo	0.225
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1077"
}

#1_"1079 Mimosa:Mimosa:1927 AD:1961 AM" "Sol" #1=
#2_"*Мимоза:1079 Mimosa:Mimosa:1927 AD" "Sol" #2=
#3_"1927 AD:*Мимоза:1079 Mimosa:Mimosa" "Sol" #3=
".:Mimosa:1079 Mimosa:1927 AD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"ida.jpg"
	Radius	10.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.876890915996
		SemiMajorAxis	2.875785963103
		Eccentricity	0.047978779418
		Inclination	1.177954033997
		AscendingNode	329.400980140326
		ArgOfPericenter	108.177768304059
		MeanAnomaly	49.066638848662
	}
	UniformRotation
	{
		Period	64.6
	}
	LunarLambert	0.5
	Albedo	0.1367
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1079"
}

#1_"1080 Orchis:Orchis:1927 QB:1955 DT:A906 BH" "Sol" #1=
#2_"*Орхида:1080 Orchis:Orchis:1927 QB" "Sol" #2=
#3_"1927 QB:*Орхида:1080 Orchis:Orchis" "Sol" #3=
".:Orchis:1080 Orchis:1927 QB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1080 orchis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	10.898
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.763761866985
		SemiMajorAxis	2.419594695422
		Eccentricity	0.257901004829
		Inclination	4.586411137462
		AscendingNode	2.059409431414
		ArgOfPericenter	57.153229420865
		MeanAnomaly	16.48902593763
	}
	UniformRotation
	{
		Period	16.1
	}
	LunarLambert	0.5
	Albedo	0.029
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1080"
}

#1_"1081 Reseda:Reseda:1927 QF:1949 UA1:1975 LS" "Sol" #1=
#2_"*Резеда:1081 Reseda:Reseda:1927 QF" "Sol" #2=
#3_"1927 QF:*Резеда:1081 Reseda:Reseda" "Sol" #3=
".:Reseda:1081 Reseda:1927 QF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1081 reseda.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	18.905
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.447982022555
		SemiMajorAxis	3.096123737242
		Eccentricity	0.146837980517
		Inclination	4.205054969048
		AscendingNode	30.452663909877
		ArgOfPericenter	6.22793324907
		MeanAnomaly	347.939373795673
	}
	UniformRotation
	{
		Period	7.3002
	}
	LunarLambert	0.5
	Albedo	0.043
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1081"
}

#1_"1082 Pirola:Pirola:1927 UC:1931 JQ:1951 AH:1952 DS:1971 YJ:A916 UP" "Sol" #1=
#2_"*Пирола:1082 Pirola:Pirola:1927 UC" "Sol" #2=
#3_"1927 UC:*Пирола:1082 Pirola:Pirola" "Sol" #3=
".:Pirola:1082 Pirola:1927 UC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1082 pirola.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	21.304
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.516338656349
		SemiMajorAxis	3.121968226057
		Eccentricity	0.181075985005
		Inclination	1.852152261191
		AscendingNode	148.010293088573
		ArgOfPericenter	187.471859757378
		MeanAnomaly	311.821786895355
	}
	UniformRotation
	{
		Period	15.8525
	}
	LunarLambert	0.5
	Albedo	0.052
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1082"
}

#1_"1083 Salvia:Salvia:1928 BC:1948 VO:A910 AA:A916 WF" "Sol" #1=
#2_"*Сальвия:1083 Salvia:Salvia:1928 BC" "Sol" #2=
#3_"1928 BC:Salvia:*Сальвия:1083 Salvia" "Sol" #3=
".:Salvia:1083 Salvia:1928 BC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1083 salvia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.464
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.554247762312
		SemiMajorAxis	2.328947315805
		Eccentricity	0.182432275178
		Inclination	5.130313780287
		AscendingNode	80.828492140689
		ArgOfPericenter	32.646649469097
		MeanAnomaly	36.02626569637
	}
	UniformRotation
	{
		Period	4.23
	}
	LunarLambert	0.5
	Albedo	0.211
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1083"
}

#1_"1084 Tamariwa:Tamariwa:1926 CC:1927 JB:1928 TA" "Sol" #1=
#2_"*Тамарива:1084 Tamariwa:Tamariwa:1926 CC" "Sol" #2=
#3_"1926 CC:*Тамарива:1084 Tamariwa:Tamariwa" "Sol" #3=
".:Tamariwa:1084 Tamariwa:1926 CC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	13.595
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.407420946585
		SemiMajorAxis	2.68813382741
		Eccentricity	0.131780255283
		Inclination	3.894741224912
		AscendingNode	186.88633855853
		ArgOfPericenter	109.875072375228
		MeanAnomaly	258.785352775327
	}
	UniformRotation
	{
		Period	6.1961
	}
	LunarLambert	0.5
	Albedo	0.1165
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1084"
}

#1_"1085 Amaryllis:Amaryllis:1927 QH:1964 CL:A908 HB:A915 QA:A921 RC" "Sol" #1=
#2_"*Амариллис:1085 Amaryllis:Amaryllis:1927 QH" "Sol" #2=
#3_"1927 QH:*Амариллис:1085 Amaryllis:Amaryllis" "Sol" #3=
".:Amaryllis:1085 Amaryllis:1927 QH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.975
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.699747472294
		SemiMajorAxis	3.190790386689
		Eccentricity	0.043172456525
		Inclination	6.637994642891
		AscendingNode	139.996891999605
		ArgOfPericenter	124.0826874637
		MeanAnomaly	230.546554646027
	}
	UniformRotation
	{
		Period	18.2
	}
	LunarLambert	0.5
	Albedo	0.0628
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1085"
}

#1_"1086 Nata:Nata:1927 QL:1925 JA:A900 YB" "Sol" #1=
#2_"*Ната:1086 Nata:Nata:1927 QL" "Sol" #2=
#3_"1927 QL:*Ната:1086 Nata:Nata" "Sol" #3=
".:Nata:1086 Nata:1927 QL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.135
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.622418694709
		SemiMajorAxis	3.161864984334
		Eccentricity	0.055207771777
		Inclination	8.360875954208
		AscendingNode	313.246154692684
		ArgOfPericenter	159.121722455908
		MeanAnomaly	60.713050781369
	}
	UniformRotation
	{
		Period	18.074
	}
	LunarLambert	0.5
	Albedo	0.0767
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1086"
}

#1_"1087 Arabis:Arabis:1927 RD:1973 LB:A917 UE" "Sol" #1=
#2_"*Арабида:1087 Arabis:Arabis:1927 RD" "Sol" #2=
#3_"1927 RD:*Арабида:1087 Arabis:Arabis" "Sol" #3=
".:Arabis:1087 Arabis:1927 RD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1087 arabis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	18.749
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.230548001421
		SemiMajorAxis	3.013186362509
		Eccentricity	0.094883094031
		Inclination	10.061626082548
		AscendingNode	30.441849247128
		ArgOfPericenter	26.036496706938
		MeanAnomaly	184.390960054677
	}
	UniformRotation
	{
		Period	5.794
	}
	LunarLambert	0.5
	Albedo	0.098
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1087"
}

#1_"1088 Mitaka:Mitaka:1927 WA:1942 FR:1953 VW3:1971 BE:A917 RA" "Sol" #1=
#2_"*Митака:1088 Mitaka:Mitaka:1927 WA" "Sol" #2=
#3_"1927 WA:*Митака:1088 Mitaka:Mitaka" "Sol" #3=
".:Mitaka:1088 Mitaka:1927 WA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1088 mitaka.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.568
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.266724659014
		SemiMajorAxis	2.201588860027
		Eccentricity	0.196042644365
		Inclination	7.649105538181
		AscendingNode	54.522101206749
		ArgOfPericenter	319.301431933349
		MeanAnomaly	319.765495002365
	}
	UniformRotation
	{
		Period	3.0361
	}
	LunarLambert	0.5
	Albedo	0.173
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1088"
}

#1_"Tama System" "Sol" #1=
#2_"*Система Тамы:Tama System" "Sol" #2=
#3_"Tama System:*Система Тамы" "Sol" #3=
".:Tama System" "Sol" #4=

{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.293417138307
		SemiMajorAxis	2.213565407571
		Eccentricity	0.127473217059
		Inclination	3.726746353846
		AscendingNode	71.496807383774
		ArgOfPericenter	354.300632459367
		MeanAnomaly	143.620875027993
	}
	LunarLambert	0.5
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-01089.html"
}

#1_"1089 Tama:Tama:1927 WB:1930 ST:1952 HE4:A894 VA:A904 VD:A919 HA" "Sol/Tama System" #1=
#2_"*Тама:1089 Tama:Tama:1927 WB" "Sol/Tama System" #2=
#3_"1927 WB:*Тама:1089 Tama:Tama" "Sol/Tama System" #3=
".:Tama:1089 Tama:1927 WB" "Sol/Tama System" #4=
{
	Class	"asteroid"
	Mesh	"1089 tama.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	5.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.6852
		SemiMajorAxis	5
		ArgOfPericenter	180
	}
	UniformRotation
	{
		Period	16.4448
	}
	LunarLambert	0.5
	Albedo	0.216
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1089"
}

#1_"2003 1089 I" "Sol/Tama System" #1=
#2_"2003 1089 I" "Sol/Tama System" #2=
#3_"2003 1089 I" "Sol/Tama System" #3=
".:2003 1089 I" "Sol/Tama System" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"gaspra.jpg"
	Radius	3.665
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.6852
		SemiMajorAxis	15.7
		ArgOfPericenter	20
	}
	UniformRotation
	{
		Period	16.4448
	}
	LunarLambert	0.5
	Albedo	0.216
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-01089.html"
}

#1_"1091 Spiraea:Spiraea:1928 DT:1934 CN1:1938 UR:1964 XH" "Sol" #1=
#2_"*Спирея:1091 Spiraea:Spiraea:1928 DT" "Sol" #2=
#3_"1928 DT:*Спирея:1091 Spiraea:Spiraea" "Sol" #3=
".:Spiraea:1091 Spiraea:1928 DT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.99
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.321178648242
		SemiMajorAxis	3.418691468205
		Eccentricity	0.062054285355
		Inclination	1.155825963452
		AscendingNode	80.728669443597
		ArgOfPericenter	9.697419821851
		MeanAnomaly	317.184982850706
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0994
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1091"
}

#1_"1092 Lilium:Lilium:1924 PN:1929 BE:1936 QE" "Sol" #1=
#2_"*Лилиум:1092 Lilium:Lilium:1924 PN" "Sol" #2=
#3_"1924 PN:*Лилиум:1092 Lilium:Lilium" "Sol" #3=
".:Lilium:1092 Lilium:1924 PN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.085
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.939866145076
		SemiMajorAxis	2.90048964407
		Eccentricity	0.083623783966
		Inclination	5.388588231875
		AscendingNode	307.514018204875
		ArgOfPericenter	316.578707693217
		MeanAnomaly	1.05774261343
	}
	UniformRotation
	{
		Period	24.6
	}
	LunarLambert	0.5
	Albedo	0.039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1092"
}

#1_"1093 Freda:Freda:1925 LA:A898 VE" "Sol" #1=
#2_"*Фреда:1093 Freda:Freda:1925 LA" "Sol" #2=
#3_"1925 LA:*Фреда:1093 Freda:Freda" "Sol" #3=
".:Freda:1093 Freda:1925 LA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.541641786561
		SemiMajorAxis	3.131507802321
		Eccentricity	0.270820267627
		Inclination	25.207690411425
		AscendingNode	55.637175318903
		ArgOfPericenter	251.566436151955
		MeanAnomaly	357.624417684286
	}
	UniformRotation
	{
		Period	19.67
	}
	LunarLambert	0.5
	Albedo	0.0381
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1093"
}

#1_"1094 Siberia:Siberia:1926 CB:A918 EJ" "Sol" #1=
#2_"*Сиберия:1094 Siberia:Siberia:1926 CB" "Sol" #2=
#3_"1926 CB:*Сиберия:1094 Siberia:Siberia" "Sol" #3=
".:Siberia:1094 Siberia:1926 CB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.025
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.059493761054
		SemiMajorAxis	2.544734341367
		Eccentricity	0.132912042232
		Inclination	14.028377037768
		AscendingNode	149.149112858607
		ArgOfPericenter	310.656250247513
		MeanAnomaly	338.008182336715
	}
	UniformRotation
	{
		Period	21.15
	}
	LunarLambert	0.5
	Albedo	0.0943
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1094"
}

#1_"1095 Tulipa:Tulipa:1926 GS:1936 FE1:1937 LQ:1939 VG:1941 CC:1942 JG:1942 KB:1952 FE1:1954 SO: #1=
#1_1954 UG3:1955 XO:1956 AD1:1959 RM:1965 VB" "Sol" #1=
#2_"*Тулипа:1095 Tulipa:Tulipa:1926 GS" "Sol" #2=
#3_"1926 GS:*Тулипа:1095 Tulipa:Tulipa" "Sol" #3=
".:Tulipa:1095 Tulipa:1926 GS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1095 tulipa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.938
	Visible	false
	Clickable	false
	EllipticalOrbit
	{

		Epoch	2458000.5  # 2017 Sept 04
		Period	5.261262334338
		SemiMajorAxis	3.024970681519
		Eccentricity	0.02209291165
		Inclination	10.029597408418
		AscendingNode	178.538602896124
		ArgOfPericenter	342.691185204486
		MeanAnomaly	181.755167338344
	}
	UniformRotation
	{
		Period	2.78721
	}
	LunarLambert	0.5
	Albedo	0.146
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1095"
}

#1_"1096 Reunerta:Reunerta:1928 OB" "Sol" #1=
#2_"*Ройнерта:1096 Reunerta:Reunerta:1928 OB" "Sol" #2=
#3_"1928 OB:*Ройнерта:1096 Reunerta:Reunerta" "Sol" #3=
".:Reunerta:1096 Reunerta:1928 OB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.915
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.198317764545
		SemiMajorAxis	2.602424084679
		Eccentricity	0.192906350989
		Inclination	9.470694674708
		AscendingNode	81.394347208781
		ArgOfPericenter	247.836210828847
		MeanAnomaly	190.217681223577
	}
	UniformRotation
	{
		Period	13.036
	}
	LunarLambert	0.5
	Albedo	0.0638
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1096"
}

#1_"1097 Vicia:Vicia:1928 PC:1941 SO2:1958 PF:1978 BG:A907 VF" "Sol" #1=
#2_"*Виция:1097 Vicia:Vicia:1928 PC" "Sol" #2=
#3_"1928 PC:*Виция:1097 Vicia:Vicia" "Sol" #3=
".:Vicia:1097 Vicia:1928 PC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.293438948576
		SemiMajorAxis	2.64158583022
		Eccentricity	0.294343435744
		Inclination	1.533166242422
		AscendingNode	133.862077264726
		ArgOfPericenter	176.668362556852
		MeanAnomaly	44.352876201464
	}
	UniformRotation
	{
		Period	26.5
	}
	LunarLambert	0.5
	Albedo	0.0831
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1097"
}

#1_"1098 Hakone:Hakone:1928 RJ:1926 EC:1950 QH1:1952 BE1:A906 RD:A917 DD" "Sol" #1=
#2_"*Хакона:1098 Hakone:Hakone:1928 RJ" "Sol" #2=
#3_"1928 RJ:*Хакона:1098 Hakone:Hakone" "Sol" #3=
".:Hakone:1098 Hakone:1928 RJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1098 hakone.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.342
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.405458337908
		SemiMajorAxis	2.687335757298
		Eccentricity	0.119336937263
		Inclination	13.379519995207
		AscendingNode	329.011616898237
		ArgOfPericenter	81.031338742873
		MeanAnomaly	149.875880021282
	}
	UniformRotation
	{
		Period	7.142
	}
	LunarLambert	0.5
	Albedo	0.206
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1098"
}

#1_"1099 Figneria:Figneria:1928 RQ:1952 BM:A917 UF" "Sol" #1=
#2_"*Фигнерия:1099 Figneria:Figneria:1928 RQ" "Sol" #2=
#3_"1928 RQ:*Фигнерия:1099 Figneria:Figneria" "Sol" #3=
".:Figneria:1099 Figneria:1928 RQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.695
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.712580352411
		SemiMajorAxis	3.195577929858
		Eccentricity	0.269903153053
		Inclination	11.735749239174
		AscendingNode	22.672669030818
		ArgOfPericenter	346.551642292257
		MeanAnomaly	88.809785369136
	}
	UniformRotation
	{
		Period	13.577
	}
	LunarLambert	0.5
	Albedo	0.1415
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1099"
}

#1_"1101 Clematis:Clematis:1928 SJ:1928 WB:1963 TG1:1969 TG1" "Sol" #1=
#2_"*Клематида:1101 Clematis:Clematis:1928 SJ" "Sol" #2=
#3_"1928 SJ:*Клематида:1101 Clematis:Clematis" "Sol" #3=
".:Clematis:1101 Clematis:1928 SJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	18.93
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.809679575766
		SemiMajorAxis	3.231687203807
		Eccentricity	0.077963860316
		Inclination	21.419650942942
		AscendingNode	201.991709830636
		ArgOfPericenter	108.0127614961
		MeanAnomaly	340.984851942826
	}
	UniformRotation
	{
		Period	34.3
	}
	LunarLambert	0.5
	Albedo	0.1124
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1101"
}

#1_"1102 Pepita:Pepita:1928 VA:1960 WQ:A899 KB" "Sol" #1=
#2_"*Пепита:1102 Pepita:Pepita:1928 VA" "Sol" #2=
#3_"1928 VA:*Пепита:1102 Pepita:Pepita" "Sol" #3=
".:Pepita:1102 Pepita:1928 VA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1102 pepita.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	18.316
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.37227703687
		SemiMajorAxis	3.067374470333
		Eccentricity	0.113722702017
		Inclination	15.791905813652
		AscendingNode	216.741505975929
		ArgOfPericenter	115.367040589795
		MeanAnomaly	85.841837486122
	}
	UniformRotation
	{
		Period	5.1054
	}
	LunarLambert	0.5
	Albedo	0.229
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1102"
}

#1_"1103 Sequoia:Sequoia:1928 VB" "Sol" #1=
#2_"*Секвойя:1103 Sequoia:Sequoia:1928 VB" "Sol" #2=
#3_"1928 VB:Sequoia:*Секвойя:1103 Sequoia" "Sol" #3=
".:Sequoia:1103 Sequoia:1928 VB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1103 sequoia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.346
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.688774296069
		SemiMajorAxis	1.933588689418
		Eccentricity	0.094689751948
		Inclination	17.898195941735
		AscendingNode	267.651161737058
		ArgOfPericenter	77.927988746433
		MeanAnomaly	353.616792555282
	}
	UniformRotation
	{
		Period	3.0378
	}
	LunarLambert	0.5
	Albedo	0.384
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1103"
}

#1_"1104 Syringa:Syringa:1928 XA" "Sol" #1=
#2_"*Сиринга:1104 Syringa:Syringa:1928 XA" "Sol" #2=
#3_"1928 XA:*Сиринга:1104 Syringa:Syringa" "Sol" #3=
".:Syringa:1104 Syringa:1928 XA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.268330195902
		SemiMajorAxis	2.631276807052
		Eccentricity	0.343035722191
		Inclination	6.441715102437
		AscendingNode	128.670923839101
		ArgOfPericenter	277.639363908516
		MeanAnomaly	74.321650722383
	}
	UniformRotation
	{
		Period	5.1547
	}
	LunarLambert	0.5
	Albedo	0.0362
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1104"
}

#1_"1105 Fragaria:Fragaria:1929 AB:1947 KB:1977 EU:A916 MA:A917 UH" "Sol" #1=
#2_"*Фрагария:1105 Fragaria:Fragaria:1929 AB" "Sol" #2=
#3_"1929 AB:*Фрагария:1105 Fragaria:Fragaria" "Sol" #3=
".:Fragaria:1105 Fragaria:1929 AB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	18.515
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.220420426407
		SemiMajorAxis	3.009295613117
		Eccentricity	0.105535007149
		Inclination	10.968073628647
		AscendingNode	116.919652817783
		ArgOfPericenter	225.445630275905
		MeanAnomaly	243.742137701296
	}
	UniformRotation
	{
		Period	10.88
	}
	LunarLambert	0.5
	Albedo	0.1186
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1105"
}

#1_"1107 Lictoria:Lictoria:1929 FB:A909 UB:A917 DF:A924 KC" "Sol" #1=
#2_"*Ликтория:1107 Lictoria:Lictoria:1929 FB" "Sol" #2=
#3_"1929 FB:*Ликтория:1107 Lictoria:Lictoria" "Sol" #3=
".:Lictoria:1107 Lictoria:1929 FB" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	39.585
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.675981158978
		SemiMajorAxis	3.181914423573
		Eccentricity	0.12534354378
		Inclination	7.075668146439
		AscendingNode	110.854942424158
		ArgOfPericenter	351.383817105141
		MeanAnomaly	104.189125008451
	}
	UniformRotation
	{
		Period	8.5616
	}
	LunarLambert	0.5
	Albedo	0.0646
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1107"
}

#1_"1108 Demeter:Demeter:1929 KA:1963 MF" "Sol" #1=
#2_"*Деметра:1108 Demeter:Demeter:1929 KA" "Sol" #2=
#3_"1929 KA:*Деметра:1108 Demeter:Demeter" "Sol" #3=
".:Demeter:1108 Demeter:1929 KA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.785315741281
		SemiMajorAxis	2.428823403654
		Eccentricity	0.256169498092
		Inclination	24.904464350195
		AscendingNode	234.329674100084
		ArgOfPericenter	77.943071149365
		MeanAnomaly	187.048848883776
	}
	UniformRotation
	{
		Period	9.7
	}
	LunarLambert	0.5
	Albedo	0.0464
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1108"
}

#1_"1109 Tata:Tata:1929 CU:1925 QE:1964 HA" "Sol" #1=
#2_"*Тата:1109 Tata:Tata:1929 CU" "Sol" #2=
#3_"1929 CU:*Тата:1109 Tata:Tata" "Sol" #3=
".:Tata:1109 Tata:1929 CU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.804589768367
		SemiMajorAxis	3.229799426932
		Eccentricity	0.09842313953
		Inclination	4.121117173739
		AscendingNode	268.193886210534
		ArgOfPericenter	358.09162786323
		MeanAnomaly	253.999664548766
	}
	UniformRotation
	{
		Period	8.277
	}
	LunarLambert	0.5
	Albedo	0.0378
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1109"
}

#1_"1110 Jaroslawa:Jaroslawa:1928 PD:1934 FN:A917 FA" "Sol" #1=
#2_"*Ярослава:1110 Jaroslawa:Jaroslawa:1928 PD" "Sol" #2=
#3_"1928 PD:Jaroslawa:*Ярослава:1110 Jaroslawa" "Sol" #3=
".:Jaroslawa:1110 Jaroslawa:1928 PD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1110 jaroslawa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.153
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.304954363894
		SemiMajorAxis	2.218731979733
		Eccentricity	0.240949493699
		Inclination	5.855097818405
		AscendingNode	241.747541300981
		ArgOfPericenter	78.54628957427
		MeanAnomaly	286.484629217873
	}
	UniformRotation
	{
		Period	97.4
	}
	LunarLambert	0.5
	Albedo	0.237
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1110"
}

#1_"1111 Reinmuthia:Reinmuthia:1927 CO:1929 QG" "Sol" #1=
#2_"*Рейнмутия:1111 Reinmuthia:Reinmuthia:1927 CO" "Sol" #2=
#3_"1927 CO:*Рейнмутия:1111 Reinmuthia:Reinmuthia" "Sol" #3=
".:Reinmuthia:1111 Reinmuthia:1927 CO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1111 reinmuthia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	15.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	5.179821507945
		SemiMajorAxis	2.993673237395
		Eccentricity	0.100007076226
		Inclination	3.891923709596
		AscendingNode	132.446233346576
		ArgOfPericenter	236.267100431977
		MeanAnomaly	176.669681199751
	}
	UniformRotation
	{
		Period	4.02
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1111"
}

#1_"1112 Polonia:Polonia:1928 PE:1933 PA:A908 XA" "Sol" #1=
#2_"*Полония:1112 Polonia:Polonia:1928 PE" "Sol" #2=
#3_"1928 PE:*Полония:1112 Polonia:Polonia" "Sol" #3=
".:Polonia:1112 Polonia:1928 PE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	17.88
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.258430898472
		SemiMajorAxis	3.023885291949
		Eccentricity	0.104829637716
		Inclination	8.997667325307
		AscendingNode	302.925793795232
		ArgOfPericenter	87.905965371553
		MeanAnomaly	100.715120225894
	}
	UniformRotation
	{
		Period	82.5
	}
	LunarLambert	0.5
	Albedo	0.1319
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1112"
}

#1_"1113 Katja:Katja:1928 QC:A909 DH" "Sol" #1=
#2_"*Катя:1113 Katja:Katja:1928 QC" "Sol" #2=
#3_"1928 QC:*Катя:1113 Katja:Katja" "Sol" #3=
".:Katja:1113 Katja:1928 QC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	22.396
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.48451837458
		SemiMajorAxis	3.109950875743
		Eccentricity	0.142948641643
		Inclination	13.283185749719
		AscendingNode	324.551645131542
		ArgOfPericenter	119.20045339992
		MeanAnomaly	162.313423625615
	}
	UniformRotation
	{
		Period	18.465
	}
	LunarLambert	0.5
	Albedo	0.195
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1113"
}

#1_"1114 Lorraine:Lorraine:1928 WA:1971 YK:A906 UE" "Sol" #1=
#2_"*Лорен:1114 Lorraine:Lorraine:1928 WA" "Sol" #2=
#3_"1928 WA:*Лорен:1114 Lorraine:Lorraine" "Sol" #3=
".:Lorraine:1114 Lorraine:1928 WA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.44297501394
		SemiMajorAxis	3.094226436098
		Eccentricity	0.072857657956
		Inclination	10.741959346332
		AscendingNode	195.51823604142
		ArgOfPericenter	203.097154230597
		MeanAnomaly	317.993883477029
	}
	UniformRotation
	{
		Period	33
	}
	LunarLambert	0.5
	Albedo	0.0501
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1114"
}

#1_"1115 Sabauda:Sabauda:1928 XC:A906 YF" "Sol" #1=
#2_"*Сабауда:1115 Sabauda:Sabauda:1928 XC" "Sol" #2=
#3_"1928 XC:*Сабауда:1115 Sabauda:Sabauda" "Sol" #3=
".:Sabauda:1115 Sabauda:1928 XC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.465276294748
		SemiMajorAxis	3.102672573982
		Eccentricity	0.16963301916
		Inclination	15.264776405208
		AscendingNode	71.724310198238
		ArgOfPericenter	56.968388274304
		MeanAnomaly	238.350561091975
	}
	UniformRotation
	{
		Period	6.75
	}
	LunarLambert	0.5
	Albedo	0.0711
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1115"
}

#1_"1116 Catriona:Catriona:1929 GD:1926 RQ:A908 AC" "Sol" #1=
#2_"*Катриона:1116 Catriona:Catriona:1929 GD" "Sol" #2=
#3_"1929 GD:*Катриона:1116 Catriona:Catriona" "Sol" #3=
".:Catriona:1116 Catriona:1929 GD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	19.56
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.994957417147
		SemiMajorAxis	2.922014669579
		Eccentricity	0.23028134671
		Inclination	16.524318502269
		AscendingNode	356.533653519766
		ArgOfPericenter	82.713497166179
		MeanAnomaly	151.02002940366
	}
	UniformRotation
	{
		Period	8.832
	}
	LunarLambert	0.5
	Albedo	0.1522
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1116"
}

#1_"1118 Hanskya:Hanskya:1927 QD:1930 DK:1935 BM" "Sol" #1=
#2_"*Ганския:1118 Hanskya:Hanskya:1927 QD" "Sol" #2=
#3_"1927 QD:*Ганския:1118 Hanskya:Hanskya" "Sol" #3=
".:Hanskya:1118 Hanskya:1927 QD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.747556720214
		SemiMajorAxis	3.208608347655
		Eccentricity	0.048001437008
		Inclination	13.990455911798
		AscendingNode	318.9111351274
		ArgOfPericenter	334.466907563291
		MeanAnomaly	135.865320782614
	}
	UniformRotation
	{
		Period	15.61
	}
	LunarLambert	0.5
	Albedo	0.047
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1118"
}

#1_"1119 Euboea:Euboea:1927 UB" "Sol" #1=
#2_"*Эвбея:1119 Euboea:Euboea:1927 UB" "Sol" #2=
#3_"1927 UB:*Эвбея:1119 Euboea:Euboea" "Sol" #3=
".:Euboea:1119 Euboea:1927 UB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1119 euboea.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	14.722
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.218471419423
		SemiMajorAxis	2.610745907335
		Eccentricity	0.155268408597
		Inclination	7.857644077412
		AscendingNode	57.389548140994
		ArgOfPericenter	230.284164999124
		MeanAnomaly	316.675151938996
	}
	UniformRotation
	{
		Period	11.41
	}
	LunarLambert	0.5
	Albedo	0.213
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1119"
}

#1_"1121 Natascha:Natascha:1928 RZ:A918 EK" "Sol" #1=
#2_"*Наташа:1121 Natascha:Natascha:1928 RZ" "Sol" #2=
#3_"1928 RZ:Natascha:*Наташа:1121 Natascha" "Sol" #3=
".:Natascha:1121 Natascha:1928 RZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1121 natascha.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.43
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.062812629425
		SemiMajorAxis	2.54612112971
		Eccentricity	0.158474916412
		Inclination	6.164615422296
		AscendingNode	357.908920500895
		ArgOfPericenter	50.423567162786
		MeanAnomaly	236.747555292486
	}
	UniformRotation
	{
		Period	13.197
	}
	LunarLambert	0.5
	Albedo	0.294
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1121"
}

#1_"1122 Neith:Neith:1928 SB:1941 YH:1953 OA:A924 VA" "Sol" #1=
#2_"*Нейт:1122 Neith:Neith:1928 SB" "Sol" #2=
#3_"1928 SB:*Нейт:1122 Neith:Neith" "Sol" #3=
".:Neith:1122 Neith:1928 SB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	6.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.20391726335
		SemiMajorAxis	2.604737556248
		Eccentricity	0.257568378174
		Inclination	4.738660131311
		AscendingNode	63.390791827386
		ArgOfPericenter	329.075172819099
		MeanAnomaly	156.153442228244
	}
	UniformRotation
	{
		Period	12.599
	}
	LunarLambert	0.5
	Albedo	0.445
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1122"
}

#1_"1124 Stroobantia:Stroobantia:1928 TB:1926 FC:1930 BK:1951 DJ" "Sol" #1=
#2_"*Стробантия:1124 Stroobantia:Stroobantia:1928 TB" "Sol" #2=
#3_"1928 TB:*Стробантия:1124 Stroobantia:Stroobantia" "Sol" #3=
".:Stroobantia:1124 Stroobantia:1928 TB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.325
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.005162494034
		SemiMajorAxis	2.925993247334
		Eccentricity	0.032645402406
		Inclination	7.786835829807
		AscendingNode	22.320927111539
		ArgOfPericenter	262.791742425092
		MeanAnomaly	154.281474662453
	}
	UniformRotation
	{
		Period	16.39
	}
	LunarLambert	0.5
	Albedo	0.1569
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1124"
}

#1_"1125 China:China:1957 UN1:1959 EL:1971 KX:1974 VM:A909 BE" "Sol" #1=
#2_"*Китай:1125 China:China:1957 UN1" "Sol" #2=
#3_"1957 UN1:China:*Китай:1125 China" "Sol" #3=
".:China:1125 China:1957 UN1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1125 china.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	13.256
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.52765293224
		SemiMajorAxis	3.12623563943
		Eccentricity	0.218142337723
		Inclination	3.040984815754
		AscendingNode	97.173506324713
		ArgOfPericenter	10.767609113907
		MeanAnomaly	179.316216694034
	}
	UniformRotation
	{
		Period	5.367
	}
	LunarLambert	0.5
	Albedo	0.057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1125"
}

#1_"1126 Otero:Otero:1929 AC:1926 GD:1948 RN1:1949 YO" "Sol" #1=
#2_"*Отеро:1126 Otero:Otero:1929 AC" "Sol" #2=
#3_"1929 AC:*Отеро:1126 Otero:Otero" "Sol" #3=
".:Otero:1126 Otero:1929 AC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1126 otero.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	5.487
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.425542461305
		SemiMajorAxis	2.272379007779
		Eccentricity	0.147059905916
		Inclination	6.504420271029
		AscendingNode	1.093920886361
		ArgOfPericenter	136.08898777922
		MeanAnomaly	3.3024780317
	}
	UniformRotation
	{
		Period	3.6481
	}
	LunarLambert	0.5
	Albedo	0.399
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1126"
}

#1_"1127 Mimi:Mimi:1929 AJ:1948 PU:A906 OA" "Sol" #1=
#2_"*Мими:1127 Mimi:Mimi:1929 AJ" "Sol" #2=
#3_"1929 AJ:*Мими:1127 Mimi:Mimi" "Sol" #3=
".:Mimi:1127 Mimi:1929 AJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1127 mimi.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	23.003
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.17991810651
		SemiMajorAxis	2.59481488495
		Eccentricity	0.264619632055
		Inclination	14.753076024939
		AscendingNode	128.662868977282
		ArgOfPericenter	281.761539871899
		MeanAnomaly	246.639878883193
	}
	UniformRotation
	{
		Period	12.749
	}
	LunarLambert	0.5
	Albedo	0.034
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1127"
}

#1_"1128 Astrid:Astrid:1929 EB:1949 QF2:1954 UL3:1964 VW:1972 LM1:A917 SQ:A920 JA" "Sol" #1=
#2_"*Астрид:1128 Astrid:Astrid:1929 EB" "Sol" #2=
#3_"1929 EB:*Астрид:1128 Astrid:Astrid" "Sol" #3=
".:Astrid:1128 Astrid:1929 EB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.345
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.653783619618
		SemiMajorAxis	2.78739589586
		Eccentricity	0.046739534298
		Inclination	1.01455728451
		AscendingNode	59.409359666798
		ArgOfPericenter	235.467418812821
		MeanAnomaly	35.303858847417
	}
	UniformRotation
	{
		Period	10.228
	}
	LunarLambert	0.5
	Albedo	0.077
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1128"
}

#1_"1129 Neujmina:Neujmina:1929 PH:1926 AE:A914 WE" "Sol" #1=
#2_"*Неуймина:1129 Neujmina:Neujmina:1929 PH" "Sol" #2=
#3_"1929 PH:*Неуймина:1129 Neujmina:Neujmina" "Sol" #3=
".:Neujmina:1129 Neujmina:1929 PH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	17.38
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.254283972866
		SemiMajorAxis	3.022295276934
		Eccentricity	0.079699209971
		Inclination	8.616768111939
		AscendingNode	269.523603001854
		ArgOfPericenter	138.255661756141
		MeanAnomaly	18.91547699819
	}
	UniformRotation
	{
		Period	5.0844
	}
	LunarLambert	0.5
	Albedo	0.1216
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1129"
}

#1_"1130 Skuld:Skuld:1929 RC:1928 FJ:1949 UD:1962 LA:A906 VC" "Sol" #1=
#2_"*Скульд:1130 Skuld:Skuld:1929 RC" "Sol" #2=
#3_"1929 RC:*Скульд:1130 Skuld:Skuld" "Sol" #3=
".:Skuld:1130 Skuld:1929 RC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1130 skuld.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	5.062
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.32663908003
		SemiMajorAxis	2.22842653875
		Eccentricity	0.198240175508
		Inclination	2.167404996505
		AscendingNode	216.140278262256
		ArgOfPericenter	113.90475254
		MeanAnomaly	296.223706621454
	}
	UniformRotation
	{
		Period	4.81
	}
	LunarLambert	0.5
	Albedo	0.302
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1130"
}

#1_"1135 Colchis:Colchis:1929 TA:1936 FJ1:1940 EP:1954 LL:1958 FO:A911 MJ:A916 UH" "Sol" #1=
#2_"*Колхида:1135 Colchis:Colchis:1929 TA" "Sol" #2=
#3_"1929 TA:*Колхида:1135 Colchis:Colchis" "Sol" #3=
".:Colchis:1135 Colchis:1929 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1135 colchis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	25.296
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.349677672066
		SemiMajorAxis	2.66460342624
		Eccentricity	0.115980883854
		Inclination	4.541468965331
		AscendingNode	350.744065941612
		ArgOfPericenter	3.970415474684
		MeanAnomaly	221.032094152231
	}
	UniformRotation
	{
		Period	23.47
	}
	LunarLambert	0.5
	Albedo	0.057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1135"
}

#1_"1136 Mercedes:Mercedes:1929 UA:1966 XB" "Sol" #1=
#2_"*Мерседес:1136 Mercedes:Mercedes:1929 UA" "Sol" #2=
#3_"1929 UA:*Мерседес:1136 Mercedes:Mercedes" "Sol" #3=
".:Mercedes:1136 Mercedes:1929 UA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.108801285786
		SemiMajorAxis	2.565298794867
		Eccentricity	0.255900663885
		Inclination	8.981223915953
		AscendingNode	209.542793465273
		ArgOfPericenter	148.503471032844
		MeanAnomaly	291.752569105147
	}
	UniformRotation
	{
		Period	24.64
	}
	LunarLambert	0.5
	Albedo	0.11
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1136"
}

#1_"1137 Raissa:Raissa:1929 WB:A908 BB:A910 TB:A924 JA" "Sol" #1=
#2_"*Раиса:1137 Raissa:Raissa:1929 WB" "Sol" #2=
#3_"1929 WB:*Раиса:1137 Raissa:Raissa" "Sol" #3=
".:Raissa:1137 Raissa:1929 WB" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"1137 raissa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.71
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.77231050953
		SemiMajorAxis	2.423257064571
		Eccentricity	0.097781895054
		Inclination	4.316288194429
		AscendingNode	78.461419439055
		ArgOfPericenter	277.33525417295
		MeanAnomaly	231.209490464265
	}
	UniformRotation
	{
		Period	142.79
	}
	LunarLambert	0.5
	Albedo	0.228
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1137"
}

#1_"1140 Crimea:Crimea:1929 YC:A922 HA" "Sol" #1=
#2_"*Крымия:1140 Crimea:Crimea:1929 YC" "Sol" #2=
#3_"1929 YC:*Крымия:1140 Crimea:Crimea" "Sol" #3=
".:Crimea:1140 Crimea:1929 YC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1140 crimea.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	14.59
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.6121975655842
		SemiMajorAxis	2.770765682230143
		Eccentricity	0.1133698018133698
		Inclination	14.13676869104091
		AscendingNode	72.15136364494717
		ArgOfPericenter	310.4565943064716
		MeanAnomaly	210.3541734723853
	}
	UniformRotation
	{
		Period	9.77
	}
	LunarLambert	0.5
	Albedo	0.16
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1140"
}

#1_"1141 Bohmia:Bohmia:1930 AA:1949 SU" "Sol" #1=
#2_"*Бомия:1141 Bohmia:Bohmia:1930 AA" "Sol" #2=
#3_"1930 AA:*Бомия:1141 Bohmia:Bohmia" "Sol" #3=
".:Bohmia:1141 Bohmia:1930 AA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.421333001558
		SemiMajorAxis	2.270517025679
		Eccentricity	0.164661869912
		Inclination	4.276385721081
		AscendingNode	105.589750657016
		ArgOfPericenter	275.722967101178
		MeanAnomaly	357.341764399004
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.054
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1141"
}

#1_"1143 Odysseus:Odysseus:1930 BH" "Sol" #1=
#2_"*Одиссей:1143 Odysseus:Odysseus:1930 BH" "Sol" #2=
#3_"1930 BH:*Одиссей:1143 Odysseus:Odysseus" "Sol" #3=
".:Odysseus:1143 Odysseus:1930 BH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	62.82
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.023422444876
		SemiMajorAxis	5.248234954364
		Eccentricity	0.090262961131
		Inclination	3.137894135166
		AscendingNode	221.292445445242
		ArgOfPericenter	236.927753251188
		MeanAnomaly	84.986147863775
	}
	UniformRotation
	{
		Period	10.111
	}
	LunarLambert	0.5
	Albedo	0.0753
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1143"
}

#1_"1144 Oda:Oda:1930 BJ:1959 CJ:1967 EV" "Sol" #1=
#2_"*Ода:1144 Oda:Oda:1930 BJ" "Sol" #2=
#3_"1930 BJ:*Ода:1144 Oda:Oda" "Sol" #3=
".:Oda:1144 Oda:1930 BJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.795
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.264150645425
		SemiMajorAxis	3.750746907705
		Eccentricity	0.095136118964
		Inclination	9.742559086396
		AscendingNode	156.729430608753
		ArgOfPericenter	220.976022189718
		MeanAnomaly	355.335724720777
	}
	UniformRotation
	{
		Period	14.4
	}
	LunarLambert	0.5
	Albedo	0.0533
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1144"
}

#1_"1145 Robelmonte:Robelmonte:1929 CC:A915 RN" "Sol" #1=
#2_"*Робельмон:1145 Robelmonte:Robelmonte:1929 CC" "Sol" #2=
#3_"1929 CC:*Робельмон:1145 Robelmonte:Robelmonte" "Sol" #3=
".:Robelmonte:1145 Robelmonte:1929 CC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.625
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.771814104694
		SemiMajorAxis	2.423044472862
		Eccentricity	0.119673150915
		Inclination	6.208469852853
		AscendingNode	346.831801670181
		ArgOfPericenter	267.596929576492
		MeanAnomaly	166.758817144642
	}
	UniformRotation
	{
		Period	9.01
	}
	LunarLambert	0.5
	Albedo	0.1186
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1145"
}

#1_"1146 Biarmia:Biarmia:1929 JF:1941 WD1:A913 KA" "Sol" #1=
#2_"*Биармия:1146 Biarmia:Biarmia:1929 JF" "Sol" #2=
#3_"1929 JF:*Биармия:1146 Biarmia:Biarmia" "Sol" #3=
".:Biarmia:1146 Biarmia:1929 JF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	15.57
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.315737119681
		SemiMajorAxis	3.045815053986
		Eccentricity	0.25444289876
		Inclination	17.062412597934
		AscendingNode	213.897806147452
		ArgOfPericenter	63.883936398406
		MeanAnomaly	358.905437307188
	}
	UniformRotation
	{
		Period	5.47
	}
	LunarLambert	0.5
	Albedo	0.219
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1146"
}

#1_"1147 Stavropolis:Stavropolis:1929 LF:1946 KA" "Sol" #1=
#2_"*Ставрополис:1147 Stavropolis:Stavropolis:1929 LF" "Sol" #2=
#3_"1929 LF:Stavropolis:*Ставрополис:1147 Stavropolis" "Sol" #3=
".:Stavropolis:1147 Stavropolis:1929 LF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1147 stavropolis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.715
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.421244632143
		SemiMajorAxis	2.270477928808
		Eccentricity	0.232063515202
		Inclination	3.880790478183
		AscendingNode	265.226598031418
		ArgOfPericenter	15.774266639118
		MeanAnomaly	213.58426338462
	}
	UniformRotation
	{
		Period	5.6607
	}
	LunarLambert	0.5
	Albedo	0.155
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1147"
}

#1_"1148 Rarahu:Rarahu:1929 NA:A924 OA" "Sol" #1=
#2_"*Рараху:1148 Rarahu:Rarahu:1929 NA" "Sol" #2=
#3_"1929 NA:*Рараху:1148 Rarahu:Rarahu" "Sol" #3=
".:Rarahu:1148 Rarahu:1929 NA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1148 rarahu.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	13.756
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.233896491984
		SemiMajorAxis	3.014472212465
		Eccentricity	0.111970999553
		Inclination	10.84993130129
		AscendingNode	145.530744408298
		ArgOfPericenter	174.157408871623
		MeanAnomaly	90.952893620961
	}
	UniformRotation
	{
		Period	6.5447
	}
	LunarLambert	0.5
	Albedo	0.064
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1148"
}

#1_"1149 Volga:Volga:1929 PF" "Sol" #1=
#2_"*Волга:1149 Volga:Volga:1929 PF" "Sol" #2=
#3_"1929 PF:*Волга:1149 Volga:Volga" "Sol" #3=
".:Volga:1149 Volga:1929 PF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.935559570232
		SemiMajorAxis	2.898803634633
		Eccentricity	0.093297550847
		Inclination	11.749474561634
		AscendingNode	261.700298026174
		ArgOfPericenter	114.778816517063
		MeanAnomaly	60.595473094449
	}
	UniformRotation
	{
		Period	27.5
	}
	LunarLambert	0.5
	Albedo	0.0338
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1149"
}

#1_"1150 Achaia:Achaia:1929 RB:1955 SZ1" "Sol" #1=
#2_"*Ахайя:1150 Achaia:Achaia:1929 RB" "Sol" #2=
#3_"1929 RB:Achaia:*Ахайя:1150 Achaia" "Sol" #3=
".:Achaia:1150 Achaia:1929 RB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1150 achaia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	3.844
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.24274162213
		SemiMajorAxis	2.190800152429
		Eccentricity	0.204675591859
		Inclination	2.392864238024
		AscendingNode	206.542619903577
		ArgOfPericenter	139.584567511149
		MeanAnomaly	348.005954647842
	}
	UniformRotation
	{
		Period	60.99
	}
	LunarLambert	0.5
	Albedo	0.251
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1150"
}

#1_"1152 Pawona:Pawona:1930 AD:1926 AK:1942 GE1:1942 GY:1969 MD:A924 QA" "Sol" #1=
#2_"*Павона:1152 Pawona:Pawona:1930 AD" "Sol" #2=
#3_"1930 AD:*Павона:1152 Pawona:Pawona" "Sol" #3=
".:Pawona:1152 Pawona:1930 AD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	7.845
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.781308237034
		SemiMajorAxis	2.427108841549
		Eccentricity	0.041244512017
		Inclination	5.081043965208
		AscendingNode	331.917836804628
		ArgOfPericenter	218.37613849558
		MeanAnomaly	95.562296057728
	}
	UniformRotation
	{
		Period	3.4154
	}
	LunarLambert	0.5
	Albedo	0.2167
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1152"
}

#1_"1154 Astronomia:Astronomia:1927 CB:A911 RA" "Sol" #1=
#2_"*Астрономия:1154 Astronomia:Astronomia:1927 CB" "Sol" #2=
#3_"1927 CB:*Астрономия:1154 Astronomia:Astronomia" "Sol" #3=
".:Astronomia:1154 Astronomia:1927 CB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	30.54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.2683863596022
		SemiMajorAxis	3.399630391956757
		Eccentricity	0.0701866055015772
		Inclination	4.533131539144511
		AscendingNode	82.64001956923249
		ArgOfPericenter	201.3278697887671
		MeanAnomaly	227.1441932891221
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0296
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1154"
}

#1_"1155 Aenna:Aenna:1928 BD:1928 FU:1941 UZ:1982 DR6" "Sol" #1=
#2_"*Аэнна:1155 Aenna:Aenna:1928 BD" "Sol" #2=
#3_"1928 BD:*Аэнна:1155 Aenna:Aenna" "Sol" #3=
".:Aenna:1155 Aenna:1928 BD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	5.82
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.867895896502
		SemiMajorAxis	2.464020875547
		Eccentricity	0.164193586199
		Inclination	6.592172619131
		AscendingNode	39.12776275242
		ArgOfPericenter	195.612574516058
		MeanAnomaly	96.014325297882
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.3278
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1155"
}

#1_"1158 Luda:Luda:1929 QF:1954 UQ1:1958 TG1:1972 GC" "Sol" #1=
#2_"*Люда:1158 Luda:Luda:1929 QF" "Sol" #2=
#3_"1929 QF:*Люда:1158 Luda:Luda" "Sol" #3=
".:Luda:1158 Luda:1929 QF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.53
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.105497312943
		SemiMajorAxis	2.563923403639
		Eccentricity	0.11334147398
		Inclination	14.834035397862
		AscendingNode	344.742002973415
		ArgOfPericenter	56.33196281921
		MeanAnomaly	223.918256389853
	}
	UniformRotation
	{
		Period	6.863
	}
	LunarLambert	0.5
	Albedo	0.2329
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1158"
}

#1_"1159 Granada:Granada:1929 RD:1931 AR:1940 RS" "Sol" #1=
#2_"*Гранада:1159 Granada:Granada:1929 RD" "Sol" #2=
#3_"1929 RD:*Гранада:1159 Granada:Granada" "Sol" #3=
".:Granada:1159 Granada:1929 RD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.99
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.669910822745
		SemiMajorAxis	2.379203221909
		Eccentricity	0.059002806244
		Inclination	13.030427843996
		AscendingNode	347.901119219068
		ArgOfPericenter	312.398198401333
		MeanAnomaly	127.67525522396
	}
	UniformRotation
	{
		Period	31
	}
	LunarLambert	0.5
	Albedo	0.0471
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1159"
}

#1_"1161 Thessalia:Thessalia:1929 SF:1931 BB" "Sol" #1=
#2_"*Фессалия:1161 Thessalia:Thessalia:1929 SF" "Sol" #2=
#3_"1929 SF:*Фессалия:1161 Thessalia:Thessalia" "Sol" #3=
".:Thessalia:1161 Thessalia:1929 SF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.642368100727
		SemiMajorAxis	3.169339832053
		Eccentricity	0.086320734108
		Inclination	9.376055421932
		AscendingNode	72.899030498198
		ArgOfPericenter	306.113944512688
		MeanAnomaly	41.684852733446
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0439
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1161"
}

#1_"1162 Larissa:Larissa (asteroid):1930 AC:1948 KJ" "Sol" #1=
#2_"*Ларисса (астероид):1162 Larissa:Larissa (asteroid):1930 AC" "Sol" #2=
#3_"1930 AC:*Ларисса (астероид):1162 Larissa:Larissa (asteroid)" "Sol" #3=
".:Larissa (asteroid):1162 Larissa:1930 AC" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	22.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.769436397744
		SemiMajorAxis	3.922722101424
		Eccentricity	0.109796879659
		Inclination	1.887360844156
		AscendingNode	39.784472359972
		ArgOfPericenter	211.840761176714
		MeanAnomaly	186.392008564564
	}
	UniformRotation
	{
		Period	6.516
	}
	LunarLambert	0.5
	Albedo	0.1485
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1162"
}

#1_"1163 Saga:Saga:1930 BA" "Sol" #1=
#2_"*Сага:1163 Saga:Saga:1930 BA" "Sol" #2=
#3_"1930 BA:*Сага:1163 Saga:Saga" "Sol" #3=
".:Saga:1163 Saga:1930 BA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.555
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.767684063819
		SemiMajorAxis	3.216094790084
		Eccentricity	0.047404924283
		Inclination	9.026402261057
		AscendingNode	127.803223863252
		ArgOfPericenter	197.98333016063
		MeanAnomaly	66.070474378939
	}
	UniformRotation
	{
		Period	9.365
	}
	LunarLambert	0.5
	Albedo	0.12
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1163"
}

#1_"1165 Imprinetta:Imprinetta:1930 HM:A909 TA" "Sol" #1=
#2_"*Импринетта:1165 Imprinetta:Imprinetta:1930 HM" "Sol" #2=
#3_"1930 HM:*Импринетта:1165 Imprinetta:Imprinetta" "Sol" #3=
".:Imprinetta:1165 Imprinetta:1930 HM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.52610525712
		SemiMajorAxis	3.125652073736
		Eccentricity	0.212820855726
		Inclination	12.809229953881
		AscendingNode	203.787000560718
		ArgOfPericenter	97.179484047082
		MeanAnomaly	43.188070420046
	}
	UniformRotation
	{
		Period	7.9374
	}
	LunarLambert	0.5
	Albedo	0.0562
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1165"
}

#1_"1166 Sakuntala:Sakuntala:1930 MA:1962 KA" "Sol" #1=
#2_"*Шакунтала:1166 Sakuntala:Sakuntala:1930 MA" "Sol" #2=
#3_"1930 MA:*Шакунтала:1166 Sakuntala:Sakuntala" "Sol" #3=
".:Sakuntala:1166 Sakuntala:1930 MA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.37
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.036064204646
		SemiMajorAxis	2.534933530433
		Eccentricity	0.208766685126
		Inclination	18.921558547673
		AscendingNode	106.700255369317
		ArgOfPericenter	190.012568500591
		MeanAnomaly	293.096284248738
	}
	UniformRotation
	{
		Period	6.3
	}
	LunarLambert	0.5
	Albedo	0.646
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1166"
}

#1_"1167 Dubiago:Dubiago:1930 PB:1931 VJ1:1938 WW:1950 QX:A924 RF" "Sol" #1=
#2_"*Дубяго:1167 Dubiago:Dubiago:1930 PB" "Sol" #2=
#3_"1930 PB:*Дубяго:1167 Dubiago:Dubiago" "Sol" #3=
".:Dubiago:1167 Dubiago:1930 PB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.56
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.299105645949
		SemiMajorAxis	3.410728315108
		Eccentricity	0.075136392013
		Inclination	5.719948740593
		AscendingNode	223.884676327276
		ArgOfPericenter	69.484877546704
		MeanAnomaly	159.7573807488
	}
	UniformRotation
	{
		Period	14.3
	}
	LunarLambert	0.5
	Albedo	0.0509
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1167"
}

#1_"1168 Brandia:Brandia:1930 QA" "Sol" #1=
#2_"*Брандия:1168 Brandia:Brandia:1930 QA" "Sol" #2=
#3_"1930 QA:*Брандия:1168 Brandia:Brandia" "Sol" #3=
".:Brandia:1168 Brandia:1930 QA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.305
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.074348508638
		SemiMajorAxis	2.550938459706
		Eccentricity	0.218516619641
		Inclination	12.734258554957
		AscendingNode	218.660773981273
		ArgOfPericenter	123.047053963696
		MeanAnomaly	238.515261044673
	}
	UniformRotation
	{
		Period	11.444
	}
	LunarLambert	0.5
	Albedo	0.1526
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1168"
}

#1_"1170 Siva:Siva:1930 SQ" "Sol" #1=
#2_"*Шива:1170 Siva:Siva:1930 SQ" "Sol" #2=
#3_"1930 SQ:*Шива:1170 Siva:Siva" "Sol" #3=
".:Siva:1170 Siva:1930 SQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.54733180004
		SemiMajorAxis	2.325925177991
		Eccentricity	0.299939788549
		Inclination	22.184759734201
		AscendingNode	0.92731603521
		ArgOfPericenter	59.313947807697
		MeanAnomaly	232.573754248258
	}
	UniformRotation
	{
		Period	5
	}
	LunarLambert	0.5
	Albedo	0.1751
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1170"
}

#1_"1171 Rusthawelia:Rusthawelia:1930 TA:1926 AD:1926 FH:1927 FC:1949 BT:A904 EB:A913 TA" "Sol" #1=
#2_"*Руставелия:1171 Rusthawelia:Rusthawelia:1930 TA" "Sol" #2=
#3_"1930 TA:*Руставелия:1171 Rusthawelia:Rusthawelia" "Sol" #3=
".:Rusthawelia:1171 Rusthawelia:1930 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	35.065
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.667323472201
		SemiMajorAxis	3.178677975616
		Eccentricity	0.191016324956
		Inclination	3.075934929787
		AscendingNode	122.216076358722
		ArgOfPericenter	288.59108208
		MeanAnomaly	329.162015934438
	}
	UniformRotation
	{
		Period	10.98
	}
	LunarLambert	0.5
	Albedo	0.0394
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1171"
}

#1_"1172 Aneas:Aneas:1930 UA" "Sol" #1=
#2_"*Эней:1172 Aneas:Aneas:1930 UA" "Sol" #2=
#3_"1930 UA:*Эней:1172 Aneas:Aneas" "Sol" #3=
".:Aneas:1172 Aneas:1930 UA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	71.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.915929822538
		SemiMajorAxis	5.216907739966
		Eccentricity	0.103946131965
		Inclination	16.667511644117
		AscendingNode	247.335081400071
		ArgOfPericenter	51.584022764128
		MeanAnomaly	138.217984140275
	}
	UniformRotation
	{
		Period	8.705
	}
	LunarLambert	0.5
	Albedo	0.0403
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1172"
}

#1_"1173 Anchises:Anchises:1930 UB" "Sol" #1=
#2_"*Анхис:1173 Anchises:Anchises:1930 UB" "Sol" #2=
#3_"1930 UB:*Анхис:1173 Anchises:Anchises" "Sol" #3=
".:Anchises:1173 Anchises:1930 UB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	63.135
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.209352677267
		SemiMajorAxis	5.302202267107
		Eccentricity	0.137136477799
		Inclination	6.91533000201
		AscendingNode	283.904693301186
		ArgOfPericenter	41.089809185171
		MeanAnomaly	86.757043268947
	}
	UniformRotation
	{
		Period	11.6
	}
	LunarLambert	0.5
	Albedo	0.0308
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1173"
}

#1_"1174 Marmara:Marmara:1930 UC" "Sol" #1=
#2_"*Мармара:1174 Marmara:Marmara:1930 UC" "Sol" #2=
#3_"1930 UC:*Мармара:1174 Marmara:Marmara" "Sol" #3=
".:Marmara:1174 Marmara:1930 UC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.105
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.253059743583
		SemiMajorAxis	3.021825802743
		Eccentricity	0.112470433981
		Inclination	10.091191074385
		AscendingNode	1.036836079814
		ArgOfPericenter	351.006867172323
		MeanAnomaly	41.148943081144
	}
	UniformRotation
	{
		Period	12
	}
	LunarLambert	0.5
	Albedo	0.1065
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1174"
}

#1_"1175 Margo:Margo:1930 UD:1953 VK:1957 KU:A907 VA" "Sol" #1=
#2_"*Марго:1175 Margo:Margo:1930 UD" "Sol" #2=
#3_"1930 UD:Margo:*Марго:1175 Margo" "Sol" #3=
".:Margo:1175 Margo:1930 UD:1953 VK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1175 margo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	12.133
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.767879968349
		SemiMajorAxis	3.216167614689
		Eccentricity	0.067778113159
		Inclination	16.306177514131
		AscendingNode	237.189368911459
		ArgOfPericenter	102.850350779694
		MeanAnomaly	27.029945180689
	}
	UniformRotation
	{
		Period	6.01
	}
	LunarLambert	0.5
	Albedo	0.249
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1175"
}

#1_"1176 Lucidor:Lucidor:1930 VE:1927 BF:1971 BD2" "Sol" #1=
#2_"*Люсидор:1176 Lucidor:Lucidor:1930 VE" "Sol" #2=
#3_"1930 VE:*Люсидор:1176 Lucidor:Lucidor" "Sol" #3=
".:Lucidor:1176 Lucidor:1930 VE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.325
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.417012269328
		SemiMajorAxis	2.692032315462
		Eccentricity	0.141537145917
		Inclination	6.647353310814
		AscendingNode	272.369175832137
		ArgOfPericenter	156.331672130744
		MeanAnomaly	1.706073922235
	}
	UniformRotation
	{
		Period	4.0791
	}
	LunarLambert	0.5
	Albedo	0.0821
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1176"
}

#1_"1177 Gonnessia:Gonnessia:1930 WA:A923 RO" "Sol" #1=
#2_"*Гоннессия:1177 Gonnessia:Gonnessia:1930 WA" "Sol" #2=
#3_"1930 WA:*Гоннессия:1177 Gonnessia:Gonnessia" "Sol" #3=
".:Gonnessia:1177 Gonnessia:1930 WA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	45.99
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.133275548698
		SemiMajorAxis	3.350602047594
		Eccentricity	0.031314235162
		Inclination	15.066019593786
		AscendingNode	252.182245766646
		ArgOfPericenter	240.399087295904
		MeanAnomaly	185.137741939991
	}
	UniformRotation
	{
		Period	30.51
	}
	LunarLambert	0.5
	Albedo	0.0398
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1177"
}

#1_"1178 Irmela:Irmela:1931 EC:1940 GC:1962 JD:1988 CK6" "Sol" #1=
#2_"*Ирмела:1178 Irmela:Irmela:1931 EC" "Sol" #2=
#3_"1931 EC:*Ирмела:1178 Irmela:Irmela" "Sol" #3=
".:Irmela:1178 Irmela:1931 EC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.545
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.386413457583
		SemiMajorAxis	2.679585230514
		Eccentricity	0.182656289083
		Inclination	6.950999872428
		AscendingNode	170.114572089863
		ArgOfPericenter	357.0505222494
		MeanAnomaly	30.353961315478
	}
	UniformRotation
	{
		Period	11.989
	}
	LunarLambert	0.5
	Albedo	0.0916
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1178"
}

#1_"1180 Rita:Rita:1931 GE:1929 CM:1953 AH:1957 UF1:A907 GG:A908 KA:A916 LA" "Sol" #1=
#2_"*Рита:1180 Rita:Rita:1931 GE" "Sol" #2=
#3_"1931 GE:*Рита:1180 Rita:Rita" "Sol" #3=
".:Rita:1180 Rita:1931 GE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	48.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.953791447355
		SemiMajorAxis	3.984532113615
		Eccentricity	0.157897032966
		Inclination	7.199338175851
		AscendingNode	88.341483077217
		ArgOfPericenter	209.384195433589
		MeanAnomaly	109.639844337384
	}
	UniformRotation
	{
		Period	9.605
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1180"
}

#1_"1182 Ilona:Ilona:1927 EA:A915 RD" "Sol" #1=
#2_"*Илона:1182 Ilona:Ilona:1927 EA" "Sol" #2=
#3_"1927 EA:*Илона:1182 Ilona:Ilona" "Sol" #3=
".:Ilona:1182 Ilona:1927 EA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.13
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.396609078244
		SemiMajorAxis	2.25956536499
		Eccentricity	0.116967022986
		Inclination	9.389065113451
		AscendingNode	336.384594944178
		ArgOfPericenter	63.05913670844
		MeanAnomaly	37.83727599029
	}
	UniformRotation
	{
		Period	29.8
	}
	LunarLambert	0.5
	Albedo	0.2624
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1182"
}

#1_"1183 Jutta:Jutta:1930 DC:1961 VB" "Sol" #1=
#2_"*Ютта:1183 Jutta:Jutta:1930 DC" "Sol" #2=
#3_"1930 DC:*Ютта:1183 Jutta:Jutta" "Sol" #3=
".:Jutta:1183 Jutta:1930 DC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.679247348279
		SemiMajorAxis	2.383236759242
		Eccentricity	0.129786676756
		Inclination	2.801433242172
		AscendingNode	15.146060090321
		ArgOfPericenter	205.397731112287
		MeanAnomaly	335.96883396488
	}
	UniformRotation
	{
		Period	212.5
	}
	LunarLambert	0.5
	Albedo	0.0797
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1183"
}

#1_"1186 Turnera:Turnera:1929 PL:1930 UO:1930 WL:1932 CC:A919 SE" "Sol" #1=
#2_"*Тернера:1186 Turnera:Turnera:1929 PL" "Sol" #2=
#3_"1929 PL:*Тернера:1186 Turnera:Turnera" "Sol" #3=
".:Turnera:1186 Turnera:1929 PL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	17.78
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.248037792587
		SemiMajorAxis	3.01989957551
		Eccentricity	0.104110917678
		Inclination	10.739027532837
		AscendingNode	43.09346835601
		ArgOfPericenter	294.011037666621
		MeanAnomaly	65.679546181294
	}
	UniformRotation
	{
		Period	12.066
	}
	LunarLambert	0.5
	Albedo	0.2919
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1186"
}

#1_"1187 Afra:Afra:1929 XC" "Sol" #1=
#2_"*Афра:1187 Afra:Afra:1929 XC" "Sol" #2=
#3_"1929 XC:*Афра:1187 Afra:Afra" "Sol" #3=
".:Afra:1187 Afra:1929 XC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1187 afra.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	16.174
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.292570808045
		SemiMajorAxis	2.641229729506
		Eccentricity	0.221021437422
		Inclination	10.717780236469
		AscendingNode	327.41568319502
		ArgOfPericenter	74.040651787843
		MeanAnomaly	313.617098022927
	}
	UniformRotation
	{
		Period	14.0701
	}
	LunarLambert	0.5
	Albedo	0.051
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1187"
}

#1_"1188 Gothlandia:Gothlandia:1930 SB:A917 SK" "Sol" #1=
#2_"*Готландия:1188 Gothlandia:Gothlandia:1930 SB" "Sol" #2=
#3_"1930 SB:*Готландия:1188 Gothlandia:Gothlandia:1917 SK" "Sol" #3=
".:Gothlandia:1188 Gothlandia:1930 SB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1188 gothlandia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.335
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.24217355011
		SemiMajorAxis	2.190544284863
		Eccentricity	0.180156641971
		Inclination	4.817884623685
		AscendingNode	5.464276136561
		ArgOfPericenter	6.767935133845
		MeanAnomaly	351.202555864506
	}
	UniformRotation
	{
		Period	3.4916
	}
	LunarLambert	0.5
	Albedo	0.273
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1188"
}

#1_"1189 Terentia:Terentia:1930 SG:1935 SK2:A915 TJ" "Sol" #1=
#2_"*Теренция:1189 Terentia:Terentia:1930 SG" "Sol" #2=
#3_"1930 SG:*Теренция:1189 Terentia:Terentia" "Sol" #3=
".:Terentia:1189 Terentia:1930 SG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.017150126307
		SemiMajorAxis	2.930663324763
		Eccentricity	0.115820461407
		Inclination	9.866706161912
		AscendingNode	275.25917196045
		ArgOfPericenter	95.856130077423
		MeanAnomaly	266.917508583739
	}
	UniformRotation
	{
		Period	19.308
	}
	LunarLambert	0.5
	Albedo	0.0566
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1189"
}

#1_"1190 Pelagia:Pelagia:1930 SL:1928 DP:1938 YA:1953 VB:1953 XP:A909 BC" "Sol" #1=
#2_"*Пелагея:1190 Pelagia:Pelagia:1930 SL" "Sol" #2=
#3_"1930 SL:*Пелагея:1190 Pelagia:Pelagia" "Sol" #3=
".:Pelagia:1190 Pelagia:1930 SL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.725
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.791893693249
		SemiMajorAxis	2.431636389605
		Eccentricity	0.131531093701
		Inclination	3.168706001726
		AscendingNode	26.50496547543
		ArgOfPericenter	41.490822372706
		MeanAnomaly	24.676904887439
	}
	UniformRotation
	{
		Period	2.3661
	}
	LunarLambert	0.5
	Albedo	0.0636
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1190"
}

#1_"1191 Alfaterna:Alfaterna:1931 CA:1965 AA " "Sol" #1=
#2_"*Альфатерна:1191 Alfaterna:Alfaterna:1931 CA" "Sol" #2=
#3_"1931 CA:*Альфатерна:1191 Alfaterna:Alfaterna" "Sol" #3=
".:Alfaterna:1191 Alfaterna:1931 CA" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	21.045
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.919912546492
		SemiMajorAxis	2.892673745554
		Eccentricity	0.047694283096
		Inclination	18.494519694757
		AscendingNode	134.729728913541
		ArgOfPericenter	52.731513339525
		MeanAnomaly	338.26334196513
	}
	UniformRotation
	{
		Period	3.664
	}
	LunarLambert	0.5
	Albedo	0.0574
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1191"
}

#1_"1192 Prisma:Prisma:1931 FE" "Sol" #1=
#2_"*Призма:1192 Prisma:Prisma:1931 FE" "Sol" #2=
#3_"1931 FE:Prisma:*Призма:1192 Prisma" "Sol" #3=
".:Prisma:1192 Prisma:1931 FE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1192 prisma.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.688
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.639704822803
		SemiMajorAxis	2.366130213995
		Eccentricity	0.257897998877
		Inclination	23.903258735737
		AscendingNode	1.352611630109
		ArgOfPericenter	131.43803812718
		MeanAnomaly	243.472637002508
	}
	UniformRotation
	{
		Period	6.558
	}
	LunarLambert	0.5
	Albedo	0.22
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1192"
}

#1_"1194 Aletta:Aletta:1931 JG:1946 KC:1962 SB" "Sol" #1=
#2_"*Алетта:1194 Aletta:Aletta:1931 JG" "Sol" #2=
#3_"1931 JG:*Алетта:1194 Aletta:Aletta" "Sol" #3=
".:Aletta:1194 Aletta:1931 JG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.695
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.975552081312
		SemiMajorAxis	2.914441771605
		Eccentricity	0.092801106515
		Inclination	10.872506528239
		AscendingNode	291.33442817932
		ArgOfPericenter	243.040944605167
		MeanAnomaly	340.251338466058
	}
	UniformRotation
	{
		Period	20.39
	}
	LunarLambert	0.5
	Albedo	0.0479
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1194"
}

#1_"1196 Sheba:Sheba:1931 KE:A912 BB" "Sol" #1=
#2_"*Шеба:1196 Sheba:Sheba:1931 KE" "Sol" #2=
#3_"1931 KE:*Шеба:1196 Sheba:Sheba" "Sol" #3=
".:Sheba:1196 Sheba:1931 KE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.585
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.320797568319
		SemiMajorAxis	2.652795741664
		Eccentricity	0.179657695101
		Inclination	17.668848392087
		AscendingNode	100.961269428259
		ArgOfPericenter	261.67481445536
		MeanAnomaly	16.524216933023
	}
	UniformRotation
	{
		Period	6.32
	}
	LunarLambert	0.5
	Albedo	0.1634
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1196"
}

#1_"1197 Rhodesia:Rhodesia:1931 LD:1925 AC:1970 HL" "Sol" #1=
#2_"*Родезия:1197 Rhodesia:Rhodesia:1931 LD" "Sol" #2=
#3_"1931 LD:*Родезия:1197 Rhodesia:Rhodesia" "Sol" #3=
".:Rhodesia:1197 Rhodesia:1931 LD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.905300675951
		SemiMajorAxis	2.886943518506
		Eccentricity	0.230381633281
		Inclination	12.98322729081
		AscendingNode	255.775331319757
		ArgOfPericenter	276.935641687011
		MeanAnomaly	82.252141690017
	}
	UniformRotation
	{
		Period	16.062
	}
	LunarLambert	0.5
	Albedo	0.0783
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1197"
}

#1_"1199 Geldonia:Geldonia:1931 RF:1930 MB:1946 OH:1958 WC:A921 TF" "Sol" #1=
#2_"*Гельдония:1199 Geldonia:Geldonia:1931 RF" "Sol" #2=
#3_"1931 RF:*Гельдония:1199 Geldonia:Geldonia" "Sol" #3=
".:Geldonia:1199 Geldonia:1931 RF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	15.625
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.247028690804
		SemiMajorAxis	3.019512448761
		Eccentricity	0.027643557005
		Inclination	8.788793895098
		AscendingNode	235.646252103842
		ArgOfPericenter	289.829603620662
		MeanAnomaly	138.046941583041
	}
	UniformRotation
	{
		Period	28.3
	}
	LunarLambert	0.5
	Albedo	0.1299
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1199"
}

#1_"1200 Imperatrix:Imperatrix:1931 RH:1929 CX:1950 DC1:1957 OY:A913 EC:A915 TL:A924 GC" "Sol" #1=
#2_"*Императрикс:1200 Imperatrix:Imperatrix:1931 RH" "Sol" #2=
#3_"1931 RH:*Императрикс:1200 Imperatrix:Imperatrix" "Sol" #3=
".:Imperatrix:1200 Imperatrix:1931 RH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.76
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.364570607043
		SemiMajorAxis	3.064440374784
		Eccentricity	0.104616414611
		Inclination	4.592588563485
		AscendingNode	204.784745799247
		ArgOfPericenter	51.20402561573
		MeanAnomaly	291.483128114014
	}
	UniformRotation
	{
		Period	17.769
	}
	LunarLambert	0.5
	Albedo	0.0714
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1200"
}

#1_"1201 Strenua:Strenua:1931 RK:1931 TC:A907 GV:A909 UC:A916 FB" "Sol" #1=
#2_"*Стренуя:1201 Strenua:Strenua:1931 RK" "Sol" #2=
#3_"1931 RK:*Стренуя:1201 Strenua:Strenua" "Sol" #3=
".:1201 Strenua:Strenua:1931 RK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.43
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.433016389254
		SemiMajorAxis	2.698531072207
		Eccentricity	0.040860573632
		Inclination	7.005359010097
		AscendingNode	203.155076856672
		ArgOfPericenter	164.290899271244
		MeanAnomaly	275.696088562893
	}
	UniformRotation
	{
		Period	14.775
	}
	LunarLambert	0.5
	Albedo	0.0401
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1201"
}

#1_"1202 Marina:Marina:1931 RL:1931 TH:1980 BL3:A924 WG:A924 YA" "Sol" #1=
#2_"*Марина:1202 Marina:Marina:1931 RL" "Sol" #2=
#3_"1931 RL:*Марина:1202 Marina:Marina" "Sol" #3=
".:1202 Marina:Marina:1931 RL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.465
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.9804137257454
		SemiMajorAxis	3.993418293763362
		Eccentricity	0.1658382986067708
		Inclination	3.335119287814237
		AscendingNode	49.88734227953725
		ArgOfPericenter	307.7729070918515
		MeanAnomaly	222.3933084304629
	}
	UniformRotation
	{
		Period	9.45
	}
	LunarLambert	0.5
	Albedo	0.0337
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1202"
}

#1_"1203 Nanna:Nanna:1931 TA:1926 RH:1978 AD" "Sol" #1=
#2_"*Нанна:1203 Nanna:Nanna:1931 TA" "Sol" #2=
#3_"1931 TA:*Нанна:1203 Nanna:Nanna" "Sol" #3=
".:1203 Nanna:Nanna:1931 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.59
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.907644447713
		SemiMajorAxis	2.887863040526
		Eccentricity	0.246349229288
		Inclination	5.958319026427
		AscendingNode	224.741745849591
		ArgOfPericenter	175.740455045562
		MeanAnomaly	337.222710091894
	}
	UniformRotation
	{
		Period	18.54
	}
	LunarLambert	0.5
	Albedo	0.0473
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1203"
}

#1_"1204 Renzia:Renzia:1931 TE" "Sol" #1=
#2_"*Ренция:1204 Renzia:Renzia:1931 TE" "Sol" #2=
#3_"1931 TE:Renzia:*Ренция:1204 Renzia" "Sol" #3=
".:Renzia:1204 Renzia:1931 TE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1204 renzia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.366
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.405267825141
		SemiMajorAxis	2.263403840545
		Eccentricity	0.293672130772
		Inclination	1.879680381838
		AscendingNode	7.581253595586
		ArgOfPericenter	313.766501073802
		MeanAnomaly	52.26875830061
	}
	UniformRotation
	{
		Period	7.885
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1204"
}

#1_"1206 Numerowia:Numerowia:1931 UH:1974 QE:1974 TY1" "Sol" #1=
#2_"*Нумеровия:1206 Numerowia:Numerowia:1931 UH" "Sol" #2=
#3_"1931 UH:Numerowia:*Нумеровия:1206 Numerowia" "Sol" #3=
".:Numerowia:1206 Numerowia:1931 UH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1206 numerowia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.267
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.851027534106
		SemiMajorAxis	2.865609609931
		Eccentricity	0.053523267247
		Inclination	13.002720890332
		AscendingNode	324.448381689139
		ArgOfPericenter	277.365736975476
		MeanAnomaly	357.515707219658
	}
	UniformRotation
	{
		Period	4.7743
	}
	LunarLambert	0.5
	Albedo	0.159
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1206"
}

#1_"1207 Ostenia:Ostenia:1931 VT:1959 EF1" "Sol" #1=
#2_"*Остения:1207 Ostenia:Ostenia:1931 VT" "Sol" #2=
#3_"1931 VT:*Остения:1207 Ostenia:Ostenia" "Sol" #3=
".:Ostenia:1207 Ostenia:1931 VT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1207 ostenia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.962
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.254698908769
		SemiMajorAxis	3.022454390566
		Eccentricity	0.08540235232
		Inclination	10.361375299934
		AscendingNode	20.13081657126
		ArgOfPericenter	43.31478885357
		MeanAnomaly	299.307341709074
	}
	UniformRotation
	{
		Period	9.073
	}
	LunarLambert	0.5
	Albedo	0.176
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1207"
}

#1_"1208 Troilus:Troilus:1931 YA:1965 WK" "Sol" #1=
#2_"*Троил:1208 Troilus:Troilus:1931 YA" "Sol" #2=
#3_"1931 YA:*Троил:1208 Troilus:Troilus" "Sol" #3=
".:Troilus:1208 Troilus:1931 YA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	51.67
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.029956144947
		SemiMajorAxis	5.250136092931
		Eccentricity	0.09246944415
		Inclination	33.543921502133
		AscendingNode	48.557450357305
		ArgOfPericenter	296.770543312776
		MeanAnomaly	89.926966257589
	}
	UniformRotation
	{
		Period	56.17
	}
	LunarLambert	0.5
	Albedo	0.0419
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1208"
}

#1_"1210 Morosovia:Morosovia:1931 LB:1927 SK:A904 GA" "Sol" #1=
#2_"*Морозовия:1210 Morosovia:Morosovia:1931 LB" "Sol" #2=
#3_"1931 LB:*Морозовия:1210 Morosovia:Morosovia" "Sol" #3=
".:Morosovia:1210 Morosovia:1931 LB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1210 morosovia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	16.832
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.223065076409
		SemiMajorAxis	3.010311861004
		Eccentricity	0.059664928684
		Inclination	11.27123060219
		AscendingNode	106.639923263911
		ArgOfPericenter	169.255983045196
		MeanAnomaly	334.192848285291
	}
	UniformRotation
	{
		Period	15.2616
	}
	LunarLambert	0.5
	Albedo	0.132
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1210"
}

#1_"1211 Bressole:Bressole:1931 XA:1930 ON:A920 QA" "Sol" #1=
#2_"*Брессоль:1211 Bressole:Bressole:1931 XA" "Sol" #2=
#3_"1931 XA:*Брессоль:1211 Bressole:Bressole" "Sol" #3=
".:Bressole:1211 Bressole:1931 XA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.008999023023
		SemiMajorAxis	2.927488266968
		Eccentricity	0.16088929895
		Inclination	12.76238947043
		AscendingNode	129.772540381128
		ArgOfPericenter	212.204249807654
		MeanAnomaly	270.978463244747
	}
	UniformRotation
	{
		Period	31.812
	}
	LunarLambert	0.5
	Albedo	0.0695
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1211"
}

#1_"1212 Francette:Francette:1931 XC:1949 HB1:1949 HZ:1965 JB:A918 KA" "Sol" #1=
#2_"*Франсетта:1212 Francette:Francette:1931 XC" "Sol" #2=
#3_"1931 XC:*Франсетта:1212 Francette:Francette" "Sol" #3=
".:Francette:1212 Francette:1931 XC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	41.065
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.862355926378
		SemiMajorAxis	3.953936273044
		Eccentricity	0.19189216794
		Inclination	7.590764739467
		AscendingNode	149.589079494261
		ArgOfPericenter	348.067095415201
		MeanAnomaly	157.796092974001
	}
	UniformRotation
	{
		Period	16
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1212"
}

#1_"1213 Algeria:Algeria:1931 XD" "Sol" #1=
#2_"*Алжир:1213 Algeria:Algeria:1931 XD" "Sol" #2=
#3_"1931 XD:*Алжир:1213 Algeria:Algeria" "Sol" #3=
".:Algeria:1213 Algeria:1931 XD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.553688435405
		SemiMajorAxis	3.136044426636
		Eccentricity	0.127625439138
		Inclination	13.0800192017
		AscendingNode	271.76752446032
		ArgOfPericenter	107.368409813727
		MeanAnomaly	27.374502468749
	}
	UniformRotation
	{
		Period	16
	}
	LunarLambert	0.5
	Albedo	0.0767
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1213"
}

#1_"1214 Richilde:Richilde:1932 AA:1930 QD:1961 PC" "Sol" #1=
#2_"*Рихильда:1214 Richilde:Richilde:1932 AA" "Sol" #2=
#3_"1932 AA:*Рихильда:1214 Richilde:Richilde" "Sol" #3=
".:Richilde:1214 Richilde:1932 AA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.463078385324
		SemiMajorAxis	2.710717179158
		Eccentricity	0.118985017934
		Inclination	9.834764170148
		AscendingNode	285.941823916538
		ArgOfPericenter	32.866480170579
		MeanAnomaly	345.879268277143
	}
	UniformRotation
	{
		Period	9.86
	}
	LunarLambert	0.5
	Albedo	0.0619
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1214"
}

#1_"1219 Britta:Britta:1932 CJ:1947 XG:1975 FE:A904 SB:A915 BD" "Sol" #1=
#2_"*Бритта:1219 Britta:Britta:1932 CJ" "Sol" #2=
#3_"1932 CJ:*Бритта:1219 Britta:Britta" "Sol" #3=
".:Britta:1219 Britta:1932 CJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1219 britta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.93
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.291902350548
		SemiMajorAxis	2.212886611306
		Eccentricity	0.124177274111
		Inclination	4.413723090301
		AscendingNode	42.540963433935
		ArgOfPericenter	23.56264036491
		MeanAnomaly	71.407050197222
	}
	UniformRotation
	{
		Period	5.575
	}
	LunarLambert	0.5
	Albedo	0.346
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1219"
}

#1_"1221 Amor:Amor:1932 EA1" "Sol" #1=
#2_"*Амур:1221 Amor:Amor:1932 EA1" "Sol" #2=
#3_"1932 EA1:*Амур:1221 Amor:Amor" "Sol" #3=
".:Amor:1221 Amor:1932 EA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.658891172739
		SemiMajorAxis	1.919235375415
		Eccentricity	0.435329227987
		Inclination	11.878534666102
		AscendingNode	171.347730339036
		ArgOfPericenter	26.622847705833
		MeanAnomaly	17.255818546436
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1221"
}

#1_"1222 Tina:Tina:1932 LA:1955 HP" "Sol" #1=
#2_"*Тина:1222 Tina:Tina:1932 LA" "Sol" #2=
#3_"1932 LA:*Тина:1222 Tina:Tina" "Sol" #3=
".:Tina:1222 Tina:1932 LA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.42
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.676170599973
		SemiMajorAxis	2.796327904554
		Eccentricity	0.248538745931
		Inclination	19.581522918074
		AscendingNode	245.859287934705
		ArgOfPericenter	59.6801591381
		MeanAnomaly	222.475651020723
	}
	UniformRotation
	{
		Period	13.395
	}
	LunarLambert	0.5
	Albedo	0.3086
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1222"
}

#1_"1223 Neckar:Neckar:1931 TG:1930 MN:1931 TA1:1953 FC:A907 VD:A909 BD:A917 XC:A917 YA" "Sol" #1=
#2_"*Неккар:1223 Neckar:Neckar:1931 TG" "Sol" #2=
#3_"1931 TG:*Неккар:1223 Neckar:Neckar" "Sol" #3=
".:Neckar:1223 Neckar:1931 TG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1223 neckar.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	11.392
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.859897329662
		SemiMajorAxis	2.869101603028
		Eccentricity	0.057212819967
		Inclination	2.544927050979
		AscendingNode	40.848773861051
		ArgOfPericenter	13.934123087039
		MeanAnomaly	34.045198584259
	}
	UniformRotation
	{
		Period	7.81
	}
	LunarLambert	0.5
	Albedo	0.17
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1223"
}

#1_"1224 Fantasia:Fantasia:1927 SD:1934 TO" "Sol" #1=
#2_"*Фантазия:1224 Fantasia:Fantasia:1927 SD" "Sol" #2=
#3_"1927 SD:*Фантазия:1224 Fantasia:Fantasia" "Sol" #3=
".:Fantasia:1224 Fantasia:1927 SD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.97
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.498149370229
		SemiMajorAxis	2.304376468463
		Eccentricity	0.198341211351
		Inclination	7.881318064893
		AscendingNode	258.216472642396
		ArgOfPericenter	129.005361313325
		MeanAnomaly	317.562633955232
	}
	UniformRotation
	{
		Period	4.995
	}
	LunarLambert	0.5
	Albedo	0.2599
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1224"
}

#1_"1226 Golia:Golia:1930 HL:1957 WN" "Sol" #1=
#2_"*Голия:1226 Golia:Golia:1930 HL" "Sol" #2=
#3_"1930 HL:*Голия:1226 Golia:Golia" "Sol" #3=
".:Golia:1226 Golia:1930 HL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.195
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.151464862373
		SemiMajorAxis	2.583025990733
		Eccentricity	0.111652834845
		Inclination	9.84688484455
		AscendingNode	17.488538658668
		ArgOfPericenter	139.754013312978
		MeanAnomaly	179.977067918881
	}
	UniformRotation
	{
		Period	4.097
	}
	LunarLambert	0.5
	Albedo	0.2388
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1226"
}

#1_"1227 Geranium:Geranium:1931 TD:1934 CL1" "Sol" #1=
#2_"*Гераниум:1227 Geranium:Geranium:1931 TD" "Sol" #2=
#3_"1931 TD:*Гераниум:1227 Geranium:Geranium" "Sol" #3=
".:Geranium:1227 Geranium:1931 TD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.91
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.795509353027
		SemiMajorAxis	3.226430188303
		Eccentricity	0.190360553917
		Inclination	16.459541907706
		AscendingNode	0.741444257323
		ArgOfPericenter	302.001759701824
		MeanAnomaly	213.954978309054
	}
	UniformRotation
	{
		Period	12.363
	}
	LunarLambert	0.5
	Albedo	0.0921
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1227"
}

#1_"1229 Tilia:Tilia:1931 TP1:1936 MC:1942 PH:1948 PT:1951 AC:1951 CM:1973 YW3:1975 FP:1976 KB1: #1=
#1_1977 RC4:1978 VK4" "Sol" #1=
#2_"*Тилия:1229 Tilia:Tilia:1931 TP1" "Sol" #2=
#3_"1931 TP1:*Тилия:1229 Tilia:Tilia" "Sol" #3=
".:Tilia:1229 Tilia:1931 TP1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.825
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.827015983786
		SemiMajorAxis	3.238113033904
		Eccentricity	0.159566954214
		Inclination	1.022909304631
		AscendingNode	197.911978043234
		ArgOfPericenter	165.258436236209
		MeanAnomaly	115.211572308777
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0839
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1229"
}

#1_"1230 Riceia:Riceia:1931 TX1:1964 TS:1964 UE:1975 HH" "Sol" #1=
#2_"*Рицея:1230 Riceia:Riceia:1931 TX1" "Sol" #2=
#3_"1931 TX1:Riceia:*Рицея:1230 Riceia" "Sol" #3=
".:Riceia:1230 Riceia:1931 TX1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1230 riceia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.097
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.124902112195
		SemiMajorAxis	2.571996044533
		Eccentricity	0.179342281859
		Inclination	10.514588614756
		AscendingNode	200.552470831738
		ArgOfPericenter	185.24269561614
		MeanAnomaly	241.008342097516
	}
	UniformRotation
	{
		Period	6.67317
	}
	LunarLambert	0.5
	Albedo	0.318
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1230"
}

#1_"1231 Auricula:Auricula:1931 TE2" "Sol" #1=
#2_"*Аврикула:1231 Auricula:Auricula:1931 TE2" "Sol" #2=
#3_"1931 TE2:*Аврикула:1231 Auricula:Auricula" "Sol" #3=
".:Auricula:1231 Auricula:1931 TE2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1231 auricula.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	9.356
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.357407715548
		SemiMajorAxis	2.667759430876
		Eccentricity	0.087124145589
		Inclination	11.491302921381
		AscendingNode	342.069241351285
		ArgOfPericenter	246.131683941903
		MeanAnomaly	168.9445392539
	}
	UniformRotation
	{
		Period	3.9816
	}
	LunarLambert	0.5
	Albedo	0.066
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1231"
}

#1_"1232 Cortusa:Cortusa:1931 TF2:1930 OH" "Sol" #1=
#2_"*Кортуза:1232 Cortusa:Cortusa:1931 TF2" "Sol" #2=
#3_"1931 TF2:*Кортуза:1232 Cortusa:Cortusa" "Sol" #3=
".:Cortusa:1232 Cortusa:1931 TF2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.565
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.678989914173
		SemiMajorAxis	3.183038782009
		Eccentricity	0.133767933684
		Inclination	10.358918546363
		AscendingNode	261.243835205302
		ArgOfPericenter	340.057763681643
		MeanAnomaly	2.166388773514
	}
	UniformRotation
	{
		Period	25.16
	}
	LunarLambert	0.5
	Albedo	0.1339
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1232"
}

#1_"1233 Kobresia:Kobresia:1931 TG2:1927 TB:1951 QJ:1951 RP1:1954 EG" "Sol" #1=
#2_"*Кобрезия:1233 Kobresia:Kobresia:1931 TG2" "Sol" #2=
#3_"1931 TG2:*Кобрезия:1233 Kobresia:Kobresia" "Sol" #3=
".:Kobresia:1233 Kobresia:1931 TG2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.088872659199
		SemiMajorAxis	2.556997217542
		Eccentricity	0.055384316455
		Inclination	5.605212530142
		AscendingNode	291.466289557534
		ArgOfPericenter	333.919428087801
		MeanAnomaly	237.077421240273
	}
	UniformRotation
	{
		Period	27.83
	}
	LunarLambert	0.5
	Albedo	0.0475
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1233"
}

#1_"1234 Elyna:Elyna:1931 UF:1933 BN" "Sol" #1=
#2_"*Элина:1234 Elyna:Elyna:1931 UF" "Sol" #2=
#3_"1931 UF:*Элина:1234 Elyna:Elyna" "Sol" #3=
".:Elyna:1234 Elyna:1931 UF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.233195418091
		SemiMajorAxis	3.014203016599
		Eccentricity	0.088315478918
		Inclination	8.518291245653
		AscendingNode	304.721129612678
		ArgOfPericenter	86.854010748374
		MeanAnomaly	320.597405762536
	}
	UniformRotation
	{
		Period	17.6
	}
	LunarLambert	0.5
	Albedo	0.0672
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1234"
}

#1_"1236 Thais:Thais:1931 VX:1957 LQ:1964 JH:1965 WA" "Sol" #1=
#2_"*Таис:1236 Thais:Thais:1931 VX" "Sol" #2=
#3_"1931 VX:*Таис:1236 Thais:Thais" "Sol" #3=
".:Thais:1236 Thais:1931 VX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.17
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.78868061173
		SemiMajorAxis	2.430262555421
		Eccentricity	0.242291089259
		Inclination	13.158927778455
		AscendingNode	48.713610984828
		ArgOfPericenter	305.565479056867
		MeanAnomaly	8.75569452156
	}
	UniformRotation
	{
		Period	72
	}
	LunarLambert	0.5
	Albedo	0.0599
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1236"
}

#1_"1237 Genevieve:Genevieve:1931 XB:1929 GA:1984 MM:A908 HA" "Sol" #1=
#2_"*Женевьева:1237 Genevieve:Genevieve:1931 XB" "Sol" #2=
#3_"1931 XB:*Женевьева:1237 Genevieve:Genevieve" "Sol" #3=
".:Genevieve:1237 Genevieve:1931 XB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.905
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.222556733913
		SemiMajorAxis	2.612431193506
		Eccentricity	0.07790642568
		Inclination	9.733784373688
		AscendingNode	57.88456683934
		ArgOfPericenter	305.992919292977
		MeanAnomaly	295.68719421202
	}
	UniformRotation
	{
		Period	16.37
	}
	LunarLambert	0.5
	Albedo	0.0585
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1237"
}

#1_"1238 Predappia:Predappia:1932 CA:1954 EQ:1961 XU" "Sol" #1=
#2_"*Предаппия:1238 Predappia:Predappia:1932 CA" "Sol" #2=
#3_"1932 CA:*Предаппия:1238 Predappia:Predappia" "Sol" #3=
".:Predappia:1238 Predappia:1932 CA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.98
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.355298361204
		SemiMajorAxis	2.666898413742
		Eccentricity	0.141907386865
		Inclination	12.153501878267
		AscendingNode	51.970946283733
		ArgOfPericenter	91.937583599506
		MeanAnomaly	359.485970305904
	}
	UniformRotation
	{
		Period	8.94
	}
	LunarLambert	0.5
	Albedo	0.0771
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1238"
}

#1_"1239 Queteleta:Queteleta:1932 CB:1978 TH3" "Sol" #1=
#2_"*Кетелета:1239 Queteleta:Queteleta:1932 CB" "Sol" #2=
#3_"1932 CB:*Кетелета:1239 Queteleta:Queteleta" "Sol" #3=
".:Queteleta:1239 Queteleta:1932 CB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.97
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.337379378506
		SemiMajorAxis	2.659578450532
		Eccentricity	0.234485331039
		Inclination	1.662089945918
		AscendingNode	73.164144917479
		ArgOfPericenter	35.531284988301
		MeanAnomaly	44.302561059417
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0695
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1239"
}

#1_"1240 Centenaria:Centenaria:1932 CD:1930 VA:1930 XG:A915 RF" "Sol" #1=
#2_"*Центенария:1240 Centenaria:Centenaria:1932 CD" "Sol" #2=
#3_"1932 CD:*Центенария:1240 Centenaria:Centenaria" "Sol" #3=
".:Centenaria:1240 Centenaria:1932 CD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.425
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.864085542947
		SemiMajorAxis	2.870749742671
		Eccentricity	0.172697054844
		Inclination	10.16951295837
		AscendingNode	323.746362276778
		ArgOfPericenter	24.026054072398
		MeanAnomaly	158.567688094942
	}
	UniformRotation
	{
		Period	11.2907
	}
	LunarLambert	0.5
	Albedo	0.0673
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1240"
}

#1_"1241 Dysona:Dysona:1932 EB1:1931 AA1:1945 RA:1948 CE:1956 PB:A908 DC:A920 EB" "Sol" #1=
#2_"*Дайсона:1241 Dysona:Dysona:1932 EB1" "Sol" #2=
#3_"1932 EB1:*Дайсона:1241 Dysona:Dysona" "Sol" #3=
".:Dysona:1241 Dysona:1932 EB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1241 dysona.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	39.595
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.685247592869
		SemiMajorAxis	3.185376612979
		Eccentricity	0.103537847782
		Inclination	23.548691387474
		AscendingNode	322.308695194876
		ArgOfPericenter	320.837591594144
		MeanAnomaly	116.046528551551
	}
	UniformRotation
	{
		Period	8.608
	}
	LunarLambert	0.5
	Albedo	0.047
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1241"
}

#1_"1242 Zambesia:Zambesia:1932 HL:1947 TE:1948 AC:1967 EF:A908 BF" "Sol" #1=
#2_"*Замбезия:1242 Zambesia:Zambesia:1932 HL" "Sol" #2=
#3_"1932 HL:*Замбезия:1242 Zambesia:Zambesia" "Sol" #3=
".:Zambesia:1242 Zambesia:1932 HL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.527023518551
		SemiMajorAxis	2.736547761101
		Eccentricity	0.190002791755
		Inclination	10.170399261203
		AscendingNode	350.022191352403
		ArgOfPericenter	52.631195717286
		MeanAnomaly	282.036139521266
	}
	UniformRotation
	{
		Period	17.305
	}
	LunarLambert	0.5
	Albedo	0.0708
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1242"
}

#1_"1243 Pamela:Pamela:1932 JE:1929 XD:1934 VL:1951 AN:1954 JO" "Sol" #1=
#2_"*Памела:1243 Pamela:Pamela:1932 JE" "Sol" #2=
#3_"1932 JE:*Памела:1243 Pamela:Pamela" "Sol" #3=
".:Pamela:1243 Pamela:1932 JE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	35.035
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.451428716629
		SemiMajorAxis	3.097429452078
		Eccentricity	0.046334020221
		Inclination	13.282818913119
		AscendingNode	245.69627675533
		ArgOfPericenter	57.290104670275
		MeanAnomaly	344.051855862095
	}
	UniformRotation
	{
		Period	26.017
	}
	LunarLambert	0.5
	Albedo	0.0483
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1243"
}

#1_"1244 Deira:Deira:1932 KE:1930 YR:1984 YQ6:A908 TD:A921 GC:A924 BH" "Sol" #1=
#2_"*Дейра:1244 Deira:Deira:1932 KE" "Sol" #2=
#3_"1932 KE:*Дейра:1244 Deira:Deira" "Sol" #3=
".:Deira:1244 Deira:1932 KE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1244 deira.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	14.408
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.586777138947
		SemiMajorAxis	2.343135805332
		Eccentricity	0.098030196147
		Inclination	8.695183732001
		AscendingNode	277.135758261314
		ArgOfPericenter	261.124916441609
		MeanAnomaly	60.788961425228
	}
	UniformRotation
	{
		Period	210.6
	}
	LunarLambert	0.5
	Albedo	0.037
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1244"
}

#1_"1245 Calvinia:Calvinia:1932 KF:1948 VT:1950 CP:A906 FB:A914 YB:A916 DC:A917 KE" "Sol" #1=
#2_"*Кальвиния:1245 Calvinia:Calvinia:1932 KF" "Sol" #2=
#3_"1932 KF:*Кальвиния:1245 Calvinia:Calvinia" "Sol" #3=
".:Calvinia:1245 Calvinia:1932 KF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1245 calvinia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	14.876
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.918917275533
		SemiMajorAxis	2.892283617853
		Eccentricity	0.081533717049
		Inclination	2.893145173894
		AscendingNode	151.728278056449
		ArgOfPericenter	208.848825512541
		MeanAnomaly	176.144591300882
	}
	UniformRotation
	{
		Period	4.84
	}
	LunarLambert	0.5
	Albedo	0.221
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1245"
}

#1_"1246 Chaka:Chaka:1932 OA" "Sol" #1=
#2_"*Чака:1246 Chaka:Chaka:1932 OA" "Sol" #2=
#3_"1932 OA:*Чака:1246 Chaka:Chaka" "Sol" #3=
".:Chaka:1246 Chaka:1932 OA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.055
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.249956635704
		SemiMajorAxis	2.623720272874
		Eccentricity	0.307996349178
		Inclination	16.041511921308
		AscendingNode	290.754091635372
		ArgOfPericenter	54.310812721452
		MeanAnomaly	117.799866532548
	}
	UniformRotation
	{
		Period	25.462
	}
	LunarLambert	0.5
	Albedo	0.2351
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1246"
}

#1_"1247 Memoria:Memoria:1932 QA:1927 UL:1931 JU:1936 FN:A905 WA" "Sol" #1=
#2_"*Мемория:1247 Memoria:Memoria:1932 QA" "Sol" #2=
#3_"1932 QA:*Мемория:1247 Memoria:Memoria" "Sol" #3=
".:Memoria:1247 Memoria:1932 QA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.985
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.542520750714
		SemiMajorAxis	3.131838920842
		Eccentricity	0.174097798441
		Inclination	1.777677464594
		AscendingNode	161.730799766563
		ArgOfPericenter	139.595676777014
		MeanAnomaly	312.553090081792
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0846
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1247"
}

#1_"1248 Jugurtha:Jugurtha:1932 RO:1930 DU:1901 VE:A915 XB" "Sol" #1=
#2_"*Югурта:1248 Jugurtha:Jugurtha:1932 RO" "Sol" #2=
#3_"1932 RO:Jugurtha:*Югурта:1248 Jugurtha" "Sol" #3=
".:Jugurtha:1248 Jugurtha:1932 RO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1248 jugurtha.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	14.234
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.488471772296
		SemiMajorAxis	2.720989488232
		Eccentricity	0.016591642348
		Inclination	9.138683328938
		AscendingNode	79.388723107243
		ArgOfPericenter	347.773780024596
		MeanAnomaly	215.453273676522
	}
	UniformRotation
	{
		Period	12.91
	}
	LunarLambert	0.5
	Albedo	0.282
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1248"
}

#1_"1249 Rutherfordia:Rutherfordia:1932 VB:1925 SF:1942 XV" "Sol" #1=
#2_"*Резерфордия:1249 Rutherfordia:Rutherfordia:1932 VB" "Sol" #2=
#3_"1932 VB:*Резерфордия:1249 Rutherfordia:Rutherfordia" "Sol" #3=
".:Rutherfordia:1249 Rutherfordia:1932 VB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1249 rutherfordia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.532
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.317979959289
		SemiMajorAxis	2.224557850279
		Eccentricity	0.076140939756
		Inclination	4.873739248735
		AscendingNode	259.055384457515
		ArgOfPericenter	223.415106359576
		MeanAnomaly	212.976888587263
	}
	UniformRotation
	{
		Period	18.242
	}
	LunarLambert	0.5
	Albedo	0.251
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1249"
}

#1_"1250 Galanthus:Galanthus:1933 BD:1971 OQ" "Sol" #1=
#2_"*Галантус:1250 Galanthus:Galanthus:1933 BD" "Sol" #2=
#3_"1933 BD:*Галантус:1250 Galanthus:Galanthus" "Sol" #3=
".:Galanthus:1250 Galanthus:1933 BD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.073488794823
		SemiMajorAxis	2.550579604106
		Eccentricity	0.273054647338
		Inclination	15.174808469691
		AscendingNode	292.032322672189
		ArgOfPericenter	217.096342476017
		MeanAnomaly	7.717808570258
	}
	UniformRotation
	{
		Period	3.92
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1250"
}

#1_"1251 Hedera:Hedera:1933 BE:1929 CD1:1931 TJ2:1975 NW1:A907 GD:A915 CA" "Sol" #1=
#2_"*Гедера:1251 Hedera:Hedera:1933 BE" "Sol" #2=
#3_"1933 BE:Hedera:*Гедера:1251 Hedera" "Sol" #3=
".:Hedera:1251 Hedera:1933 BE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1251 hedera.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.62
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.478173470767
		SemiMajorAxis	2.716825888984
		Eccentricity	0.157689924089
		Inclination	6.048853174025
		AscendingNode	140.648960074718
		ArgOfPericenter	217.518975782095
		MeanAnomaly	55.862286158576
	}
	UniformRotation
	{
		Period	19.9
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1251"
}

#1_"1252 Celestia:Celestia:1933 DG:1934 PA1" "Sol" #1=
#2_"*Селестия:1252 Celestia:Celestia:1933 DG" "Sol" #2=
#3_"1933 DG:*Селестия:1252 Celestia:Celestia" "Sol" #3=
".:Celestia:1252 Celestia:1933 DG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.695
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.4246175943383
		SemiMajorAxis	2.695121569548736
		Eccentricity	0.2071987011077538
		Inclination	33.84405530038728
		AscendingNode	140.9352174139787
		ArgOfPericenter	63.64036103939761
		MeanAnomaly	140.4909989674621
	}
	UniformRotation
	{
		Period	10.636
	}
	LunarLambert	0.5
	Albedo	0.2573
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1252"
}

#1_"1253 Frisia:Frisia:1931 TV1:1933 BO:1937 VN:1948 SE:1954 UC:1959 RC:1971 UE3" "Sol" #1=
#2_"*Фризия:1253 Frisia:Frisia:1931 TV1" "Sol" #2=
#3_"1931 TV1:*Фризия:1253 Frisia:Frisia" "Sol" #3=
".:Frisia:1253 Frisia:1931 TV1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.627176986884
		SemiMajorAxis	3.163648671735
		Eccentricity	0.211539646808
		Inclination	1.346903233373
		AscendingNode	40.02296839853
		ArgOfPericenter	355.3285006113
		MeanAnomaly	262.969168335323
	}
	UniformRotation
	{
		Period	14.557
	}
	LunarLambert	0.5
	Albedo	0.0657
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1253"
}

#1_"1254 Erfordia:Erfordia:1932 JA:1931 BE:1971 KG:1974 XR" "Sol" #1=
#2_"*Эрфордия:1254 Erfordia:Erfordia:1932 JA" "Sol" #2=
#3_"1932 JA:*Эрфордия:1254 Erfordia:Erfordia" "Sol" #3=
".:Erfordia:1254 Erfordia:1932 JA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.74
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.55078563379
		SemiMajorAxis	3.134951566382
		Eccentricity	0.032647252885
		Inclination	7.072462231496
		AscendingNode	288.016079736485
		ArgOfPericenter	239.526023071227
		MeanAnomaly	5.857545802211
	}
	UniformRotation
	{
		Period	12.287
	}
	LunarLambert	0.5
	Albedo	0.0409
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1254"
}

#1_"1255 Schilowa:Schilowa:1932 NC:1933 VB:A905 UC" "Sol" #1=
#2_"*Шилова:1255 Schilowa:Schilowa:1932 NC" "Sol" #2=
#3_"1932 NC:*Шилова:1255 Schilowa:Schilowa" "Sol" #3=
".:Schilowa:1255 Schilowa:1932 NC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.26
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.572229781828
		SemiMajorAxis	3.143020472724
		Eccentricity	0.173249576392
		Inclination	8.548189964536
		AscendingNode	237.636467289997
		ArgOfPericenter	133.912228289503
		MeanAnomaly	199.609326099935
	}
	UniformRotation
	{
		Period	29.536
	}
	LunarLambert	0.5
	Albedo	0.1389
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1255"
}

#1_"1256 Normannia:Normannia:1932 PD:1930 KO" "Sol" #1=
#2_"*Норманния:1256 Normannia:Normannia:1932 PD" "Sol" #2=
#3_"1932 PD:*Норманния:1256 Normannia:Normannia" "Sol" #3=
".:Normannia:1256 Normannia:1932 PD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.61
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.674156556991
		SemiMajorAxis	3.890585540217
		Eccentricity	0.077615582052
		Inclination	4.174584750012
		AscendingNode	236.95914244063
		ArgOfPericenter	101.62416905826
		MeanAnomaly	236.60305344615
	}
	UniformRotation
	{
		Period	6.8
	}
	LunarLambert	0.5
	Albedo	0.0504
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1256"
}

#1_"1258 Sicilia:Sicilia:1932 PG:1935 BG" "Sol" #1=
#2_"*Сицилия:1258 Sicilia:Sicilia:1932 PG" "Sol" #2=
#3_"1932 PG:*Сицилия:1258 Sicilia:Sicilia" "Sol" #3=
".:Sicilia:1258 Sicilia:1932 PG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.69554574326
		SemiMajorAxis	3.189222073423
		Eccentricity	0.041171034758
		Inclination	7.70557983878
		AscendingNode	299.658852943592
		ArgOfPericenter	78.790471848252
		MeanAnomaly	130.457283053641
	}
	UniformRotation
	{
		Period	13.5
	}
	LunarLambert	0.5
	Albedo	0.0564
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1258"
}

#1_"1259 Ogyalla:Ogyalla:1933 BT:1928 DJ1:1928 FO:1929 MA:1935 QE1:1949 YN:1956 JF" "Sol" #1=
#2_"*Одьялла:1259 Ogyalla:Ogyalla:1933 BT" "Sol" #2=
#3_"1933 BT:*Одьялла:1259 Ogyalla:Ogyalla" "Sol" #3=
".:Ogyalla:1259 Ogyalla:1933 BT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.565
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.474969972145
		SemiMajorAxis	3.106340265714
		Eccentricity	0.129542797201
		Inclination	2.381919084693
		AscendingNode	75.083854730942
		ArgOfPericenter	149.508131327294
		MeanAnomaly	274.586465537164
	}
	UniformRotation
	{
		Period	12
	}
	LunarLambert	0.5
	Albedo	0.0641
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1259"
}

#1_"1261 Legia:Legia:1933 FB:1938 CS:1938 DH:1944 FD:1966 DG" "Sol" #1=
#2_"*Легия:1261 Legia:Legia:1933 FB" "Sol" #2=
#3_"1933 FB:*Легия:1261 Legia:Legia" "Sol" #3=
".:Legia:1261 Legia:1933 FB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.55629208052
		SemiMajorAxis	3.137024497087
		Eccentricity	0.178340546111
		Inclination	2.426997712512
		AscendingNode	67.30773383545
		ArgOfPericenter	105.002306438708
		MeanAnomaly	239.861034535883
	}
	UniformRotation
	{
		Period	8.693
	}
	LunarLambert	0.5
	Albedo	0.0719
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1261"
}

#1_"1262 Sniadeckia:Sniadeckia:1933 FE:1949 JJ:A907 GU" "Sol" #1=
#2_"*Снядецкия:1262 Sniadeckia:Sniadeckia:1933 FE" "Sol" #2=
#3_"1933 FE:*Снядецкия:1262 Sniadeckia:Sniadeckia" "Sol" #3=
".:Sniadeckia:1262 Sniadeckia:1933 FE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.745
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.198593338512
		SemiMajorAxis	3.00090165098
		Eccentricity	0.007622148456
		Inclination	13.146890832842
		AscendingNode	124.401305974701
		ArgOfPericenter	146.411260168729
		MeanAnomaly	157.58338304981
	}
	UniformRotation
	{
		Period	17.57
	}
	LunarLambert	0.5
	Albedo	0.0529
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1262"
}

#1_"1263 Varsavia:Varsavia:1933 FF:1948 PB1" "Sol" #1=
#2_"*Варшавия:1263 Varsavia:Varsavia:1933 FF" "Sol" #2=
#3_"1933 FF:*Варшавия:1263 Varsavia:Varsavia" "Sol" #3=
".:Varsavia:1263 Varsavia:1933 FF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1263 varsavia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	24.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.350940133742
		SemiMajorAxis	2.665118988887
		Eccentricity	0.187711872813
		Inclination	29.272177128284
		AscendingNode	158.492020604755
		ArgOfPericenter	287.715994639452
		MeanAnomaly	346.973596951838
	}
	UniformRotation
	{
		Period	7.1639
	}
	LunarLambert	0.5
	Albedo	0.0459
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1263"
}

#1_"1264 Letaba:Letaba:1933 HG:1930 WC:1954 YB:1962 HJ:1964 VB" "Sol" #1=
#2_"*Летаба:1264 Letaba:Letaba:1933 HG" "Sol" #2=
#3_"1933 HG:*Летаба:1264 Letaba:Letaba" "Sol" #3=
".:Letaba:1264 Letaba:1933 HG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	37.37
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.853367090652
		SemiMajorAxis	2.866530887867
		Eccentricity	0.154584959584
		Inclination	24.94837596492
		AscendingNode	235.077058686143
		ArgOfPericenter	31.261935932528
		MeanAnomaly	269.407790753146
	}
	UniformRotation
	{
		Period	32.16
	}
	LunarLambert	0.5
	Albedo	0.0725
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1264"
}

#1_"1266 Tone:Tone:1927 BD:1933 BM:1934 EC:A899 PH" "Sol" #1=
#2_"*Тоне:1266 Tone:Tone:1927 BD" "Sol" #2=
#3_"1927 BD:*Тоне:1266 Tone:Tone" "Sol" #3=
".:Tone:1266 Tone:1927 BD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.67
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.151916395316
		SemiMajorAxis	3.357387596677
		Eccentricity	0.050328686305
		Inclination	17.186826520868
		AscendingNode	320.631216457214
		ArgOfPericenter	297.669651608291
		MeanAnomaly	303.205697952018
	}
	UniformRotation
	{
		Period	7.4
	}
	LunarLambert	0.5
	Albedo	0.0566
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1266"
}

#1_"1267 Geertruida:Geertruida:1930 HD:1926 GV:1927 SH:1930 LA:1954 TM1:1965 HB:1965 JE" "Sol" #1=
#2_"*Гертруда:1267 Geertruida:Geertruida:1930 HD" "Sol" #2=
#3_"1930 HD:*Гертруда:1267 Geertruida:Geertruida" "Sol" #3=
".:Geertruida:1267 Geertruida:1930 HD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.705
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.88102772443
		SemiMajorAxis	2.469594761611
		Eccentricity	0.178849976815
		Inclination	4.781538664995
		AscendingNode	24.401271499165
		ArgOfPericenter	268.072301446012
		MeanAnomaly	242.687561266538
	}
	UniformRotation
	{
		Period	5.5
	}
	LunarLambert	0.5
	Albedo	0.0466
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1267"
}

#1_"1268 Libya:Libya:1930 HJ:1929 EA:1930 KN" "Sol" #1=
#2_"*Ливия:1268 Libya:Libya:1930 HJ" "Sol" #2=
#3_"1930 HJ:*Ливия:1268 Libya:Libya" "Sol" #3=
".:Libya:1268 Libya:1930 HJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	47.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.96489648195
		SemiMajorAxis	3.988240037238
		Eccentricity	0.103104526117
		Inclination	4.425078810548
		AscendingNode	351.034587576247
		ArgOfPericenter	121.320180372801
		MeanAnomaly	31.347057620559
	}
	UniformRotation
	{
		Period	14.05
	}
	LunarLambert	0.5
	Albedo	0.0449
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1268"
}

#1_"1269 Rollandia:Rollandia:1930 SH:1926 GC1:1931 VY:1936 LE:1961 PB:A902 EA:A906 SA:A907 WB:A918 EG" "Sol" #1=
#2_"*Ролландия:1269 Rollandia:Rollandia:1930 SH" "Sol" #2=
#3_"1930 SH:*Ролландия:1269 Rollandia:Rollandia" "Sol" #3=
".:Rollandia:1269 Rollandia:1930 SH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	52.595
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.721485590512
		SemiMajorAxis	3.906565485042
		Eccentricity	0.100355673569
		Inclination	2.757953766617
		AscendingNode	134.723637101478
		ArgOfPericenter	18.777992399719
		MeanAnomaly	149.329294582314
	}
	UniformRotation
	{
		Period	15.4
	}
	LunarLambert	0.5
	Albedo	0.0473
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1269"
}

#1_"1270 Datura:Datura:1930 YE:1953 XF1:A913 VB" "Sol" #1=
#2_"*Датура:1270 Datura:Datura:1930 YE" "Sol" #2=
#3_"1930 YE:*Датура:1270 Datura:Datura" "Sol" #3=
".:Datura:1270 Datura:1930 YE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1270 datura.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.102
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.341076785301
		SemiMajorAxis	2.234869505635
		Eccentricity	0.208172723138
		Inclination	5.985414234014
		AscendingNode	97.817943742756
		ArgOfPericenter	259.017609899951
		MeanAnomaly	187.211532574858
	}
	UniformRotation
	{
		Period	3.359
	}
	LunarLambert	0.5
	Albedo	0.288
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1270"
}

#1_"1271 Isergina:Isergina:1931 TN:1930 MK:1932 CK1:2003 RV22:A906 HD" "Sol" #1=
#2_"*Изергина:1271 Isergina:Isergina:1931 TN" "Sol" #2=
#3_"1931 TN:*Изергина:1271 Isergina:Isergina" "Sol" #3=
".:Isergina:1271 Isergina:1931 TN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.165
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.564727247959
		SemiMajorAxis	3.140198632612
		Eccentricity	0.120759496268
		Inclination	6.679740671907
		AscendingNode	127.346850519278
		ArgOfPericenter	268.058681868689
		MeanAnomaly	345.050206012357
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0517
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1271"
}

#1_"1275 Cimbria:Cimbria:1932 WG:1949 QL2:A914 TG" "Sol" #1=
#2_"*Кимбрия:1275 Cimbria:Cimbria:1932 WG" "Sol" #2=
#3_"1932 WG:*Кимбрия:1275 Cimbria:Cimbria" "Sol" #3=
".:Cimbria:1275 Cimbria:1932 WG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1275 cimbria.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.811
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.387650658615
		SemiMajorAxis	2.680089063516
		Eccentricity	0.168876137948
		Inclination	12.875965859016
		AscendingNode	188.566384254083
		ArgOfPericenter	196.877271470291
		MeanAnomaly	279.375544640392
	}
	UniformRotation
	{
		Period	5.65
	}
	LunarLambert	0.5
	Albedo	0.141
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1275"
}

#1_"1276 Ucclia:Ucclia:1933 BA:1963 KF" "Sol" #1=
#2_"*Укклия:1276 Ucclia:Ucclia:1933 BA" "Sol" #2=
#3_"1933 BA:*Укклия:1276 Ucclia:Ucclia" "Sol" #3=
".:Ucclia:1276 Ucclia:1933 BA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	15.315
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.667340649706
		SemiMajorAxis	3.178684398605
		Eccentricity	0.09473456694
		Inclination	23.2756108983
		AscendingNode	114.478360199963
		ArgOfPericenter	333.508224606946
		MeanAnomaly	212.086528434864
	}
	UniformRotation
	{
		Period	4.9077
	}
	LunarLambert	0.5
	Albedo	0.1303
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1276"
}

#1_"1277 Dolores:Dolores:1933 HA:1925 SE:1929 NB:1942 JA:1951 PB" "Sol" #1=
#2_"*Долорес:1277 Dolores:Dolores:1933 HA" "Sol" #2=
#3_"1933 HA:*Долорес:1277 Dolores:Dolores" "Sol" #3=
".:Dolores:1277 Dolores:1933 HA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.82
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.432247653579
		SemiMajorAxis	2.69821909245
		Eccentricity	0.23908856398
		Inclination	6.966035315642
		AscendingNode	247.170061347619
		ArgOfPericenter	47.057684037087
		MeanAnomaly	92.956027728382
	}
	UniformRotation
	{
		Period	17.19
	}
	LunarLambert	0.5
	Albedo	0.0879
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1277"
}

#1_"1278 Kenya:Kenya:1933 LA:A905 AA" "Sol" #1=
#2_"*Кения:1278 Kenya:Kenya:1933 LA" "Sol" #2=
#3_"1933 LA:Kenya:*Кения:1278 Kenya" "Sol" #3=
".:Kenya:1278 Kenya:1933 LA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1278 kenya.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.68
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.727796471234
		SemiMajorAxis	2.404156087632
		Eccentricity	0.263617935727
		Inclination	10.853502929023
		AscendingNode	90.308619123949
		ArgOfPericenter	238.615051734572
		MeanAnomaly	113.942759420015
	}
	UniformRotation
	{
		Period	188
	}
	LunarLambert	0.5
	Albedo	0.195
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1278"
}

#1_"1280 Baillauda:Baillauda:1933 QB:1931 HE:1946 SF:1959 UK:1961 AN:A912 GB" "Sol" #1=
#2_"*Беллода:1280 Baillauda:Baillauda:1933 QB" "Sol" #2=
#3_"1933 QB:*Беллода:1280 Baillauda:Baillauda" "Sol" #3=
".:Baillauda:1280 Baillauda:1933 QB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.415
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.311865830121
		SemiMajorAxis	3.415332867292
		Eccentricity	0.050583780422
		Inclination	6.459774692537
		AscendingNode	293.08956441156
		ArgOfPericenter	99.522367914045
		MeanAnomaly	265.035046184738
	}
	UniformRotation
	{
		Period	12.6
	}
	LunarLambert	0.5
	Albedo	0.0505
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1280"
}

#1_"1281 Jeanne:Jeanne:1933 QJ:1929 RG:1938 YL:A904 NA" "Sol" #1=
#2_"*Джейн:1281 Jeanne:Jeanne:1933 QJ" "Sol" #2=
#3_"1933 QJ:*Джейн:1281 Jeanne:Jeanne" "Sol" #3=
".:Jeanne:1281 Jeanne:1933 QJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1281 jeanne.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	12.858
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.087434533883
		SemiMajorAxis	2.556397623093
		Eccentricity	0.208220607039
		Inclination	7.445715784427
		AscendingNode	210.111195715955
		ArgOfPericenter	72.892632594998
		MeanAnomaly	351.186368091499
	}
	UniformRotation
	{
		Period	15.18
	}
	LunarLambert	0.5
	Albedo	0.058
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1281"
}

#1_"1282 Utopia:Utopia:1933 QM1:1930 CA:1933 QB1:1933 RF:1939 RB:1955 SO1" "Sol" #1=
#2_"*Утопия:1282 Utopia:Utopia:1933 QM1" "Sol" #2=
#3_"1933 QM1:*Утопия:1282 Utopia:Utopia" "Sol" #3=
".:Utopia:1282 Utopia:1933 QM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.535
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.500799807463
		SemiMajorAxis	3.116102669284
		Eccentricity	0.12492978835
		Inclination	18.042858284074
		AscendingNode	324.326062306784
		ArgOfPericenter	79.501410955574
		MeanAnomaly	204.522660214046
	}
	UniformRotation
	{
		Period	13.623
	}
	LunarLambert	0.5
	Albedo	0.0627
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1282"
}

#1_"1283 Komsomolia:Komsomolia:1925 SC:1931 VE1:1951 EO2:1960 VC:1962 EB:A902 TE" "Sol" #1=
#2_"*Комсомолия:1283 Komsomolia:Komsomolia:1925 SC" "Sol" #2=
#3_"1925 SC:*Комсомолия:1283 Komsomolia:Komsomolia" "Sol" #3=
".:Komsomolia:1283 Komsomolia:1925 SC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	13.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.672985879271
		SemiMajorAxis	3.180794903514
		Eccentricity	0.221297952022
		Inclination	8.908788001931
		AscendingNode	157.743974959501
		ArgOfPericenter	235.232062267027
		MeanAnomaly	171.120444806622
	}
	UniformRotation
	{
		Period	96
	}
	LunarLambert	0.5
	Albedo	0.1856
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1283"
}

#1_"1284 Latvia:Latvia:1933 OP:1925 WK:1931 DW:1933 QP:1950 RL" "Sol" #1=
#2_"*Латвия:1284 Latvia:Latvia:1933 OP" "Sol" #2=
#3_"1933 OP:*Латвия:1284 Latvia:Latvia" "Sol" #3=
".:Latvia:1284 Latvia:1933 OP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	18.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.30443130278
		SemiMajorAxis	2.646092686847
		Eccentricity	0.170694599754
		Inclination	10.876428472643
		AscendingNode	302.970084465298
		ArgOfPericenter	114.28978096516
		MeanAnomaly	255.721908569453
	}
	UniformRotation
	{
		Period	9.644
	}
	LunarLambert	0.5
	Albedo	0.1045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1284"
}

#1_"1285 Julietta:Julietta:1933 QF:1928 SR:1933 RB:1941 BW:1951 CM1" "Sol" #1=
#2_"*Джульетта (астероид):1285 Julietta:Julietta:1933 QF" "Sol" #2=
#3_"1933 QF:*Джульетта (астероид):1285 Julietta:Julietta" "Sol" #3=
".:Julietta:1285 Julietta:1933 QF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.415
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.173915826806
		SemiMajorAxis	2.991397349345
		Eccentricity	0.053688380261
		Inclination	5.693611656678
		AscendingNode	317.911270648986
		ArgOfPericenter	71.69895165114
		MeanAnomaly	208.483134284664
	}
	UniformRotation
	{
		Period	20.3
	}
	LunarLambert	0.5
	Albedo	0.061
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1285"
}

#1_"1286 Banachiewicza:Banachiewicza:1933 QH:1928 SE:1954 UJ" "Sol" #1=
#2_"*Банахевича:1286 Banachiewicza:Banachiewicza:1933 QH" "Sol" #2=
#3_"1933 QH:*Банахевича:1286 Banachiewicza:Banachiewicza" "Sol" #3=
".:Banachiewicza:1286 Banachiewicza:1933 QH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1286 banachiewicza.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.737
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	5.261325128118
		SemiMajorAxis	3.02499475039
		Eccentricity	0.088276380019
		Inclination	9.744665617685
		AscendingNode	200.469556795276
		ArgOfPericenter	107.111687418169
		MeanAnomaly	240.117232163349
	}
	UniformRotation
	{
		Period	8.63
	}
	LunarLambert	0.5
	Albedo	0.17
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1286"
}

#1_"1287 Lorcia:Lorcia:1933 QL:1954 TG" "Sol" #1=
#2_"*Лорция:1287 Lorcia:Lorcia:1933 QL" "Sol" #2=
#3_"1933 QL:*Лорция:1287 Lorcia:Lorcia" "Sol" #3=
".:Lorcia:1287 Lorcia:1933 QL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.221789521234
		SemiMajorAxis	3.009821730512
		Eccentricity	0.06399127032
		Inclination	9.821323429695
		AscendingNode	202.5393965
		ArgOfPericenter	267.806277153963
		MeanAnomaly	85.626162504875
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1328
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1287"
}

#1_"1289 Kutaissi:Kutaissi:1933 QR:1928 QD:1948 TJ2:1953 TO2:A893 GA:A919 UC" "Sol" #1=
#2_"*Кутаиси:1289 Kutaissi:Kutaissi:1933 QR" "Sol" #2=
#3_"1933 QR:*Кутаиси:1289 Kutaissi:Kutaissi" "Sol" #3=
".:Kutaissi:1289 Kutaissi:1933 QR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.835927387687
		SemiMajorAxis	2.859659859511
		Eccentricity	0.063154211186
		Inclination	1.616032530888
		AscendingNode	193.201174544892
		ArgOfPericenter	117.794996814134
		MeanAnomaly	310.212712232256
	}
	UniformRotation
	{
		Period	3.6
	}
	LunarLambert	0.5
	Albedo	0.1374
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1289"
}

#1_"1291 Phryne:Phryne:1933 RA:1931 DX:1932 KJ:1953 JS:A907 TA:A922 NA" "Sol" #1=
#2_"*Фрин:1291 Phryne:Phryne:1933 RA" "Sol" #2=
#3_"1933 RA:*Фрин:1291 Phryne:Phryne" "Sol" #3=
".:Phryne:1291 Phryne:1933 RA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1291 phryne.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.709
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.230878440989
		SemiMajorAxis	3.013313266423
		Eccentricity	0.093396069095
		Inclination	9.103077416559
		AscendingNode	215.394906089724
		ArgOfPericenter	118.819316189938
		MeanAnomaly	200.667999812107
	}
	UniformRotation
	{
		Period	5.5841
	}
	LunarLambert	0.5
	Albedo	0.127
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1291"
}

#1_"1293 Sonja:Sonja:1933 SO" "Sol" #1=
#2_"*Соня:1293 Sonja:Sonja:1933 SO" "Sol" #2=
#3_"1933 SO:*Соня:1293 Sonja:Sonja" "Sol" #3=
".:Sonja:1293 Sonja:1933 SO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.327316253562
		SemiMajorAxis	2.228728942115
		Eccentricity	0.274591729567
		Inclination	5.36057938497
		AscendingNode	236.453403508544
		ArgOfPericenter	99.704720145351
		MeanAnomaly	168.064194245466
	}
	UniformRotation
	{
		Period	2.878
	}
	LunarLambert	0.5
	Albedo	0.4598
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1293"
}

#1_"1294 Antwerpia:Antwerpia:1933 UB1:1930 AF:1932 LC:1964 VA2:1964 XF:A917 DB" "Sol" #1=
#2_"*Антверпия:1294 Antwerpia:Antwerpia:1933 UB1" "Sol" #2=
#3_"1933 UB1:*Антверпия:1294 Antwerpia:Antwerpia" "Sol" #3=
".:Antwerpia:1294 Antwerpia:1933 UB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1294 antwerpia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	18.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.400523326633
		SemiMajorAxis	2.685328473226
		Eccentricity	0.234302497659
		Inclination	8.728165941465
		AscendingNode	81.140242861846
		ArgOfPericenter	313.359012319716
		MeanAnomaly	152.091191032928
	}
	UniformRotation
	{
		Period	6.63
	}
	LunarLambert	0.5
	Albedo	0.117
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1294"
}

#1_"1295 Deflotte:Deflotte:1933 WD:1932 RE:1938 QF:1939 VN:1941 CE:1947 CA:1951 TV:1963 TU" "Sol" #1=
#2_"*Дефлотта:1295 Deflotte:Deflotte:1933 WD" "Sol" #2=
#3_"1933 WD:*Дефлотта:1295 Deflotte:Deflotte" "Sol" #3=
".:Deflotte:1295 Deflotte:1933 WD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.015
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.245855988962
		SemiMajorAxis	3.391479342565
		Eccentricity	0.117763783823
		Inclination	2.876833133759
		AscendingNode	185.128406225968
		ArgOfPericenter	276.028768975481
		MeanAnomaly	333.816720383531
	}
	UniformRotation
	{
		Period	14.64
	}
	LunarLambert	0.5
	Albedo	0.0441
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1295"
}

#1_"1296 Andree:Andree:1933 WE:1925 TA:1929 TH:1931 HF" "Sol" #1=
#2_"*Андрэ:1296 Andree:Andree:1933 WE" "Sol" #2=
#3_"1933 WE:*Андрэ:1296 Andree:Andree" "Sol" #3=
".:Andree:1296 Andree:1933 WE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.625
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.759554963908
		SemiMajorAxis	2.417791375957
		Eccentricity	0.142485921111
		Inclination	4.10617367416
		AscendingNode	227.016380671986
		ArgOfPericenter	236.619217615746
		MeanAnomaly	172.185318776541
	}
	UniformRotation
	{
		Period	5.1837
	}
	LunarLambert	0.5
	Albedo	0.1209
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1296"
}

#1_"1298 Nocturna:Nocturna:1934 AE:A904 RA" "Sol" #1=
#2_"*Ноктюрна:1298 Nocturna:Nocturna:1934 AE" "Sol" #2=
#3_"1934 AE:*Ноктюрна:1298 Nocturna:Nocturna" "Sol" #3=
".:Nocturna:1298 Nocturna:1934 AE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.02
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.528983725651
		SemiMajorAxis	3.126737384254
		Eccentricity	0.150326712752
		Inclination	5.489743963798
		AscendingNode	300.006519602453
		ArgOfPericenter	58.848558994604
		MeanAnomaly	332.810213078159
	}
	UniformRotation
	{
		Period	34.8
	}
	LunarLambert	0.5
	Albedo	0.0578
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1298"
}

#1_"1299 Mertona:Mertona:1934 BA" "Sol" #1=
#2_"*Мертона:1299 Mertona:Mertona:1934 BA" "Sol" #2=
#3_"1934 BA:Mertona:*Мертона:1299 Mertona" "Sol" #3=
".:Mertona:1299 Mertona:1934 BA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1299 mertona.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.07
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.688367866654
		SemiMajorAxis	2.801188398269
		Eccentricity	0.189529507656
		Inclination	7.875827410086
		AscendingNode	165.605703889256
		ArgOfPericenter	260.481663679058
		MeanAnomaly	286.53500333872
	}
	UniformRotation
	{
		Period	4.977
	}
	LunarLambert	0.5
	Albedo	0.243
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1299"
}

#1_"1300 Marcelle:Marcelle:1934 CL" "Sol" #1=
#2_"*Марсель:1300 Marcelle:Marcelle:1934 CL" "Sol" #2=
#3_"1934 CL:*Марсель:1300 Marcelle:Marcelle" "Sol" #3=
".:Marcelle:1300 Marcelle:1934 CL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.92
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.640748624724
		SemiMajorAxis	2.782188566822
		Eccentricity	0.006950350861
		Inclination	9.547397158402
		AscendingNode	82.958555463118
		ArgOfPericenter	327.535209308526
		MeanAnomaly	239.780542360366
	}
	UniformRotation
	{
		Period	12
	}
	LunarLambert	0.5
	Albedo	0.0995
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1300"
}

#1_"1301 Yvonne:Yvonne:1934 EA" "Sol" #1=
#2_"*Ивонна:1301 Yvonne:Yvonne:1934 EA" "Sol" #2=
#3_"1934 EA:*Ивонна:1301 Yvonne:Yvonne" "Sol" #3=
".:Yvonne:1301 Yvonne:1934 EA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1301 yvonne.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.719
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.605611668319
		SemiMajorAxis	2.768127413677
		Eccentricity	0.268882000088
		Inclination	34.042573583175
		AscendingNode	161.578047971217
		ArgOfPericenter	302.197215407512
		MeanAnomaly	242.511678125721
	}
	UniformRotation
	{
		Period	7.32
	}
	LunarLambert	0.5
	Albedo	0.111
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1301"
}

#1_"1303 Luthera:Luthera:1928 FP:1926 XD:1928 HH:1972 VP1:A917 KC" "Sol" #1=
#2_"*Лютера:1303 Luthera:Luthera:1928 FP" "Sol" #2=
#3_"1928 FP:*Лютера:1303 Luthera:Luthera" "Sol" #3=
".:Luthera:1303 Luthera:1928 FP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	42.725
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.79694741995
		SemiMajorAxis	3.226963892405
		Eccentricity	0.105171810269
		Inclination	19.495699325354
		AscendingNode	72.067953626591
		ArgOfPericenter	100.030872880713
		MeanAnomaly	28.463177547977
	}
	UniformRotation
	{
		Period	5.878
	}
	LunarLambert	0.5
	Albedo	0.0608
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1303"
}

#1_"1304 Arosa:Arosa:1928 KC:1929 RY:1934 JL:1934 LE:1974 OW:A908 YC" "Sol" #1=
#2_"*Ароза:1304 Arosa:Arosa:1928 KC" "Sol" #2=
#3_"1928 KC:*Ароза:1304 Arosa:Arosa" "Sol" #3=
".:Arosa:1304 Arosa:1928 KC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	21.47
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.719825517425
		SemiMajorAxis	3.198279289169
		Eccentricity	0.116708689424
		Inclination	18.989079752729
		AscendingNode	86.60868729735
		ArgOfPericenter	148.127761573565
		MeanAnomaly	35.01468245925
	}
	UniformRotation
	{
		Period	7.7478
	}
	LunarLambert	0.5
	Albedo	0.348
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1304"
}

#1_"1306 Scythia:Scythia:1930 OB:1933 DN:1935 OA:1951 JB:1956 EM1:1957 KQ" "Sol" #1=
#2_"*Скифия:1306 Scythia:Scythia:1930 OB" "Sol" #2=
#3_"1930 OB:*Скифия:1306 Scythia:Scythia" "Sol" #3=
".:Scythia:1306 Scythia:1930 OB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.57
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.578073543236
		SemiMajorAxis	3.145217540877
		Eccentricity	0.094509588983
		Inclination	14.939056832087
		AscendingNode	274.374453873993
		ArgOfPericenter	138.218198056451
		MeanAnomaly	326.579900364327
	}
	UniformRotation
	{
		Period	7.525
	}
	LunarLambert	0.5
	Albedo	0.0512
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1306"
}

#1_"1308 Halleria:Halleria:1931 EB:1933 SP:1936 FU1:1938 SO1:1938 SP1:1953 TT:1963 VA:A901 DB" "Sol" #1=
#2_"*Халлерия:1308 Halleria:Halleria:1931 EB" "Sol" #2=
#3_"1931 EB:*Халлерия:1308 Halleria:Halleria" "Sol" #3=
".:Halleria:1308 Halleria:1931 EB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	21.58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.968447554961
		SemiMajorAxis	2.911666781851
		Eccentricity	0.01352142286
		Inclination	5.573672306808
		AscendingNode	354.155103633756
		ArgOfPericenter	167.588933161053
		MeanAnomaly	331.084934427161
	}
	UniformRotation
	{
		Period	6.028
	}
	LunarLambert	0.5
	Albedo	0.0454
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1308"
}

#1_"1309 Hyperborea:Hyperborea:1931 TO:1934 GT:1971 SG1:1973 AW4:A919 RB:A919 SH" "Sol" #1=
#2_"*Гиперборея:1309 Hyperborea:Hyperborea:1931 TO" "Sol" #2=
#3_"1931 TO:*Гиперборея:1309 Hyperborea:Hyperborea" "Sol" #3=
".:Hyperborea:1309 Hyperborea:1931 TO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.575
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.735729968729
		SemiMajorAxis	3.204205266325
		Eccentricity	0.151081236816
		Inclination	10.280985698059
		AscendingNode	206.105152869368
		ArgOfPericenter	244.95218377
		MeanAnomaly	120.585102734352
	}
	UniformRotation
	{
		Period	13.88
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1309"
}

#1_"1310 Villigera:Villigera:1932 DB:1964 TC" "Sol" #1=
#2_"*Филлигера:1310 Villigera:Villigera:1932 DB" "Sol" #2=
#3_"1932 DB:Villigera:*Филлигера:1310 Villigera" "Sol" #3=
".:Villigera:1310 Villigera:1932 DB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1310 villigera.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.777
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.700362555381
		SemiMajorAxis	2.392346326467
		Eccentricity	0.355328253015
		Inclination	21.074381518251
		AscendingNode	357.32059637157
		ArgOfPericenter	88.72055216618
		MeanAnomaly	23.4773410956
	}
	UniformRotation
	{
		Period	7.83
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1310"
}

#1_"1311 Knopfia:Knopfia:1933 FF1:1929 CG1:1972 RP2:1976 SD" "Sol" #1=
#2_"*Кнопфлия:1311 Knopfia:Knopfia:1933 FF1" "Sol" #2=
#3_"1933 FF1:*Кнопфлия:1311 Knopfia:Knopfia" "Sol" #3=
".:Knopfia:1311 Knopfia:1933 FF1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.03
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.779937531046
		SemiMajorAxis	2.426522262612
		Eccentricity	0.04360309749
		Inclination	2.831360385772
		AscendingNode	245.230486626124
		ArgOfPericenter	242.791473161615
		MeanAnomaly	266.99934771879
	}
	UniformRotation
	{
		Period	9.65
	}
	LunarLambert	0.5
	Albedo	0.1178
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1311"
}

#1_"1312 Vassar:Vassar:1933 OT:1944 QE:A908 CD" "Sol" #1=
#2_"*Вассар:1312 Vassar:Vassar:1933 OT" "Sol" #2=
#3_"1933 OT:*Вассар:1312 Vassar:Vassar" "Sol" #3=
".:Vassar:1312 Vassar:1933 OT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1312 vassar.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	18.14
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.444325872102
		SemiMajorAxis	3.094738372817
		Eccentricity	0.216174931737
		Inclination	21.902862870913
		AscendingNode	129.456868349726
		ArgOfPericenter	261.339701951104
		MeanAnomaly	283.857571908879
	}
	UniformRotation
	{
		Period	7.932
	}
	LunarLambert	0.5
	Albedo	0.0643
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1312"
}

#1_"1314 Paula:Paula:1933 SC:1933 QK:1945 AA:1973 FM" "Sol" #1=
#2_"*Паула:1314 Paula:Paula:1933 SC" "Sol" #2=
#3_"1933 SC:*Паула:1314 Paula:Paula" "Sol" #3=
".:Paula:1314 Paula:1933 SC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.655
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.478614604323
		SemiMajorAxis	2.295789555562
		Eccentricity	0.174728731146
		Inclination	5.240125727385
		AscendingNode	264.671978949851
		ArgOfPericenter	144.007158199406
		MeanAnomaly	88.749978119699
	}
	UniformRotation
	{
		Period	5.9498
	}
	LunarLambert	0.5
	Albedo	0.1171
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1314"
}

#1_"1315 Bronislawa:Bronislawa:1933 SF1:1949 KC:1951 UB:1962 UB:1966 HN:A905 VE:A916 UF:A924 BG" "Sol" #1=
#2_"*Бронислава:1315 Bronislawa:Bronislawa:1933 SF1" "Sol" #2=
#3_"1933 SF1:*Бронислава:1315 Bronislawa:Bronislawa" "Sol" #3=
".:Bronislawa:1315 Bronislawa:1933 SF1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.738832638189
		SemiMajorAxis	3.205360677964
		Eccentricity	0.07776781229
		Inclination	7.072150852868
		AscendingNode	236.579190840575
		ArgOfPericenter	23.336456592902
		MeanAnomaly	136.915958096985
	}
	UniformRotation
	{
		Period	9.565
	}
	LunarLambert	0.5
	Albedo	0.0527
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1315"
}

#1_"1317 Silvretta:Silvretta:1935 RC:1949 HA1:1949 HY:1952 YG:A912 RA" "Sol" #1=
#2_"*Зильфретта:1317 Silvretta:Silvretta:1935 RC" "Sol" #2=
#3_"1935 RC:*Зильфретта:1317 Silvretta:Silvretta" "Sol" #3=
".:Silvretta:1317 Silvretta:1935 RC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1317 silvretta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	5.715890883178
		SemiMajorAxis	3.19681240265
		Eccentricity	0.237976289579
		Inclination	20.571533619062
		AscendingNode	6.703711949753
		ArgOfPericenter	31.759757827726
		MeanAnomaly	3.284596252652
	}
	UniformRotation
	{
		Period	7.048
	}
	LunarLambert	0.5
	Albedo	0.275
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1317"
}

#1_"1318 Nerina:Nerina:1934 FG:1955 FA" "Sol" #1=
#2_"*Нерина:1318 Nerina:Nerina:1934 FG" "Sol" #2=
#3_"1934 FG:*Нерина:1318 Nerina:Nerina" "Sol" #3=
".:Nerina:1318 Nerina:1934 FG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.51
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.504607125204
		SemiMajorAxis	2.307211591122
		Eccentricity	0.203654539543
		Inclination	24.663970046379
		AscendingNode	358.335489889674
		ArgOfPericenter	196.071958848128
		MeanAnomaly	8.859150857977
	}
	UniformRotation
	{
		Period	2.528
	}
	LunarLambert	0.5
	Albedo	0.1811
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1318"
}

#1_"1320 Impala:Impala:1934 JG:1939 JE:1949 FV:1951 WU" "Sol" #1=
#2_"*Импала:1320 Impala:Impala:1934 JG" "Sol" #2=
#3_"1934 JG:*Импала:1320 Impala:Impala" "Sol" #3=
".:Impala:1320 Impala:1934 JG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1320 impala.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	18.666
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.174555628256
		SemiMajorAxis	2.991643953141
		Eccentricity	0.228829891267
		Inclination	19.799382075867
		AscendingNode	71.904669749671
		ArgOfPericenter	205.719878501564
		MeanAnomaly	31.026230926699
	}
	UniformRotation
	{
		Period	6.1713
	}
	LunarLambert	0.5
	Albedo	0.078
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1320"
}

#1_"1321 Majuba:Majuba:1934 JH:1928 FH:1930 UW:1935 SG:1950 QE:1950 QQ:1950 RE:1950 RK1:1950 RQ: #1=
#1_1964 GD:A908 FD" "Sol" #1=
#2_"*Маюба:1321 Majuba:Majuba:1934 JH" "Sol" #2=
#3_"1934 JH:*Маюба:1321 Majuba:Majuba" "Sol" #3=
".:Majuba:1321 Majuba:1934 JH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	15.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.039551059007
		SemiMajorAxis	2.939380203749
		Eccentricity	0.169112559706
		Inclination	9.509386713343
		AscendingNode	317.728344880149
		ArgOfPericenter	345.800205851834
		MeanAnomaly	296.661658666914
	}
	UniformRotation
	{
		Period	5.207
	}
	LunarLambert	0.5
	Albedo	0.1439
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1321"
}

#1_"1323 Tugela:Tugela:1934 LD:1974 HR3:1974 KM:1974 KO:A908 UB:A911 HC" "Sol" #1=
#2_"*Тугела:1323 Tugela:Tugela:1934 LD" "Sol" #2=
#3_"1934 LD:*Тугела:1323 Tugela:Tugela" "Sol" #3=
".:Tugela:1323 Tugela:1934 LD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.22
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.80312740351
		SemiMajorAxis	3.229256943173
		Eccentricity	0.148500737254
		Inclination	18.785349054226
		AscendingNode	45.26724304903
		ArgOfPericenter	135.811631419277
		MeanAnomaly	65.051902963767
	}
	UniformRotation
	{
		Period	19.5
	}
	LunarLambert	0.5
	Albedo	0.0567
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1323"
}

#1_"1325 Inanda:Inanda:1934 NR:1926 RP:1930 OD" "Sol" #1=
#2_"*Инанда:1325 Inanda:Inanda:1934 NR" "Sol" #2=
#3_"1934 NR:*Инанда:1325 Inanda:Inanda" "Sol" #3=
".:Inanda:1325 Inanda:1934 NR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.049728283366
		SemiMajorAxis	2.540651645029
		Eccentricity	0.255887163348
		Inclination	7.42069339948
		AscendingNode	14.39753574839
		ArgOfPericenter	336.874662400248
		MeanAnomaly	281.559110828067
	}
	UniformRotation
	{
		Period	20.52
	}
	LunarLambert	0.5
	Albedo	0.3756
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1325"
}

#1_"1326 Losaka:Losaka:1934 NS:1951 LS:1951 MA" "Sol" #1=
#2_"*Лосака:1326 Losaka:Losaka:1934 NS" "Sol" #2=
#3_"1934 NS:*Лосака:1326 Losaka:Losaka" "Sol" #3=
".:Losaka:1326 Losaka:1934 NS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.357868186073
		SemiMajorAxis	2.667947371815
		Eccentricity	0.224048789064
		Inclination	15.987240235166
		AscendingNode	101.742634824523
		ArgOfPericenter	278.825167445796
		MeanAnomaly	114.184682053907
	}
	UniformRotation
	{
		Period	6.9
	}
	LunarLambert	0.5
	Albedo	0.1499
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1326"
}

#1_"1327 Namaqua:Namaqua:1934 RT:1939 UU" "Sol" #1=
#2_"*Намаква:1327 Namaqua:Namaqua:1934 RT" "Sol" #2=
#3_"1934 RT:*Намаква:1327 Namaqua:Namaqua" "Sol" #3=
".:Namaqua:1327 Namaqua:1934 RT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.57
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.637796422157
		SemiMajorAxis	2.78100851938
		Eccentricity	0.161448080247
		Inclination	5.815316527823
		AscendingNode	58.026667022124
		ArgOfPericenter	268.511305105631
		MeanAnomaly	113.354930253137
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0404
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1327"
}

#1_"1328 Devota:Devota:1925 UA:1938 UC:1951 TQ:1951 TT:1964 UD" "Sol" #1=
#2_"*Девота:1328 Devota:Devota:1925 UA" "Sol" #2=
#3_"1925 UA:*Девота:1328 Devota:Devota" "Sol" #3=
".:Devota:1328 Devota:1925 UA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.555
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.559068111742
		SemiMajorAxis	3.503934337307
		Eccentricity	0.135093819335
		Inclination	5.7660380756
		AscendingNode	222.717869095127
		ArgOfPericenter	174.886233586736
		MeanAnomaly	223.445953458274
	}
	UniformRotation
	{
		Period	17.49
	}
	LunarLambert	0.5
	Albedo	0.0407
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1328"
}

#1_"1330 Spiridonia:Spiridonia:1925 DB:1931 FA:1933 QK1:1942 ED:1950 OP:1959 EZ:A922 SA" "Sol" #1=
#2_"*Спиридония:1330 Spiridonia:Spiridonia:1925 DB" "Sol" #2=
#3_"1925 DB:*Спиридония:1330 Spiridonia:Spiridonia" "Sol" #3=
".:Spiridonia:1330 Spiridonia:1925 DB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.64465732377
		SemiMajorAxis	3.17019701768
		Eccentricity	0.075509086729
		Inclination	15.957334078429
		AscendingNode	158.853086143853
		ArgOfPericenter	6.499311538427
		MeanAnomaly	287.64616913413
	}
	UniformRotation
	{
		Period	9.67
	}
	LunarLambert	0.5
	Albedo	0.0498
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1330"
}

#1_"1331 Solvejg:Solvejg:1933 QS:1926 FD:1928 TH:1942 ER:1948 GM" "Sol" #1=
#2_"*Сольвейг:1331 Solvejg:Solvejg:1933 QS" "Sol" #2=
#3_"1933 QS:*Сольвейг:1331 Solvejg:Solvejg" "Sol" #3=
".:Solvejg:1331 Solvejg:1933 QS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.04
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.4574780485
		SemiMajorAxis	3.099720461888
		Eccentricity	0.189594406076
		Inclination	3.100357976548
		AscendingNode	121.346170206098
		ArgOfPericenter	185.376612465613
		MeanAnomaly	325.067509772603
	}
	UniformRotation
	{
		Period	10
	}
	LunarLambert	0.5
	Albedo	0.1509
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1331"
}

#1_"1332 Marconia:Marconia:1934 AA:1930 HQ:1932 VC:1935 FR:1948 SH:1956 GB:A905 UD:A921 TE:A921 UD: #1=
#1_A924 EH" "Sol" #1=
#2_"*Маркония:1332 Marconia:Marconia:1934 AA" "Sol" #2=
#3_"1934 AA:*Маркония:1332 Marconia:Marconia" "Sol" #3=
".:Marconia:1332 Marconia:1934 AA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1332 marconia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	23.398
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.371206577398
		SemiMajorAxis	3.06696699456
		Eccentricity	0.129451733632
		Inclination	2.455491690024
		AscendingNode	13.67407816821
		ArgOfPericenter	348.978432615624
		MeanAnomaly	141.657190289816
	}
	UniformRotation
	{
		Period	19.16
	}
	LunarLambert	0.5
	Albedo	0.063
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1332"
}

#1_"1333 Cevenola:Cevenola:1934 DA:1951 EX" "Sol" #1=
#2_"*Севенола:1333 Cevenola:Cevenola:1934 DA" "Sol" #2=
#3_"1934 DA:*Севенола:1333 Cevenola:Cevenola" "Sol" #3=
".:Cevenola:1333 Cevenola:1934 DA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1333 cevenola.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.631
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.2728293119
		SemiMajorAxis	2.63312551451
		Eccentricity	0.13463252061
		Inclination	14.64114281489
		AscendingNode	115.110910878539
		ArgOfPericenter	336.344015893439
		MeanAnomaly	65.161900720422
	}
	UniformRotation
	{
		Period	4.877
	}
	LunarLambert	0.5
	Albedo	0.209
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1333"
}

#1_"2008 1333 I" "Sol/1333 Cevenola" #1=
#2_"2008 1333 I" "Sol/1333 Cevenola" #2=
#3_"2008 1333 I" "Sol/1333 Cevenola" #3=
".:2008 1333 I" "Sol/1333 Cevenola" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	4.4142  # Период и большая полуось гипотетические ввиду отсутствия данных

		SemiMajorAxis	100
	}
	LunarLambert	0.5
	Albedo	0.209
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-01333.html"
}

#1_"1334 Lundmarka:Lundmarka:1934 OB" "Sol" #1=
#2_"*Лундмарка:1334 Lundmarka:Lundmarka:1934 OB" "Sol" #2=
#3_"1934 OB:*Лундмарка:1334 Lundmarka:Lundmarka" "Sol" #3=
".:Lundmarka:1334 Lundmarka:1934 OB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1334 lundmarka.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.974725076796
		SemiMajorAxis	2.914118816049
		Eccentricity	0.094695473423
		Inclination	11.455796738744
		AscendingNode	133.238220258399
		ArgOfPericenter	130.226997568489
		MeanAnomaly	87.322782421665
	}
	UniformRotation
	{
		Period	6.25
	}
	LunarLambert	0.5
	Albedo	0.242
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1334"
}

#1_"1336 Zeelandia:Zeelandia:1934 RW:1929 QE:1930 XC:1935 YF:1939 RP:A906 YO" "Sol" #1=
#2_"*Зеландия:1336 Zeelandia:Zeelandia:1934 RW" "Sol" #2=
#3_"1934 RW:*Зеландия:1336 Zeelandia:Zeelandia" "Sol" #3=
".:Zeelandia:1336 Zeelandia:1934 RW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.495
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.809827990293
		SemiMajorAxis	2.849361566627
		Eccentricity	0.064363755506
		Inclination	3.197410774937
		AscendingNode	97.42930125981
		ArgOfPericenter	220.480739975166
		MeanAnomaly	271.927837424596
	}
	UniformRotation
	{
		Period	15.602
	}
	LunarLambert	0.5
	Albedo	0.2183
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1336"
}

#1_"1337 Gerarda:Gerarda:1934 RA1:1942 EE1" "Sol" #1=
#2_"*Герарда:1337 Gerarda:Gerarda:1934 RA1" "Sol" #2=
#3_"1934 RA1:*Герарда:1337 Gerarda:Gerarda" "Sol" #3=
".:Gerarda:1337 Gerarda:1934 RA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.43
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.964671832791
		SemiMajorAxis	2.910191466864
		Eccentricity	0.098280991583
		Inclination	17.995308464216
		AscendingNode	160.345774344963
		ArgOfPericenter	199.816756657406
		MeanAnomaly	61.696043161963
	}
	UniformRotation
	{
		Period	12.52
	}
	LunarLambert	0.5
	Albedo	0.0441
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1337"
}

#1_"1339 Desagneauxa:Desagneauxa:1934 XB:1951 AF" "Sol" #1=
#2_"*Дезаньо:1339 Desagneauxa:Desagneauxa:1934 XB" "Sol" #2=
#3_"1934 XB:*Дезаньо:1339 Desagneauxa:Desagneauxa" "Sol" #3=
".:Desagneauxa:1339 Desagneauxa:1934 XB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1339 desagneauxa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	12.225
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.24778889766
		SemiMajorAxis	3.019804093014
		Eccentricity	0.057990990598
		Inclination	8.692689771922
		AscendingNode	291.010223827586
		ArgOfPericenter	162.874746391047
		MeanAnomaly	71.900256695437
	}
	UniformRotation
	{
		Period	9.38
	}
	LunarLambert	0.5
	Albedo	0.144
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1339"
}

#1_"1340 Yvette:Yvette:1934 YA:1930 DO:1942 GW" "Sol" #1=
#2_"*Иветта:1340 Yvette:Yvette:1934 YA" "Sol" #2=
#3_"1934 YA:*Иветта:1340 Yvette:Yvette" "Sol" #3=
".:Yvette:1340 Yvette:1934 YA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.935
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.687642788484
		SemiMajorAxis	3.186271216582
		Eccentricity	0.129382850081
		Inclination	0.416993812555
		AscendingNode	345.684850851124
		ArgOfPericenter	223.851767548875
		MeanAnomaly	310.442591824968
	}
	UniformRotation
	{
		Period	3.525
	}
	LunarLambert	0.5
	Albedo	0.0958
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1340"
}

#1_"1341 Edmee:Edmee:1935 BA:1929 WB1:1932 NK:1957 YK:1963 KJ:A917 DA" "Sol" #1=
#2_"*Эдмэ:1341 Edmee:Edmee:1935 BA" "Sol" #2=
#3_"1935 BA:*Эдмэ:1341 Edmee:Edmee" "Sol" #3=
".:Edmee:1341 Edmee:1935 BA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.745
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.540908727341
		SemiMajorAxis	2.742140566038
		Eccentricity	0.079436121295
		Inclination	13.085440729635
		AscendingNode	107.556356938362
		ArgOfPericenter	141.570284863378
		MeanAnomaly	80.849310786519
	}
	UniformRotation
	{
		Period	23.745
	}
	LunarLambert	0.5
	Albedo	0.1371
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1341"
}

#1_"1342 Brabantia:Brabantia:1935 CV:1953 QD" "Sol" #1=
#2_"*Брабантия:1342 Brabantia:Brabantia:1935 CV" "Sol" #2=
#3_"1935 CV:*Брабантия:1342 Brabantia:Brabantia" "Sol" #3=
".:Brabantia:1342 Brabantia:1935 CV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.46251490195
		SemiMajorAxis	2.288700507685
		Eccentricity	0.203297924696
		Inclination	20.926722371043
		AscendingNode	312.993801438681
		ArgOfPericenter	229.405240961788
		MeanAnomaly	357.127610693917
	}
	UniformRotation
	{
		Period	4.1754
	}
	LunarLambert	0.5
	Albedo	0.1573
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1342"
}

#1_"1343 Nicole:Nicole:1935 FC:1952 KD" "Sol" #1=
#2_"*Николь:1343 Nicole:Nicole:1935 FC" "Sol" #2=
#3_"1935 FC:*Николь:1343 Nicole:Nicole" "Sol" #3=
".:Nicole:1343 Nicole:1935 FC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	12.205
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.117241018021
		SemiMajorAxis	2.568810448396
		Eccentricity	0.114279785636
		Inclination	6.035352761155
		AscendingNode	41.257171561217
		ArgOfPericenter	234.676019535392
		MeanAnomaly	47.50661523168
	}
	UniformRotation
	{
		Period	70
	}
	LunarLambert	0.5
	Albedo	0.1076
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1343"
}

#1_"1345 Potomac:Potomac:1908 CG:1932 CF:1932 EA:1932 FB:1971 DE2" "Sol" #1=
#2_"*Потомак:1345 Potomac:Potomac:1908 CG" "Sol" #2=
#3_"1908 CG:*Потомак:1345 Potomac:Potomac" "Sol" #3=
".:Potomac:1345 Potomac:1908 CG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	35.91
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.967998410884
		SemiMajorAxis	3.989275450094
		Eccentricity	0.183103848765
		Inclination	11.401318151677
		AscendingNode	137.454375403386
		ArgOfPericenter	333.031440159386
		MeanAnomaly	193.573406248821
	}
	UniformRotation
	{
		Period	11.41
	}
	LunarLambert	0.5
	Albedo	0.0439
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1345"
}

#1_"1347 Patria:Patria:1931 VW:1968 UK1:1970 EY2:A898 VB" "Sol" #1=
#2_"*Патрия:1347 Patria:Patria:1931 VW" "Sol" #2=
#3_"1931 VW:*Патрия:1347 Patria:Patria" "Sol" #3=
".:Patria:1347 Patria:1931 VW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.124399959606
		SemiMajorAxis	2.5717873025
		Eccentricity	0.067906596751
		Inclination	11.863165019364
		AscendingNode	229.282844856956
		ArgOfPericenter	202.313937064887
		MeanAnomaly	33.064117920564
	}
	UniformRotation
	{
		Period	29.5
	}
	LunarLambert	0.5
	Albedo	0.0386
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1347"
}

#1_"1349 Bechuana:Bechuana:1934 LJ:1934 NH:1950 PA:1950 QO" "Sol" #1=
#2_"*Бечуана:1349 Bechuana:Bechuana:1934 LJ" "Sol" #2=
#3_"1934 LJ:Bechuana:*Бечуана:1349 Bechuana" "Sol" #3=
".:Bechuana:1349 Bechuana:1934 LJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1349 bechuana.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	12.124
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.233322642147
		SemiMajorAxis	3.014251868533
		Eccentricity	0.157125851247
		Inclination	10.052745674773
		AscendingNode	307.177084166266
		ArgOfPericenter	305.378189587024
		MeanAnomaly	299.056488939628
	}
	UniformRotation
	{
		Period	15.692
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1349"
}

#1_"1350 Rosselia:Rosselia:1934 TA:1926 AF:1929 TN:1929 VH:1934 VA:1938 OC:1948 QG:1949 YY:A924 TB" "Sol" #1=
#2_"*Россалия:1350 Rosselia:Rosselia:1934 TA" "Sol" #2=
#3_"1934 TA:*Россалия:1350 Rosselia:Rosselia" "Sol" #3=
".:Rosselia:1350 Rosselia:1934 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1350 rosselia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.411
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.827859176232
		SemiMajorAxis	2.856478289709
		Eccentricity	0.089972475595
		Inclination	2.939178121262
		AscendingNode	139.554453203632
		ArgOfPericenter	238.124363046847
		MeanAnomaly	220.883942320618
	}
	UniformRotation
	{
		Period	8.14
	}
	LunarLambert	0.5
	Albedo	0.199
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1350"
}

#1_"1351 Uzbekistania:Uzbekistania:1934 TF:1925 CA:1928 QJ:1931 FK:A917 SL:A920 FA" "Sol" #1=
#2_"*Узбекистания:1351 Uzbekistania:Uzbekistania:1934 TF" "Sol" #2=
#3_"1934 TF:*Узбекистания:1351 Uzbekistania:Uzbekistania" "Sol" #3=
".:Uzbekistania:1351 Uzbekistania:1934 TF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32.455
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.714865911269
		SemiMajorAxis	3.196430223574
		Eccentricity	0.063664350829
		Inclination	9.667944786295
		AscendingNode	9.489693436223
		ArgOfPericenter	60.793435185095
		MeanAnomaly	324.955626333733
	}
	UniformRotation
	{
		Period	73.9
	}
	LunarLambert	0.5
	Albedo	0.0606
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1351"
}

#1_"1352 Wawel:Wawel:1935 CE:1928 SC:1933 VF:1949 HO:1968 FB1" "Sol" #1=
#2_"*Вавель:1352 Wawel:Wawel:1935 CE" "Sol" #2=
#3_"1935 CE:*Вавель:1352 Wawel:Wawel" "Sol" #3=
".:Wawel:1352 Wawel:1935 CE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1352 wawel.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.99
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.627239849628
		SemiMajorAxis	2.776786820943
		Eccentricity	0.067102449735
		Inclination	3.757305186488
		AscendingNode	186.173057713844
		ArgOfPericenter	212.376653829197
		MeanAnomaly	180.936718112101
	}
	UniformRotation
	{
		Period	16.97
	}
	LunarLambert	0.5
	Albedo	0.149
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1352"
}

#1_"1353 Maartje:Maartje:1935 CU:1931 ME:1953 TZ2:A910 LB:A916 QB:A920 JC" "Sol" #1=
#2_"*Мартье:1353 Maartje:Maartje:1935 CU" "Sol" #2=
#3_"1935 CU:*Мартье:1353 Maartje:Maartje" "Sol" #3=
".:Maartje:1353 Maartje:1935 CU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1353 maartje.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	19.506
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.221954563882
		SemiMajorAxis	3.009885150192
		Eccentricity	0.095522041437
		Inclination	9.202093300843
		AscendingNode	211.806033093602
		ArgOfPericenter	98.796147568648
		MeanAnomaly	305.169825877158
	}
	UniformRotation
	{
		Period	22.93
	}
	LunarLambert	0.5
	Albedo	0.136
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1353"
}

#1_"1354 Botha:Botha:1935 GK:1925 RF:1930 KG:1931 TP:1935 JK:1953 TO1:1953 TY2" "Sol" #1=
#2_"*Бота:1354 Botha:Botha:1935 GK" "Sol" #2=
#3_"1935 GK:*Бота:1354 Botha:Botha" "Sol" #3=
".:Botha:1354 Botha:1935 GK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.375
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.524031620247
		SemiMajorAxis	3.124870103733
		Eccentricity	0.216887983638
		Inclination	5.957220454354
		AscendingNode	28.712732073621
		ArgOfPericenter	250.65307824467
		MeanAnomaly	76.797723585554
	}
	UniformRotation
	{
		Period	4
	}
	LunarLambert	0.5
	Albedo	0.0225
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1354"
}

#1_"1356 Nyanza:Nyanza:1935 JH:1929 EL:1929 JH:1929 JJ:1931 TB3" "Sol" #1=
#2_"*Ньянза:1356 Nyanza:Nyanza:1935 JH" "Sol" #2=
#3_"1935 JH:*Ньянза:1356 Nyanza:Nyanza" "Sol" #3=
".:Nyanza:1356 Nyanza:1935 JH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.425037989587
		SemiMajorAxis	3.087424795076
		Eccentricity	0.04762671352
		Inclination	7.943774248344
		AscendingNode	69.740496725898
		ArgOfPericenter	302.491223553106
		MeanAnomaly	125.613474366729
	}
	UniformRotation
	{
		Period	12.422
	}
	LunarLambert	0.5
	Albedo	0.0462
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1356"
}

#1_"1357 Khama:Khama:1935 ND:1936 XE:1950 EJ" "Sol" #1=
#2_"*Кхама:1357 Khama:Khama:1935 ND" "Sol" #2=
#3_"1935 ND:*Кхама:1357 Khama:Khama" "Sol" #3=
".:Khama:1357 Khama:1935 ND" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.08
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.680985897227
		SemiMajorAxis	3.183784562445
		Eccentricity	0.15854968558
		Inclination	13.982567849921
		AscendingNode	83.750233674413
		ArgOfPericenter	284.102312858135
		MeanAnomaly	287.256558262225
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0272
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1357"
}

#1_"1358 Gaika:Gaika:1935 OB:1947 RH:1953 AJ:1974 HH3:A916 UK" "Sol" #1=
#2_"*Гайка:1358 Gaika:Gaika:1935 OB" "Sol" #2=
#3_"1935 OB:*Гайка:1358 Gaika:Gaika" "Sol" #3=
".:Gaika:1358 Gaika:1935 OB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.98
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.8974857401094
		SemiMajorAxis	2.476571600342507
		Eccentricity	0.1664002538089528
		Inclination	2.172221201297536
		AscendingNode	21.81360659145107
		ArgOfPericenter	286.6186862445038
		MeanAnomaly	133.6551328800239
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0585
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1358"
}

#1_"1359 Prieska:Prieska:1935 OC:A903 UE:A917 HA" "Sol" #1=
#2_"*Приеска:1359 Prieska:Prieska:1935 OC" "Sol" #2=
#3_"1935 OC:*Приеска:1359 Prieska:Prieska" "Sol" #3=
".:Prieska:1359 Prieska:1935 OC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.99
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.514816492544
		SemiMajorAxis	3.121393887906
		Eccentricity	0.064997271847
		Inclination	11.096623236404
		AscendingNode	64.272199079228
		ArgOfPericenter	342.674664899933
		MeanAnomaly	54.171180588921
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0413
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1359"
}

#1_"1360 Tarka:Tarka:1935 OD" "Sol" #1=
#2_"*Тарка:1360 Tarka:Tarka:1935 OD" "Sol" #2=
#3_"1935 OD:*Тарка:1360 Tarka:Tarka" "Sol" #3=
".:Tarka:1360 Tarka:1935 OD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1360 tarka.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	16.658
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.27981082821
		SemiMajorAxis	2.635992967566
		Eccentricity	0.214430084804
		Inclination	22.822584619959
		AscendingNode	331.435764134561
		ArgOfPericenter	287.7925084776
		MeanAnomaly	235.062237882838
	}
	UniformRotation
	{
		Period	8.87
	}
	LunarLambert	0.5
	Albedo	0.03
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1360"
}

#1_"1361 Leuschneria:Leuschneria:1935 QA" "Sol" #1=
#2_"*Лейшнер:1361 Leuschneria:Leuschneria:1935 QA" "Sol" #2=
#3_"1935 QA:*Лейшнер:1361 Leuschneria:Leuschneria" "Sol" #3=
".:Leuschneria:1361 Leuschneria:1935 QA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.125
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.406833492748
		SemiMajorAxis	3.080514060563
		Eccentricity	0.128749244072
		Inclination	21.592713138346
		AscendingNode	164.733022944048
		ArgOfPericenter	173.54115595027
		MeanAnomaly	230.864336219029
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0924
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1361"
}

#1_"1362 Griqua:Griqua:1935 QG1:1931 BN" "Sol" #1=
#2_"*Гриква:1362 Griqua:Griqua:1935 QG1" "Sol" #2=
#3_"1935 QG1:*Гриква:1362 Griqua:Griqua" "Sol" #3=
".:Griqua:1362 Griqua:1935 QG1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.763513426989
		SemiMajorAxis	3.214544221979
		Eccentricity	0.371530559924
		Inclination	24.225345734048
		AscendingNode	121.34291773243
		ArgOfPericenter	261.927669938935
		MeanAnomaly	171.363521578281
	}
	UniformRotation
	{
		Period	6.907
	}
	LunarLambert	0.5
	Albedo	0.0667
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1362"
}

#1_"1364 Safara:Safara:1935 VB:1932 EK" "Sol" #1=
#2_"*Сафара:1364 Safara:Safara:1935 VB" "Sol" #2=
#3_"1935 VB:Safara:*Сафара:1364 Safara" "Sol" #3=
".:Safara:1364 Safara:1935 VB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1364 safara.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	10.598
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.228806772754
		SemiMajorAxis	3.012517606882
		Eccentricity	0.06609336646
		Inclination	11.487954617752
		AscendingNode	63.985978724783
		ArgOfPericenter	220.281035608151
		MeanAnomaly	331.140310189486
	}
	UniformRotation
	{
		Period	7.25
	}
	LunarLambert	0.5
	Albedo	0.087
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1364"
}

#1_"1366 Piccolo:Piccolo:1932 WA:1930 FA1:1931 PC:1931 RJ1:1935 GM:1935 JM:1950 KL:1961 TL1:A961 VP: #1=
#1_A916 NB" "Sol" #1=
#2_"*Пикколо:1366 Piccolo:Piccolo:1932 WA" "Sol" #2=
#3_"1932 WA:*Пикколо:1366 Piccolo:Piccolo" "Sol" #3=
".:Piccolo:1366 Piccolo:1932 WA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1366 piccolo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.775
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.871031607737
		SemiMajorAxis	2.873482105636
		Eccentricity	0.141914340044
		Inclination	9.47511267489
		AscendingNode	24.146463889057
		ArgOfPericenter	283.075272792682
		MeanAnomaly	42.397229424416
	}
	UniformRotation
	{
		Period	16.57
	}
	LunarLambert	0.5
	Albedo	0.1538
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1366"
}

#1_"1368 Numidia:Numidia:1935 HD:1928 SN:1931 JF:1935 KB:1936 QN:1953 YK" "Sol" #1=
#2_"*Нумидия:1368 Numidia:Numidia:1935 HD" "Sol" #2=
#3_"1935 HD:*Нумидия:1368 Numidia:Numidia" "Sol" #3=
".:Numidia:1368 Numidia:1935 HD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1368 numidia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.796
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.010427087885
		SemiMajorAxis	2.524187519849
		Eccentricity	0.061701416691
		Inclination	14.822092357194
		AscendingNode	18.136204991401
		ArgOfPericenter	264.204170166783
		MeanAnomaly	260.446331620921
	}
	UniformRotation
	{
		Period	3.64
	}
	LunarLambert	0.5
	Albedo	0.298
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1368"
}

#1_"1369 Ostanina:Ostanina:1935 QB:1928 FE" "Sol" #1=
#2_"*Останина:1369 Ostanina:Ostanina:1935 QB" "Sol" #2=
#3_"1935 QB:*Останина:1369 Ostanina:Ostanina" "Sol" #3=
".:Ostanina:1369 Ostanina:1935 QB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.62
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.530496044882
		SemiMajorAxis	3.127307520319
		Eccentricity	0.210105499346
		Inclination	14.288834552761
		AscendingNode	180.64802265907
		ArgOfPericenter	126.44785552478
		MeanAnomaly	185.64538336443
	}
	UniformRotation
	{
		Period	8.4001
	}
	LunarLambert	0.5
	Albedo	0.0545
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1369"
}

#1_"1372 Haremari:Haremari:1935 QK:1928 DX:1937 BD:1944 QK:1951 EW1:1953 OM:1953 PZ" "Sol" #1=
#2_"*Харемари:1372 Haremari:Haremari:1935 QK" "Sol" #2=
#3_"1935 QK:*Харемари:1372 Haremari:Haremari" "Sol" #3=
".:Haremari:1372 Haremari:1935 QK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.925
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.603890798979
		SemiMajorAxis	2.767437837187
		Eccentricity	0.146266193502
		Inclination	16.456695251322
		AscendingNode	327.482736261578
		ArgOfPericenter	88.624385876749
		MeanAnomaly	29.693663142505
	}
	UniformRotation
	{
		Period	15.25
	}
	LunarLambert	0.5
	Albedo	0.0409
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1372"
}

#1_"1378 Leonce:Leonce:1936 DB:1958 FG:1958 GY:1962 KB:1915 RC:A915 WA" "Sol" #1=
#2_"*Леонса:1378 Leonce:Leonce:1936 DB" "Sol" #2=
#3_"1936 DB:*Леонса:1378 Leonce:Leonce" "Sol" #3=
".:Leonce:1378 Leonce:1936 DB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1378 leonce.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	10.614
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.65849515002
		SemiMajorAxis	2.374266806656
		Eccentricity	0.150303703532
		Inclination	3.590846103009
		AscendingNode	43.583189950079
		ArgOfPericenter	202.386678047097
		MeanAnomaly	129.079403476873
	}
	UniformRotation
	{
		Period	4.325
	}
	LunarLambert	0.5
	Albedo	0.061
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1378"
}

#1_"1379 Lomonosowa:Lomonosowa:1936 FC:1933 SG1" "Sol" #1=
#2_"*Ломоносова:1379 Lomonosowa:Lomonosowa:1936 FC" "Sol" #2=
#3_"1936 FC:Lomonosowa:*Ломоносова:1379 Lomonosowa" "Sol" #3=
".:Lomonosowa:1379 Lomonosowa:1936 FC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1379 lomonosowa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.345
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.009809989781
		SemiMajorAxis	2.523928576308
		Eccentricity	0.091615889009
		Inclination	15.606633520783
		AscendingNode	169.881477080426
		ArgOfPericenter	31.360211373533
		MeanAnomaly	39.639140468548
	}
	UniformRotation
	{
		Period	24.488
	}
	LunarLambert	0.5
	Albedo	0.182
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1379"
}

#New3
#1_"1380 Volodia:Volodia:1936 FM" "Sol" #1=
#2_"*Володя:1380 Volodia:Volodia:1936 FM" "Sol" #2=
#3_"1936 FM:Volodia:*Володя:1380 Volodia:" "Sol" #3=
".:Volodia:1380 Volodia:1936 FM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1380 volodia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	10.594
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.599565121973
		SemiMajorAxis	3.153291099828
		Eccentricity	0.102180400837
		Inclination	10.40743221177
		AscendingNode	359.065064073669
		ArgOfPericenter	247.360454896609
		MeanAnomaly	159.241441710241
	}
	UniformRotation
	{
		Period	8
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1380"
}

#1_"1382 Gerti:Gerti:1925 BB:1929 LH:1933 UL1:1936 QB1" "Sol" #1=
#2_"*Герти:1382 Gerti:Gerti:1925 BB" "Sol" #2=
#3_"1925 BB:*Герти:1382 Gerti:Gerti" "Sol" #3=
".:Gerti:1382 Gerti:1925 BB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1382 gerti.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.97
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.307716127797
		SemiMajorAxis	2.21996785374
		Eccentricity	0.131280990727
		Inclination	1.562353473424
		AscendingNode	353.054657709286
		ArgOfPericenter	246.891366956924
		MeanAnomaly	20.304739366013
	}
	UniformRotation
	{
		Period	3.082
	}
	LunarLambert	0.5
	Albedo	0.196
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1382"
}

#1_"1383 Limburgia:Limburgia:1934 RV:1929 UQ:1929 VJ:A923 PA" "Sol" #1=
#2_"*Лимбургия:1383 Limburgia:Limburgia:1934 RV" "Sol" #2=
#3_"1934 RV:*Лимбургия:1383 Limburgia:Limburgia" "Sol" #3=
".:Limburgia:1383 Limburgia:1934 RV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.16
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.400664677549
		SemiMajorAxis	3.078170515449
		Eccentricity	0.190975588042
		Inclination	0.052341251887
		AscendingNode	194.002065969951
		ArgOfPericenter	164.85433241
		MeanAnomaly	295.232714383444
	}
	UniformRotation
	{
		Period	5
	}
	LunarLambert	0.5
	Albedo	0.0891
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1383"
}

#1_"1384 Kniertje:Kniertje:1934 RX" "Sol" #1=
#2_"*Книртье:1384 Kniertje:Kniertje:1934 RX" "Sol" #2=
#3_"1934 RX:*Книртье:1384 Kniertje:Kniertje" "Sol" #3=
".:Kniertje:1384 Kniertje:1934 RX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.755
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.380343602102
		SemiMajorAxis	2.677112679198
		Eccentricity	0.182552146057
		Inclination	11.856629506454
		AscendingNode	152.860561093205
		ArgOfPericenter	276.509702665697
		MeanAnomaly	62.60044673284
	}
	UniformRotation
	{
		Period	9.807
	}
	LunarLambert	0.5
	Albedo	0.3077
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1384"
}

#1_"1385 Gelria:Gelria:1935 MJ:1932 WP:1932 WQ:1936 SN:1948 GJ:1952 DM3:1958 OD" "Sol" #1=
#2_"*Гельрия:1385 Gelria:Gelria:1935 MJ" "Sol" #2=
#3_"1935 MJ:*Гельрия:1385 Gelria:Gelria" "Sol" #3=
".:Gelria:1385 Gelria:1935 MJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.095
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.539861668049
		SemiMajorAxis	2.741719021323
		Eccentricity	0.104909318973
		Inclination	6.92822619943
		AscendingNode	115.036405476625
		ArgOfPericenter	259.866542110224
		MeanAnomaly	74.048642917649
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1883
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1385"
}

#1_"1386 Storeria:Storeria:1935 PA:1975 RF" "Sol" #1=
#2_"*Сторерия:1386 Storeria:Storeria:1935 PA" "Sol" #2=
#3_"1935 PA:*Сторерия:1386 Storeria:Storeria" "Sol" #3=
".:Storeria:1386 Storeria:1935 PA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1386 storeria.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.307
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.635906031282
		SemiMajorAxis	2.364483560377
		Eccentricity	0.287050517633
		Inclination	11.826069322246
		AscendingNode	161.503777760163
		ArgOfPericenter	153.063666857468
		MeanAnomaly	346.164549007651
	}
	UniformRotation
	{
		Period	8.67
	}
	LunarLambert	0.5
	Albedo	0.143
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1386"
}

#1_"1388 Aphrodite:Aphrodite:1935 SS:A914 TC" "Sol" #1=
#2_"*Афродита:1388 Aphrodite:Aphrodite:1935 SS" "Sol" #2=
#3_"1935 SS:*Афродита:1388 Aphrodite:Aphrodite" "Sol" #3=
".:Aphrodite:1388 Aphrodite:1935 SSC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1388 aphrodite.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.678
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.242053701803
		SemiMajorAxis	3.017603506009
		Eccentricity	0.093155462558
		Inclination	11.179604946599
		AscendingNode	54.484976959965
		ArgOfPericenter	256.289271880019
		MeanAnomaly	95.332067375991
	}
	UniformRotation
	{
		Period	11.9432
	}
	LunarLambert	0.5
	Albedo	0.144
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1388"
}

#1_"1389 Onnie:Onnie:1935 SS1:1949 QV1:1955 XB1" "Sol" #1=
#2_"*Онни:1389 Onnie:Onnie:1935 SS1" "Sol" #2=
#3_"1935 SS1:*Онни:1389 Onnie:Onnie" "Sol" #3=
".:Onnie:1389 Onnie:1935 SS1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1389 onnie.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	6.886
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.853605834707
		SemiMajorAxis	2.866624892927
		Eccentricity	0.016513985428
		Inclination	2.047215870761
		AscendingNode	174.563652005483
		ArgOfPericenter	299.95963040599
		MeanAnomaly	58.913239169283
	}
	UniformRotation
	{
		Period	22.5
	}
	LunarLambert	0.5
	Albedo	0.198
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1389"
}

#1_"1390 Abastumani:Abastumani:1935 TA:1926 GN:1929 UL:A907 GN:A916 VA" "Sol" #1=
#2_"*Абастумани:1390 Abastumani:Abastumani:1935 TA" "Sol" #2=
#3_"1935 TA:*Абастумани:1390 Abastumani:Abastumani" "Sol" #3=
".:Abastumani:1390 Abastumani:1935 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	50.79
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.373547385027
		SemiMajorAxis	3.437547261387
		Eccentricity	0.033746121615
		Inclination	19.924549434634
		AscendingNode	28.932090676996
		ArgOfPericenter	333.239544700066
		MeanAnomaly	166.28978012013
	}
	UniformRotation
	{
		Period	17.1
	}
	LunarLambert	0.5
	Albedo	0.0298
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1390"
}

#1_"1391 Carelia:Carelia:1936 DA:1949 MR" "Sol" #1=
#2_"*Карелия:1391 Carelia:Carelia:1936 DA" "Sol" #2=
#3_"1936 DA:Carelia:*Карелия:1391 Carelia" "Sol" #3=
".:Carelia:1391 Carelia:1936 DA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1391 carelia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.066427061089
		SemiMajorAxis	2.547630989617
		Eccentricity	0.164789652356
		Inclination	7.593902363798
		AscendingNode	103.357248418111
		ArgOfPericenter	86.155291018914
		MeanAnomaly	296.985129802628
	}
	UniformRotation
	{
		Period	5.8782
	}
	LunarLambert	0.5
	Albedo	0.214
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1391"
}

#1_"1392 Pierre:Pierre:1936 FO:1938 SZ:1955 TZ:1959 SH:A917 UB" "Sol" #1=
#2_"*Пьер:1392 Pierre:Pierre:1936 FO" "Sol" #2=
#3_"1936 FO:*Пьер:1392 Pierre:Pierre" "Sol" #3=
".:Pierre:1392 Pierre:1936 FO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.22
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.212517487343
		SemiMajorAxis	2.608288798893
		Eccentricity	0.200424962542
		Inclination	12.26230557705
		AscendingNode	358.274167491129
		ArgOfPericenter	44.057411992026
		MeanAnomaly	10.74637002264
	}
	UniformRotation
	{
		Period	18
	}
	LunarLambert	0.5
	Albedo	0.0519
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1392"
}

#1_"1396 Outeniqua:Outeniqua:1936 PF:1930 XV:1933 SL1:1949 HG1:1950 TO2:1957 WE1:1977 TB4:A912 HF" "Sol" #1=
#2_"*Утениква:1396 Outeniqua:Outeniqua:1936 PF" "Sol" #2=
#3_"1936 PF:*Утениква:1396 Outeniqua:Outeniqua" "Sol" #3=
".:Outeniqua:1396 Outeniqua:1936 PF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.475
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.369047545319
		SemiMajorAxis	2.247325390208
		Eccentricity	0.165665068508
		Inclination	4.494064474036
		AscendingNode	359.535977432218
		ArgOfPericenter	266.569832792642
		MeanAnomaly	121.192208382925
	}
	UniformRotation
	{
		Period	3.0816
	}
	LunarLambert	0.5
	Albedo	0.2335
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1396"
}

#1_"1398 Donnera:Donnera:1936 QL:1930 OM:1930 QZ" "Sol" #1=
#2_"*Доннера:1398 Donnera:Donnera:1936 QL" "Sol" #2=
#3_"1936 QL:*Доннера:1398 Donnera:Donnera" "Sol" #3=
".:Donnera:1398 Donnera:1936 QL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.616299689472
		SemiMajorAxis	3.15957048197
		Eccentricity	0.105620784819
		Inclination	11.825981990291
		AscendingNode	297.128081213914
		ArgOfPericenter	71.75577756027
		MeanAnomaly	327.035265807169
	}
	UniformRotation
	{
		Period	7.23
	}
	LunarLambert	0.5
	Albedo	0.1913
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1398"
}

#1_"1400 Tirela:Tirela:1936 WA:1930 UQ" "Sol" #1=
#2_"*Тирела:1400 Tirela:Tirela:1936 WA" "Sol" #2=
#3_"1936 WA:*Тирела:1400 Tirela:Tirela" "Sol" #3=
".:Tirela:1400 Tirela:1936 WA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1400 tirela.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.848
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.532218821284
		SemiMajorAxis	3.127956934269
		Eccentricity	0.232330000568
		Inclination	15.628294920758
		AscendingNode	210.097525835661
		ArgOfPericenter	111.496018944282
		MeanAnomaly	281.39434279672
	}
	UniformRotation
	{
		Period	13.356
	}
	LunarLambert	0.5
	Albedo	0.216
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1400"
}

#1_"1401 Lavonne:Lavonne:1935 UD:1945 VC:1951 KM:1951 LL:1957 EJ:1958 RL" "Sol" #1=
#2_"*Лавонна:1401 Lavonne:Lavonne:1935 UD" "Sol" #2=
#3_"1935 UD:*Лавонна:1401 Lavonne:Lavonne" "Sol" #3=
".:Lavonne:1401 Lavonne:1935 UD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1401 lavonne.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.652
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.322307648227
		SemiMajorAxis	2.226491778536
		Eccentricity	0.180003504736
		Inclination	7.290248683161
		AscendingNode	277.609277021081
		ArgOfPericenter	70.746029938975
		MeanAnomaly	24.60621609125
	}
	UniformRotation
	{
		Period	3.9338
	}
	LunarLambert	0.5
	Albedo	0.257
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1401"
}

#1_"1403 Idelsonia:Idelsonia:1936 QA" "Sol" #1=
#2_"*Идельсония:1403 Idelsonia:Idelsonia:1936 QA" "Sol" #2=
#3_"1936 QA:*Идельсония:1403 Idelsonia:Idelsonia" "Sol" #3=
".:Idelsonia:1403 Idelsonia:1936 QA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.487220196853
		SemiMajorAxis	2.720483646885
		Eccentricity	0.292267361985
		Inclination	10.172136224355
		AscendingNode	156.982309693913
		ArgOfPericenter	192.39741676644
		MeanAnomaly	156.093170813126
	}
	UniformRotation
	{
		Period	5.458
	}
	LunarLambert	0.5
	Albedo	0.0945
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1403"
}

#1_"1404 Ajax:Ajax:1936 QW" "Sol" #1=
#2_"*Аякс:1404 Ajax:Ajax:1936 QW" "Sol" #2=
#3_"1936 QW:*Аякс:1404 Ajax:Ajax" "Sol" #3=
".:Ajax:1404 Ajax:1936 QW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.845
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.215822548461
		SemiMajorAxis	5.30407523218
		Eccentricity	0.112788453248
		Inclination	18.005009575816
		AscendingNode	332.98052972029
		ArgOfPericenter	60.405142161862
		MeanAnomaly	149.398398639928
	}
	UniformRotation
	{
		Period	29.38
	}
	LunarLambert	0.5
	Albedo	0.0665
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1404"
}

#1_"1405 Sibelius:Sibelius:1936 RE:1951 CO:1953 VK3:1963 ST" "Sol" #1=
#2_"*Сибелиус:1405 Sibelius:Sibelius:1936 RE" "Sol" #2=
#3_"1936 RE:*Сибелиус:1405 Sibelius:Sibelius" "Sol" #3=
".:Sibelius:1405 Sibelius:1936 RE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.09
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.378641191654
		SemiMajorAxis	2.251589666742
		Eccentricity	0.145620537177
		Inclination	7.033457239979
		AscendingNode	312.109567556756
		ArgOfPericenter	95.838848265941
		MeanAnomaly	20.590742407558
	}
	UniformRotation
	{
		Period	6.051
	}
	LunarLambert	0.5
	Albedo	0.1432
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1405"
}

#1_"1406 Komppa:Komppa:1936 RF:1949 SW" "Sol" #1=
#2_"*Комппа:1406 Komppa:Komppa:1936 RF" "Sol" #2=
#3_"1936 RF:*Комппа:1406 Komppa:Komppa" "Sol" #3=
".:Komppa:1406 Komppa:1936 RF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.945
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.426821747032
		SemiMajorAxis	2.69601655708
		Eccentricity	0.09782541653
		Inclination	12.419945153366
		AscendingNode	333.249314576076
		ArgOfPericenter	84.637130152399
		MeanAnomaly	200.75810727768
	}
	UniformRotation
	{
		Period	3.508
	}
	LunarLambert	0.5
	Albedo	0.1517
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1406"
}

#1_"1407 Lindelof:Lindelof:1936 WC:1977 FL:A905 AB" "Sol" #1=
#2_"*Линделёф:1407 Lindelof:Lindelof:1936 WC" "Sol" #2=
#3_"1936 WC:*Линделёф:1407 Lindelof:Lindelof" "Sol" #3=
".:Lindelof:1407 Lindelof:1936 WC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1407 lindelof.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.155
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.597244187301
		SemiMajorAxis	2.764773639418
		Eccentricity	0.280569324253
		Inclination	5.805623723106
		AscendingNode	269.094123713502
		ArgOfPericenter	109.578223392233
		MeanAnomaly	18.417934468864
	}
	UniformRotation
	{
		Period	31.151
	}
	LunarLambert	0.5
	Albedo	0.187
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1407"
}

#1_"1408 Trusanda:Trusanda:1936 WF" "Sol" #1=
#2_"*Трусанда:1408 Trusanda:Trusanda:1936 WF" "Sol" #2=
#3_"1936 WF*:Трусанда:1408 Trusanda:Trusanda" "Sol" #3=
".:Trusanda:1408 Trusanda:1936 WF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.23
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.487153942003
		SemiMajorAxis	3.1109471138
		Eccentricity	0.09288916581
		Inclination	8.347166269923
		AscendingNode	201.530462098567
		ArgOfPericenter	188.320527916614
		MeanAnomaly	120.388123642922
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0668
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1408"
}

#1_"1409 Isko:Isko:1937 AK:1933 FG:1935 SZ1:1951 GN:A900 UD" "Sol" #1=
#2_"*Иско:1409 Isko:Isko:1937 AK" "Sol" #2=
#3_"1937 AK:*Иско:1409 Isko:Isko" "Sol" #3=
".:Isko:1409 Isko:1937 AK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.77
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.37728677048
		SemiMajorAxis	2.675867048635
		Eccentricity	0.054989083068
		Inclination	6.705168659691
		AscendingNode	177.57914996707
		ArgOfPericenter	205.892536875926
		MeanAnomaly	27.745662204647
	}
	UniformRotation
	{
		Period	11.6426
	}
	LunarLambert	0.5
	Albedo	0.0805
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1409"
}

#1_"1410 Margret:Margret:1937 AL:A924 RD" "Sol" #1=
#2_"*Маргрет:1410 Margret:Margret:1937 AL" "Sol" #2=
#3_"1937 AL:*Маргрет:1410 Margret:Margret" "Sol" #3=
".:Margret:1410 Margret:1937 AL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.55
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.249145135984
		SemiMajorAxis	3.020324362627
		Eccentricity	0.101915600261
		Inclination	10.349978444437
		AscendingNode	170.973102239228
		ArgOfPericenter	232.067883862402
		MeanAnomaly	22.877184518396
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1763
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1410"
}

#1_"1411 Brauna:Brauna:1937 AM:1929 RT" "Sol" #1=
#2_"*Брауна:1411 Brauna:Brauna:1937 AM" "Sol" #2=
#3_"1937 AM:*Брауна:1411 Brauna:Brauna" "Sol" #3=
".:Brauna:1411 Brauna:1937 AM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.585
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.21403663247
		SemiMajorAxis	3.006841833669
		Eccentricity	0.054099229806
		Inclination	8.050979891063
		AscendingNode	284.757511294662
		ArgOfPericenter	93.949751210599
		MeanAnomaly	97.387287147115
	}
	UniformRotation
	{
		Period	4.9
	}
	LunarLambert	0.5
	Albedo	0.0794
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1411"
}

#1_"1413 Roucarie:Roucarie:1937 CD:1950 QU" "Sol" #1=
#2_"*Рукари:1413 Roucarie:Roucarie:1937 CD" "Sol" #2=
#3_"1937 CD:*Рукари:1413 Roucarie:Roucarie" "Sol" #3=
".:Roucarie:1413 Roucarie:1937 CD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.725
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.248234566252
		SemiMajorAxis	3.019975061882
		Eccentricity	0.063296696479
		Inclination	10.229849823715
		AscendingNode	178.777689938404
		ArgOfPericenter	301.723194065533
		MeanAnomaly	310.032475778821
	}
	UniformRotation
	{
		Period	6.357
	}
	LunarLambert	0.5
	Albedo	0.1677
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1413"
}

#1_"1414 Jerome:Jerome:1937 CE:1951 EO1" "Sol" #1=
#2_"*Жером:1414 Jerome:Jerome:1937 CE" "Sol" #2=
#3_"1937 CE:*Жером:1414 Jerome:Jerome" "Sol" #3=
".:Jerome:1414 Jerome:1937 CE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.62
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.645666581213
		SemiMajorAxis	2.784153805321
		Eccentricity	0.160765026669
		Inclination	8.858546896054
		AscendingNode	143.781828923054
		ArgOfPericenter	2.951992617501
		MeanAnomaly	257.624050001302
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0652
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1414"
}

#1_"1415 Malautra:Malautra:1937 EA:1934 HF:1955 UW1:1977 HF:A905 SB" "Sol" #1=
#2_"*Малаутра:1415 Malautra:Malautra:1937 EA" "Sol" #2=
#3_"1937 EA:*Малаутра:1415 Malautra:Malautra" "Sol" #3=
".:Malautra:1415 Malautra:1937 EA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.31671247723
		SemiMajorAxis	2.223991287341
		Eccentricity	0.086454360113
		Inclination	3.426107348926
		AscendingNode	329.230055608656
		ArgOfPericenter	241.02402097
		MeanAnomaly	116.143840402111
	}
	UniformRotation
	{
		Period	12
	}
	LunarLambert	0.5
	Albedo	0.1123
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1415"
}

#1_"1416 Renauxa:Renauxa:1937 EC:1930 XE:A914 TB:A919 SC" "Sol" #1=
#2_"*Ренаукса:1416 Renauxa:Renauxa:1937 EC" "Sol" #2=
#3_"1937 EC:*Ренаукса:1416 Renauxa:Renauxa" "Sol" #3=
".:Renauxa:1416 Renauxa:1937 EC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.475
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.243492679967
		SemiMajorAxis	3.018155715398
		Eccentricity	0.103319333266
		Inclination	10.041515058512
		AscendingNode	352.654247824995
		ArgOfPericenter	65.484864509882
		MeanAnomaly	7.145297306889
	}
	UniformRotation
	{
		Period	8.7
	}
	LunarLambert	0.5
	Albedo	0.1459
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1416"
}

#1_"1418 Fayeta:Fayeta:1903 RG:1930 UM:A913 RC" "Sol" #1=
#2_"*Файета:1418 Fayeta:Fayeta:1903 RG" "Sol" #2=
#3_"1903 RG:*Файета:1418 Fayeta:Fayeta" "Sol" #3=
".:Fayeta:1418 Fayeta:1903 RG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.355151438188
		SemiMajorAxis	2.241141529335
		Eccentricity	0.20387565807
		Inclination	7.194632113291
		AscendingNode	355.131641159952
		ArgOfPericenter	324.022072867996
		MeanAnomaly	78.345506081569
	}
	UniformRotation
	{
		Period	63.641
	}
	LunarLambert	0.5
	Albedo	0.2571
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1418"
}

#1_"1419 Danzig:Danzig:1929 RF:1936 RD:1952 HJ4:1957 WO1:A917 GA" "Sol" #1=
#2_"*Данзиг:1419 Danzig:Danzig:1929 RF" "Sol" #2=
#3_"1929 RF:*Данзиг:1419 Danzig:Danzig" "Sol" #3=
".:Danzig:1419 Danzig:1929 RF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1419 danzig.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.498
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.471659444197
		SemiMajorAxis	2.292728392528
		Eccentricity	0.14674758794
		Inclination	5.724931671927
		AscendingNode	213.539661026257
		ArgOfPericenter	232.638857299521
		MeanAnomaly	186.321993414308
	}
	UniformRotation
	{
		Period	8.1202
	}
	LunarLambert	0.5
	Albedo	0.26
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1419"
}

#1_"1421 Esperanto:Esperanto:1936 FQ:1931 HC:1958 GD:A906 UD:A917 XD:A920 GD" "Sol" #1=
#2_"*Эсперанто:1421 Esperanto:Esperanto:1936 FQ" "Sol" #2=
#3_"1936 FQ:*Эсперанто:1421 Esperanto:Esperanto" "Sol" #3=
".:Esperanto:1421 Esperanto:1936 FQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	21.655
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.432184381889
		SemiMajorAxis	3.090135572713
		Eccentricity	0.082903496459
		Inclination	9.807203535402
		AscendingNode	42.624195582638
		ArgOfPericenter	164.37398135491
		MeanAnomaly	146.208714818019
	}
	UniformRotation
	{
		Period	21.982
	}
	LunarLambert	0.5
	Albedo	0.0714
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1421"
}

#1_"1423 Jose:Jose:1936 QM:1931 TM2:1934 EE:1936 SC:1937 YE:1946 UF:1950 PW:1968 HL" "Sol" #1=
#2_"*Жозе:1423 Jose:Jose:1936 QM" "Sol" #2=
#3_"1936 QM:*Жозе:1423 Jose:Jose" "Sol" #3=
".:Jose:1423 Jose:1936 QM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1423 jose.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	9.79
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.836663810306
		SemiMajorAxis	2.859950167807
		Eccentricity	0.077885451204
		Inclination	2.90575135499
		AscendingNode	58.58740150333
		ArgOfPericenter	319.594016708056
		MeanAnomaly	49.810794688534
	}
	UniformRotation
	{
		Period	12.307
	}
	LunarLambert	0.5
	Albedo	0.338
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1423"
}

#1_"1424 Sundmania:Sundmania:1937 AJ:1929 SS:1929 UB:1931 AD:1938 FP:A918 WA" "Sol" #1=
#2_"*Сундмания:1424 Sundmania:Sundmania:1937 AJ" "Sol" #2=
#3_"1937 AJ:*Сундмания:1424 Sundmania:Sundmania" "Sol" #3=
".:Sundmania:1424 Sundmania:1937 AJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1424 sundmania.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	32.346
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.692941275894
		SemiMajorAxis	3.188249751266
		Eccentricity	0.061922549654
		Inclination	9.176506501192
		AscendingNode	43.000410056554
		ArgOfPericenter	301.802726545068
		MeanAnomaly	22.785325323872
	}
	UniformRotation
	{
		Period	93.73
	}
	LunarLambert	0.5
	Albedo	0.03
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1424"
}

#1_"1425 Tuorla:Tuorla:1937 GB:1950 KC:1950 LQ" "Sol" #1=
#2_"*Туорла:1425 Tuorla:Tuorla:1937 GB" "Sol" #2=
#3_"1937 GB:*Туорла:1425 Tuorla:Tuorla" "Sol" #3=
".:Tuorla:1425 Tuorla:1937 GB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.47
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.221743296927
		SemiMajorAxis	2.612095675395
		Eccentricity	0.100269822324
		Inclination	12.973856117517
		AscendingNode	185.988996475426
		ArgOfPericenter	342.218815168408
		MeanAnomaly	166.7527156005
	}
	UniformRotation
	{
		Period	7.75
	}
	LunarLambert	0.5
	Albedo	0.239
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1425"
}

#1_"1426 Riviera:Riviera:1937 GF:1930 UD1:1933 HJ:1938 SN:1949 HP:2004 ST12:A920 CA" "Sol" #1=
#2_"*Ривьера:1426 Riviera:Riviera:1937 GF" "Sol" #2=
#3_"1937 GF:*Ривьера:1426 Riviera:Riviera" "Sol" #3=
".:Riviera:1426 Riviera:1937 GF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.72
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.148664499365
		SemiMajorAxis	2.581864276474
		Eccentricity	0.160718283235
		Inclination	9.063505882501
		AscendingNode	335.049401290772
		ArgOfPericenter	274.840396616862
		MeanAnomaly	234.388588952642
	}
	UniformRotation
	{
		Period	4.4044
	}
	LunarLambert	0.5
	Albedo	0.3546
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1426"
}

#1_"1427 Ruvuma:Ruvuma:1937 KB:1929 XF" "Sol" #1=
#2_"*Рувума:1427 Ruvuma:Ruvuma:1937 KB" "Sol" #2=
#3_"1937 KB:*Рувума:1427 Ruvuma:Ruvuma" "Sol" #3=
".:Ruvuma:1427 Ruvuma:1937 KB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.78
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.558751008045
		SemiMajorAxis	2.749318873315
		Eccentricity	0.211866892391
		Inclination	9.345550585576
		AscendingNode	78.454048388267
		ArgOfPericenter	241.976997470184
		MeanAnomaly	309.317650009518
	}
	UniformRotation
	{
		Period	4.797
	}
	LunarLambert	0.5
	Albedo	0.0657
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1427"
}

#1_"1428 Mombasa:Mombasa:1937 NO:1933 WO:1949 FA:1957 YZ" "Sol" #1=
#2_"*Момбаса:1428 Mombasa:Mombasa:1937 NO" "Sol" #2=
#3_"1937 NO:*Момбаса:1428 Mombasa:Mombasa" "Sol" #3=
".:Mombasa:1428 Mombasa:1937 NO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.315
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.717867686692
		SemiMajorAxis	2.812926404551
		Eccentricity	0.138143105667
		Inclination	17.324681768279
		AscendingNode	115.819894364984
		ArgOfPericenter	252.102888072719
		MeanAnomaly	97.109477309365
	}
	UniformRotation
	{
		Period	16.67
	}
	LunarLambert	0.5
	Albedo	0.024
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1428"
}

#1_"1430 Somalia:Somalia:1937 NK:1929 RQ:1954 UR1:1957 HT:1962 VF" "Sol" #1=
#2_"*Сомали:1430 Somalia:Somalia:1937 NK" "Sol" #2=
#3_"1937 NK:Somalia:*Сомали:1430 Somalia" "Sol" #3=
".:Somalia:1430 Somalia:1937 NK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1430 somalia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.676
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.094238674022
		SemiMajorAxis	2.559233838207
		Eccentricity	0.198607760268
		Inclination	3.288227065305
		AscendingNode	327.24944873
		ArgOfPericenter	351.451866536252
		MeanAnomaly	136.340768965603
	}
	UniformRotation
	{
		Period	6.913
	}
	LunarLambert	0.5
	Albedo	0.153
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1430"
}

#1_"1432 Ethiopia:Ethiopia:1937 PG:1948 OE:1951 KF:1973 FQ1" "Sol" #1=
#2_"*Эфиопия:1432 Ethiopia:Ethiopia:1937 PG" "Sol" #2=
#3_"1937 PG:*Эфиопия:1432 Ethiopia:Ethiopia" "Sol" #3=
".:Ethiopia:1432 Ethiopia:1937 PG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1432 ethiopia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.537
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.673937314625
		SemiMajorAxis	2.380943153657
		Eccentricity	0.226847830254
		Inclination	8.277805789623
		AscendingNode	123.34123379201
		ArgOfPericenter	218.142437129343
		MeanAnomaly	52.266772104976
	}
	UniformRotation
	{
		Period	9.8458
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1432"
}

#1_"1434 Margot:Margot:1936 FD1:1931 GM:1931 HA:1938 RD:1938 UN:1988 DU:A906 QA:A922 SD" "Sol" #1=
#2_"*Марго:1434 Margot:Margot:1936 FD1" "Sol" #2=
#3_"1936 FD1:*Марго:1434 Margot:Margot" "Sol" #3=
".:Margot:1434 Margot:1936 FD1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.825
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.240850085902
		SemiMajorAxis	3.017141578327
		Eccentricity	0.06459778104
		Inclination	10.833313328879
		AscendingNode	152.421968270397
		ArgOfPericenter	147.83842552305
		MeanAnomaly	258.558563557422
	}
	UniformRotation
	{
		Period	8.17
	}
	LunarLambert	0.5
	Albedo	0.1353
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1434"
}

#1_"1435 Garlena:Garlena:1936 WE:1953 UM" "Sol" #1=
#2_"*Гарлена:1435 Garlena:Garlena:1936 WE" "Sol" #2=
#3_"1936 WE:*Гарлена:1435 Garlena:Garlena" "Sol" #3=
".:Garlena:1435 Garlena:1936 WE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.299956964332
		SemiMajorAxis	2.644258675103
		Eccentricity	0.251204861227
		Inclination	4.038178476804
		AscendingNode	189.213899809934
		ArgOfPericenter	268.877217529419
		MeanAnomaly	30.029887756582
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0432
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1435"
}

#1_"1436 Salonta:Salonta:1936 YA:1933 FX1:1934 NU:1954 CQ" "Sol" #1=
#2_"*Салонта:1436 Salonta:Salonta:1936 YA" "Sol" #2=
#3_"1936 YA:*Салонта:1436 Salonta:Salonta" "Sol" #3=
".:Salonta:1436 Salonta:1936 YA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1436 salonta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	26.884
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.576846726664
		SemiMajorAxis	3.144756360576
		Eccentricity	0.065261924651
		Inclination	13.892334010299
		AscendingNode	260.692754329784
		ArgOfPericenter	28.906087036679
		MeanAnomaly	152.50598865138
	}
	UniformRotation
	{
		Period	8.87
	}
	LunarLambert	0.5
	Albedo	0.028
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1436"
}

#1_"1437 Diomedes:Diomedes:1937 PB:1931 DN:1936 PQ:1971 RD" "Sol" #1=
#2_"*Диомед:1437 Diomedes:Diomedes:1937 PB" "Sol" #2=
#3_"1937 PB:*Диомед:1437 Diomedes:Diomedes" "Sol" #3=
".:Diomedes:1437 Diomedes:1937 PB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	82.155
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.822061899507
		SemiMajorAxis	5.189474127995
		Eccentricity	0.045085370672
		Inclination	20.490287510099
		AscendingNode	315.80184566068
		ArgOfPericenter	131.257426346149
		MeanAnomaly	134.149861457308
	}
	UniformRotation
	{
		Period	24.49
	}
	LunarLambert	0.5
	Albedo	0.0313
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1437"
}

#1_"1439 Vogtia:Vogtia:1937 TE:1953 UJ:1957 HP:1964 FC " "Sol" #1=
#2_"*Фогтия:1439 Vogtia:Vogtia:1937 TE" "Sol" #2=
#3_"1937 TE:*Фогтия:1439 Vogtia:Vogtia" "Sol" #3=
".:Vogtia:1439 Vogtia:1937 TE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.935
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	8.006621315525
		SemiMajorAxis	4.002156409602
		Eccentricity	0.118320164336
		Inclination	4.202931473805
		AscendingNode	35.596369893968
		ArgOfPericenter	101.4487830807
		MeanAnomaly	152.7720999976
	}
	UniformRotation
	{
		Period	12.95
	}
	LunarLambert	0.5
	Albedo	0.0509
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1439"
}

#1_"1441 Bolyai:Bolyai:1937 WA" "Sol" #1=
#2_"*Бойяи:1441 Bolyai:Bolyai:1937 WA" "Sol" #2=
#3_"1937 WA:*Бойяи:1441 Bolyai:Bolyai" "Sol" #3=
".:Bolyai:1441 Bolyai:1937 WA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.38
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.27116938147
		SemiMajorAxis	2.632443517033
		Eccentricity	0.237073259675
		Inclination	13.906646801996
		AscendingNode	254.300997237899
		ArgOfPericenter	115.273102259027
		MeanAnomaly	57.033951199348
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0467
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1441"
}

#1_"1444 Pannonia:Pannonia:1938 AE" "Sol" #1=
#2_"*Паннония:1444 Pannonia:Pannonia:1938 AE" "Sol" #2=
#3_"1938 AE:*Паннония:1444 Pannonia:Pannonia" "Sol" #3=
".:Pannonia:1444 Pannonia:1938 AE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.596173840409
		SemiMajorAxis	3.152017813131
		Eccentricity	0.139103584109
		Inclination	17.763492555417
		AscendingNode	303.332341743912
		ArgOfPericenter	311.136789225552
		MeanAnomaly	127.470386245803
	}
	UniformRotation
	{
		Period	10.756
	}
	LunarLambert	0.5
	Albedo	0.4748
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1444"
}

#1_"1446 Sillanpaa:Sillanpaa:1938 BA:1935 GB:1952 HQ3:1955 DQ:1965 EA" "Sol" #1=
#2_"*Силланпяя:1446 Sillanpaa:Sillanpaa:1938 BA" "Sol" #2=
#3_"1938 BA:*Силланпяя:1446 Sillanpaa:Sillanpaa" "Sol" #3=
".:Sillanpaa:1446 Sillanpaa:1938 BA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1446 sillanpaa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	4.084
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.365716339634
		SemiMajorAxis	2.245843757341
		Eccentricity	0.101791656899
		Inclination	5.256298340341
		AscendingNode	17.558839924241
		ArgOfPericenter	196.269111744833
		MeanAnomaly	282.371530477663
	}
	UniformRotation
	{
		Period	9.6602
	}
	LunarLambert	0.5
	Albedo	0.241
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1446"
}

#1_"1448 Lindbladia:Lindbladia:1938 DF:1949 BK:1964 JG" "Sol" #1=
#2_"*Линдбладия:1448 Lindbladia:Lindbladia:1938 DF" "Sol" #2=
#3_"1938 DF:*Линдбладия:1448 Lindbladia:Lindbladia" "Sol" #3=
".:Lindbladia:1448 Lindbladia:1938 DF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.325
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.656413352561
		SemiMajorAxis	2.373366033472
		Eccentricity	0.184819659294
		Inclination	5.818870472941
		AscendingNode	44.919203691745
		ArgOfPericenter	74.695361251799
		MeanAnomaly	17.713342137717
	}
	UniformRotation
	{
		Period	10.969
	}
	LunarLambert	0.5
	Albedo	0.0378
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1448"
}

#1_"1449 Virtanen:Virtanen:1938 DO:1928 DC" "Sol" #1=
#2_"*Виртанен:1449 Virtanen:Virtanen:1938 DO" "Sol" #2=
#3_"1938 DO:Virtanen:*Виртанен:1449 Virtanen" "Sol" #3=
".:Virtanen:1449 Virtanen:1938 DO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1449 virtanen.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	4.632
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.312946249509
		SemiMajorAxis	2.222307362127
		Eccentricity	0.14186691687
		Inclination	6.641302039837
		AscendingNode	110.78289283983
		ArgOfPericenter	132.171944111221
		MeanAnomaly	229.552989671748
	}
	UniformRotation
	{
		Period	30.495
	}
	LunarLambert	0.5
	Albedo	0.285
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1449"
}

#1_"1450 Raimonda:Raimonda:1938 DP:1934 GJ:A915 TF" "Sol" #1=
#2_"*Раймонда:1450 Raimonda:Raimonda:1938 DP" "Sol" #2=
#3_"1938 DP:*Раймонда:1450 Raimonda:Raimonda" "Sol" #3=
".:Raimonda:1450 Raimonda:1938 DP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1450 raimonda.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	9.24
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.21852255859
		SemiMajorAxis	2.610767006779
		Eccentricity	0.171965528691
		Inclination	4.864375715029
		AscendingNode	74.939060719057
		ArgOfPericenter	13.441673877784
		MeanAnomaly	117.906719125328
	}
	UniformRotation
	{
		Period	12.66
	}
	LunarLambert	0.5
	Albedo	0.094
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1450"
}

#1_"1453 Fennia:Fennia:1938 ED1" "Sol" #1=
#2_"*Фенния:1453 Fennia:Fennia:1938 ED1" "Sol" #2=
#3_"1938 ED1:*Фенния:1453 Fennia:Fennia" "Sol" #3=
".:Fennia:1453 Fennia:1938 ED1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.48
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.613015397865
		SemiMajorAxis	1.897095429688
		Eccentricity	0.028349576998
		Inclination	23.673123133763
		AscendingNode	7.093301117197
		ArgOfPericenter	255.035504370637
		MeanAnomaly	55.386234201308
	}
	UniformRotation
	{
		Period	4.4121
	}
	LunarLambert	0.5
	Albedo	0.2494
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1453"
}

#1_"2007 1453 I" "Sol/1453 Fennia" #1=
#2_"2007 1453 I" "Sol/1453 Fennia" #2=
#3_"2007 1453 I" "Sol/1453 Fennia" #3=
".:2007 1453 I" "Sol/1453 Fennia" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.975
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.9579
		SemiMajorAxis	15
	}
	LunarLambert	0.5
	Albedo	0.2494
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-01453.html"
}

#1_"1456 Saldanha:Saldanha:1937 NG:1926 PC:1933 XE" "Sol" #1=
#2_"*Салдана:1456 Saldanha:Saldanha:1937 NG" "Sol" #2=
#3_"1937 NG:*Салдана:1456 Saldanha:Saldanha" "Sol" #3=
".:Saldanha:1456 Saldanha:1937 NG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	21.795
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.774434650732
		SemiMajorAxis	3.218603745649
		Eccentricity	0.215110735541
		Inclination	10.464325545941
		AscendingNode	282.887429019239
		ArgOfPericenter	64.166772992871
		MeanAnomaly	141.894168264627
	}
	UniformRotation
	{
		Period	19.035
	}
	LunarLambert	0.5
	Albedo	0.0395
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1456"
}

#1_"1458 Mineura:Mineura:1937 RC:1955 XK" "Sol" #1=
#2_"*Миневра:1458 Mineura:Mineura:1937 RC" "Sol" #2=
#3_"1937 RC:*Миневра:1458 Mineura:Mineura" "Sol" #3=
".:Mineura:1458 Mineura:1937 RC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.595
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.254684281325
		SemiMajorAxis	2.625665660738
		Eccentricity	0.181206359857
		Inclination	12.538973747981
		AscendingNode	181.673410562656
		ArgOfPericenter	100.086920432044
		MeanAnomaly	107.11822964175
	}
	UniformRotation
	{
		Period	36
	}
	LunarLambert	0.5
	Albedo	0.1502
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1458"
}

#1_"1459 Magnya:Magnya:1937 VA" "Sol" #1=
#2_"*Магния:1459 Magnya:Magnya:1937 VA" "Sol" #2=
#3_"1937 VA:*Магния:1459 Magnya:Magnya" "Sol" #3=
".:Magnya:1459 Magnya:1937 VA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1459 magnya.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	14.594
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.57786891982
		SemiMajorAxis	3.145140621957
		Eccentricity	0.233506938295
		Inclination	16.937599198959
		AscendingNode	41.550039125173
		ArgOfPericenter	328.88374118744
		MeanAnomaly	304.666002137112
	}
	UniformRotation
	{
		Period	4.678
	}
	LunarLambert	0.5
	Albedo	0.2168
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1459"
}

#1_"1461 Jean-Jacques:Jean-Jacques:1937 YL:1935 OH:1939 GH" "Sol" #1=
#2_"*Жан-Жак:1461 Jean-Jacques:Jean-Jacques:1937 YL" "Sol" #2=
#3_"1937 YL:*Жан-Жак:1461 Jean-Jacques:Jean-Jacques" "Sol" #3=
".:Jean-Jacques:1461 Jean-Jacques:1937 YL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.47
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.525798051278
		SemiMajorAxis	3.125536232357
		Eccentricity	0.045170119641
		Inclination	15.329586732729
		AscendingNode	104.814490562651
		ArgOfPericenter	335.838988083016
		MeanAnomaly	4.846018611302
	}
	UniformRotation
	{
		Period	16.56
	}
	LunarLambert	0.5
	Albedo	0.1613
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1461"
}

#1_"1462 Zamenhof:Zamenhof:1938 CA:1963 TS:1964 VF2:1969 TU5" "Sol" #1=
#2_"*Заменгоф:1462 Zamenhof:Zamenhof:1938 CA" "Sol" #2=
#3_"1938 CA:*Заменгоф:1462 Zamenhof:Zamenhof" "Sol" #3=
".:Zamenhof:1462 Zamenhof:1938 CA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.91
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.580906436392
		SemiMajorAxis	3.146282342332
		Eccentricity	0.109322208912
		Inclination	0.967754930448
		AscendingNode	24.768903445458
		ArgOfPericenter	188.467306253121
		MeanAnomaly	189.677929458394
	}
	UniformRotation
	{
		Period	10.4
	}
	LunarLambert	0.5
	Albedo	0.1268
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1462"
}

#1_"1463 Nordenmarkia:Nordenmarkia:1938 CB:1925 UB:1925 WJ:1927 DC:1930 QE:1938 EE:1950 FD" "Sol" #1=
#2_"*Норденмаркия:1463 Nordenmarkia:Nordenmarkia:1938 CB" "Sol" #2=
#3_"1938 CB:*Норденмаркия:1463 Nordenmarkia:Nordenmarkia" "Sol" #3=
".:Nordenmarkia:1463 Nordenmarkia:1938 CB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.24
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.603952031183
		SemiMajorAxis	3.154937822488
		Eccentricity	0.18836544453
		Inclination	7.298554147449
		AscendingNode	329.823865043784
		ArgOfPericenter	77.45705422563
		MeanAnomaly	355.460325854602
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0514
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1463"
}

#1_"1464 Armisticia:Armisticia:1939 VO:1937 LJ:1955 YN:1974 HF1:A908 YD" "Sol" #1=
#2_"*Армистиция:1464 Armisticia:Armisticia:1939 VO" "Sol" #2=
#3_"1939 VO:*Армистиция:1464 Armisticia:Armisticia" "Sol" #3=
".:Armisticia:1464 Armisticia:1939 VO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1464 armisticia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	11.656
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	5.205723194424
		SemiMajorAxis	3.003644842867
		Eccentricity	0.047042113693
		Inclination	11.565962290377
		AscendingNode	86.915784097572
		ArgOfPericenter	52.503186025577
		MeanAnomaly	114.353548810198
	}
	UniformRotation
	{
		Period	7.5
	}
	LunarLambert	0.5
	Albedo	0.126
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1464"
}

#1_"1466 Mundleria:Mundleria:1938 KA:1950 UK:1952 DF1:1963 DJ:A923 GA" "Sol" #1=
#2_"*Мюндлерия:1466 Mundleria:Mundleria:1938 KA" "Sol" #2=
#3_"1938 KA:*Мюндлерия:1466 Mundleria:Mundleria" "Sol" #3=
".:Mundleria:1466 Mundleria:1938 KA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.755
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.664815087333
		SemiMajorAxis	2.377000335043
		Eccentricity	0.15637737145
		Inclination	13.146856118693
		AscendingNode	155.015118804095
		ArgOfPericenter	74.646177046352
		MeanAnomaly	338.83434716115
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0664
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1466"
}

#1_"1469 Linzia:Linzia:1938 QD:1931 JD:1933 SM1:1936 FC1:1949 OP1:1955 ST:1955 UB:A916 QD" "Sol" #1=
#2_"*Линзия:1469 Linzia:Linzia:1938 QD" "Sol" #2=
#3_"1938 QD:*Линзия:1469 Linzia:Linzia" "Sol" #3=
".:Linzia:1469 Linzia:1938 QD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.495
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.519903390574
		SemiMajorAxis	3.123313053898
		Eccentricity	0.067183520226
		Inclination	13.39666555363
		AscendingNode	188.977213324263
		ArgOfPericenter	207.765402809946
		MeanAnomaly	233.512270096791
	}
	UniformRotation
	{
		Period	22.215
	}
	LunarLambert	0.5
	Albedo	0.0734
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1469"
}

#1_"1470 Carla:Carla:1938 SD:1930 DE:1955 UN" "Sol" #1=
#2_"*Карла:1470 Carla:Carla:1938 SD" "Sol" #2=
#3_"1938 SD:*Карла:1470 Carla:Carla" "Sol" #3=
".:Carla:1470 Carla:1938 SD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.485
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.6113780153757
		SemiMajorAxis	3.157724349685638
		Eccentricity	0.06854570553342722
		Inclination	3.212971491285721
		AscendingNode	358.4360001043059
		ArgOfPericenter	342.2323787065878
		MeanAnomaly	220.4034826444667
	}
	UniformRotation
	{
		Period	6.1514
	}
	LunarLambert	0.5
	Albedo	0.0515
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1470"
}

#1_"1471 Tornio:Tornio:1938 SL1:1931 BA:1949 EK" "Sol" #1=
#2_"*Торнио:1471 Tornio:Tornio:1938 SL1" "Sol" #2=
#3_"1938 SL1:*Торнио:1471 Tornio:Tornio" "Sol" #3=
".:Tornio:1471 Tornio:1938 SL1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.52
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.478202351775
		SemiMajorAxis	2.716837570024
		Eccentricity	0.116541761451
		Inclination	13.621954401397
		AscendingNode	322.069456512064
		ArgOfPericenter	93.378377682122
		MeanAnomaly	328.471950149345
	}
	UniformRotation
	{
		Period	6.6
	}
	LunarLambert	0.5
	Albedo	0.0849
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1471"
}

#1_"1472 Muonio:Muonio:1938 UQ:1931 RX:1948 VU:1948 WB:1961 OA" "Sol" #1=
#2_"*Муонио:1472 Muonio:Muonio:1938 UQ" "Sol" #2=
#3_"1938 UQ:*Муонио:1472 Muonio:Muonio" "Sol" #3=
".:Muonio:1472 Muonio:1938 UQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1472 muonio.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.194
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.338963490947
		SemiMajorAxis	2.233927008062
		Eccentricity	0.198750146539
		Inclination	4.565959916938
		AscendingNode	45.222214505133
		ArgOfPericenter	318.618734785342
		MeanAnomaly	11.454196349706
	}
	UniformRotation
	{
		Period	8.706
	}
	LunarLambert	0.5
	Albedo	0.24
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1472"
}

#1_"1473 Ounas:Ounas:1938 UT:1950 NZ:1950 PB1" "Sol" #1=
#2_"*Оунас:1473 Ounas:Ounas:1938 UT" "Sol" #2=
#3_"1938 UT:*Оунас:1473 Ounas:Ounas" "Sol" #3=
".:Ounas:1473 Ounas:1938 UT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.79
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.130894188988
		SemiMajorAxis	2.57448626426
		Eccentricity	0.237096477185
		Inclination	13.64589063228
		AscendingNode	216.536398865528
		ArgOfPericenter	129.426065045588
		MeanAnomaly	188.865482158368
	}
	UniformRotation
	{
		Period	139.1
	}
	LunarLambert	0.5
	Albedo	0.1089
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1473"
}

#1_"1475 Yalta:Yalta:1935 SM:1946 WA:1953 TY3:A917 SJ" "Sol" #1=
#2_"*Ялта:1475 Yalta:Yalta:1935 SM" "Sol" #2=
#3_"1935 SM:Yalta:*Ялта:1475 Yalta" "Sol" #3=
".:Yalta:1475 Yalta:1935 SM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.788
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.600494652856
		SemiMajorAxis	2.349106168851
		Eccentricity	0.168469060093
		Inclination	4.504208737937
		AscendingNode	200.171267402474
		ArgOfPericenter	201.647066217099
		MeanAnomaly	194.120589279392
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1475"
}

#1_"1477 Bonsdorffia:Bonsdorffia:1938 CC:1959 WD" "Sol" #1=
#2_"*Бонсдорффия:1477 Bonsdorffia:Bonsdorffia:1938 CC" "Sol" #2=
#3_"1938 CC:*Бонсдорффия:1477 Bonsdorffia:Bonsdorffia" "Sol" #3=
".:Bonsdorffia:1477 Bonsdorffia:1938 CC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.725014218188
		SemiMajorAxis	3.200213195038
		Eccentricity	0.27565721939
		Inclination	15.715864773511
		AscendingNode	320.661935310937
		ArgOfPericenter	103.311614767359
		MeanAnomaly	257.761867219635
	}
	UniformRotation
	{
		Period	7.8
	}
	LunarLambert	0.5
	Albedo	0.0517
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1477"
}

#1_"1481 Tubingia:Tubingia:1938 DR:1930 UL:1933 FT1:1933 FY1:1935 SY1:1938 CN:1938 ES:1939 LD:1941 WF: #1=
#1_1950 OQ:1955 LA:1959 GY:A907 GQ:A912 FB" "Sol" #1=
#2_"*Тюбингия:1481 Tubingia:Tubingia:1938 DR" "Sol" #2=
#3_"1938 DR:*Тюбингия:1481 Tubingia:Tubingia" "Sol" #3=
".:Tubingia:1481 Tubingia:1938 DR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.63
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.236948621137
		SemiMajorAxis	3.015644018156
		Eccentricity	0.04560720974
		Inclination	3.518108922962
		AscendingNode	353.778271007312
		ArgOfPericenter	312.171104578086
		MeanAnomaly	95.899441190382
	}
	UniformRotation
	{
		Period	24
	}
	LunarLambert	0.5
	Albedo	0.1167
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1481"
}

#1_"1482 Sebastiana:Sebastiana:1938 DA1:1928 FT:1939 LG:1948 GC:1950 TU3" "Sol" #1=
#2_"*Себастьяна:1482 Sebastiana:Sebastiana:1938 DA1" "Sol" #2=
#3_"1938 DA1:*Себастьяна:1482 Sebastiana:Sebastiana" "Sol" #3=
".:Sebastiana:1482 Sebastiana:1938 DA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1482 sebastiana.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.593
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.870409239236
		SemiMajorAxis	2.87323733848
		Eccentricity	0.037141093395
		Inclination	2.972195093102
		AscendingNode	71.123560661527
		ArgOfPericenter	211.649022158916
		MeanAnomaly	202.088075351926
	}
	UniformRotation
	{
		Period	10.489
	}
	LunarLambert	0.5
	Albedo	0.217
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1482"
}

#1_"1484 Postrema:Postrema:1938 HC:1933 DH:A911 KC" "Sol" #1=
#2_"*Пострема:1484 Postrema:Postrema:1938 HC" "Sol" #2=
#3_"1938 HC:*Пострема:1484 Postrema:Postrema" "Sol" #3=
".:Postrema:1484 Postrema:1938 HC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1484 postrema.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	20.436
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.532531640975
		SemiMajorAxis	2.738767053759
		Eccentricity	0.203843096948
		Inclination	17.301011374165
		AscendingNode	72.790394054544
		ArgOfPericenter	126.627337781486
		MeanAnomaly	336.947239191783
	}
	UniformRotation
	{
		Period	12.1923
	}
	LunarLambert	0.5
	Albedo	0.015
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1484"
}

#1_"1486 Marilyn:Marilyn:1938 QA" "Sol" #1=
#2_"*Марилин:1486 Marilyn:Marilyn:1938 QA" "Sol" #2=
#3_"1938 QA:Marilyn:*Марилин:1486 Marilyn" "Sol" #3=
".:Marilyn:1486 Marilyn:1938 QA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1486 marilyn.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.207
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.259837629766
		SemiMajorAxis	2.198493457933
		Eccentricity	0.124558792796
		Inclination	0.075187986229
		AscendingNode	333.312748406655
		ArgOfPericenter	350.057933020618
		MeanAnomaly	32.996702921177
	}
	UniformRotation
	{
		Period	4.566
	}
	LunarLambert	0.5
	Albedo	0.391
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1486"
}

#1_"1487 Boda:Boda:1938 WC:1929 EH:1931 RG:1934 CF:1940 EN:A918 EL" "Sol" #1=
#2_"*Бода:1487 Boda:Boda:1938 WC" "Sol" #2=
#3_"1938 WC:*Бода:1487 Boda:Boda" "Sol" #3=
".:Boda:1487 Boda:1938 WC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.560226929829
		SemiMajorAxis	3.138505372226
		Eccentricity	0.120375019796
		Inclination	2.46672266059
		AscendingNode	97.074699220807
		ArgOfPericenter	108.262392411711
		MeanAnomaly	114.658728966036
	}
	UniformRotation
	{
		Period	11.025
	}
	LunarLambert	0.5
	Albedo	0.1195
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1487"
}

#1_"1489 Attila:Attila:1939 GC:1965 WH" "Sol" #1=
#2_"*Аттила:1489 Attila:Attila:1939 GC" "Sol" #2=
#3_"1939 GC:*Аттила:1489 Attila:Attila" "Sol" #3=
".:Attila:1489 Attila:1939 GC:1965 WH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.135
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.716780112209
		SemiMajorAxis	3.197143949065
		Eccentricity	0.143533764511
		Inclination	2.452784130757
		AscendingNode	154.818247111223
		ArgOfPericenter	25.464137482444
		MeanAnomaly	107.55354739446
	}
	UniformRotation
	{
		Period	11.28
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1489"
}

#1_"1490 Limpopo:Limpopo:1936 LB:1931 BL:1937 WJ:1937 YK:1947 ND:1965 OD" "Sol" #1=
#2_"*Лимпопо:1490 Limpopo:Limpopo:1936 LB" "Sol" #2=
#3_"1936 LB:*Лимпопо:1490 Limpopo:Limpopo" "Sol" #3=
".:Limpopo:1490 Limpopo:1936 LB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1490 limpopo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	7.422
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.607973882608
		SemiMajorAxis	2.352358208596
		Eccentricity	0.155192304495
		Inclination	10.019454513378
		AscendingNode	254.285437593162
		ArgOfPericenter	90.909606688602
		MeanAnomaly	205.2251737033
	}
	UniformRotation
	{
		Period	6.647
	}
	LunarLambert	0.5
	Albedo	0.068
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1490"
}

#1_"1492 Oppolzer:Oppolzer:1938 FL:1971 VR" "Sol" #1=
#2_"*Оппольцер:1492 Oppolzer:Oppolzer:1938 FL" "Sol" #2=
#3_"1938 FL:*Оппольцер:1492 Oppolzer:Oppolzer" "Sol" #3=
".:Oppolzer:1492 Oppolzer:1938 FL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.135
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.203752262959
		SemiMajorAxis	2.173203933626
		Eccentricity	0.116289704801
		Inclination	6.057933822381
		AscendingNode	137.810525685784
		ArgOfPericenter	81.197316973462
		MeanAnomaly	315.138760563584
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.089
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1492"
}

#1_"1493 Sigrid:Sigrid:1938 QB:1934 NB1:1934 PW:1957 UT:1961 TM1:1961 XL:1977 UN:A908 WA:A916 YD" "Sol" #1=
#2_"*Зигрид:1493 Sigrid:Sigrid:1938 QB" "Sol" #2=
#3_"1938 QB:*Зигрид:1493 Sigrid:Sigrid" "Sol" #3=
".:Sigrid:1493 Sigrid:1938 QB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1493 sigrid.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	14.452
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.785408039704
		SemiMajorAxis	2.428862885285
		Eccentricity	0.202135437598
		Inclination	2.583739364436
		AscendingNode	330.656064133028
		ArgOfPericenter	1.127721400721
		MeanAnomaly	58.499867150177
	}
	UniformRotation
	{
		Period	43.296
	}
	LunarLambert	0.5
	Albedo	0.034
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1493"
}

#1_"1494 Savo:Savo:1938 SJ:1925 RL:1938 SG1:1948 VR:1951 SV:1953 GD:1966 HB:1976 HZ" "Sol" #1=
#2_"*Саво:1494 Savo:Savo:1938 SJ" "Sol" #2=
#3_"1938 SJ:Savo:*Саво:1494 Savo" "Sol" #3=
".:Savo:1494 Savo:1938 SJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1494 savo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.902
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.240906709355
		SemiMajorAxis	2.189973628278
		Eccentricity	0.131541764063
		Inclination	2.456009456213
		AscendingNode	195.02068699
		ArgOfPericenter	184.345000793605
		MeanAnomaly	53.430232550531
	}
	UniformRotation
	{
		Period	5.3501
	}
	LunarLambert	0.5
	Albedo	0.349
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1494"
}

#1_"1495 Helsinki:Helsinki:1938 SW" "Sol" #1=
#2_"*Хельсинки:1495 Helsinki:Helsinki:1938 SW" "Sol" #2=
#3_"1938 SW:*Хельсинки:1495 Helsinki:Helsinki" "Sol" #3=
".:Helsinki:1495 Helsinki:1938 SW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1495 helsinki.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.118
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.285107028324
		SemiMajorAxis	2.638167186479
		Eccentricity	0.155616096764
		Inclination	12.731353205917
		AscendingNode	13.125567281935
		ArgOfPericenter	268.747553808766
		MeanAnomaly	345.181291991692
	}
	UniformRotation
	{
		Period	5.3312
	}
	LunarLambert	0.5
	Albedo	0.274
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1495"
}

#1_"1496 Turku:Turku:1938 SA1:1928 QN:1928 RE:1950 EC:1954 MH:1957 HB" "Sol" #1=
#2_"*Турку:1496 Turku:Turku:1938 SA1" "Sol" #2=
#3_"1938 SA1:Turku:*Турку:1496 Turku" "Sol" #3=
".:Turku:1496 Turku:1938 SA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1496 turku.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.879
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.276167333333
		SemiMajorAxis	2.205829373353
		Eccentricity	0.161767024713
		Inclination	2.500564282859
		AscendingNode	294.38482036401
		ArgOfPericenter	0.905483325356
		MeanAnomaly	30.404252296481
	}
	UniformRotation
	{
		Period	6.47
	}
	LunarLambert	0.5
	Albedo	0.203
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1496"
}

#1_"1500 Jyvaskyla:Jyvaskyla:1938 UH" "Sol" #1=
#2_"*Ювяскюля:1500 Jyvaskyla:Jyvaskyla:1938 UH" "Sol" #2=
#3_"1938 UH:Jyvaskyla:*Ювяскюля:1500 Jyvaskyla" "Sol" #3=
".:Jyvaskyla:1500 Jyvaskyla:1938 UH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1500 jyvaskyla.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	4.048
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.359256788802
		SemiMajorAxis	2.242969324915
		Eccentricity	0.189481338137
		Inclination	7.437435035976
		AscendingNode	19.924159513483
		ArgOfPericenter	16.964115472842
		MeanAnomaly	114.479235524556
	}
	UniformRotation
	{
		Period	8.8275
	}
	LunarLambert	0.5
	Albedo	0.161
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1500"
}

#1_"1501 Baade:Baade:1938 UJ:1930 UH1:1930 WJ:1930 XH:1934 VG:1950 RD:1970 QA" "Sol" #1=
#2_"*Бааде:1501 Baade:Baade:1938 UJ" "Sol" #2=
#3_"1938 UJ:*Бааде:1501 Baade:Baade" "Sol" #3=
".:Baade:1501 Baade:1938 UJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.525
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.059442381912
		SemiMajorAxis	2.544712869635
		Eccentricity	0.241177979676
		Inclination	7.319121260483
		AscendingNode	17.010491483756
		ArgOfPericenter	13.367463983051
		MeanAnomaly	262.827411758858
	}
	UniformRotation
	{
		Period	15.132
	}
	LunarLambert	0.5
	Albedo	0.2093
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1501"
}

#1_"1502 Arenda:Arenda:1938 WB:1926 CD:1926 EH:1929 WY:1933 US1:1935 CD:1937 PD:1940 ES:1963 KD: #1=
#1_A906 VF" "Sol" #1=
#2_"*Арена:1502 Arenda:Arenda:1938 WB" "Sol" #2=
#3_"1938 WB:*Арена:1502 Arenda:Arenda" "Sol" #3=
".:Arenda:1502 Arenda:1938 WB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.61
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.51587772875
		SemiMajorAxis	2.732054224958
		Eccentricity	0.087108206349
		Inclination	4.091103016292
		AscendingNode	204.369961792809
		ArgOfPericenter	274.790724976255
		MeanAnomaly	259.620256853663
	}
	UniformRotation
	{
		Period	45.8
	}
	LunarLambert	0.5
	Albedo	0.0367
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1502"
}

#1_"1503 Kuopio:Kuopio:1938 XD:1935 EF:1953 LH" "Sol" #1=
#2_"*Куопио:1503 Kuopio:Kuopio:1938 XD" "Sol" #2=
#3_"1938 XD:*Куопио:1503 Kuopio:Kuopio" "Sol" #3=
".:Kuopio:1503 Kuopio:1938 XD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1503 kuopio.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	11.492
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.252629055879
		SemiMajorAxis	2.6248200407
		Eccentricity	0.104218853429
		Inclination	12.374818709611
		AscendingNode	317.005420855361
		ArgOfPericenter	178.42175713362
		MeanAnomaly	282.707739410214
	}
	UniformRotation
	{
		Period	9.957
	}
	LunarLambert	0.5
	Albedo	0.399
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1503"
}

#1_"1504 Lappeenranta:Lappeenranta:1939 FM" "Sol" #1=
#2_"*Лаппеэнранта:1504 Lappeenranta:Lappeenranta:1939 FM" "Sol" #2=
#3_"1939 FM:*Лаппеэнранта:1504 Lappeenranta:Lappeenranta" "Sol" #3=
".:Lappeenranta:1504 Lappeenranta:1939 FM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.717347666171
		SemiMajorAxis	2.399661509599
		Eccentricity	0.15741930106
		Inclination	11.048052192194
		AscendingNode	94.902805415072
		ArgOfPericenter	50.959154715877
		MeanAnomaly	162.863407652676
	}
	UniformRotation
	{
		Period	15.19
	}
	LunarLambert	0.5
	Albedo	0.1939
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1504"
}

#1_"1505 Koranna:Koranna:1939 HH:1935 MD:1948 MB:1958 UM" "Sol" #1=
#2_"*Коранна:1505 Koranna:Koranna:1939 HH" "Sol" #2=
#3_"1939 HH:*Коранна:1505 Koranna:Koranna" "Sol" #3=
".:Koranna:1505 Koranna:1939 HH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.336179618756
		SemiMajorAxis	2.65908798505
		Eccentricity	0.133796495301
		Inclination	14.465467304883
		AscendingNode	248.324457358099
		ArgOfPericenter	342.790725880571
		MeanAnomaly	148.259406023364
	}
	UniformRotation
	{
		Period	4.451
	}
	LunarLambert	0.5
	Albedo	0.0929
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1505"
}

#1_"1508 Kemi:Kemi:1938 UP:1935 FA:1938 UO" "Sol" #1=
#2_"*Кеми:1508 Kemi:Kemi:1938 UP" "Sol" #2=
#3_"1938 UP:Kemi:*Кеми:1508 Kemi" "Sol" #3=
".:Kemi:1508 Kemi:1938 UP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1508 kemi.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.251
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.615131595461
		SemiMajorAxis	2.771940631553
		Eccentricity	0.416761615545
		Inclination	28.72385922488
		AscendingNode	14.29845351495
		ArgOfPericenter	92.88982026301
		MeanAnomaly	311.326559728022
	}
	UniformRotation
	{
		Period	9.196
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1508"
}

#1_"1509 Esclangona:Esclangona:1938 YG" "Sol" #1=
#2_"*Эсклангона:1509 Esclangona:Esclangona:1938 YG" "Sol" #2=
#3_"1938 YG:*Эсклангона:1509 Esclangona:Esclangona" "Sol" #3=
".:Esclangona:1509 Esclangona:1938 YG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.88
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.549334982712
		SemiMajorAxis	1.866146790331
		Eccentricity	0.032321230568
		Inclination	22.323773540932
		AscendingNode	283.544043280687
		ArgOfPericenter	267.988517550599
		MeanAnomaly	198.301733430078
	}
	UniformRotation
	{
		Period	3.25283
	}
	LunarLambert	0.5
	Albedo	0.2327
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1509"
}

#1_"2003 1509 I" "Sol/1509 Esclangona" #1=
#2_"2003 1509 I" "Sol/1509 Esclangona" #2=
#3_"2003 1509 I" "Sol/1509 Esclangona" #3=
".:2003 1509 I" "Sol/1509 Esclangona" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid.dds"
	Radius	1.285
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	23
		SemiMajorAxis	140
	}
	LunarLambert	0.5
	Albedo	0.2327
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-01509.html"
}

#1_"1510 Charlois:Charlois:1939 DC:1959 WE:1963 UB" "Sol" #1=
#2_"*Шарлуа:1510 Charlois:Charlois:1939 DC" "Sol" #2=
#3_"1939 DC:*Шарлуа:1510 Charlois:Charlois" "Sol" #3=
".:Charlois:1510 Charlois:1939 DC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.369607748632
		SemiMajorAxis	2.672736638534
		Eccentricity	0.147125594663
		Inclination	11.82158264221
		AscendingNode	331.501503758677
		ArgOfPericenter	165.013803925658
		MeanAnomaly	151.263538641324
	}
	UniformRotation
	{
		Period	5.866
	}
	LunarLambert	0.5
	Albedo	0.1033
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1510"
}

#1_"1511 Dalera:Dalera:1939 FB:1928 DB:1954 LM" "Sol" #1=
#2_"*Далера:1511 Dalera:Dalera:1939 FB" "Sol" #2=
#3_"1939 FB:*Далера:1511 Dalera:Dalera" "Sol" #3=
".:Dalera:1511 Dalera:1939 FB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.735
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.621372116219
		SemiMajorAxis	2.35817827479
		Eccentricity	0.109008561313
		Inclination	4.06912094017
		AscendingNode	81.753292942735
		ArgOfPericenter	97.275251682
		MeanAnomaly	323.49451379715
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0614
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1511"
}

#1_"1512 Oulu:Oulu:1939 FE:1938 CU:1957 TA:1958 XS" "Sol" #1=
#2_"*Оулу:1512 Oulu:Oulu:1939 FE" "Sol" #2=
#3_"1939 FE:*Оулу:1512 Oulu:Oulu" "Sol" #3=
".:Oulu:1512 Oulu:1939 FE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	41.36
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.852795732966
		SemiMajorAxis	3.950730443431
		Eccentricity	0.149007192505
		Inclination	6.489812456609
		AscendingNode	10.231196759632
		ArgOfPericenter	240.607820981112
		MeanAnomaly	206.554058518294
	}
	UniformRotation
	{
		Period	132.3
	}
	LunarLambert	0.5
	Albedo	0.0366
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1512"
}

#1_"1514 Ricouxa:Ricouxa:1906 UR:1936 ME:1939 HC:1940 XA:1970 XA:A916 OC" "Sol" #1=
#2_"*Рикукса:1514 Ricouxa:Ricouxa:1906 UR" "Sol" #2=
#3_"1906 UR:*Рикукса:1514 Ricouxa:Ricouxa" "Sol" #3=
".:Ricouxa:1514 Ricouxa:1906 UR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1514 ricouxa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	3.892
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.355671697063
		SemiMajorAxis	2.241373201668
		Eccentricity	0.199317577968
		Inclination	4.534909606453
		AscendingNode	145.859028363958
		ArgOfPericenter	179.097309343008
		MeanAnomaly	167.200177410279
	}
	UniformRotation
	{
		Period	10.438
	}
	LunarLambert	0.5
	Albedo	0.228
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1514"
}

#1_"1516 Henry:Henry:1938 BG:1938 DM" "Sol" #1=
#2_"*Анри:1516 Henry:Henry:1938 BG" "Sol" #2=
#3_"1938 BG:*Анри:1516 Henry:Henry" "Sol" #3=
".:Henry:1516 Henry:1938 BG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.246229902337
		SemiMajorAxis	2.622186243815
		Eccentricity	0.184919486959
		Inclination	8.74489720345
		AscendingNode	125.857415543323
		ArgOfPericenter	94.301798086607
		MeanAnomaly	345.040052599859
	}
	UniformRotation
	{
		Period	17.37
	}
	LunarLambert	0.5
	Albedo	0.0536
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1516"
}

#1_"1517 Beograd:Beograd:1938 FD:1931 VF:1934 JF:1935 ST:1942 CD:1952 JG:1952 KM1:1971 VT:1978 EW6" "Sol" #1=
#2_"*Белград:1517 Beograd:Beograd:1938 FD" "Sol" #2=
#3_"1938 FD:*Белград:1517 Beograd:Beograd" "Sol" #3=
".:Beograd:1517 Beograd:1938 FD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.08
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.476561562594
		SemiMajorAxis	2.716173906408
		Eccentricity	0.044643519919
		Inclination	5.277497910759
		AscendingNode	63.900509738377
		ArgOfPericenter	232.365868713264
		MeanAnomaly	298.516846412966
	}
	UniformRotation
	{
		Period	6.943
	}
	LunarLambert	0.5
	Albedo	0.0491
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1517"
}

#1_"1518 Rovaniemi:Rovaniemi:1938 UA:1928 TL:1951 SH" "Sol" #1=
#2_"*Рованиеми:1518 Rovaniemi:Rovaniemi:1938 UA" "Sol" #2=
#3_"1938 UA:*Рованиеми:1518 Rovaniemi:Rovaniemi" "Sol" #3=
".:Rovaniemi:1518 Rovaniemi:1938 UA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1518 rovaniemi.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.24
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.319552923655
		SemiMajorAxis	2.225260863127
		Eccentricity	0.14279355925
		Inclination	6.711928137905
		AscendingNode	27.819383789871
		ArgOfPericenter	37.077034918602
		MeanAnomaly	9.105419432203
	}
	UniformRotation
	{
		Period	5.249
	}
	LunarLambert	0.5
	Albedo	0.295
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1518"
}

#1_"1519 Kajaani:Kajaani:1938 UB:1938 UK" "Sol" #1=
#2_"*Каяани:1519 Kajaani:Kajaani:1938 UB" "Sol" #2=
#3_"1938 UB:*Каяани:1519 Kajaani:Kajaani" "Sol" #3=
".:Kajaani:1519 Kajaani:1938 UB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.52214345437
		SemiMajorAxis	3.124157989866
		Eccentricity	0.241213621439
		Inclination	12.605720536776
		AscendingNode	15.883083579268
		ArgOfPericenter	339.617163741176
		MeanAnomaly	275.043811406318
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1519"
}

#1_"1520 Imatra:Imatra:1938 UY:1938 YH" "Sol" #1=
#2_"*Иматра:1520 Imatra:Imatra:1938 UY" "Sol" #2=
#3_"1938 UY:*Иматра:1520 Imatra:Imatra" "Sol" #3=
".:Imatra:1520 Imatra:1938 UY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.482925205667
		SemiMajorAxis	3.109348584394
		Eccentricity	0.098258639724
		Inclination	15.238906595943
		AscendingNode	253.474113635492
		ArgOfPericenter	116.402146300146
		MeanAnomaly	0.272033455489
	}
	UniformRotation
	{
		Period	18.635
	}
	LunarLambert	0.5
	Albedo	0.0615
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1520"
}

#1_"1521 Seinajoki:Seinajoki:1938 UB1:1933 UR1:1967 UW" "Sol" #1=
#2_"*Сейняйоки:1521 Seinajoki:Seinajoki:1938 UB1" "Sol" #2=
#3_"1938 UB1:Seinajoki:*Сейняйоки:1521 Seinajoki" "Sol" #3=
".:Seinajoki:1521 Seinajoki:1938 UB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1521 seinajoki.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.406
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.814773688472
		SemiMajorAxis	2.851314466456
		Eccentricity	0.136760003939
		Inclination	15.063617245158
		AscendingNode	12.591007639249
		ArgOfPericenter	48.483039653242
		MeanAnomaly	82.875245825907
	}
	UniformRotation
	{
		Period	4.32
	}
	LunarLambert	0.5
	Albedo	0.205
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1521"
}

#1_"1524 Joensuu:Joensuu:1939 SB:1931 EL:1933 QO:1936 DG:1958 DH1" "Sol" #1=
#2_"*Йоэнсуу:1524 Joensuu:Joensuu:1939 SB" "Sol" #2=
#3_"1939 SB:*Йоэнсуу:1524 Joensuu:Joensuu" "Sol" #3=
".:Joensuu:1524 Joensuu:1939 SB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	21.395
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.481685313005
		SemiMajorAxis	3.108879807397
		Eccentricity	0.121893993216
		Inclination	12.687468827695
		AscendingNode	347.731930718254
		ArgOfPericenter	3.106211344831
		MeanAnomaly	268.63443756218
	}
	UniformRotation
	{
		Period	9.276
	}
	LunarLambert	0.5
	Albedo	0.0462
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1524"
}

#1_"1525 Savonlinna:Savonlinna:1939 SC:1930 SE" "Sol" #1=
#2_"*Савонлинна:1525 Savonlinna:Savonlinna:1939 SC" "Sol" #2=
#3_"1939 SC:*Савонлинна:1525 Savonlinna:Savonlinna" "Sol" #3=
".:Savonlinna:1525 Savonlinna:1939 SC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.09
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.425079884112
		SemiMajorAxis	2.695309292807
		Eccentricity	0.265735583794
		Inclination	5.866983016112
		AscendingNode	279.288309601842
		ArgOfPericenter	64.473036140058
		MeanAnomaly	13.107095732514
	}
	UniformRotation
	{
		Period	14.634
	}
	LunarLambert	0.5
	Albedo	0.1306
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1525"
}

#1_"1527 Malmquista:Malmquista:1939 UG:1929 TG:1932 OB:1972 TK:A909 TC" "Sol" #1=
#2_"*Мальмквиста:1527 Malmquista:Malmquista:1939 UG" "Sol" #2=
#3_"1939 UG:*Мальмквиста:1527 Malmquista:Malmquista" "Sol" #3=
".:Malmquista:1527 Malmquista:1939 UG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1527 malmquista.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.02
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.323875268485
		SemiMajorAxis	2.227192098828
		Eccentricity	0.198707126945
		Inclination	5.193846665221
		AscendingNode	16.135188492408
		ArgOfPericenter	304.592313273467
		MeanAnomaly	326.632441574155
	}
	UniformRotation
	{
		Period	14.077
	}
	LunarLambert	0.5
	Albedo	0.307
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1527"
}

#1_"1528 Conrada:Conrada:1940 CA:1929 FA:1955 ED:1959 GW:A914 HA" "Sol" #1=
#2_"*Конрада:1528 Conrada:Conrada:1940 CA" "Sol" #2=
#3_"1940 CA:*Конрада:1528 Conrada:Conrada" "Sol" #3=
".:Conrada:1528 Conrada:1940 CA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1528 conrada.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.548
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.752104450913
		SemiMajorAxis	2.41459600819
		Eccentricity	0.144186102424
		Inclination	8.514147875393
		AscendingNode	139.392896462825
		ArgOfPericenter	59.27042324167
		MeanAnomaly	340.544187971298
	}
	UniformRotation
	{
		Period	6.321
	}
	LunarLambert	0.5
	Albedo	0.355
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1528"
}

#1_"1532 Inari:Inari:1938 SM:1933 SZ:1935 BJ:1936 FP1" "Sol" #1=
#2_"*Инари:1532 Inari:Inari:1938 SM" "Sol" #2=
#3_"1938 SM:*Инари:1532 Inari:Inari" "Sol" #3=
".:Inari:1532 Inari:1938 SM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.206029729974
		SemiMajorAxis	3.003762753462
		Eccentricity	0.052838278576
		Inclination	8.778736560773
		AscendingNode	330.646396248948
		ArgOfPericenter	122.850757577905
		MeanAnomaly	136.600656731423
	}
	UniformRotation
	{
		Period	25
	}
	LunarLambert	0.5
	Albedo	0.0562
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1532"
}

#1_"1533 Saimaa:Saimaa:1939 BD:1934 FA:1936 QC:1936 RP" "Sol" #1=
#2_"*Саймаа:1533 Saimaa:Saimaa:1939 BD" "Sol" #2=
#3_"1939 BD:*Саймаа:1533 Saimaa:Saimaa" "Sol" #3=
".:Saimaa:1533 Saimaa:1939 BD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.065
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.228702567993
		SemiMajorAxis	3.01247758249
		Eccentricity	0.036717762069
		Inclination	10.709594901623
		AscendingNode	156.745660405025
		ArgOfPericenter	9.479452754326
		MeanAnomaly	159.356027823622
	}
	UniformRotation
	{
		Period	7.08
	}
	LunarLambert	0.5
	Albedo	0.1216
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1533"
}

#1_"1534 Nasi:Nasi:1939 BK:1933 UQ:1957 EA:1960 UB:1962 JA:A915 VB:A924 WE:A924 YE" "Sol" #1=
#2_"*Няси:1534 Nasi:Nasi:1939 BK" "Sol" #2=
#3_"1939 BK:*Няси:1534 Nasi:Nasi" "Sol" #3=
".:Nasi:1534 Nasi:Nasi:1939 BK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1534 nasi.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	11.06
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.508096735328
		SemiMajorAxis	2.728915048533
		Eccentricity	0.251371544528
		Inclination	9.790104804693
		AscendingNode	62.176894154634
		ArgOfPericenter	42.984537857127
		MeanAnomaly	315.216327638306
	}
	UniformRotation
	{
		Period	7.94
	}
	LunarLambert	0.5
	Albedo	0.0754
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1534"
}

#1_"1535 Paijanne:Paijanne:1939 RC:1933 QE1:1944 OA:1956 XB:1985 XE2:A916 OB" "Sol" #1=
#2_"*Пяйянне:1535 Paijanne:Paijanne:1939 RC" "Sol" #2=
#3_"1939 RC:*Пяйянне:1535 Paijanne:Paijanne" "Sol" #3=
".:Paijanne:1535 Paijanne:1939 RC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.36
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.653044787865
		SemiMajorAxis	3.173336663004
		Eccentricity	0.190156543745
		Inclination	6.060490190552
		AscendingNode	265.059186066006
		ArgOfPericenter	38.798731575805
		MeanAnomaly	209.105190139301
	}
	UniformRotation
	{
		Period	8.8448
	}
	LunarLambert	0.5
	Albedo	0.1299
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1535"
}

#1_"1537 Transylvania:Transylvania:1940 QA:1940 QN:A903 VB" "Sol" #1=
#2_"*Трансильвания:1537 Transylvania:Transylvania:1940 QA" "Sol" #2=
#3_"1940 QA:*Трансильвания:1537 Transylvania:Transylvania" "Sol" #3=
".:Transylvania:1537 Transylvania:1940 QA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.885
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.326788087509
		SemiMajorAxis	3.050034920612
		Eccentricity	0.301298020751
		Inclination	3.857460336799
		AscendingNode	230.13846843
		ArgOfPericenter	147.990999945344
		MeanAnomaly	319.005413090036
	}
	UniformRotation
	{
		Period	12
	}
	LunarLambert	0.5
	Albedo	0.1619
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1537"
}

#1_"1540 Kevola:Kevola:1938 WK:1926 GT:1933 UM:1933 WR:1936 KL:1937 QG:1940 EJ" "Sol" #1=
#2_"*Кевола:1540 Kevola:Kevola:1938 WK" "Sol" #2=
#3_"1938 WK:*Кевола:1540 Kevola:Kevola" "Sol" #3=
".:Kevola:1540 Kevola:1938 WK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.09
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.80910065544
		SemiMajorAxis	2.849074308647
		Eccentricity	0.084286470667
		Inclination	11.966053589206
		AscendingNode	52.492193504115
		ArgOfPericenter	113.61645737
		MeanAnomaly	192.328804647325
	}
	UniformRotation
	{
		Period	20.082
	}
	LunarLambert	0.5
	Albedo	0.0433
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1540"
}

#1_"1541 Estonia:Estonia:1939 CK:1930 FE:1930 FV:1950 RG1:1950 SR:1959 RF1:A916 GE:1923 VE" "Sol" #1=
#2_"*Эстония:1541 Estonia:Estonia:1939 CK" "Sol" #2=
#3_"1939 CK:*Эстония:1541 Estonia:Estonia" "Sol" #3=
".:Estonia:1541 Estonia:1939 CK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.607373071422
		SemiMajorAxis	2.768833143677
		Eccentricity	0.068706899986
		Inclination	4.875267440442
		AscendingNode	1.454921869073
		ArgOfPericenter	192.766591943767
		MeanAnomaly	132.276873284508
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1434
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1541"
}

#1_"1542 Schalen:Schalen:1941 QE:1927 BH:1936 UL:1940 LP:1976 CA:A898 VD:A924 NA" "Sol" #1=
#2_"*Шален:1542 Schalen:Schalen:1941 QE" "Sol" #2=
#3_"1941 QE:*Шален:1542 Schalen:Schalen" "Sol" #3=
".:Schalen:1542 Schalen:1941 QE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.595
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.446262232045
		SemiMajorAxis	3.095472124176
		Eccentricity	0.114684638262
		Inclination	2.763297966758
		AscendingNode	211.69498981222
		ArgOfPericenter	164.318071769228
		MeanAnomaly	139.719037601596
	}
	UniformRotation
	{
		Period	7.516
	}
	LunarLambert	0.5
	Albedo	0.0656
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1542"
}

#1_"1544 Vinterhansenia:Vinterhansenia:1941 UK:1928 DO:1937 RK:1939 CL:1948 QT:1974 YB:A906 DB:A919 UB" "Sol" #1=
#2_"*Винтерхансения:1544 Vinterhansenia:Vinterhansenia:1941 UK" "Sol" #2=
#3_"1941 UK:*Винтерхансения:1544 Vinterhansenia:Vinterhansenia" "Sol" #3=
".:Vinterhansenia:1544 Vinterhansenia:1941 UK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.855
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.655988946272
		SemiMajorAxis	2.37318237609
		Eccentricity	0.104254814604
		Inclination	3.333319140832
		AscendingNode	60.016155136046
		ArgOfPericenter	356.314968279813
		MeanAnomaly	341.987306480078
	}
	UniformRotation
	{
		Period	13.77
	}
	LunarLambert	0.5
	Albedo	0.0784
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1544"
}

#1_"1545 Thernoe:Thernoe:1941 UW:1932 YD:1955 VV:1957 HY:A906 FE:A915 CE" "Sol" #1=
#2_"*Тернёэ:1545 Thernoe:Thernoe:1941 UW" "Sol" #2=
#3_"1941 UW:*Тернёэ:1545 Thernoe:Thernoe" "Sol" #3=
".:Thernoe:1545 Thernoe:1941 UW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1545 thernoe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	9.328
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.612125020983
		SemiMajorAxis	2.770736628167
		Eccentricity	0.237731825944
		Inclination	2.953594484202
		AscendingNode	51.811636307873
		ArgOfPericenter	90.60076782448
		MeanAnomaly	231.131244654059
	}
	UniformRotation
	{
		Period	17.2
	}
	LunarLambert	0.5
	Albedo	0.097
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1545"
}

#1_"1546 Izsak:Izsak:1941 SG1:1935 QC:1938 FH:1978 BF" "Sol" #1=
#2_"*Ижак:1546 Izsak:Izsak:1941 SG1" "Sol" #2=
#3_"1941 SG1:Izsak:*Ижак:1546 Izsak" "Sol" #3=
".:Izsak:1546 Izsak:1941 SG1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1546 izsak.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.219
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.659997397156
		SemiMajorAxis	3.175938028082
		Eccentricity	0.122022993792
		Inclination	16.141346666957
		AscendingNode	190.47362889057
		ArgOfPericenter	280.676028188421
		MeanAnomaly	42.922040965424
	}
	UniformRotation
	{
		Period	7.35
	}
	LunarLambert	0.5
	Albedo	0.133
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1546"
}

#1_"1547 Nele:Nele:1929 CZ:1932 YQ:1940 PB:1953 QA" "Sol" #1=
#2_"*Неле:1547 Nele:Nele:1929 CZ" "Sol" #2=
#3_"1929 CZ:Nele:*Неле:1547 Nele" "Sol" #3=
".:Nele:1547 Nele:1929 CZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1547 nele.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.438
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.296590973084
		SemiMajorAxis	2.64287855072
		Eccentricity	0.254273417224
		Inclination	11.744468437405
		AscendingNode	291.33438319226
		ArgOfPericenter	154.965833856657
		MeanAnomaly	199.754987443955
	}
	UniformRotation
	{
		Period	7.1
	}
	LunarLambert	0.5
	Albedo	0.203
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1547"
}

#1_"1548 Palomaa:Palomaa:1935 FK:1959 NF" "Sol" #1=
#2_"*Паломаа:1548 Palomaa:Palomaa:1935 FK" "Sol" #2=
#3_"1935 FK:*Паломаа:1548 Palomaa:Palomaa" "Sol" #3=
".:Palomaa:1548 Palomaa:1935 FK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1548 palomaa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	15.38
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.654851328843
		SemiMajorAxis	2.787822217718
		Eccentricity	0.078595141598
		Inclination	16.545542369936
		AscendingNode	116.953224172787
		ArgOfPericenter	88.103593859592
		MeanAnomaly	27.228014410261
	}
	UniformRotation
	{
		Period	7.4961
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1548"
}

#1_"1549 Mikko:Mikko:1937 GA:1935 SG1:1940 AO:1949 YV:1951 ME" "Sol" #1=
#2_"*Микко:1549 Mikko:Mikko:1937 GA" "Sol" #2=
#3_"1937 GA:*Микко:1549 Mikko:Mikko" "Sol" #3=
".:Mikko:1549 Mikko:1937 GA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.955
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.332337477907
		SemiMajorAxis	2.230970615657
		Eccentricity	0.083690210341
		Inclination	5.546848660598
		AscendingNode	85.326289180646
		ArgOfPericenter	6.332159207698
		MeanAnomaly	198.792029458606
	}
	UniformRotation
	{
		Period	11.49
	}
	LunarLambert	0.5
	Albedo	0.3761
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1549"
}

#1_"1551 Argelander:Argelander:1938 DC1:1930 BL:1940 XD:1951 XG1:1953 GD1:1957 KR:1962 XP" "Sol" #1=
#2_"*Аргеландер:1551 Argelander:Argelander:1938 DC1" "Sol" #2=
#3_"1938 DC1:Argelander:*Аргеландер:1551 Argelander" "Sol" #3=
".:Argelander:1551 Argelander:1938 DC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1551 argelander.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.119
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.70466730355
		SemiMajorAxis	2.394201361408
		Eccentricity	0.066148961815
		Inclination	3.761320932584
		AscendingNode	107.238721548408
		ArgOfPericenter	233.718398610998
		MeanAnomaly	294.507695021315
	}
	UniformRotation
	{
		Period	4.0614
	}
	LunarLambert	0.5
	Albedo	0.222
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1551"
}

#1_"1552 Bessel:Bessel:1938 DE1:1933 FJ1:1948 EH:1951 UF" "Sol" #1=
#2_"*Бессель:1552 Bessel:Bessel:1938 DE1" "Sol" #2=
#3_"1938 DE1:*Бессель:1552 Bessel:Bessel" "Sol" #3=
".:Bessel:1552 Bessel:1938 DE1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1552 bessel.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.257
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.2229974364
		SemiMajorAxis	3.010285871416
		Eccentricity	0.095766750449
		Inclination	9.841957714904
		AscendingNode	10.019396640916
		ArgOfPericenter	38.130785259109
		MeanAnomaly	358.39686040641
	}
	UniformRotation
	{
		Period	8.996
	}
	LunarLambert	0.5
	Albedo	0.156
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1552"
}

#1_"1554 Yugoslavia:Yugoslavia:1940 RE:1932 YA:1935 JN:1936 UH:1948 MH" "Sol" #1=
#2_"*Югославия:1554 Yugoslavia:Yugoslavia:1940 RE" "Sol" #2=
#3_"1940 RE:*Югославия:1554 Yugoslavia:Yugoslavia" "Sol" #3=
".:Yugoslavia:1554 Yugoslavia:1940 RE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1554 yugoslavia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.092
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.23675268233
		SemiMajorAxis	2.618283128202
		Eccentricity	0.202044351672
		Inclination	12.150341460288
		AscendingNode	217.12643763019
		ArgOfPericenter	131.67276545534
		MeanAnomaly	236.018117715843
	}
	UniformRotation
	{
		Period	3.8879
	}
	LunarLambert	0.5
	Albedo	0.117
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1554"
}

#1_"1556 Wingolfia:Wingolfia:1942 AA:1973 AQ2" "Sol" #1=
#2_"*Вингольфия:1556 Wingolfia:Wingolfia:1942 AA" "Sol" #2=
#3_"1942 AA:*Вингольфия:1556 Wingolfia:Wingolfia" "Sol" #3=
".:Wingolfia:1556 Wingolfia:1942 AA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.325
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.346185489129
		SemiMajorAxis	3.427701855854
		Eccentricity	0.109057209295
		Inclination	15.747790642282
		AscendingNode	91.61284908298
		ArgOfPericenter	269.707890094219
		MeanAnomaly	303.78498771151
	}
	UniformRotation
	{
		Period	10
	}
	LunarLambert	0.5
	Albedo	0.1297
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1556"
}

#1_"1557 Roehla:Roehla:1942 AD:1930 YS:1950 RF1:A903 SB" "Sol" #1=
#2_"*Рёла:1557 Roehla:Roehla:1942 AD" "Sol" #2=
#3_"1942 AD:Roehla:*Рёла:1557 Roehla" "Sol" #3=
".:Roehla:1557 Roehla:1942 AD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1557 roehla.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.383
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.224715379928
		SemiMajorAxis	3.010945928881
		Eccentricity	0.1038641446
		Inclination	10.30051116011
		AscendingNode	355.220594693846
		ArgOfPericenter	3.430126849639
		MeanAnomaly	249.82585968212
	}
	UniformRotation
	{
		Period	5.679
	}
	LunarLambert	0.5
	Albedo	0.151
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1557"
}

#1_"1558 Jarnefelt:Jarnefelt:1942 BD:1929 WD1:1934 VX:1937 EF:1943 GQ:1951 RC2:1972 BO:A913 AA" "Sol" #1=
#2_"*Ярнефельт:1558 Jarnefelt:Jarnefelt:1942 BD" "Sol" #2=
#3_"1942 BD:*Ярнефельт:1558 Jarnefelt:Jarnefelt" "Sol" #3=
".:Jarnefelt:1558 Jarnefelt:1942 BD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32.545
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.790824905334
		SemiMajorAxis	3.224691361527
		Eccentricity	0.032406360561
		Inclination	10.488209861938
		AscendingNode	110.945939371146
		ArgOfPericenter	291.232574814178
		MeanAnomaly	294.907037247766
	}
	UniformRotation
	{
		Period	18.22
	}
	LunarLambert	0.5
	Albedo	0.0347
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1558"
}

#1_"1559 Kustaanheimo:Kustaanheimo:1942 BF:1935 FP:1935 HB" "Sol" #1=
#2_"*Кустаанхеймо:1559 Kustaanheimo:Kustaanheimo:1942 BF" "Sol" #2=
#3_"1942 BF:*Кустаанхеймо:1559 Kustaanheimo:Kustaanheimo" "Sol" #3=
".:Kustaanheimo:1559 Kustaanheimo:1942 BF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1559 kustaanheimo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.362
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.694959909943
		SemiMajorAxis	2.390017158993
		Eccentricity	0.134063098201
		Inclination	3.192480913067
		AscendingNode	327.937716131435
		ArgOfPericenter	216.832780038806
		MeanAnomaly	265.959735468401
	}
	UniformRotation
	{
		Period	4.302
	}
	LunarLambert	0.5
	Albedo	0.267
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1559"
}

#1_"1561 Fricke:Fricke:1941 CG:1970 HE:A915 RO" "Sol" #1=
#2_"*Фрикке:1561 Fricke:Fricke:1941 CG" "Sol" #2=
#3_"1941 CG:*Фрикке:1561 Fricke:Fricke" "Sol" #3=
".:Fricke:1561 Fricke:1941 CG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1561 fricke.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	12.676
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.725542399205
		SemiMajorAxis	3.20041002318
		Eccentricity	0.126049927994
		Inclination	4.316196365623
		AscendingNode	230.734464359525
		ArgOfPericenter	40.404360440615
		MeanAnomaly	259.885042011027
	}
	UniformRotation
	{
		Period	15.1533
	}
	LunarLambert	0.5
	Albedo	0.063
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1561"
}

#1_"1562 Gondolatsch:Gondolatsch:1943 EE:1926 AH:1930 HN:1931 TQ3:1934 RL:1936 AA:1937 NR:1941 SQ1" "Sol" #1=
#2_"*Гондолач:1562 Gondolatsch:Gondolatsch:1943 EE" "Sol" #2=
#3_"1943 EE:*Гондолач:1562 Gondolatsch:Gondolatsch" "Sol" #3=
".:Gondolatsch:1562 Gondolatsch:1943 EE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.76
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.321420675137
		SemiMajorAxis	2.22609548247
		Eccentricity	0.078383517538
		Inclination	4.884424910299
		AscendingNode	129.495239298151
		ArgOfPericenter	83.362016166034
		MeanAnomaly	178.097931561179
	}
	UniformRotation
	{
		Period	8.78
	}
	LunarLambert	0.5
	Albedo	0.2536
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1562"
}

#1_"1566 Icarus:Icarus:1949 MA" "Sol" #1=
#2_"*Икар:1566 Icarus:Icarus:1949 MA" "Sol" #2=
#3_"1949 MA:*Икар:1566 Icarus:Icarus" "Sol" #3=
".:Icarus:1566 Icarus:1949 MA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.11915916039
		SemiMajorAxis	1.077926381267
		Eccentricity	0.82696079431
		Inclination	22.827863100233
		AscendingNode	88.024449077533
		ArgOfPericenter	31.358231870571
		MeanAnomaly	231.089639388324
	}
	UniformRotation
	{
		Period	2.273
	}
	LunarLambert	0.5
	Albedo	0.51
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1566"
}

#1_"1567 Alikoski:Alikoski:1941 HN:1947 HE:1947 HG:1948 OC" "Sol" #1=
#2_"*Аликоски:1567 Alikoski:Alikoski:1941 HN" "Sol" #2=
#3_"1941 HN:*Аликоски:1567 Alikoski:Alikoski" "Sol" #3=
".:Alikoski:1567 Alikoski:1941 HN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.915
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.760259868872
		SemiMajorAxis	3.213334347617
		Eccentricity	0.084809604167
		Inclination	17.269758734518
		AscendingNode	51.563545721366
		ArgOfPericenter	111.508759799511
		MeanAnomaly	323.077360003197
	}
	UniformRotation
	{
		Period	16.405
	}
	LunarLambert	0.5
	Albedo	0.0626
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1567"
}

#1_"1568 Aisleen:Aisleen:1946 QB" "Sol" #1=
#2_"*Айслин:1568 Aisleen:Aisleen:1946 QB" "Sol" #2=
#3_"1946 QB:*Айслин:1568 Aisleen:Aisleen" "Sol" #3=
".:Aisleen:1568 Aisleen:1946 QB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1568 aisleen.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.224
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.606658198022
		SemiMajorAxis	2.35178629951
		Eccentricity	0.254134077224
		Inclination	24.896730768655
		AscendingNode	146.240349788955
		ArgOfPericenter	228.721737640513
		MeanAnomaly	3.538900671881
	}
	UniformRotation
	{
		Period	6.683
	}
	LunarLambert	0.5
	Albedo	0.165
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1568"
}

#1_"1569 Evita:Evita:1948 PA:1936 KE:1947 LA:1976 SJ10" "Sol" #1=
#2_"*Эвита:1569 Evita:Evita:1948 PA" "Sol" #2=
#3_"1948 PA:*Эвита:1569 Evita:Evita" "Sol" #3=
".:Evita:1569 Evita:1948 PA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.582999084129
		SemiMajorAxis	3.147068791546
		Eccentricity	0.133500644996
		Inclination	12.266850283551
		AscendingNode	99.524469353994
		ArgOfPericenter	250.04568036661
		MeanAnomaly	278.794067324045
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0558
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1569"
}

#1_"1571 Cesco:Cesco:1950 FJ" "Sol" #1=
#2_"*Сеско:1571 Cesco:Cesco:1950 FJ" "Sol" #2=
#3_"1950 FJ:*Сеско:1571 Cesco:Cesco" "Sol" #3=
".:Cesco:1571 Cesco:1950 FJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.57322112283
		SemiMajorAxis	3.143393239439
		Eccentricity	0.110629629474
		Inclination	14.572220325588
		AscendingNode	292.706840440583
		ArgOfPericenter	139.240316232715
		MeanAnomaly	315.603707957039
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.053
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1571"
}

#1_"1572 Posnania:Posnania:1949 SC:1929 CJ:1933 WN:1933 YB:1938 QH:1949 QE2:1949 TD:1949 YK: #1=
#1_1951 AO1:1952 FN1:A908 EC" "Sol" #1=
#2_"*Познания:1572 Posnania:Posnania:1949 SC" "Sol" #2=
#3_"1949 SC:*Познания:1572 Posnania:Posnania" "Sol" #3=
".:Posnania:1572 Posnania:1949 SC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1572 posnania.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	15.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.476102386658
		SemiMajorAxis	3.106768583868
		Eccentricity	0.20809341274
		Inclination	13.293574181813
		AscendingNode	6.101044727513
		ArgOfPericenter	354.428920326837
		MeanAnomaly	317.908592312444
	}
	UniformRotation
	{
		Period	8.048
	}
	LunarLambert	0.5
	Albedo	0.521
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1572"
}

#1_"1573 Vaisala:Vaisala:1949 UA" "Sol" #1=
#2_"*Вяйсяля:1573 Vaisala:Vaisala:1949 UA" "Sol" #2=
#3_"1949 UA:*Вяйсяля:1573 Vaisala:Vaisala" "Sol" #3=
".:Vaisala:1573 Vaisala:1949 UA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.885
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.650823884033
		SemiMajorAxis	2.370946679562
		Eccentricity	0.23128397507
		Inclination	24.539389369587
		AscendingNode	202.399825356912
		ArgOfPericenter	173.538237938279
		MeanAnomaly	315.534125939256
	}
	UniformRotation
	{
		Period	252
	}
	LunarLambert	0.5
	Albedo	0.2226
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1573"
}

#1_"1574 Meyer:Meyer:1949 FD:1930 KE:1935 CW" "Sol" #1=
#2_"*Мейер:1574 Meyer:Meyer:1949 FD" "Sol" #2=
#3_"1949 FD:*Мейер:1574 Meyer:Meyer" "Sol" #3=
".:Meyer:1574 Meyer:1949 FD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.675795636613
		SemiMajorAxis	3.545383512447
		Eccentricity	0.036898991094
		Inclination	14.468800501117
		AscendingNode	245.835786594883
		ArgOfPericenter	264.912963738656
		MeanAnomaly	346.168186252996
	}
	UniformRotation
	{
		Period	12.64
	}
	LunarLambert	0.5
	Albedo	0.0389
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1574"
}

#1_"1575 Winifred:Winifred:1950 HH:1928 HG:1939 GK:1950 HD1:1977 UH1" "Sol" #1=
#2_"*Уинифред:1575 Winifred:Winifred:1950 HH" "Sol" #2=
#3_"1950 HH:*Уинифред:1575 Winifred:Winifred" "Sol" #3=
".:Winifred:1575 Winifred:1950 HH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.6571028564
		SemiMajorAxis	2.373664393897
		Eccentricity	0.179175672902
		Inclination	24.822706293681
		AscendingNode	206.863258963199
		ArgOfPericenter	348.431388700666
		MeanAnomaly	249.046005627966
	}
	UniformRotation
	{
		Period	125
	}
	LunarLambert	0.5
	Albedo	0.2452
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1575"
}

#1_"1576 Fabiola:Fabiola:1948 SA:1931 RV:1931 TQ2:1933 BZ:1939 CS:1943 YA:1948 TU1:1948 UJ:1950 DZ" "Sol" #1=
#2_"*Фабиола:1576 Fabiola:Fabiola:1948 SA" "Sol" #2=
#3_"1948 SA:*Фабиола:1576 Fabiola:Fabiola" "Sol" #3=
".:Fabiola:1576 Fabiola:1948 SA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.625
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.579025438848
		SemiMajorAxis	3.145575350625
		Eccentricity	0.167275521271
		Inclination	0.949525870589
		AscendingNode	166.603498780131
		ArgOfPericenter	243.520590218272
		MeanAnomaly	314.35079680081
	}
	UniformRotation
	{
		Period	6.7
	}
	LunarLambert	0.5
	Albedo	0.0913
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1576"
}

#1_"1578 Kirkwood:Kirkwood:1951 AT:1944 DF:1949 TF:1952 FK" "Sol" #1=
#2_"*Кирквуд:1578 Kirkwood:Kirkwood:1951 AT" "Sol" #2=
#3_"1951 AT:*Кирквуд:1578 Kirkwood:Kirkwood" "Sol" #3=
".:Kirkwood:1578 Kirkwood:1951 AT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.789794437716
		SemiMajorAxis	3.929571512754
		Eccentricity	0.238881015241
		Inclination	0.809305598298
		AscendingNode	73.979581500678
		ArgOfPericenter	2.217139101609
		MeanAnomaly	67.955775715465
	}
	UniformRotation
	{
		Period	12.518
	}
	LunarLambert	0.5
	Albedo	0.0517
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1578"
}

#1_"1579 Herrick:Herrick:1948 SB:1925 DA:1929 TF:1931 BP:1942 VS:1950 BG:1951 GZ" "Sol" #1=
#2_"*Эррик:1579 Herrick:Herrick:1948 SB" "Sol" #2=
#3_"1948 SB:*Эррик:1579 Herrick:Herrick" "Sol" #3=
".:Herrick:1579 Herrick:1948 SB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	21.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.366024646302
		SemiMajorAxis	3.434841822999
		Eccentricity	0.127205784278
		Inclination	8.763044339028
		AscendingNode	184.155782231352
		ArgOfPericenter	280.165586422095
		MeanAnomaly	89.119433733424
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0517
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1579"
}

#1_"1580 Betulia:Betulia:1950 KA" "Sol" #1=
#2_"*Бетулия:1580 Betulia:Betulia:1950 KA" "Sol" #2=
#3_"1950 KA:*Бетулия:1580 Betulia:Betulia" "Sol" #3=
".:Betulia:1580 Betulia:1950 KA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1580 betulia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	2.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.25669998901
		SemiMajorAxis	2.197082510412
		Eccentricity	0.487448961085
		Inclination	52.082945477736
		AscendingNode	62.30938674638
		ArgOfPericenter	159.460173854274
		MeanAnomaly	309.84338769241
	}
	UniformRotation
	{
		Period	6.1324
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1580"
}

#1_"1581 Abanderada:Abanderada:1950 LA1:1927 JD:1929 TY:1943 EK:1949 FM1:1949 FQ:1949 FY:1966 FP: #1=
#1_1975 YH" "Sol" #1=
#2_"*Абандерада:1581 Abanderada:Abanderada:1950 LA1" "Sol" #2=
#3_"1950 LA1:*Абандерада:1581 Abanderada:Abanderada" "Sol" #3=
".:Abanderada:1581 Abanderada:1950 LA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.605430738275
		SemiMajorAxis	3.155492790811
		Eccentricity	0.123925121411
		Inclination	2.539345641157
		AscendingNode	104.874260464375
		ArgOfPericenter	91.062730923217
		MeanAnomaly	223.683477839043
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0523
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1581"
}

#1_"1582 Martir:Martir:1950 LY" "Sol" #1=
#2_"*Мартир:1582 Martir:Martir:1950 LY" "Sol" #2=
#3_"1950 LY:*Мартир:1582 Martir:Martir" "Sol" #3=
".:Martir:1582 Martir:1950 LY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.395
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.598727249483
		SemiMajorAxis	3.152976537096
		Eccentricity	0.128682307583
		Inclination	11.613448154989
		AscendingNode	94.031172200147
		ArgOfPericenter	128.886415788309
		MeanAnomaly	212.954526554645
	}
	UniformRotation
	{
		Period	9.84
	}
	LunarLambert	0.5
	Albedo	0.057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1582"
}

#1_"1583 Antilochus:Antilochus:1950 SA:1926 VF:1974 WH1" "Sol" #1=
#2_"*Антилох:1583 Antilochus:Antilochus:1950 SA" "Sol" #2=
#3_"1950 SA:*Антилох:1583 Antilochus:Antilochus" "Sol" #3=
".:Antilochus:1583 Antilochus:1950 SA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	50.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.601948329451
		SemiMajorAxis	5.124857764424015
		Eccentricity	0.05236610992482564
		Inclination	28.52912116972118
		AscendingNode	221.3919561174499
		ArgOfPericenter	188.291359761833
		MeanAnomaly	153.9577920038375
	}
	UniformRotation
	{
		Period	31.52
	}
	LunarLambert	0.5
	Albedo	0.0633
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1583"
}

#1_"1584 Fuji:Fuji:1927 CR:1949 CA:1954 NT:1965 OG:A916 AA" "Sol" #1=
#2_"*Фудзи:1584 Fuji:Fuji:1927 CR" "Sol" #2=
#3_"1927 CR:*Фудзи:1584 Fuji:Fuji" "Sol" #3=
".:Fuji:1584 Fuji:1927 CR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.664577977065
		SemiMajorAxis	2.376897807403
		Eccentricity	0.194527625072
		Inclination	26.622094708868
		AscendingNode	305.402920253636
		ArgOfPericenter	188.69693622933
		MeanAnomaly	350.059361804268
	}
	UniformRotation
	{
		Period	14.88
	}
	LunarLambert	0.5
	Albedo	0.2025
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1584"
}

#1_"1585 Union:Union:1947 RG:1929 DB:1937 QF:1939 CD1:1944 DG:1949 EE:1952 QA1:1952 SD" "Sol" #1=
#2_"*Юнион:1585 Union:Union:1947 RG" "Sol" #2=
#3_"1947 RG:*Юнион:1585 Union:Union" "Sol" #3=
".:Union:1585 Union:1947 RG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.008522123956
		SemiMajorAxis	2.927302449593
		Eccentricity	0.309240721182
		Inclination	26.188488915059
		AscendingNode	150.0978393209
		ArgOfPericenter	264.66492996219
		MeanAnomaly	107.411061454871
	}
	UniformRotation
	{
		Period	9.38
	}
	LunarLambert	0.5
	Albedo	0.0378
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1585"
}

#1_"1586 Thiele:Thiele:1939 CJ:1943 DA:1951 KT" "Sol" #1=
#2_"*Тиле:1586 Thiele:Thiele:1939 CJ" "Sol" #2=
#3_"1939 CJ:*Тиле:1586 Thiele:Thiele" "Sol" #3=
".:Thiele:1586 Thiele:1939 CJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.789004843975
		SemiMajorAxis	2.430401206723
		Eccentricity	0.104939103054
		Inclination	4.055626129561
		AscendingNode	125.885541013051
		ArgOfPericenter	29.877064998539
		MeanAnomaly	349.610868355897
	}
	UniformRotation
	{
		Period	3.086
	}
	LunarLambert	0.5
	Albedo	0.1575
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1586"
}

#1_"1590 Tsiolkovskaja:Tsiolkovskaja:1933 NA:1933 OU:1936 HB:1937 VE:1940 RN:1940 RX:1943 OD:1950 SF: #1=
#1_A907 TB:A913 MC" "Sol" #1=
#2_"*Циолковская:1590 Tsiolkovskaja:Tsiolkovskaja:1933 NA" "Sol" #2=
#3_"1933 NA:*Циолковская:1590 Tsiolkovskaja:Tsiolkovskaja" "Sol" #3=
".:Tsiolkovskaja:1590 Tsiolkovskaja:1933 NA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.635
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.330038477
		SemiMajorAxis	2.229944390384
		Eccentricity	0.157497689471
		Inclination	4.35057697508
		AscendingNode	226.63294164501
		ArgOfPericenter	52.38000695941
		MeanAnomaly	166.845023237469
	}
	UniformRotation
	{
		Period	6.731
	}
	LunarLambert	0.5
	Albedo	0.2095
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1590"
}

#1_"1591 Baize:Baize:1951 KA:1943 DE" "Sol" #1=
#2_"*Без:1591 Baize:Baize:1951 KA" "Sol" #2=
#3_"1951 KA:*Без:1591 Baize:Baize" "Sol" #3=
".:Baize:1591 Baize:1951 KA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.699332723849
		SemiMajorAxis	2.391902436995
		Eccentricity	0.175998902985
		Inclination	24.817925443255
		AscendingNode	90.563471199412
		ArgOfPericenter	163.621017523534
		MeanAnomaly	57.062611373164
	}
	UniformRotation
	{
		Period	7.78
	}
	LunarLambert	0.5
	Albedo	0.1056
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1591"
}

#1_"1592 Mathieu:Mathieu:1951 LA:1951 LG" "Sol" #1=
#2_"*Матьё:1592 Mathieu:Mathieu:1951 LA" "Sol" #2=
#3_"1951 LA:*Матьё:1592 Mathieu:Mathieu" "Sol" #3=
".:Mathieu:1592 Mathieu:1951 LA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1592 mathieu.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.928
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.605016484464
		SemiMajorAxis	2.767888924873
		Eccentricity	0.304373081447
		Inclination	13.532800898048
		AscendingNode	106.160099882096
		ArgOfPericenter	177.940814613877
		MeanAnomaly	270.080621203506
	}
	UniformRotation
	{
		Period	28.46
	}
	LunarLambert	0.5
	Albedo	0.211
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1592"
}

#1_"1594 Danjon:Danjon:1949 WA:1931 JA:1935 SF1:1937 AB:1938 KC:1941 FG:1951 CY1:A924 GB" "Sol" #1=
#2_"*Данжон:1594 Danjon:Danjon:1949 WA" "Sol" #2=
#3_"1949 WA:*Данжон:1594 Danjon:Danjon" "Sol" #3=
".:Danjon:1594 Danjon:1949 WA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.78
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.41651711733
		SemiMajorAxis	2.268385865302
		Eccentricity	0.195981338904
		Inclination	8.947057211175
		AscendingNode	69.488353025662
		ArgOfPericenter	222.046831628281
		MeanAnomaly	110.724627608845
	}
	UniformRotation
	{
		Period	12
	}
	LunarLambert	0.5
	Albedo	0.1743
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1594"
}

#1_"1595 Tanga:Tanga:1930 ME:1935 TB:1942 FB:1947 LQ:1948 TN2:1950 BB:1951 JK:1952 QG1:1959 EK: #1=
#1_1968 HA1" "Sol" #1=
#2_"*Танга:1595 Tanga:Tanga:1930 ME" "Sol" #2=
#3_"1930 ME:*Танга:1595 Tanga:Tanga" "Sol" #3=
".:Tanga:1595 Tanga:1930 ME" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.105
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.307100880623
		SemiMajorAxis	2.647186632433
		Eccentricity	0.110016540507
		Inclination	4.16461691442
		AscendingNode	112.214495732386
		ArgOfPericenter	189.868856156683
		MeanAnomaly	207.159083908313
	}
	UniformRotation
	{
		Period	11.05
	}
	LunarLambert	0.5
	Albedo	0.0557
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1595"
}

#1_"1596 Itzigsohn:Itzigsohn:1951 EV:1934 VD:1951 CE1:1951 FC" "Sol" #1=
#2_"*Ицигсон:1596 Itzigsohn:Itzigsohn:1951 EV" "Sol" #2=
#3_"1951 EV:*Ицигсон:1596 Itzigsohn:Itzigsohn" "Sol" #3=
".:Itzigsohn:1596 Itzigsohn:1951 EV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.82
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.913498193179
		SemiMajorAxis	2.890158976525
		Eccentricity	0.130090923872
		Inclination	13.280067456485
		AscendingNode	249.124838577487
		ArgOfPericenter	161.129856926559
		MeanAnomaly	101.750753193448
	}
	UniformRotation
	{
		Period	39.722
	}
	LunarLambert	0.5
	Albedo	0.0496
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1596"
}

#1_"1597 Laugier:Laugier:1949 EB" "Sol" #1=
#2_"*Ложье:1597 Laugier:Laugier:1949 EB" "Sol" #2=
#3_"1949 EB:Laugier:*Ложье:1597 Laugier:1949 EB" "Sol" #3=
".:Laugier:1597 Laugier:1949 EB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1597 laugier.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.442
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.79884797602
		SemiMajorAxis	2.845023511813
		Eccentricity	0.090767452086
		Inclination	11.812197324751
		AscendingNode	158.62988093836
		ArgOfPericenter	52.060229224432
		MeanAnomaly	26.649599827664
	}
	UniformRotation
	{
		Period	8.0199
	}
	LunarLambert	0.5
	Albedo	0.244
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1597"
}

#1_"1598 Paloque:Paloque:1950 CA:1962 RB" "Sol" #1=
#2_"*Палок:1598 Paloque:Paloque:1950 CA" "Sol" #2=
#3_"1950 CA:*Палок:1598 Paloque:Paloque" "Sol" #3=
".:Paloque:1598 Paloque:1950 CA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.695
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.560626269156
		SemiMajorAxis	2.331732859131
		Eccentricity	0.080592802499
		Inclination	7.535104501925
		AscendingNode	298.078024355079
		ArgOfPericenter	300.967223031061
		MeanAnomaly	330.268353141654
	}
	UniformRotation
	{
		Period	5.949
	}
	LunarLambert	0.5
	Albedo	0.1299
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1598"
}

#1_"1599 Giomus:Giomus:1950 WA:1933 SV" "Sol" #1=
#2_"*Гиом:1599 Giomus:Giomus:1950 WA" "Sol" #2=
#3_"1950 WA:*Гиом:1599 Giomus:Giomus" "Sol" #3=
".:Giomus:1599 Giomus:1950 WA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.77
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.531543405672
		SemiMajorAxis	3.127702339141
		Eccentricity	0.144116422793
		Inclination	6.091210279778
		AscendingNode	43.447197596581
		ArgOfPericenter	356.773427093995
		MeanAnomaly	191.789213075465
	}
	UniformRotation
	{
		Period	6.46
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1599"
}

#1_"1600 Vyssotsky:Vyssotsky:1947 UC" "Sol" #1=
#2_"*Высоцкий:1600 Vyssotsky:Vyssotsky:1947 UC" "Sol" #2=
#3_"1947 UC:*Высоцкий:1600 Vyssotsky:Vyssotsky" "Sol" #3=
".:Vyssotsky:1600 Vyssotsky:1947 UC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1600 vyssotsky.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.706
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	2.514255700158
		SemiMajorAxis	1.848988290274
		Eccentricity	0.037315161392
		Inclination	21.169022114621
		AscendingNode	60.614846385256
		ArgOfPericenter	50.558534447277
		MeanAnomaly	245.7620513156
	}
	UniformRotation
	{
		Period	3.2011
	}
	LunarLambert	0.5
	Albedo	0.321
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1600"
}

#1_"1603 Neva:Neva:1926 VH:1935 TF:1942 FE:A907 PA" "Sol" #1=
#2_"*Нева:1603 Neva:Neva:1926 VH" "Sol" #2=
#3_"1926 VH:*Нева:1603 Neva:Neva" "Sol" #3=
".:Neva:1603 Neva:1926 VH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.015
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.578293999369
		SemiMajorAxis	2.757170672849
		Eccentricity	0.093808838091
		Inclination	8.558890322364
		AscendingNode	130.025434273116
		ArgOfPericenter	257.841204664523
		MeanAnomaly	103.91188180332
	}
	UniformRotation
	{
		Period	6.4249
	}
	LunarLambert	0.5
	Albedo	0.0594
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1603"
}

#1_"1604 Tombaugh:Tombaugh:1931 FH:1930 DX:1933 SA1:1936 FA:1937 JH:1941 CF:1943 OE:1948 ME: #1=
#1_1949 ST1:A920 EC" "Sol" #1=
#2_"*Томбо:1604 Tombaugh:Tombaugh:1931 FH" "Sol" #2=
#3_"1931 FH:*Томбо:1604 Tombaugh:Tombaugh" "Sol" #3=
".:Tombaugh:1604 Tombaugh:1931 FH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.165
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.262455859684
		SemiMajorAxis	3.025428143684
		Eccentricity	0.100235568559
		Inclination	9.396861788491
		AscendingNode	309.119108967962
		ArgOfPericenter	38.15018012268
		MeanAnomaly	171.882103288336
	}
	UniformRotation
	{
		Period	7.047
	}
	LunarLambert	0.5
	Albedo	0.1038
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1604"
}

#1_"1605 Milankovitch:Milankovitch:1936 GA:1925 DC:1931 KB:1938 ST:1941 FA:1946 FF:1949 UC1:1968 KP: #1=
#1_A907 UB" "Sol" #1=
#2_"*Миланкович:1605 Milankovitch:Milankovitch:1936 GA" "Sol" #2=
#3_"1936 GA:*Миланкович:1605 Milankovitch:Milankovitch" "Sol" #3=
".:Milankovitch:1605 Milankovitch:1936 GA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.225820106902
		SemiMajorAxis	3.011370341917
		Eccentricity	0.078312251256
		Inclination	10.563014790367
		AscendingNode	173.751303278167
		ArgOfPericenter	276.252929173518
		MeanAnomaly	122.190863786801
	}
	UniformRotation
	{
		Period	11.6
	}
	LunarLambert	0.5
	Albedo	0.1529
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1605"
}

#1_"1607 Mavis:Mavis:1950 RA:1934 VQ:1958 OB:1958 PD:A903 BH" "Sol" #1=
#2_"*Мейвис:1607 Mavis:Mavis:1950 RA" "Sol" #2=
#3_"1950 RA:*Мейвис:1607 Mavis:Mavis" "Sol" #3=
".:Mavis:1607 Mavis:1950 RA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1607 mavis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.378
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.070527155957
		SemiMajorAxis	2.549343184629
		Eccentricity	0.30524485985
		Inclination	8.581093207059
		AscendingNode	122.540064906505
		ArgOfPericenter	235.985410311117
		MeanAnomaly	276.682246550111
	}
	UniformRotation
	{
		Period	6.1339
	}
	LunarLambert	0.5
	Albedo	0.193
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1607"
}

#1_"1609 Brenda:Brenda:1951 NL:1925 EA:1934 JB:1947 WB:1950 HD:1954 EP:1954 HE" "Sol" #1=
#2_"*Бренда:1609 Brenda:Brenda:1951 NL" "Sol" #2=
#3_"1951 NL:*Бренда:1609 Brenda:Brenda" "Sol" #3=
".:Brenda:1609 Brenda:1951 NL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.82
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.15130789099
		SemiMajorAxis	2.582960878982
		Eccentricity	0.249425208397
		Inclination	18.658765418461
		AscendingNode	105.423960906237
		ArgOfPericenter	228.505240225484
		MeanAnomaly	72.491742411172
	}
	UniformRotation
	{
		Period	19.46
	}
	LunarLambert	0.5
	Albedo	0.1147
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1609"
}

#1_"1613 Smiley:Smiley:1950 SD:1929 CL:1941 SR:1952 DC3:1952 FY:1952 HQ:1988 CS3" "Sol" #1=
#2_"*Смайли:1613 Smiley:Smiley:1950 SD" "Sol" #2=
#3_"1950 SD:*Смайли:1613 Smiley:Smiley" "Sol" #3=
".:Smiley:1613 Smiley:1950 SD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.555
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.5224565802153
		SemiMajorAxis	2.734707000893706
		Eccentricity	0.2615882757780875
		Inclination	7.988195758411781
		AscendingNode	320.8016863026803
		ArgOfPericenter	127.3083711439305
		MeanAnomaly	9.768703280717892
	}
	UniformRotation
	{
		Period	80.61
	}
	LunarLambert	0.5
	Albedo	0.0883
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1613"
}

#1_"1614 Goldschmidt:Goldschmidt:1952 HA:1928 SA:1931 EA:1936 DP:1936 DQ:1936 FQ1:1941 CH:1964 PC: #1=
#1_1979 MD" "Sol" #1=
#2_"*Гольдшмидт:1614 Goldschmidt:Goldschmidt:1952 HA" "Sol" #2=
#3_"1952 HA:*Гольдшмидт:1614 Goldschmidt:Goldschmidt" "Sol" #3=
".:Goldschmidt:1614 Goldschmidt:1952 HA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.16
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.187927659147
		SemiMajorAxis	2.996795718584
		Eccentricity	0.070592033167
		Inclination	14.072956663933
		AscendingNode	162.405496782459
		ArgOfPericenter	342.381669333832
		MeanAnomaly	81.167585377801
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0432
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1614"
}

#1_"1615 Bardwell:Bardwell:1950 BW:1926 TO:1937 TJ:1948 RB1:1948 RH1:1948 TG" "Sol" #1=
#2_"*Бардуэлл:1615 Bardwell:Bardwell:1950 BW" "Sol" #2=
#3_"1950 BW:*Бардуэлл:1615 Bardwell:Bardwell" "Sol" #3=
".:Bardwell:1615 Bardwell:1950 BW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.89
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.514631179124
		SemiMajorAxis	3.12132396241
		Eccentricity	0.177994508547
		Inclination	1.688030476802
		AscendingNode	152.543113662974
		ArgOfPericenter	251.727694424528
		MeanAnomaly	352.823311405655
	}
	UniformRotation
	{
		Period	18
	}
	LunarLambert	0.5
	Albedo	0.0642
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1615"
}

#1_"1616 Filipoff:Filipoff:1950 EA:1929 BB:1957 UG" "Sol" #1=
#2_"*Филипофф:1616 Filipoff:Filipoff:1950 EA" "Sol" #2=
#3_"1950 EA:*Филипофф:1616 Filipoff:Filipoff" "Sol" #3=
".:Filipoff:1616 Filipoff:1950 EA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.155
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.962727756648
		SemiMajorAxis	2.909431698203
		Eccentricity	0.020625085204
		Inclination	8.483003353246
		AscendingNode	48.287904266844
		ArgOfPericenter	14.927849421881
		MeanAnomaly	140.865726583773
	}
	UniformRotation
	{
		Period	5.652
	}
	LunarLambert	0.5
	Albedo	0.0751
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1616"
}

#1_"1618 Dawn:Dawn (asteroid):1948 NF:1927 CF:1951 AK:1952 HF:1964 VH2:1964 VV" "Sol" #1=
#2_"*Дон (астероид):1618 Dawn:Dawn (asteroid):1948 NF" "Sol" #2=
#3_"1948 NF:*Дон (астероид):1618 Dawn:Dawn (asteroid)" "Sol" #3=
".:Dawn (asteroid):1618 Dawn:1948 NF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1618 dawn.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.748
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.861280713466
		SemiMajorAxis	2.86964604257
		Eccentricity	0.026380655433
		Inclination	3.224877493443
		AscendingNode	102.945007214908
		ArgOfPericenter	181.02099790051
		MeanAnomaly	244.614619909242
	}
	UniformRotation
	{
		Period	43.19
	}
	LunarLambert	0.5
	Albedo	0.145
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1618"
}

#1_"1619 Ueta:Ueta:1953 TA:1926 RR:1931 AO:1940 YJ:1951 AG1:1978 GM" "Sol" #1=
#2_"*Уэта:1619 Ueta:Ueta:1953 TA" "Sol" #2=
#3_"1953 TA:Ueta:*Уэта:1619 Ueta" "Sol" #3=
".:Ueta:1619 Ueta:1953 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1619 ueta.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.482
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.354359457749
		SemiMajorAxis	2.240788835848
		Eccentricity	0.17651419587
		Inclination	6.214145807955
		AscendingNode	61.495775925954
		ArgOfPericenter	328.210932231168
		MeanAnomaly	307.156343589877
	}
	UniformRotation
	{
		Period	2.72
	}
	LunarLambert	0.5
	Albedo	0.479
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1619"
}

#1_"1620 Geographos:Geographos:1951 RA:1983 CY3" "Sol" #1=
#2_"*Географ:1620 Geographos:Geographos:1951 RA" "Sol" #2=
#3_"1951 RA:*Географ:1620 Geographos:Geographos" "Sol" #3=
".:Geographos:1620 Geographos:1951 RA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1620 geographos.cmod"
	MeshCenter	[ 0.154 -0.002 -0.026 ]
	Texture	"geographos.jpg"
	Radius	2.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.3901518471382
		SemiMajorAxis	1.245573498070266
		Eccentricity	0.335430907784686
		Inclination	13.33763553912958
		AscendingNode	337.2193489353145
		ArgOfPericenter	276.8688555134938
		MeanAnomaly	256.826134483741
	}
	UniformRotation
	{
		Period	5.22204
		Inclination	136
		AscendingNode	145
	}
	LunarLambert	0.5
	Albedo	0.3258
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1620"
}

#1_"1621 Druzhba:Druzhba:1926 TM:1927 AE:1931 EO:1946 UH:1949 QS1:1951 EK1:1951 ER1:1958 GA: #1=
#1_1979 QP4" "Sol" #1=
#2_"*Дружба:1621 Druzhba:Druzhba:1926 TM" "Sol" #2=
#3_"1926 TM:*Дружба:1621 Druzhba:Druzhba" "Sol" #3=
".:Druzhba:1621 Druzhba:1926 TM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1621 druzhba.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	6.347
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.329486974516
		SemiMajorAxis	2.229698176248
		Eccentricity	0.119252219164
		Inclination	3.172757636904
		AscendingNode	181.892386617031
		ArgOfPericenter	238.22777699482
		MeanAnomaly	137.121459118917
	}
	UniformRotation
	{
		Period	99.2
	}
	LunarLambert	0.5
	Albedo	0.244
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1621"
}

#1_"1623 Vivian:Vivian:1948 PL:1951 EG2:1954 SA:1955 YC:1960 WP:1965 QB:1965 UW:1973 GG" "Sol" #1=
#2_"*Вивиан:1623 Vivian:Vivian:1948 PL" "Sol" #2=
#3_"1948 PL:Vivian:*Вивиан:1623 Vivian" "Sol" #3=
".:Vivian:1623 Vivian:1948 PL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1623 vivian.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	13.926
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.570723553827
		SemiMajorAxis	3.1424540545
		Eccentricity	0.155555561843
		Inclination	2.490394219579
		AscendingNode	115.626310363438
		ArgOfPericenter	316.900101962836
		MeanAnomaly	36.720903664055
	}
	UniformRotation
	{
		Period	20.5209
	}
	LunarLambert	0.5
	Albedo	0.075
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1623"
}

#1_"1624 Rabe:Rabe:1931 TT1:1928 DS:1934 FS:1939 BN:1954 UP2:1957 JU:1977 VA2" "Sol" #1=
#2_"*Рабе:1624 Rabe:Rabe:1931 TT1" "Sol" #2=
#3_"1931 TT1:*Рабе:1624 Rabe:Rabe" "Sol" #3=
".:Rabe:1624 Rabe:1931 TT1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.709770361723
		SemiMajorAxis	3.194529917693
		Eccentricity	0.090246441148
		Inclination	1.986184702022
		AscendingNode	133.431364322136
		ArgOfPericenter	21.148474456923
		MeanAnomaly	114.714336834377
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1028
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1624"
}

#1_"1627 Ivar:Ivar:1929 SH:1957 NA:1957 XA" "Sol" #1=
#2_"*Ивар:1627 Ivar:Ivar:1929 SH" "Sol" #2=
#3_"1929 SH:*Ивар:1627 Ivar:Ivar" "Sol" #3=
".:Ivar:1627 Ivar:1929 SH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1627 ivar.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.56
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.544135831289
		SemiMajorAxis	1.863608695583
		Eccentricity	0.396469998872
		Inclination	8.451202439104
		AscendingNode	133.149902584288
		ArgOfPericenter	167.716915777784
		MeanAnomaly	201.476774352722
	}
	UniformRotation
	{
		Period	4.795
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1627"
}

#1_"1628 Strobel:Strobel:1923 OG:1926 GY:1947 GC:1949 QA2:1952 DV2:1957 CA:1960 WH" "Sol" #1=
#2_"*Штробель:1628 Strobel:Strobel:1923 OG" "Sol" #2=
#3_"1923 OG:*Штробель:1628 Strobel:Strobel" "Sol" #3=
".:Strobel:1628 Strobel:1923 OG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.56
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.226363313979
		SemiMajorAxis	3.011579019766
		Eccentricity	0.06821551186
		Inclination	19.385280617773
		AscendingNode	181.19416130826
		ArgOfPericenter	289.541812820006
		MeanAnomaly	55.314214940483
	}
	UniformRotation
	{
		Period	9.52
	}
	LunarLambert	0.5
	Albedo	0.0532
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1628"
}

#1_"1629 Pecker:Pecker:1952 DB:1942 DE:1949 FO1:1949 HK:1952 DE1" "Sol" #1=
#2_"*Пеккер:1629 Pecker:Pecker:1952 DB" "Sol" #2=
#3_"1952 DB:*Пеккер:1629 Pecker:Pecker" "Sol" #3=
".:Pecker:1629 Pecker:1952 DB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.67
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.347153572747
		SemiMajorAxis	2.237578555107
		Eccentricity	0.155501500587
		Inclination	9.701604760264
		AscendingNode	132.7157900554
		ArgOfPericenter	106.750780783559
		MeanAnomaly	192.389067411455
	}
	UniformRotation
	{
		Period	8.2166
	}
	LunarLambert	0.5
	Albedo	0.1847
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1629"
}

#1_"1630 Milet:Milet:1952 DA:1931 DQ:1936 AB:1942 GH:1956 YL:A924 YD" "Sol" #1=
#2_"*Милет:1630 Milet:Milet:1952 DA" "Sol" #2=
#3_"1952 DA:*Милет:1630 Milet:Milet" "Sol" #3=
".:Milet:1630 Milet:1952 DA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1630 milet.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.584
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.269947648696
		SemiMajorAxis	3.028298855935
		Eccentricity	0.169598752461
		Inclination	4.537126680673
		AscendingNode	54.520541123885
		ArgOfPericenter	95.878059796722
		MeanAnomaly	315.783733920571
	}
	UniformRotation
	{
		Period	32.55
	}
	LunarLambert	0.5
	Albedo	0.22
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1630"
}

#1_"1631 Kopff:Kopff:1936 UC:1926 TH:1935 FG:1946 SA:1952 HV2" "Sol" #1=
#2_"*Копфф:1631 Kopff:Kopff:1936 UC" "Sol" #2=
#3_"1936 UC:*Копфф:1631 Kopff:Kopff" "Sol" #3=
".:Kopff:1631 Kopff:1936 UC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.83
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.344387330429
		SemiMajorAxis	2.236345559719
		Eccentricity	0.213043677565
		Inclination	7.49028663308
		AscendingNode	16.848746355956
		ArgOfPericenter	315.019354874637
		MeanAnomaly	172.342579625274
	}
	UniformRotation
	{
		Period	6.683
	}
	LunarLambert	0.5
	Albedo	0.2497
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1631"
}

#1_"1632 Siebohme:Siebohme:1941 DF:1930 UJ:1942 JC:1947 RB:1951 MN:1956 TM:A917 SO" "Sol" #1=
#2_"*Зибёме:1632 Siebohme:Siebohme:1941 DF" "Sol" #2=
#3_"1941 DF:*Зибёме:1632 Siebohme:Siebohme" "Sol" #3=
".:Siebohme:1632 Siebohme:1941 DF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.329224836338
		SemiMajorAxis	2.656243956881
		Eccentricity	0.13629517222
		Inclination	5.714212175995
		AscendingNode	199.816960761901
		ArgOfPericenter	127.111233174767
		MeanAnomaly	201.022644662221
	}
	UniformRotation
	{
		Period	56.65
	}
	LunarLambert	0.5
	Albedo	0.0748
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1632"
}

#1_"1633 Chimay:Chimay:1929 EC:1941 KF:1946 HC:1948 RO:1951 AM:1952 HY3:1954 SS:1955 XN:1972 VM1: #1=
#1_A917 BB" "Sol" #1=
#2_"*Шиме:1633 Chimay:Chimay:1929 EC" "Sol" #2=
#3_"1929 EC:*Шиме:1633 Chimay:Chimay" "Sol" #3=
".:Chimay:1633 Chimay:1929 EC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1633 chimay.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	18.714
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.705840277601
		SemiMajorAxis	3.193063867839
		Eccentricity	0.12413033325
		Inclination	2.676237369134
		AscendingNode	114.095142894686
		ArgOfPericenter	65.198730584744
		MeanAnomaly	65.063572319109
	}
	UniformRotation
	{
		Period	6.5911
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1633"
}

#1_"1634 Ndola:Ndola:1935 QP:1928 KB" "Sol" #1=
#2_"*Ндола:1634 Ndola:Ndola:1935 QP" "Sol" #2=
#3_"1935 QP:*Ндола:1634 Ndola:Ndola" "Sol" #3=
".:Ndola:1634 Ndola:1935 QP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1634 ndola.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.518
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.365967869802
		SemiMajorAxis	2.245955648414
		Eccentricity	0.161516907041
		Inclination	7.596885359114
		AscendingNode	90.735170767959
		ArgOfPericenter	191.042215760031
		MeanAnomaly	288.298773910721
	}
	UniformRotation
	{
		Period	64.23
	}
	LunarLambert	0.5
	Albedo	0.179
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1634"
}

#1_"1635 Bohrmann:Bohrmann:1924 QW:1931 VH1:1936 UJ:1938 CH:1939 HL:1943 EG1:1948 EA1:1953 FH" "Sol" #1=
#2_"*Борман:1635 Bohrmann:Bohrmann:1924 QW" "Sol" #2=
#3_"1924 QW:*Борман:1635 Bohrmann:Bohrmann" "Sol" #3=
".:Bohrmann:1635 Bohrmann:1924 QW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1635 bohrmann.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	8.564
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.828756059226
		SemiMajorAxis	2.856832048645
		Eccentricity	0.056841529921
		Inclination	1.818506811379
		AscendingNode	184.368837358593
		ArgOfPericenter	134.548132430313
		MeanAnomaly	195.207509021827
	}
	UniformRotation
	{
		Period	5.864
	}
	LunarLambert	0.5
	Albedo	0.219
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1635"
}

#1_"1636 Porter:Porter:1950 BH:1972 YT1" "Sol" #1=
#2_"*Портер:1636 Porter:Porter:1950 BH" "Sol" #2=
#3_"1950 BH:*Портер:1636 Porter:Porter" "Sol" #3=
".:Porter:1636 Porter:1950 BH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.61
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.340611759487
		SemiMajorAxis	2.234662128156
		Eccentricity	0.127485083335
		Inclination	4.435431664352
		AscendingNode	168.384254797428
		ArgOfPericenter	239.146389998422
		MeanAnomaly	228.735681444385
	}
	UniformRotation
	{
		Period	2.9653
	}
	LunarLambert	0.5
	Albedo	0.1197
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1636"
}

#1_"1637 Swings:Swings:1936 QO:1907 YT:1934 FL:1934 FP:1936 SD:1939 FU:1950 GA" "Sol" #1=
#2_"*Свингс:1637 Swings:Swings:1936 QO" "Sol" #2=
#3_"1936 QO:*Свингс:1637 Swings:Swings" "Sol" #3=
".:Swings:1637 Swings:1936 QO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.575
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.380149911646
		SemiMajorAxis	3.070370488658
		Eccentricity	0.043900322775
		Inclination	14.069029598323
		AscendingNode	21.295777769539
		ArgOfPericenter	235.569010274093
		MeanAnomaly	300.945693547987
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0415
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1637"
}

#1_"1639 Bower:Bower:1951 RB:1934 PT:1936 AC:1939 XH:1942 NA:1951 RV1:1951 TE:1953 DK:1953 EU1: #1=
#1_1953 GV:1957 BJ1:A906 YD:A924 EN" "Sol" #1=
#2_"*Бауэр:1639 Bower:Bower:1951 RB" "Sol" #2=
#3_"1951 RB:*Бауэр:1639 Bower:Bower" "Sol" #3=
".:Bower:1639 Bower:1951 RB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.205
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.127095717655
		SemiMajorAxis	2.572907814796
		Eccentricity	0.150760572513
		Inclination	8.440342113443
		AscendingNode	324.206784813521
		ArgOfPericenter	106.629342151775
		MeanAnomaly	67.730539978727
	}
	UniformRotation
	{
		Period	12.5
	}
	LunarLambert	0.5
	Albedo	0.0541
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1639"
}

#1_"1641 Tana:Tana:1935 OJ:1930 QQ:1951 RJ1:A909 SC" "Sol" #1=
#2_"*Тана:1641 Tana:Tana:1935 OJ" "Sol" #2=
#3_"1935 OJ:*Тана:1641 Tana:Tana" "Sol" #3=
".:Tana:1641 Tana:1935 OJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1641 tana.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	12.83
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.243302487112
		SemiMajorAxis	3.018082731587
		Eccentricity	0.102121322382
		Inclination	9.337770097014
		AscendingNode	331.635578097154
		ArgOfPericenter	359.763040341116
		MeanAnomaly	32.501550018141
	}
	UniformRotation
	{
		Period	7.95
	}
	LunarLambert	0.5
	Albedo	0.0739
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1641"
}

#1_"1643 Brown:Brown:1951 RQ:1933 BG:1951 SR" "Sol" #1=
#2_"*Браун:1643 Brown:Brown:1951 RQ" "Sol" #2=
#3_"1951 RQ:Brown:*Браун:1643 Brown" "Sol" #3=
".:Brown:1643 Brown:1951 RQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1643 brown.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.752
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.928303273154
		SemiMajorAxis	2.489609338727
		Eccentricity	0.201704480768
		Inclination	3.51307320866
		AscendingNode	287.947181200793
		ArgOfPericenter	90.194081085785
		MeanAnomaly	217.194288251755
	}
	UniformRotation
	{
		Period	5.932
	}
	LunarLambert	0.5
	Albedo	0.179
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1643"
}

#1_"1645 Waterfield:Waterfield:1933 OJ:1936 FY:1939 UH:1944 RF:1958 GL:A917 QC" "Sol" #1=
#2_"*Ватерфильд:1645 Waterfield:Waterfield:1933 OJ" "Sol" #2=
#3_"1933 OJ:*Ватерфильд:1645 Waterfield:Waterfield" "Sol" #3=
".:Waterfield:1645 Waterfield:1933 OJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.29
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.352719377586
		SemiMajorAxis	3.059925472138
		Eccentricity	0.110203980593
		Inclination	1.020609277351
		AscendingNode	266.397184380733
		ArgOfPericenter	102.265154770105
		MeanAnomaly	35.293892486546
	}
	UniformRotation
	{
		Period	4.861
	}
	LunarLambert	0.5
	Albedo	0.0991
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1645"
}

#1_"1648 Shajna:Shajna:1935 RF:1934 CK1:1938 MC:1941 FD:1948 LC:1951 EX2:1952 SX:1952 UW:1955 QT: #1=
#1_1955 RP:A921 GB:A924 EQ" "Sol" #1=
#2_"*Шайна:1648 Shajna:Shajna:1935 RF" "Sol" #2=
#3_"1935 RF:Shajna:*Шайна:1648 Shajna" "Sol" #3=
".:Shajna:1648 Shajna:1935 RF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1648 shajna.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.725
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.342673880325
		SemiMajorAxis	2.235581654221
		Eccentricity	0.206425642826
		Inclination	4.57212932395
		AscendingNode	130.423910407239
		ArgOfPericenter	134.707465829071
		MeanAnomaly	191.946936320856
	}
	UniformRotation
	{
		Period	6.414
	}
	LunarLambert	0.5
	Albedo	0.191
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1648"
}

#1_"1650 Heckmann:Heckmann:1937 TG:1929 SK:1940 NB:1941 UA1:1943 DG:1944 OC:1947 FA:1951 GX: #1=
#1_1952 SL1:1963 PB:A906 OC:A909 DF" "Sol" #1=
#2_"*Хекман:1650 Heckmann:Heckmann:1937 TG" "Sol" #2=
#3_"1937 TG:*Хекман:1650 Heckmann:Heckmann" "Sol" #3=
".:Heckmann:1650 Heckmann:1937 TG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.535
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.801214530168
		SemiMajorAxis	2.435619555236
		Eccentricity	0.163400076888
		Inclination	2.747294255636
		AscendingNode	199.845256230488
		ArgOfPericenter	56.691327482406
		MeanAnomaly	218.482333770038
	}
	UniformRotation
	{
		Period	14.893
	}
	LunarLambert	0.5
	Albedo	0.0497
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1650"
}

#1_"1654 Bojeva:Bojeva:1931 TL:1936 SH:1944 DK:1955 HD:A915 TM" "Sol" #1=
#2_"*Боева:1654 Bojeva:Bojeva:1931 TL" "Sol" #2=
#3_"1931 TL:*Боева:1654 Bojeva:Bojeva" "Sol" #3=
".:Bojeva:1654 Bojeva:1931 TL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.49
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.238365571631
		SemiMajorAxis	3.016187951391
		Eccentricity	0.090754591202
		Inclination	10.449017181652
		AscendingNode	25.319328981124
		ArgOfPericenter	332.267662940333
		MeanAnomaly	332.104392680457
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1162
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1654"
}

#1_"1655 Comas Sola:Comas Sola:1929 WG:1929 WC1:1958 BG:A901 VG" "Sol" #1=
#2_"*Комас Сола:1655 Comas Sola:Comas Sola:1929 WG" "Sol" #2=
#3_"1929 WG:*Комас Сола:1655 Comas Sola:Comas Sola" "Sol" #3=
".:Comas Sola:1655 Comas Sola:1929 WG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.285
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.631702601248
		SemiMajorAxis	2.778571919505
		Eccentricity	0.236331085569
		Inclination	9.602677124344
		AscendingNode	111.141500016676
		ArgOfPericenter	323.609398321248
		MeanAnomaly	111.00126010622
	}
	UniformRotation
	{
		Period	20.456
	}
	LunarLambert	0.5
	Albedo	0.0726
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1655"
}

#1_"1656 Suomi:Suomi:1942 EC:1955 HL" "Sol" #1=
#2_"*Суоми:1656 Suomi:Suomi:1942 EC" "Sol" #2=
#3_"1942 EC:*Суоми:1656 Suomi:Suomi" "Sol" #3=
".:Suomi:1656 Suomi:1942 EC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.93
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.572765542327
		SemiMajorAxis	1.877563665171
		Eccentricity	0.123323214302
		Inclination	25.067548337144
		AscendingNode	175.576183655232
		ArgOfPericenter	287.413246295834
		MeanAnomaly	151.653809157472
	}
	UniformRotation
	{
		Period	2.583
	}
	LunarLambert	0.5
	Albedo	0.1556
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1656"
}

#1_"1659 Punkaharju:Punkaharju:1940 YL:1930 QB:1937 EB:1944 RE:1951 EG:1953 NH:1957 KO:1958 TS1" "Sol" #1=
#2_"*Пункахарью:1659 Punkaharju:Punkaharju:1940 YL" "Sol" #2=
#3_"1940 YL:*Пункахарью:1659 Punkaharju:Punkaharju" "Sol" #3=
".:Punkaharju:1659 Punkaharju:1940 YL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1659 punkaharju.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	14.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.647082894729
		SemiMajorAxis	2.784719642216
		Eccentricity	0.2571991071
		Inclination	16.478326442079
		AscendingNode	338.399006730388
		ArgOfPericenter	35.300285220523
		MeanAnomaly	33.001449225704
	}
	UniformRotation
	{
		Period	5.01
	}
	LunarLambert	0.5
	Albedo	0.271
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1659"
}

#1_"1663 van den Bos:van den Bos:1926 PE:1928 DD:1936 OM:1948 BE:1948 EG1:1949 KE:1950 XD:1963 SC" "Sol" #1=
#2_"*ван ден Бос:1663 van den Bos:van den Bos:1926 PE" "Sol" #2=
#3_"1926 PE:*ван ден Бос:1663 van den Bos:van den Bos" "Sol" #3=
".:van den Bos:1663 van den Bos:1926 PE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1663 van den bos.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.768
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.351882623671
		SemiMajorAxis	2.239685645514
		Eccentricity	0.180368126935
		Inclination	5.361711513404
		AscendingNode	83.196370015375
		ArgOfPericenter	275.242794349602
		MeanAnomaly	33.127755491405
	}
	UniformRotation
	{
		Period	740
	}
	LunarLambert	0.5
	Albedo	0.255
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1663"
}

#1_"1665 Gaby:Gaby:1930 DQ:1941 BC:1949 HS:1951 WQ:1957 KF" "Sol" #1=
#2_"*Габи:1665 Gaby:Gaby:1930 DQ" "Sol" #2=
#3_"1930 DQ:Gaby:*Габи:1665 Gaby" "Sol" #3=
".:Gaby:1665 Gaby:1930 DQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1665 gaby.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.373
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.751376334706
		SemiMajorAxis	2.414283621123
		Eccentricity	0.207285611309
		Inclination	10.833199925459
		AscendingNode	91.548520748178
		ArgOfPericenter	5.969981246988
		MeanAnomaly	113.232732746968
	}
	UniformRotation
	{
		Period	66
	}
	LunarLambert	0.5
	Albedo	0.278
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1665"
}

#1_"1669 Dagmar:Dagmar:1934 RS:1943 GE:1950 PX:1953 AD:1957 WA:1959 CV:1962 RH" "Sol" #1=
#2_"*Дагмар:1669 Dagmar:Dagmar:1934 RS" "Sol" #2=
#3_"1934 RS:*Дагмар:1669 Dagmar:Dagmar" "Sol" #3=
".:Dagmar:1669 Dagmar:1934 RS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.89
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.571228273239
		SemiMajorAxis	3.142643860318
		Eccentricity	0.11218333291
		Inclination	0.941201733573
		AscendingNode	18.973212472698
		ArgOfPericenter	177.981839330141
		MeanAnomaly	309.658676474622
	}
	UniformRotation
	{
		Period	12
	}
	LunarLambert	0.5
	Albedo	0.0565
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1669"
}

#1_"1672 Gezelle:Gezelle:1935 BD:1929 AA:1933 SE1:1939 VK:1950 SX:1978 NA8:A924 EO" "Sol" #1=
#2_"*Гезелле:1672 Gezelle:Gezelle:1935 BD" "Sol" #2=
#3_"1935 BD:Gezelle:*Гезелле:1672 Gezelle" "Sol" #3=
".:Gezelle:1672 Gezelle:1935 BD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1672 gezelle.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	13.168
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.652125074579
		SemiMajorAxis	3.172992466305
		Eccentricity	0.276014056274
		Inclination	1.067084242325
		AscendingNode	181.269999159928
		ArgOfPericenter	255.181803765424
		MeanAnomaly	148.922440216662
	}
	UniformRotation
	{
		Period	40.72
	}
	LunarLambert	0.5
	Albedo	0.055
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1672"
}

#1_"1674 Groeneveld:Groeneveld:1938 DS:1949 DF:1953 VE2:1955 DF:1966 FK" "Sol" #1=
#2_"*Груневельд:1674 Groeneveld:Groeneveld:1938 DS" "Sol" #2=
#3_"1938 DS:*Груневельд:1674 Groeneveld:Groeneveld" "Sol" #3=
".:Groeneveld:1674 Groeneveld:1938 DS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.69
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.720330268667
		SemiMajorAxis	3.198467443126
		Eccentricity	0.122954695004
		Inclination	2.662021184241
		AscendingNode	95.678295054399
		ArgOfPericenter	0.00978721232
		MeanAnomaly	238.816082876787
	}
	UniformRotation
	{
		Period	8.1
	}
	LunarLambert	0.5
	Albedo	0.0888
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1674"
}

#1_"1675 Simonida:Simonida:1938 FB:1931 AZ:1936 SG:1941 BD:1943 VJ:1951 CL1:1953 VD:1958 FE:1958 GX" "Sol" #1=
#2_"*Симонида:1675 Simonida:Simonida:1938 FB" "Sol" #2=
#3_"1938 FB:*Симонида:1675 Simonida:Simonida" "Sol" #3=
".:Simonida:1675 Simonida:1938 FB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.337240372524
		SemiMajorAxis	2.23315837593
		Eccentricity	0.124985946995
		Inclination	6.79635246187
		AscendingNode	30.152933647355
		ArgOfPericenter	50.236239503993
		MeanAnomaly	83.396314037047
	}
	UniformRotation
	{
		Period	5.2885
	}
	LunarLambert	0.5
	Albedo	0.248
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1675"
}

#1_"1676 Kariba:Kariba:1939 LC:1939 MA:1942 EH1:1949 KB:1949 KU:1952 DG2:1953 TJ3:1959 LD" "Sol" #1=
#2_"*Кариба:1676 Kariba:Kariba:1939 LC" "Sol" #2=
#3_"1939 LC:Kariba:*Кариба:1676 Kariba" "Sol" #3=
".:Kariba:1676 Kariba:1939 LC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1676 kariba.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.776
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.34328448954
		SemiMajorAxis	2.235853896394
		Eccentricity	0.186975833093
		Inclination	6.129515796132
		AscendingNode	54.563054899664
		ArgOfPericenter	204.655052029709
		MeanAnomaly	82.116347259143
	}
	UniformRotation
	{
		Period	3.1673
	}
	LunarLambert	0.5
	Albedo	0.283
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1676"
}

#1_"1678 Hveen:Hveen:1940 YH:1951 YD1:A919 GA" "Sol" #1=
#2_"*Вен:1678 Hveen:Hveen:1940 YH" "Sol" #2=
#3_"1940 YH:*Вен:1678 Hveen:Hveen" "Sol" #3=
".:Hveen:1678 Hveen:1940 YH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.93
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.612075200158
		SemiMajorAxis	3.157985898248
		Eccentricity	0.111413574942
		Inclination	10.197127338101
		AscendingNode	351.595271297323
		ArgOfPericenter	121.880131708153
		MeanAnomaly	45.488532976773
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0486
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1678"
}

#1_"1679 Nevanlinna:Nevanlinna:1941 FR:1930 FH:1952 DB3:1953 ND:1953 OK:1959 RT:1963 FH:1965 UB2: #1=
#1_1974 DD2" "Sol" #1=
#2_"*Неванлинна:1679 Nevanlinna:Nevanlinna:1941 FR" "Sol" #2=
#3_"1941 FR:*Неванлинна:1679 Nevanlinna:Nevanlinna" "Sol" #3=
".:Nevanlinna:1679 Nevanlinna:1941 FR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.505098928878
		SemiMajorAxis	3.117726040406
		Eccentricity	0.15298047711
		Inclination	17.974017050676
		AscendingNode	177.503562311792
		ArgOfPericenter	90.550122939008
		MeanAnomaly	56.879131682383
	}
	UniformRotation
	{
		Period	17.92
	}
	LunarLambert	0.5
	Albedo	0.0388
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1679"
}

#1_"1680 Per Brahe:Per Brahe:1942 CH:1934 PP:1937 AA:1937 AY:1938 JA:1943 PC:1949 XL:1952 OG:1953 VD1: #1=
#1_1960 FF:A902 JA" "Sol" #1=
#2_"*Пер Браге:1680 Per Brahe:Per Brahe:1942 CH" "Sol" #2=
#3_"1942 CH:*Пер Браге:1680 Per Brahe:Per Brahe" "Sol" #3=
".:Per Brahe:1680 Per Brahe:1942 CH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.498512021189
		SemiMajorAxis	2.725045692374
		Eccentricity	0.181385918804
		Inclination	4.260816265025
		AscendingNode	83.3581686343
		ArgOfPericenter	158.583137841309
		MeanAnomaly	359.172662722935
	}
	UniformRotation
	{
		Period	3.428
	}
	LunarLambert	0.5
	Albedo	0.2903
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1680"
}

#1_"1682 Karel:Karel:1949 PH:1929 SD:1939 RK:1946 WC:1949 QQ:1949 QX1:1949 SL:1959 PH:1988 CR3" "Sol" #1=
#2_"*Карел:1682 Karel:Karel:1949 PH" "Sol" #2=
#3_"1949 PH:*Карел:1682 Karel:Karel" "Sol" #3=
".:Karel:1682 Karel:1949 PH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1682 karel.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	3.634
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.349697538394
		SemiMajorAxis	2.238712175467
		Eccentricity	0.191822204741
		Inclination	4.027932572857
		AscendingNode	325.791269365075
		ArgOfPericenter	9.930278500322
		MeanAnomaly	231.039433806945
	}
	UniformRotation
	{
		Period	3.37485
	}
	LunarLambert	0.5
	Albedo	0.278
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1682"
}

#1_"1684 Iguassu:Iguassu:1951 QE:1934 LN:1935 SK1:1939 HK:1949 DE:1950 JT:1965 AA1:A922 DA" "Sol" #1=
#2_"*Игуасу:1684 Iguassu:Iguassu:1951 QE" "Sol" #2=
#3_"1951 QE:*Игуасу:1684 Iguassu:Iguassu" "Sol" #3=
".:Iguassu:1684 Iguassu:1951 QE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.449945315269
		SemiMajorAxis	3.096867527281
		Eccentricity	0.124528042033
		Inclination	3.666939549665
		AscendingNode	105.414510005787
		ArgOfPericenter	153.989655222932
		MeanAnomaly	292.791382117097
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1202
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1684"
}

#1_"1685 Toro:Toro:1948 OA" "Sol" #1=
#2_"*Торо:1685 Toro:Toro:1948 OA" "Sol" #2=
#3_"1948 OA:*Торо:1685 Toro:Toro" "Sol" #3=
".:Toro:1685 Toro:1948 OA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.598605529353
		SemiMajorAxis	1.367168590707
		Eccentricity	0.435909653698
		Inclination	9.381101011075
		AscendingNode	274.30235609199
		ArgOfPericenter	127.118389186155
		MeanAnomaly	137.567642943574
	}
	UniformRotation
	{
		Period	10.1995
	}
	LunarLambert	0.5
	Albedo	0.31
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1685"
}

#1_"1687 Glarona:Glarona:1965 SC:1926 UA:1931 RB1:1942 PD:1945 EA:1948 QN:1948 RD1:1954 TB:1954 UB2: #1=
#1_1959 PG:1960 XD:1965 UX:A909 UA:A915 XC" "Sol" #1=
#2_"*Гларона:1687 Glarona:Glarona:1965 SC" "Sol" #2=
#3_"1965 SC:*Гларона:1687 Glarona:Glarona" "Sol" #3=
".:Glarona:1687 Glarona:1965 SC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1687 glarona.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	18.925
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.614660973964
		SemiMajorAxis	3.158955855585
		Eccentricity	0.177101776429
		Inclination	2.636763876479
		AscendingNode	93.578719337541
		ArgOfPericenter	316.646639931194
		MeanAnomaly	247.219920960646
	}
	UniformRotation
	{
		Period	6.3
	}
	LunarLambert	0.5
	Albedo	0.141
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1687"
}

#1_"1690 Mayrhofer:Mayrhofer:1948 VB:1932 WN:1953 VC2:1956 GN" "Sol" #1=
#2_"*Майрхофер:1690 Mayrhofer:Mayrhofer:1948 VB" "Sol" #2=
#3_"1948 VB:*Майрхофер:1690 Mayrhofer:Mayrhofer" "Sol" #3=
".:Mayrhofer:1690 Mayrhofer:1948 VB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.855
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.292369570834
		SemiMajorAxis	3.036882397626
		Eccentricity	0.098642776431
		Inclination	13.05085135068
		AscendingNode	230.469656884878
		ArgOfPericenter	156.832726509694
		MeanAnomaly	197.697868061481
	}
	UniformRotation
	{
		Period	22.194
	}
	LunarLambert	0.5
	Albedo	0.0767
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1690"
}

#1_"1691 Oort:Oort:1956 RB:1945 TD:1947 DA:1950 PZ:1950 RU:1951 XW:1955 MW:1956 SD:1964 DA:A917 TD" "Sol" #1=
#2_"*Оорт:1691 Oort:Oort:1956 RB" "Sol" #2=
#3_"1956 RB:*Оорт:1691 Oort:Oort" "Sol" #3=
".:Oort:1691 Oort:1956 RB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1691 oort.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	16.822
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	5.641078146076
		SemiMajorAxis	3.168856765324
		Eccentricity	0.172689911929
		Inclination	1.082448287023
		AscendingNode	174.479827716982
		ArgOfPericenter	233.134741099356
		MeanAnomaly	99.783640606026
	}
	UniformRotation
	{
		Period	10.2705
	}
	LunarLambert	0.5
	Albedo	0.065
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1691"
}

#1_"1692 Subbotina:Subbotina:1936 QD:1927 SL:1930 FG:1931 OA:1935 GJ:1935 JJ:1940 LK:1941 SO1:1941 UA: #1=
#1_1949 HL1:1950 RZ:1951 YM1:1955 SO2:1964 RC" "Sol" #1=
#2_"*Субботина:1692 Subbotina:Subbotina:1936 QD" "Sol" #2=
#3_"1936 QD:*Субботина:1692 Subbotina:Subbotina" "Sol" #3=
".:Subbotina:1692 Subbotina:1936 QD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.295
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.651201886483
		SemiMajorAxis	2.786364909969
		Eccentricity	0.138063183301
		Inclination	2.427155683569
		AscendingNode	199.667019851035
		ArgOfPericenter	112.428363073137
		MeanAnomaly	310.162980791612
	}
	UniformRotation
	{
		Period	9.2457
	}
	LunarLambert	0.5
	Albedo	0.0479
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1692"
}

#1_"1693 Hertzsprung:Hertzsprung:1935 LA:1930 HG:1944 HA:1950 VM" "Sol" #1=
#2_"*Герцшпрунг:1693 Hertzsprung:Hertzsprung:1935 LA" "Sol" #2=
#3_"1935 LA:*Герцшпрунг:1693 Hertzsprung:Hertzsprung" "Sol" #3=
".:Hertzsprung:1693 Hertzsprung:1935 LA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.335
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.675605285194
		SemiMajorAxis	2.796102529637
		Eccentricity	0.273196726929
		Inclination	11.939970909575
		AscendingNode	69.995545306532
		ArgOfPericenter	235.046551715089
		MeanAnomaly	313.271972185527
	}
	UniformRotation
	{
		Period	8.825
	}
	LunarLambert	0.5
	Albedo	0.0484
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1693"
}

#1_"1695 Walbeck:Walbeck:1941 UO:1964 QA:1964 RE" "Sol" #1=
#2_"*Вальбек:1695 Walbeck:Walbeck:1941 UO" "Sol" #2=
#3_"1941 UO:*Вальбек:1695 Walbeck:Walbeck" "Sol" #3=
".:Walbeck:1695 Walbeck:1941 UO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.639080660108
		SemiMajorAxis	2.781521882703
		Eccentricity	0.291941813793
		Inclination	16.704606704149
		AscendingNode	218.466555070283
		ArgOfPericenter	139.486548083091
		MeanAnomaly	289.089100259798
	}
	UniformRotation
	{
		Period	5.1607
	}
	LunarLambert	0.5
	Albedo	0.0504
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1695"
}

#1_"1698 Christophe:Christophe:1934 CS:1935 HA:1940 FC:1951 EH1:1962 AD:1965 UE1:1973 CC" "Sol" #1=
#2_"*Кристоф:1698 Christophe:Christophe:1934 CS" "Sol" #2=
#3_"1934 CS:*Кристоф:1698 Christophe:Christophe" "Sol" #3=
".:Christophe:1698 Christophe:1934 CS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.49
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.638706031341
		SemiMajorAxis	3.167968351378
		Eccentricity	0.101530457979
		Inclination	1.496838562403
		AscendingNode	27.246109803217
		ArgOfPericenter	128.84444137446
		MeanAnomaly	129.749566061502
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0938
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1698"
}

#1_"1700 Zvezdara:Zvezdara:1940 QC:1929 PM:1951 SB:1951 SO:1955 XP:1962 WJ" "Sol" #1=
#2_"*Звездара:1700 Zvezdara:Zvezdara:1940 QC" "Sol" #2=
#3_"1940 QC:*Звездара:1700 Zvezdara:Zvezdara" "Sol" #3=
".:Zvezdara:1700 Zvezdara:1940 QC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.62758846922
		SemiMajorAxis	2.360876161552
		Eccentricity	0.225756104329
		Inclination	4.515159881048
		AscendingNode	356.968386364322
		ArgOfPericenter	15.414355723996
		MeanAnomaly	148.701779510614
	}
	UniformRotation
	{
		Period	9.114
	}
	LunarLambert	0.5
	Albedo	0.0425
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1700"
}

#1_"1701 Okavango:Okavango:1953 NJ:1931 TU2" "Sol" #1=
#2_"*Окаванго:1701 Okavango:Okavango:1953 NJ" "Sol" #2=
#3_"1953 NJ:*Окаванго:1701 Okavango:Okavango" "Sol" #3=
".:Okavango:1701 Okavango:1953 NJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.624939399413
		SemiMajorAxis	3.162809955167
		Eccentricity	0.191098207634
		Inclination	16.27614906878
		AscendingNode	61.276712153342
		ArgOfPericenter	260.243807710658
		MeanAnomaly	282.324678267112
	}
	UniformRotation
	{
		Period	13.204
	}
	LunarLambert	0.5
	Albedo	0.2141
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1701"
}

#1_"1702 Kalahari:Kalahari:A924 NC:1948 NE:1953 OE:1962 JN:1964 YM" "Sol" #1=
#2_"*Калахари:1702 Kalahari:Kalahari:1924 NC" "Sol" #2=
#3_"1924 NC:*Калахари:1702 Kalahari:Kalahari" "Sol" #3=
".:Kalahari:1702 Kalahari:1924 NC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.825898179766
		SemiMajorAxis	2.855704734544
		Eccentricity	0.143480585056
		Inclination	9.964808697188
		AscendingNode	103.884431879104
		ArgOfPericenter	242.429203016317
		MeanAnomaly	223.515782374581
	}
	UniformRotation
	{
		Period	21.153
	}
	LunarLambert	0.5
	Albedo	0.064
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1702"
}

#1_"1703 Barry:Barry:1930 RB:1939 FD:1940 TP:1943 PA:1953 PK:1963 SB" "Sol" #1=
#2_"*Барри:1703 Barry:Barry:1930 RB" "Sol" #2=
#3_"1930 RB:*Барри:1703 Barry:Barry" "Sol" #3=
".:Barry:1703 Barry:1930 RB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1703 barry.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	4.606
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.296152680846
		SemiMajorAxis	2.214790976461
		Eccentricity	0.171768001193
		Inclination	4.519509515175
		AscendingNode	112.289550067128
		ArgOfPericenter	213.481083479893
		MeanAnomaly	215.943444710231
	}
	UniformRotation
	{
		Period	107.1
	}
	LunarLambert	0.5
	Albedo	0.33
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1703"
}

#1_"1704 Wachmann:Wachmann:A924 EE:1947 CE:1957 BJ" "Sol" #1=
#2_"*Вахман:1704 Wachmann:Wachmann:1924 EE" "Sol" #2=
#3_"1924 EE:*Вахман:1704 Wachmann:Wachmann" "Sol" #3=
".:Wachmann:1704 Wachmann:1924 EE" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"1704 wachmann.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.309
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.31442217837
		SemiMajorAxis	2.222967343473
		Eccentricity	0.086775744209
		Inclination	0.970821209349
		AscendingNode	259.53645676481
		ArgOfPericenter	280.928597504828
		MeanAnomaly	188.918156459472
	}
	UniformRotation
	{
		Period	3.314
	}
	LunarLambert	0.5
	Albedo	0.193
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1704"
}

#1_"1705 Tapio:Tapio:1941 SL1:1948 TJ1:1948 TV1:1955 VN:1982 FM3" "Sol" #1=
#2_"*Тапио:1705 Tapio:Tapio:1941 SL1" "Sol" #2=
#3_"1941 SL1:*Тапио:1705 Tapio:Tapio" "Sol" #3=
".:Tapio:1705 Tapio:1941 SL1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.485843867442
		SemiMajorAxis	2.298969197526
		Eccentricity	0.245887192663
		Inclination	7.703680149955
		AscendingNode	188.641873554058
		ArgOfPericenter	156.066988507154
		MeanAnomaly	13.459143438864
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1175
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1705"
}

#1_"1708 Polit:Polit:1929 XA:1934 XF:1939 YB" "Sol" #1=
#2_"*Полит:1708 Polit:Polit:1929 XA" "Sol" #2=
#3_"1929 XA:*Полит:1708 Polit:Polit" "Sol" #3=
".:Polit:1708 Polit:1929 XA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.973642974277
		SemiMajorAxis	2.913696214519
		Eccentricity	0.306821136101
		Inclination	6.038714861167
		AscendingNode	192.237099154368
		ArgOfPericenter	249.19383698851
		MeanAnomaly	14.863034068542
	}
	UniformRotation
	{
		Period	7.52
	}
	LunarLambert	0.5
	Albedo	0.0392
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1708"
}

#1_"1709 Ukraina:Ukraina:1925 QA:1936 QH" "Sol" #1=
#2_"*Украина:1709 Ukraina:Ukraina:1925 QA" "Sol" #2=
#3_"1925 QA:*Украина:1709 Ukraina:Ukraina" "Sol" #3=
".:Ukraina:1709 Ukraina:1925 QA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1709 ukraina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.722
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.672188926638
		SemiMajorAxis	2.380187716589
		Eccentricity	0.212837242294
		Inclination	7.560007448229
		AscendingNode	300.14247649082
		ArgOfPericenter	42.333850679612
		MeanAnomaly	167.870179832457
	}
	UniformRotation
	{
		Period	7.28
	}
	LunarLambert	0.5
	Albedo	0.196
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1709"
}

#1_"1712 Angola:Angola:1935 KC:1929 GC:1935 ML:1946 JB:1953 SD:1963 MD" "Sol" #1=
#2_"*Ангола:1712 Angola:Angola:1935 KC" "Sol" #2=
#3_"1935 KC:*Ангола:1712 Angola:Angola" "Sol" #3=
".:Angola:1712 Angola:1935 KC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.74
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.635743258994
		SemiMajorAxis	3.166858546975
		Eccentricity	0.151854843662
		Inclination	19.38734392319
		AscendingNode	237.627806894652
		ArgOfPericenter	18.209980198787
		MeanAnomaly	15.507968091634
	}
	UniformRotation
	{
		Period	11.527
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1712"
}

#1_"1714 Sy:Sy:1951 OA:1949 YM:1950 DE1:1951 NM" "Sol" #1=
#2_"*Си:1714 Sy:Sy:1951 OA" "Sol" #2=
#3_"1951 OA:*Си:1714 Sy:Sy" "Sol" #3=
".:Sy:1714 Sy:1951 OA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.112058592549
		SemiMajorAxis	2.566654398911
		Eccentricity	0.155040391063
		Inclination	7.980312922868
		AscendingNode	300.96210155643
		ArgOfPericenter	321.023089502134
		MeanAnomaly	170.635782991738
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1088
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1714"
}

#1_"1715 Salli:Salli:1938 GK:1942 LF:1953 JA:A912 HG" "Sol" #1=
#2_"*Салли:1715 Salli:Salli:1938 GK" "Sol" #2=
#3_"1938 GK:*Салли:1715 Salli:Salli" "Sol" #3=
".:Salli:1715 Salli:1938 GK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1715 salli.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	12.082
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.712687242617
		SemiMajorAxis	2.397655459748
		Eccentricity	0.241594720469
		Inclination	11.470828729805
		AscendingNode	38.998002400046
		ArgOfPericenter	209.20973176
		MeanAnomaly	193.589825094383
	}
	UniformRotation
	{
		Period	11.087
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1715"
}

#1_"1716 Peter:Peter:1934 GF:1930 KB:1932 YJ:1948 JJ:1957 HZ" "Sol" #1=
#2_"*Питер:1716 Peter:Peter:1934 GF" "Sol" #2=
#3_"1934 GF:*Питер:1716 Peter:Peter" "Sol" #3=
".:Peter:1716 Peter:1934 GF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1716 peter.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	13.328
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.523655748451
		SemiMajorAxis	2.735190400244
		Eccentricity	0.091223654048
		Inclination	5.733700638899
		AscendingNode	243.744013338241
		ArgOfPericenter	315.433888349679
		MeanAnomaly	287.496984869665
	}
	UniformRotation
	{
		Period	11.514
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1716"
}

#1_"1719 Jens:Jens:1950 DP:1939 PP:1939 TD:1941 BB:1948 RQ:1948 RS1:1948 TS1:1961 TZ1:A922 SC" "Sol" #1=
#2_"*Енс:1719 Jens:Jens:1950 DP" "Sol" #2=
#3_"1950 DP:*Енс:1719 Jens:Jens" "Sol" #3=
".:Jens:1719 Jens:1950 DP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1719 jens.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	10.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.336795319033
		SemiMajorAxis	2.659339690869
		Eccentricity	0.220644066111
		Inclination	14.284102652121
		AscendingNode	323.461636116309
		ArgOfPericenter	58.196339617518
		MeanAnomaly	93.932114047286
	}
	UniformRotation
	{
		Period	5.87
	}
	LunarLambert	0.5
	Albedo	0.085
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1719"
}

#1_"1721 Wells:Wells:1953 TD3:1944 DA:1958 QE:A905 CG" "Sol" #1=
#2_"*Уэллс:1721 Wells:Wells:1953 TD3" "Sol" #2=
#3_"1953 TD3:*Уэллс:1721 Wells:Wells" "Sol" #3=
".:Wells:1721 Wells:1953 TD3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.015
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.584593835098
		SemiMajorAxis	3.147668057524
		Eccentricity	0.045737421348
		Inclination	16.1261999752
		AscendingNode	317.350347973782
		ArgOfPericenter	135.575249808093
		MeanAnomaly	287.056335394129
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0528
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1721"
}

#1_"1723 Klemola:Klemola:1936 FX:1929 WE1:1931 FB:1936 DJ:1941 BF:1942 HK:1947 GG:1949 UZ:1955 XT: #1=
#1_1957 DE:1957 DF:1958 LB:1959 PC:1964 PF:1965 TC:1968 KV:A913 UF:A915 CD:A916 KB" "Sol" #1=
#2_"*Клемола:1723 Klemola:Klemola:1936 FX" "Sol" #2=
#3_"1936 FX:*Клемола:1723 Klemola:Klemola" "Sol" #3=
".:Klemola:1723 Klemola:1936 FX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1723 klemola.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	16.724
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.22990165875
		SemiMajorAxis	3.012938129624
		Eccentricity	0.042976446285
		Inclination	10.935636004291
		AscendingNode	149.829218737946
		ArgOfPericenter	1.166195374287
		MeanAnomaly	22.862986083381
	}
	UniformRotation
	{
		Period	6.2545
	}
	LunarLambert	0.5
	Albedo	0.156
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1723"
}

#1_"1724 Vladimir:Vladimir:1932 DC:1932 ED1:1934 TB:1952 UV1:1961 VK:1965 SE" "Sol" #1=
#2_"*Владимир:1724 Vladimir:Vladimir:1932 DC" "Sol" #2=
#3_"1932 DC:*Владимир:1724 Vladimir:Vladimir" "Sol" #3=
".:Vladimir:1724 Vladimir:1932 DC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.395
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.4654567403411
		SemiMajorAxis	2.711680113226163
		Eccentricity	0.05589776750905965
		Inclination	12.23879658373486
		AscendingNode	164.0545872445951
		ArgOfPericenter	297.7861149809904
		MeanAnomaly	259.7952266105837
	}
	UniformRotation
	{
		Period	12.582
	}
	LunarLambert	0.5
	Albedo	0.0441
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1724"
}

#1_"1726 Hoffmeister:Hoffmeister:1933 OE:1955 FC:1955 HX:1957 WD:A924 UA" "Sol" #1=
#2_"*Хоффмейстер:1726 Hoffmeister:Hoffmeister:1933 OE" "Sol" #2=
#3_"1933 OE:*Хоффмейстер:1726 Hoffmeister:Hoffmeister" "Sol" #3=
".:Hoffmeister:1726 Hoffmeister:1933 OE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.135
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.660546833833
		SemiMajorAxis	2.790095805426
		Eccentricity	0.041671606629
		Inclination	3.480446239123
		AscendingNode	231.11657882837
		ArgOfPericenter	66.684418270183
		MeanAnomaly	192.579260734157
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.037
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1726"
}

#1_"1730 Marceline:Marceline:1936 UA:1931 RE:1950 WF:1952 DR2:1954 QA:1971 JC" "Sol" #1=
#2_"*Марселине:1730 Marceline:Marceline:1936 UA" "Sol" #2=
#3_"1936 UA:Marceline:*Марселине:1730 Marceline" "Sol" #3=
".:Marceline:1730 Marceline:1936 UA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1730 marceline.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.602
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.649998268996
		SemiMajorAxis	2.785884193762
		Eccentricity	0.223036539005
		Inclination	9.515940703519
		AscendingNode	171.458598157864
		ArgOfPericenter	225.169742236376
		MeanAnomaly	104.72868038555
	}
	UniformRotation
	{
		Period	3.837
	}
	LunarLambert	0.5
	Albedo	0.192
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1730"
}

#1_"1731 Smuts:Smuts:1948 PH:1926 TF:1931 QA:1935 FS:1938 YB:1941 KG:1947 LC:1948 PP:1954 SX: #1=
#1_1960 WE:1966 UY" "Sol" #1=
#2_"*Смэтс:1731 Smuts:Smuts:1948 PH" "Sol" #2=
#3_"1948 PH:*Смэтс:1731 Smuts:Smuts" "Sol" #3=
".:Smuts:1731 Smuts:1948 PH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.035
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.633638692306
		SemiMajorAxis	3.166070093755
		Eccentricity	0.127004318603
		Inclination	5.93328299847
		AscendingNode	152.490099852084
		ArgOfPericenter	204.04665388916
		MeanAnomaly	225.897042578024
	}
	UniformRotation
	{
		Period	12.5
	}
	LunarLambert	0.5
	Albedo	0.0604
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1731"
}

#1_"1732 Heike:Heike:1943 EY:1934 LC:1935 TD:1938 FC:1938 GB:1950 NR1:1951 WW:1960 ME:1961 TU1: #1=
#1_1966 QJ:1971 QY1:A906 FA:A924 PB" "Sol" #1=
#2_"*Хайке:1732 Heike:Heike:1943 EY" "Sol" #2=
#3_"1943 EY:*Хайке:1732 Heike:Heike" "Sol" #3=
".:Heike:1732 Heike:1943 EY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.03
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.228983785031
		SemiMajorAxis	3.012585595573
		Eccentricity	0.11025896816
		Inclination	10.789449991913
		AscendingNode	155.724528165827
		ArgOfPericenter	209.033742145424
		MeanAnomaly	63.50035402243
	}
	UniformRotation
	{
		Period	4.742
	}
	LunarLambert	0.5
	Albedo	0.1108
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1732"
}

#1_"1733 Silke:Silke:1938 DL1:1935 FB:1951 AA:1951 AX:1951 CE:1951 CR:1964 DB" "Sol" #1=
#2_"*Зильке:1733 Silke:Silke:1938 DL1" "Sol" #2=
#3_"1938 DL1:Silke:*Зильке:1733 Silke" "Sol" #3=
".:Silke:1733 Silke:1938 DL1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1733 silke.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.358
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.246803859323
		SemiMajorAxis	2.192629405538
		Eccentricity	0.083992358096
		Inclination	4.430287475724
		AscendingNode	159.373651690843
		ArgOfPericenter	306.738687838216
		MeanAnomaly	145.640823378504
	}
	UniformRotation
	{
		Period	7.8946
	}
	LunarLambert	0.5
	Albedo	0.247
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1733"
}

#1_"1734 Zhongolovich:Zhongolovich:1928 TJ:1937 RO:1942 XQ:1951 RM1:1965 UG" "Sol" #1=
#2_"*Жонголович:1734 Zhongolovich:Zhongolovich:1928 TJ" "Sol" #2=
#3_"1928 TJ:*Жонголович:1734 Zhongolovich:Zhongolovich" "Sol" #3=
".:Zhongolovich:1734 Zhongolovich:1928 TJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.62543311024
		SemiMajorAxis	2.77606396285
		Eccentricity	0.23150016807
		Inclination	8.346867339776
		AscendingNode	182.167917832331
		ArgOfPericenter	186.59969508
		MeanAnomaly	230.22340525798
	}
	UniformRotation
	{
		Period	7.171
	}
	LunarLambert	0.5
	Albedo	0.0456
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1734"
}

#1_"1735 ITA:ITA:1948 RJ1:1929 DA:1931 RF1:1934 BC:1935 GC:1937 TN:1948 TB1:1948 TK:1951 DL:1951 EY: #1=
#1_1952 HN2:1952 JB:A907 GC" "Sol" #1=
#2_"*ИТА:1735 ITA:ITA:1948 RJ1" "Sol" #2=
#3_"1948 RJ1:*ИТА:1735 ITA:ITA" "Sol" #3=
".:ITA:1735 ITA:1948 RJ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1735 ita.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	30.932
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.563461502014
		SemiMajorAxis	3.139722437439
		Eccentricity	0.129996847318
		Inclination	15.606060299667
		AscendingNode	9.343696481798
		ArgOfPericenter	276.277983691276
		MeanAnomaly	20.85637730035
	}
	UniformRotation
	{
		Period	12.599
	}
	LunarLambert	0.5
	Albedo	0.051
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1735"
}

#1_"1737 Severny:Severny:1966 TJ:1942 CA:1944 OF:1950 TM:1950 TP4:1951 YF2:1963 DH" "Sol" #1=
#2_"*Северный:1737 Severny:Severny:1966 TJ" "Sol" #2=
#3_"1966 TJ:*Северный:1737 Severny:Severny" "Sol" #3=
".:Severny:1737 Severny:1966 TJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.229266625676
		SemiMajorAxis	3.012694230317
		Eccentricity	0.050340872693
		Inclination	9.381129608837
		AscendingNode	327.461658505135
		ArgOfPericenter	223.235115301608
		MeanAnomaly	282.593167685371
	}
	UniformRotation
	{
		Period	14.11
	}
	LunarLambert	0.5
	Albedo	0.1811
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1737"
}

#1_"1738 Oosterhoff:Oosterhoff:1930 SP:1927 UF:1939 GO:1942 FD:1943 TO:1946 OG:1949 JE:1949 KH: #1=
#1_1952 HV:1952 JJ:1959 RB1:2016 FC6" "Sol" #1=
#2_"*Устерхофф:1738 Oosterhoff:Oosterhoff:1930 SP" "Sol" #2=
#3_"1930 SP:Oosterhoff:*Устерхофф:1738 Oosterhoff" "Sol" #3=
".:Oosterhoff:1738 Oosterhoff:1930 SP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1738 oosterhoff.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.944
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.226615717137
		SemiMajorAxis	2.183530998681
		Eccentricity	0.202466985992
		Inclination	4.877396430037
		AscendingNode	44.111748877905
		ArgOfPericenter	284.406625270575
		MeanAnomaly	295.447904281615
	}
	UniformRotation
	{
		Period	4.4486
	}
	LunarLambert	0.5
	Albedo	0.341
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1738"
}

#1_"1742 Schaifers:Schaifers:1934 RO:1929 RL1:1952 HG:1954 UG2:1954 WV:1963 QB:1964 VX" "Sol" #1=
#2_"*Шайферс:1742 Schaifers:Schaifers:1934 RO" "Sol" #2=
#3_"1934 RO:*Шайферс:1742 Schaifers:Schaifers" "Sol" #3=
".:Schaifers:1742 Schaifers:1934 RO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1742 schaifers.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.354
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.920856931178
		SemiMajorAxis	2.893043902458
		Eccentricity	0.093469068812
		Inclination	2.494070124014
		AscendingNode	152.18833164649
		ArgOfPericenter	213.757386177101
		MeanAnomaly	115.816935023101
	}
	UniformRotation
	{
		Period	8.56
	}
	LunarLambert	0.5
	Albedo	0.113
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1742"
}

#1_"1743 Schmidt:Schmidt:4109 P-L:1931 BJ:1939 CN:1943 EA:1947 GD:1951 JU:1952 QD" "Sol" #1=
#2_"*Шмидт:1743 Schmidt:Schmidt:1960-1743*:4109 P-L" "Sol" #2=
#3_"1960-1743*:*Шмидт:1743 Schmidt:Schmidt:4109 P-L" "Sol" #3=
".:Schmidt:1743 Schmidt:1960-1743*:4109 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1743 schmidt.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	9.669
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.890835777818
		SemiMajorAxis	2.473753750456
		Eccentricity	0.134529194661
		Inclination	6.356103868481
		AscendingNode	189.641486074643
		ArgOfPericenter	359.739562850364
		MeanAnomaly	156.705947552692
	}
	UniformRotation
	{
		Period	17.45
	}
	LunarLambert	0.5
	Albedo	0.057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1743"
}

#1_"1746 Brouwer:Brouwer:1963 RF:1940 WE:1947 QA" "Sol" #1=
#2_"*Брауэр:1746 Brouwer:Brouwer:1963 RF" "Sol" #2=
#3_"1963 RF:*Брауэр:1746 Brouwer:Brouwer" "Sol" #3=
".:Brouwer:1746 Brouwer:1963 RF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1746 brouwer.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	31.262
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.852176930997
		SemiMajorAxis	3.950522895108
		Eccentricity	0.206249181071
		Inclination	8.367877432582
		AscendingNode	321.999944353827
		ArgOfPericenter	47.654759770772
		MeanAnomaly	166.184432660539
	}
	UniformRotation
	{
		Period	19.8
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1746"
}

#1_"1747 Wright:Wright:1947 NH" "Sol" #1=
#2_"*Райт:1747 Wright:Wright:1947 NH" "Sol" #2=
#3_"1947 NH:*Райт:1747 Wright:Wright" "Sol" #3=
".:Wright:1747 Wright:1947 NH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1747 wright.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.175
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.234477840637
		SemiMajorAxis	1.709143652967
		Eccentricity	0.110379625192
		Inclination	21.41675454736
		AscendingNode	268.406468954035
		ArgOfPericenter	340.438833591241
		MeanAnomaly	93.495497108096
	}
	UniformRotation
	{
		Period	5.2896
	}
	LunarLambert	0.5
	Albedo	0.2005
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1747"
}

#1_"1749 Telamon:Telamon:1949 SB:1941 BP:1966 CN" "Sol" #1=
#2_"*Теламон:1749 Telamon:Telamon:1949 SB" "Sol" #2=
#3_"1949 SB:*Теламон:1749 Telamon:Telamon" "Sol" #3=
".:Telamon:1749 Telamon:1949 SB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.53
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.681269164277
		SemiMajorAxis	5.148189833636
		Eccentricity	0.107918980227
		Inclination	6.094452091544
		AscendingNode	340.93472926952
		ArgOfPericenter	113.26919877937
		MeanAnomaly	87.991170606143
	}
	UniformRotation
	{
		Period	16.975
	}
	LunarLambert	0.5
	Albedo	0.0562
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1749"
}

#1_"1750 Eckert:Eckert:1950 NA1:1950 OA" "Sol" #1=
#2_"*Экерт:1750 Eckert:Eckert:1950 NA1" "Sol" #2=
#3_"1950 NA1:Eckert:*Экерт:1750 Eckert" "Sol" #3=
".:Eckert:1750 Eckert:1950 NA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1750 eckert.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.926
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.67345885929
		SemiMajorAxis	1.926239134782
		Eccentricity	0.172929962778
		Inclination	19.084883654458
		AscendingNode	273.759100840408
		ArgOfPericenter	109.02312770315
		MeanAnomaly	272.242209716038
	}
	UniformRotation
	{
		Period	375
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1750"
}

#1_"1753 Mieke:Mieke:1934 JM:1951 SM:1951 VB:1967 UG" "Sol" #1=
#2_"*Мик:1753 Mieke:Mieke:1934 JM" "Sol" #2=
#3_"1934 JM:Mieke:*Мик:1753 Mieke" "Sol" #3=
".:Mieke:1753 Mieke:1934 JM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1753 mieke.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.722
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.238882393988
		SemiMajorAxis	3.016386334865
		Eccentricity	0.081644344502
		Inclination	11.361068077477
		AscendingNode	58.464022503704
		ArgOfPericenter	229.815940300638
		MeanAnomaly	251.725757921186
	}
	UniformRotation
	{
		Period	8.8
	}
	LunarLambert	0.5
	Albedo	0.144
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1753"
}

#1_"1754 Cunningham:Cunningham:1935 FE:1938 RE:1943 GH:1951 FB:1952 HO1:1952 KB1:1954 UD1:1962 TG: #1=
#1_1967 EE:1968 KR:1969 PJ:A904 JB" "Sol" #1=
#2_"*Каннингем:1754 Cunningham:Cunningham:1935 FE" "Sol" #2=
#3_"1935 FE:*Каннингем:1754 Cunningham:Cunningham" "Sol" #3=
".:Cunningham:1754 Cunningham:1935 FE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	39.76
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.8139656298892
		SemiMajorAxis	3.937696106705617
		Eccentricity	0.1686989981800635
		Inclination	12.15347735204861
		AscendingNode	162.9051674773689
		ArgOfPericenter	109.5383044546324
		MeanAnomaly	315.816292376892
	}
	UniformRotation
	{
		Period	4.285
	}
	LunarLambert	0.5
	Albedo	0.0345
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1754"
}

#1_"1755 Lorbach:Lorbach:1936 VD:1935 QA1:1936 UK:1949 ED:1956 NA:1960 EA:1965 AV:A924 PA" "Sol" #1=
#2_"*Лорбах:1755 Lorbach:Lorbach:1936 VD" "Sol" #2=
#3_"1936 VD:*Лорбах:1755 Lorbach:Lorbach" "Sol" #3=
".:Lorbach:1755 Lorbach:1936 VD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.43265793721
		SemiMajorAxis	3.090315160245
		Eccentricity	0.048478052258
		Inclination	10.70816396657
		AscendingNode	157.108528766627
		ArgOfPericenter	322.227963082875
		MeanAnomaly	59.608422872897
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1117
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1755"
}

#1_"1758 Naantali:Naantali:1942 DK:1959 NL:1963 FD:1966 WB:1968 CC" "Sol" #1=
#2_"*Наантали:1758 Naantali:Naantali:1942 DK" "Sol" #2=
#3_"1942 DK:Naantali:*Наантали:1758 Naantali" "Sol" #3=
".:Naantali:1758 Naantali:1942 DK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1758 naantali.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	12.092
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.213162947982
		SemiMajorAxis	3.006505932125
		Eccentricity	0.031390313038
		Inclination	10.82310025722
		AscendingNode	113.707465675746
		ArgOfPericenter	113.20407704247
		MeanAnomaly	76.052506376103
	}
	UniformRotation
	{
		Period	5.4699
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1758"
}

#1_"1760 Sandra:Sandra:1950 GB:1934 NP:1935 QH:1950 HF:1950 JM:1951 OK:1967 JC:1968 OC" "Sol" #1=
#2_"*Сандра:1760 Sandra:Sandra:1950 GB" "Sol" #2=
#3_"1950 GB:*Сандра:1760 Sandra:Sandra" "Sol" #3=
".:Sandra:1760 Sandra:1950 GB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.945
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.581044223996
		SemiMajorAxis	3.146334128056
		Eccentricity	0.128337383877
		Inclination	8.434667704112
		AscendingNode	232.655541033019
		ArgOfPericenter	333.3643967435
		MeanAnomaly	189.20179076377
	}
	UniformRotation
	{
		Period	6.5668
	}
	LunarLambert	0.5
	Albedo	0.0345
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1760"
}

#1_"1764 Cogshall:Cogshall:1953 VM1:1935 MF:1939 CC:1942 VB:1951 LC:1952 SM:1953 XJ:1964 XG:1967 GO: #1=
#1_1969 TN2" "Sol" #1=
#2_"*Когшалл:1764 Cogshall:Cogshall:1953 VM1" "Sol" #2=
#3_"1953 VM1:*Когшалл:1764 Cogshall:Cogshall" "Sol" #3=
".:Cogshall:1764 Cogshall:1953 VM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.105
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.448583217979
		SemiMajorAxis	3.096351508575
		Eccentricity	0.122687538756
		Inclination	2.231827782141
		AscendingNode	152.241266625092
		ArgOfPericenter	79.367621699
		MeanAnomaly	264.287889983448
	}
	UniformRotation
	{
		Period	3.6242
	}
	LunarLambert	0.5
	Albedo	0.0852
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1764"
}

#1_"1765 Wrubel:Wrubel:1957 XB:1938 JB:1945 VA:1949 HK1:1951 XB1:1955 KQ:1966 KA:A906 XA:A917 XA" "Sol" #1=
#2_"*Рубель:1765 Wrubel:Wrubel:1957 XB" "Sol" #2=
#3_"1957 XB:*Рубель:1765 Wrubel:Wrubel" "Sol" #3=
".:Wrubel:1765 Wrubel:1957 XB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	21.165
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.67333645838
		SemiMajorAxis	3.180925946646
		Eccentricity	0.175392898578
		Inclination	19.936540983243
		AscendingNode	70.600372302323
		ArgOfPericenter	263.990370641255
		MeanAnomaly	141.508756140936
	}
	UniformRotation
	{
		Period	5.26
	}
	LunarLambert	0.5
	Albedo	0.1061
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1765"
}

#1_"1768 Appenzella:Appenzella:1965 SA:1934 PM:1942 TH" "Sol" #1=
#2_"*Аппенцелла:1768 Appenzella:Appenzella:1965 SA" "Sol" #2=
#3_"1965 SA:*Аппенцелла:1768 Appenzella:Appenzella" "Sol" #3=
".:Appenzella:1768 Appenzella:1965 SA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1768 appenzella.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	10.11
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.835991875922
		SemiMajorAxis	2.450452664486
		Eccentricity	0.179202254856
		Inclination	3.260997910142
		AscendingNode	12.423963157082
		ArgOfPericenter	19.383802807142
		MeanAnomaly	279.166374012421
	}
	UniformRotation
	{
		Period	5.1839
	}
	LunarLambert	0.5
	Albedo	0.032
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1768"
}

#1_"1771 Makover:Makover:1968 BD:1937 LM:1938 QJ:1941 FH:1950 XW:1952 FU:1958 HF:1961 XV:1966 UC" "Sol" #1=
#2_"*Маковер:1771 Makover:Makover:1968 BD" "Sol" #2=
#3_"1968 BD:*Маковер:1771 Makover:Makover" "Sol" #3=
".:Makover:1771 Makover:1968 BD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.36
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.518447186175
		SemiMajorAxis	3.122763722761
		Eccentricity	0.176032829278
		Inclination	11.249984275052
		AscendingNode	86.349968602092
		ArgOfPericenter	316.790752179938
		MeanAnomaly	240.30706770996
	}
	UniformRotation
	{
		Period	11.26
	}
	LunarLambert	0.5
	Albedo	0.0501
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1771"
}

#1_"1772 Gagarin:Gagarin:1968 CB:1940 GA:1942 VZ:1948 ET:1960 FH:1969 OO" "Sol" #1=
#2_"*Гагарин:1772 Gagarin:Gagarin:1968 CB" "Sol" #2=
#3_"1968 CB:Gagarin:*Гагарин:1772 Gagarin" "Sol" #3=
".:Gagarin:1772 Gagarin:1968 CB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1772 gagarin.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.419
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.017699320319
		SemiMajorAxis	2.527238056976
		Eccentricity	0.105277544617
		Inclination	5.741846980642
		AscendingNode	88.182325472993
		ArgOfPericenter	93.531976385513
		MeanAnomaly	41.172800675621
	}
	UniformRotation
	{
		Period	10.96
	}
	LunarLambert	0.5
	Albedo	0.164
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1772"
}

#1_"1774 Kulikov:Kulikov:1968 UG1:1931 DC:1953 TQ1:1953 VX" "Sol" #1=
#2_"*Куликов:1774 Kulikov:Kulikov:1968 UG1" "Sol" #2=
#3_"1968 UG1:Kulikov:*Куликов:1774 Kulikov" "Sol" #3=
".:Kulikov:1774 Kulikov:1968 UG1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1774 kulikov.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.274
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.87943986148
		SemiMajorAxis	2.87678791064
		Eccentricity	0.069784132356
		Inclination	1.855636189311
		AscendingNode	175.179647847528
		ArgOfPericenter	250.622638459855
		MeanAnomaly	349.146433699521
	}
	UniformRotation
	{
		Period	3.830791
	}
	LunarLambert	0.5
	Albedo	0.159
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1774"
}

#1_"1776 Kuiper:Kuiper:2520 P-L:1930 EB:1931 KK:1938 SU:1952 DQ2:1963 FJ" "Sol" #1=
#2_"*Койпер:1776 Kuiper:Kuiper:1960-1776*:2520 P-L" "Sol" #2=
#3_"1960-1776*:*Койпер:1776 Kuiper:Kuiper:2520 P-L" "Sol" #3=
".:Kuiper:1776 Kuiper:1960-1776*:2520 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.98
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.469637813825
		SemiMajorAxis	3.104323062829
		Eccentricity	0.013303839037
		Inclination	9.491719817565
		AscendingNode	176.682366901231
		ArgOfPericenter	302.709959160869
		MeanAnomaly	220.225186092853
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0544
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1776"
}

#1_"1780 Kippes:Kippes:A906 RA:1935 CC:1938 UC1:1943 TL:1943 VD:1947 NB:1951 ED2:1953 SA:1957 LD: #1=
#1_1962 JU:1969 RB2:1975 VL6:A911 QE" "Sol" #1=
#2_"*Киппэс:1780 Kippes:Kippes:1906 RA" "Sol" #2=
#3_"1906 RA:*Киппэс:1780 Kippes:Kippes" "Sol" #3=
".:Kippes:1780 Kippes:1906 RA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.23598053085
		SemiMajorAxis	3.015272363356
		Eccentricity	0.053250162311
		Inclination	9.003766531965
		AscendingNode	291.00496001137
		ArgOfPericenter	340.298322838512
		MeanAnomaly	319.719910649366
	}
	UniformRotation
	{
		Period	18
	}
	LunarLambert	0.5
	Albedo	0.1212
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1780"
}

#1_"1783 Albitskij:Albitskij:1935 FJ:1933 TB:1952 BP1:1952 DP:1970 GA1" "Sol" #1=
#2_"*Альбицкий:1783 Albitskij:Albitskij:1935 FJ" "Sol" #2=
#3_"1935 FJ:*Альбицкий:1783 Albitskij:Albitskij" "Sol" #3=
".:Albitskij:1783 Albitskij:1935 FJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.68
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.346294193647
		SemiMajorAxis	2.663221439175
		Eccentricity	0.131374762945
		Inclination	11.5031909889
		AscendingNode	189.513002423214
		ArgOfPericenter	315.667852528487
		MeanAnomaly	156.856071342262
	}
	UniformRotation
	{
		Period	12
	}
	LunarLambert	0.5
	Albedo	0.0738
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1783"
}

#1_"1784 Benguella:Benguella:1935 MG:1938 EX:1950 ON:1950 QP:1951 YQ:1953 FT:1957 JF:1957 MH:1968 HY: #1=
#1_1969 UU1" "Sol" #1=
#2_"*Бенгуелла:1784 Benguella:Benguella:1935 MG" "Sol" #2=
#3_"1935 MG:*Бенгуелла:1784 Benguella:Benguella" "Sol" #3=
".:Benguella:1784 Benguella:1935 MG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.727432839527
		SemiMajorAxis	2.403999741186
		Eccentricity	0.133782456893
		Inclination	1.472802639506
		AscendingNode	95.280386745605
		ArgOfPericenter	184.788904067488
		MeanAnomaly	111.307589055869
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0763
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1784"
}

#1_"1785 Wurm:Wurm:1941 CD:1931 DR:1951 CH" "Sol" #1=
#2_"*Вурм:1785 Wurm:Wurm:1941 CD" "Sol" #2=
#3_"1941 CD:*Вурм:1785 Wurm:Wurm" "Sol" #3=
".:Wurm:1785 Wurm:1941 CD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1785 wurm.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.346
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.343221303085
		SemiMajorAxis	2.235825725269
		Eccentricity	0.068801668384
		Inclination	3.773086581704
		AscendingNode	283.333886754785
		ArgOfPericenter	246.516485000489
		MeanAnomaly	66.301514296299
	}
	UniformRotation
	{
		Period	3.2693
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1785"
}

#1_"1789 Dobrovolsky:Dobrovolsky:1966 QC:1936 KK:1939 GR:1943 SG:1946 NA:1953 TC2:1953 VX3:1955 EJ: #1=
#1_1956 PD:1956 RT:1969 OF" "Sol" #1=
#2_"*Добровольский:1789 Dobrovolsky:Dobrovolsky:1966 QC" "Sol" #2=
#3_"1966 QC:Dobrovolsky:*Добровольский:1789 Dobrovolsky" "Sol" #3=
".:Dobrovolsky:1789 Dobrovolsky:1966 QC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1789 dobrovolsky.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	3.961
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.292416431335
		SemiMajorAxis	2.21311698932
		Eccentricity	0.188814664977
		Inclination	1.976083778151
		AscendingNode	102.094151563574
		ArgOfPericenter	214.960156781222
		MeanAnomaly	135.524873742222
	}
	UniformRotation
	{
		Period	4.812
	}
	LunarLambert	0.5
	Albedo	0.185
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1789"
}

#1_"1791 Patsayev:Patsayev:1967 RE:1931 TW3:1943 GS:1943 GZ:1948 JO:1948 KA:1957 JG:1957 KS:1958 RC" "Sol" #1=
#2_"*Пацаев:1791 Patsayev:Patsayev:1967 RE" "Sol" #2=
#3_"1967 RE:*Пацаев:1791 Patsayev:Patsayev" "Sol" #3=
".:Patsayev:1791 Patsayev:1967 RE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.855
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.554551731718
		SemiMajorAxis	2.747630264187
		Eccentricity	0.142765139715
		Inclination	5.359605233699
		AscendingNode	199.027575552976
		ArgOfPericenter	73.966581392512
		MeanAnomaly	193.100357186686
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0509
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1791"
}

#1_"1792 Reni:Reni:1968 BG:1931 AW:1934 SD:1934 TN:1943 PD:1954 BF:1959 CL" "Sol" #1=
#2_"*Рени:1792 Reni:Reni:1968 BG" "Sol" #2=
#3_"1968 BG:Reni:*Рени:1792 Reni" "Sol" #3=
".:Reni:1792 Reni:1968 BG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1792 reni.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	11.812
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.625918107007
		SemiMajorAxis	2.776258014374
		Eccentricity	0.27879160943
		Inclination	9.010485242539
		AscendingNode	72.73365254385
		ArgOfPericenter	324.372043329889
		MeanAnomaly	271.605333759936
	}
	UniformRotation
	{
		Period	15.95
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1792"
}

#1_"1793 Zoya:Zoya:1968 DW:1932 MC:1933 UV:1946 TC:1949 QX:1951 AE:1953 VP2:1953 VW1:1953 XF:1969 RP1" "Sol" #1=
#2_"*Зоя:1793 Zoya:Zoya:1968 DW" "Sol" #2=
#3_"1968 DW:Zoya:*Зоя:1793 Zoya" "Sol" #3=
".:Zoya:1793 Zoya:1968 DW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1793 zoya.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	4.174
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.315875364511
		SemiMajorAxis	2.223617059401
		Eccentricity	0.097538459277
		Inclination	1.508764459254
		AscendingNode	225.993873885525
		ArgOfPericenter	323.373558064389
		MeanAnomaly	321.354498686784
	}
	UniformRotation
	{
		Period	5.753
	}
	LunarLambert	0.5
	Albedo	0.334
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1793"
}

#1_"1794 Finsen:Finsen:1970 GA:1937 JR:1948 GK:1950 TJ:1950 TS2:1951 XL:1951 YJ:1962 WX:1965 MC" "Sol" #1=
#2_"*Финсен:1794 Finsen:Finsen:1970 GA" "Sol" #2=
#3_"1970 GA:*Финсен:1794 Finsen:Finsen" "Sol" #3=
".:Finsen:1794 Finsen:1970 GA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.655
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.540390082926
		SemiMajorAxis	3.131036237224
		Eccentricity	0.150663065553
		Inclination	14.578652674739
		AscendingNode	221.094179215644
		ArgOfPericenter	340.579919938058
		MeanAnomaly	39.361972010321
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0469
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1794"
}

#1_"1795 Woltjer:Woltjer:4010 P-L:1950 LE1:1955 QM:1959 JA:1968 DZ:1969 PK" "Sol" #1=
#2_"*Волтьер:1795 Woltjer:Woltjer:1960-1795*:4010 P-L" "Sol" #2=
#3_"1960-1795*:*Волтьер:1795 Woltjer:Woltjer:4010 P-L" "Sol" #3=
".:Woltjer:1795 Woltjer:1960-1795*:4010 P-L:" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.545
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.649352151004
		SemiMajorAxis	2.785626121754
		Eccentricity	0.190054381195
		Inclination	7.527375300919
		AscendingNode	192.162275348296
		ArgOfPericenter	79.839465400976
		MeanAnomaly	308.623295689716
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0459
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1795"
}

#1_"1796 Riga:Riga:1966 KB:1935 GE:1941 FC1:1947 GA:1950 TF2:1953 GW:1960 JA:A907 TG:A907 UD" "Sol" #1=
#2_"*Рига:1796 Riga:Riga:1966 KB" "Sol" #2=
#3_"1966 KB:*Рига:1796 Riga:Riga" "Sol" #3=
".:Riga:1796 Riga:1966 KB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.915
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.14478900237
		SemiMajorAxis	3.354793928607
		Eccentricity	0.056680851466
		Inclination	22.585570936906
		AscendingNode	186.737986961027
		ArgOfPericenter	24.75888356599
		MeanAnomaly	342.601953096004
	}
	UniformRotation
	{
		Period	10.608
	}
	LunarLambert	0.5
	Albedo	0.0376
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1796"
}

#1_"1799 Koussevitzky:Koussevitzky:1950 OE:1929 QD:1974 CF1" "Sol" #1=
#2_"*Кусевицкий:1799 Koussevitzky:Koussevitzky:1950 OE" "Sol" #2=
#3_"1950 OE:*Кусевицкий:1799 Koussevitzky:Koussevitzky" "Sol" #3=
".:Koussevitzky:1799 Koussevitzky:1950 OE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.63
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.261133165407
		SemiMajorAxis	3.024921170736
		Eccentricity	0.120675421508
		Inclination	11.514207909064
		AscendingNode	156.761752782619
		ArgOfPericenter	190.80335286311
		MeanAnomaly	62.059646913559
	}
	UniformRotation
	{
		Period	6.318
	}
	LunarLambert	0.5
	Albedo	0.1426
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1799"
}

#1_"1801 Titicaca:Titicaca:1952 SP1:1963 UR" "Sol" #1=
#2_"*Титикака:1801 Titicaca:Titicaca:1952 SP1" "Sol" #2=
#3_"1952 SP1:*Титикака:1801 Titicaca:Titicaca" "Sol" #3=
".:Titicaca:1801 Titicaca:1952 SP1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1801 titicaca.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.978
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.249961714583
		SemiMajorAxis	3.020637590557
		Eccentricity	0.068988003615
		Inclination	10.970398051133
		AscendingNode	77.62042397236
		ArgOfPericenter	9.107989391625
		MeanAnomaly	228.460519145589
	}
	UniformRotation
	{
		Period	3.2106
	}
	LunarLambert	0.5
	Albedo	0.172
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1801"
}

#1_"1805 Dirikis:Dirikis:1970 GD:1942 EJ:1948 JH:1948 JM:1950 TU1:1953 EL:1955 QL1:1959 JP:1962 WP: #1=
#1_1962 XC1:1964 FE" "Sol" #1=
#2_"*Дирикис:1805 Dirikis:Dirikis:1970 GD" "Sol" #2=
#3_"1970 GD:*Дирикис:1805 Dirikis:Dirikis" "Sol" #3=
".:Dirikis:1805 Dirikis:1970 GD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1805 dirikis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"antiope.dds"
	Radius	13.614
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.562089681482
		SemiMajorAxis	3.13920629442
		Eccentricity	0.111812139109
		Inclination	2.516181590776
		AscendingNode	78.939052022929
		ArgOfPericenter	86.019937047275
		MeanAnomaly	58.722681727537
	}
	UniformRotation
	{
		Period	23
	}
	LunarLambert	0.5
	Albedo	0.095
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1805"
}

#1_"1808 Bellerophon:Bellerophon:2517 P-L:1928 RY:1953 ED:1965 YL:1972 HQ:1978 TH9" "Sol" #1=
#2_"*Беллерофонт:1808 Bellerophon:Bellerophon:1960-1808*:2517 P-L" "Sol" #2=
#3_"1960-1808*:*Беллерофонт:1808 Bellerophon:Bellerophon:2517 P-L" "Sol" #3=
".:Bellerophon:1808 Bellerophon:1960-1808*:2517 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.705
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.559251227697
		SemiMajorAxis	2.749519986614
		Eccentricity	0.177274479414
		Inclination	2.033614463542
		AscendingNode	13.165476744308
		ArgOfPericenter	47.06922769585
		MeanAnomaly	285.63338500893
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1076
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1808"
}

#1_"1812 Gilgamesh:Gilgamesh:4645 P-L:1931 BD:1966 WA:1973 GF" "Sol" #1=
#2_"*Гильгамеш:1812 Gilgamesh:Gilgamesh:1960-1812*:4645 P-L" "Sol" #2=
#3_"1960-1812*:*Гильгамеш:1812 Gilgamesh:Gilgamesh:4645 P-L" "Sol" #3=
".:Gilgamesh:1812 Gilgamesh:1960-1812*:4645 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.59
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.213579904965
		SemiMajorAxis	3.006666240041
		Eccentricity	0.083984041999
		Inclination	10.269869628923
		AscendingNode	178.580970261564
		ArgOfPericenter	263.593241016231
		MeanAnomaly	70.468533330718
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.145
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1812"
}

#1_"1813 Imhotep:Imhotep:7589 P-L:1967 DC:1969 TT5:1971 BA" "Sol" #1=
#2_"*Имхотеп:1813 Imhotep:Imhotep:1960-1813*:7589 P-L" "Sol" #2=
#3_"1960-1813*:*Имхотеп:1813 Imhotep:Imhotep:7589 P-L" "Sol" #3=
".:Imhotep:1813 Imhotep:1960-1813*:7589 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.397929029441
		SemiMajorAxis	2.684272958644
		Eccentricity	0.080389298922
		Inclination	8.084537885235
		AscendingNode	35.191125928168
		ArgOfPericenter	165.723973077373
		MeanAnomaly	277.486424678439
	}
	UniformRotation
	{
		Period	17.994
	}
	LunarLambert	0.5
	Albedo	0.0662
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1813"
}

#1_"1814 Bach:Bach:1931 TW1:1941 SK2:1961 TN1:1961 VF" "Sol" #1=
#2_"*Бах:1814 Bach:Bach:1931 TW1" "Sol" #2=
#3_"1931 TW1:Bach:*Бах:1814 Bach" "Sol" #3=
".:Bach:1814 Bach:1931 TW1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1814 bach.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.758
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.320205461845
		SemiMajorAxis	2.225552472702
		Eccentricity	0.131029510094
		Inclination	4.346850052142
		AscendingNode	20.309852429416
		ArgOfPericenter	65.591212605797
		MeanAnomaly	197.723341439556
	}
	UniformRotation
	{
		Period	7.2395
	}
	LunarLambert	0.5
	Albedo	0.18
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1814"
}

#1_"1815 Beethoven:Beethoven:1932 CE1:1938 EP:1952 SO:1954 BD:1958 TJ:1969 UY1:1971 BN1" "Sol" #1=
#2_"*Бетховен:1815 Beethoven:Beethoven:1932 CE1" "Sol" #2=
#3_"1932 CE1:*Бетховен:1815 Beethoven:Beethoven" "Sol" #3=
".:Beethoven:1815 Beethoven:1932 CE1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.18
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.606919994849
		SemiMajorAxis	3.156051669101
		Eccentricity	0.187258051826
		Inclination	2.738260404588
		AscendingNode	110.940554160427
		ArgOfPericenter	358.687857546228
		MeanAnomaly	284.988954511973
	}
	UniformRotation
	{
		Period	54
	}
	LunarLambert	0.5
	Albedo	0.0548
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1815"
}

#1_"1816 Liberia:Liberia:1936 BD:1954 EZ:1977 QW3:A904 HA" "Sol" #1=
#2_"*Либерия:1816 Liberia:Liberia:1936 BD" "Sol" #2=
#3_"1936 BD:Liberia:*Либерия:1816 Liberia" "Sol" #3=
".:Liberia:1816 Liberia:1936 BD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1816 liberia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.889
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.577985908888
		SemiMajorAxis	2.339305538576
		Eccentricity	0.21766078494
		Inclination	26.136720804596
		AscendingNode	153.360186953658
		ArgOfPericenter	340.826587670016
		MeanAnomaly	237.529196285438
	}
	UniformRotation
	{
		Period	3.086
	}
	LunarLambert	0.5
	Albedo	0.352
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1816"
}

#1_"1817 Katanga:Katanga:1939 MB:1928 KD:1950 NK:1971 BG" "Sol" #1=
#2_"*Катанга:1817 Katanga:Katanga:1939 MB" "Sol" #2=
#3_"1939 MB:*Катанга:1817 Katanga:Katanga" "Sol" #3=
".:Katanga:1817 Katanga:1939 MB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.652189907818
		SemiMajorAxis	2.371538065273
		Eccentricity	0.191835066931
		Inclination	25.716318035376
		AscendingNode	88.758138771932
		ArgOfPericenter	140.138833677055
		MeanAnomaly	263.397736097563
	}
	UniformRotation
	{
		Period	8.481
	}
	LunarLambert	0.5
	Albedo	0.1331
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1817"
}

#1_"1819 Laputa:Laputa:1948 PC:1929 CN:1974 DY" "Sol" #1=
#2_"*Лапута:1819 Laputa:Laputa:1948 PC" "Sol" #2=
#3_"1948 PC:*Лапута:1819 Laputa:Laputa" "Sol" #3=
".:Laputa:1819 Laputa:1948 PC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1819 laputa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	27.082
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.554455205365
		SemiMajorAxis	3.136333071964
		Eccentricity	0.22713068296
		Inclination	23.89728822721
		AscendingNode	122.134072170546
		ArgOfPericenter	166.421010422246
		MeanAnomaly	333.6243563231
	}
	UniformRotation
	{
		Period	9.8004
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1819"
}

#1_"1820 Lohmann:Lohmann:1949 PO:1949 QV:1952 MG:1962 PK:1968 HS:1974 CJ1:A923 RF" "Sol" #1=
#2_"*Ло́ман:1820 Lohmann:Lohmann:1949 PO" "Sol" #2=
#3_"1949 PO:Lohmann:*Ло́ман:1820 Lohmann" "Sol" #3=
".:Lohmann:1820 Lohmann:1949 PO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1820 lohmann.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.674
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.260855234059
		SemiMajorAxis	2.198950961293
		Eccentricity	0.209982455484
		Inclination	4.999579596992
		AscendingNode	145.187174237107
		ArgOfPericenter	168.948388693305
		MeanAnomaly	263.95046762002
	}
	UniformRotation
	{
		Period	14.0554
	}
	LunarLambert	0.5
	Albedo	0.39
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1820"
}

#1_"1825 Klare:Klare:1954 QH:1934 CH:1952 DW2:1954 SB:1954 SF:1954 UF1:1969 AV" "Sol" #1=
#2_"*Кларе:1825 Klare:Klare:1954 QH" "Sol" #2=
#3_"1954 QH:Klare:*Кларе:1825 Klare" "Sol" #3=
".:Klare:1825 Klare:1954 QH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1825 klare.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.605
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.380201050823
		SemiMajorAxis	2.677054597315
		Eccentricity	0.114691075914
		Inclination	4.03425415942
		AscendingNode	288.671895872167
		ArgOfPericenter	142.528828628858
		MeanAnomaly	26.031439483131
	}
	UniformRotation
	{
		Period	4.744
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1825"
}

#1_"1826 Miller:Miller:1955 RC1:1929 RV:1940 WF:1950 TD2:1952 BL1:1962 AA:1971 TU2" "Sol" #1=
#2_"*Миллер:1826 Miller:Miller:1955 RC1" "Sol" #2=
#3_"1955 RC1:*Миллер:1826 Miller:Miller" "Sol" #3=
".:Miller:1826 Miller:1955 RC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.205
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.185166330399
		SemiMajorAxis	2.995732240323
		Eccentricity	0.084955185586
		Inclination	9.22928112785
		AscendingNode	274.256352724058
		ArgOfPericenter	163.859699603822
		MeanAnomaly	81.469837066167
	}
	UniformRotation
	{
		Period	30.049
	}
	LunarLambert	0.5
	Albedo	0.1294
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1826"
}

#1_"1828 Kashirina:Kashirina:1966 PH:1950 QG:1950 RC1:1971 QB1" "Sol" #1=
#2_"*Каширина:1828 Kashirina:Kashirina:1966 PH" "Sol" #2=
#3_"1966 PH:*Каширина:1828 Kashirina:Kashirina" "Sol" #3=
".:Kashirina:1828 Kashirina:1966 PH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.925
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.358921340057
		SemiMajorAxis	3.062288617392
		Eccentricity	0.107377337797
		Inclination	14.314359120095
		AscendingNode	184.61217728101
		ArgOfPericenter	219.76506434628
		MeanAnomaly	315.283195526337
	}
	UniformRotation
	{
		Period	14.838
	}
	LunarLambert	0.5
	Albedo	0.0995
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1828"
}

#1_"1832 Mrkos:Mrkos:1969 PC:1937 CJ" "Sol" #1=
#2_"*Мркос:1832 Mrkos:Mrkos:1969 PC" "Sol" #2=
#3_"1969 PC:*Мркос:1832 Mrkos:Mrkos" "Sol" #3=
".:Mrkos:1832 Mrkos:1969 PC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.39
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.76480405844
		SemiMajorAxis	3.215024095595
		Eccentricity	0.104940415096
		Inclination	14.946290718423
		AscendingNode	303.440181978018
		ArgOfPericenter	81.895865513245
		MeanAnomaly	275.529080218879
	}
	UniformRotation
	{
		Period	13.64
	}
	LunarLambert	0.5
	Albedo	0.0742
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1832"
}

#1_"1833 Shmakova:Shmakova:1969 PN:1935 SM1:1959 EB:1965 US" "Sol" #1=
#2_"*Шмакова:1833 Shmakova:Shmakova:1969 PN" "Sol" #2=
#3_"1969 PN:Shmakova:*Шмакова:1833 Shmakova" "Sol" #3=
".:Shmakova:1833 Shmakova:1969 PN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1833 shmakova.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.353
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.275955935822
		SemiMajorAxis	2.634409876525
		Eccentricity	0.114327801496
		Inclination	10.004134624176
		AscendingNode	158.110452677402
		ArgOfPericenter	153.988106708248
		MeanAnomaly	53.483709558277
	}
	UniformRotation
	{
		Period	3.93
	}
	LunarLambert	0.5
	Albedo	0.102
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1833"
}

#1_"1835 Gajdariya:Gajdariya:1970 OE:1958 BH:1961 TJ:1961 TQ1:1963 DB:1971 UJ3:1973 EN" "Sol" #1=
#2_"*Гайдария:1835 Gajdariya:Gajdariya:1970 OE" "Sol" #2=
#3_"1970 OE:*Гайдария:1835 Gajdariya:Gajdariya" "Sol" #3=
".:Gajdariya:1835 Gajdariya:1970 OE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1835 gajdariya.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"ida.jpg"
	Radius	6.352
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.771686122303
		SemiMajorAxis	2.834277989142
		Eccentricity	0.087292391129
		Inclination	0.989432640016
		AscendingNode	296.709440180234
		ArgOfPericenter	78.86068940586
		MeanAnomaly	94.552707822907
	}
	UniformRotation
	{
		Period	6.3276
	}
	LunarLambert	0.5
	Albedo	0.209
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1835"
}

#1_"1837 Osita:Osita:1971 QZ1:1962 XQ:1968 QB1:1972 YJ1" "Sol" #1=
#2_"*Осита:1837 Osita:Osita:1971 QZ1" "Sol" #2=
#3_"1971 QZ1:Osita:*Осита:1837 Osita" "Sol" #3=
".:Osita:1837 Osita:1971 QZ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1837 osita.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	3.765
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.27520731629
		SemiMajorAxis	2.205398435408
		Eccentricity	0.086060522023
		Inclination	3.84576878632
		AscendingNode	280.934942744897
		ArgOfPericenter	315.023493907768
		MeanAnomaly	33.807475811778
	}
	UniformRotation
	{
		Period	3.8186
	}
	LunarLambert	0.5
	Albedo	0.216
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1837"
}

#1_"1838 Ursa:Ursa:1971 UC:1951 GB1:1954 UA:1965 UE:1977 UP1" "Sol" #1=
#2_"*Урса:1838 Ursa:Ursa:1971 UC" "Sol" #2=
#3_"1971 UC:*Урса:1838 Ursa:Ursa" "Sol" #3=
".:Ursa:1838 Ursa:1971 UC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1838 ursa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	20.027
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.763237902535
		SemiMajorAxis	3.214441773752
		Eccentricity	0.01613412786
		Inclination	21.971794662197
		AscendingNode	44.212710923119
		ArgOfPericenter	52.457949879681
		MeanAnomaly	118.286070335934
	}
	UniformRotation
	{
		Period	16.141
	}
	LunarLambert	0.5
	Albedo	0.057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1838"
}

#1_"1840 Hus:Hus:1971 UY:1931 TS3:1935 NC:1953 CG" "Sol" #1=
#2_"*Гус:1840 Hus:Hus:1971 UY" "Sol" #2=
#3_"1971 UY:Hus:*Гус:1840 Hus" "Sol" #3=
".:Hus:1840 Hus:1971 UY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1840 hus.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.223
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.983156899016
		SemiMajorAxis	2.917410709304
		Eccentricity	0.016714836597
		Inclination	2.408866196481
		AscendingNode	40.52371921632
		ArgOfPericenter	13.694011800493
		MeanAnomaly	16.586110945463
	}
	UniformRotation
	{
		Period	4.78
	}
	LunarLambert	0.5
	Albedo	0.261
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1840"
}

#1_"1841 Masaryk:Masaryk:1971 UO1:1936 FW:1955 DE:1959 VJ:1968 FG:1970 QN" "Sol" #1=
#2_"*Масарык:1841 Masaryk:Masaryk:1971 UO1" "Sol" #2=
#3_"1971 UO1:*Масарык:1841 Masaryk:Masaryk" "Sol" #3=
".:Masaryk:1841 Masaryk:1971 UO1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1841 masaryk.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	20.12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.336509933346
		SemiMajorAxis	3.424216995683
		Eccentricity	0.099665783859
		Inclination	2.619922000446
		AscendingNode	45.334757057139
		ArgOfPericenter	119.434541391838
		MeanAnomaly	158.419898973002
	}
	UniformRotation
	{
		Period	7.53
	}
	LunarLambert	0.5
	Albedo	0.052
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1841"
}

#1_"1843 Jarmila:Jarmila:1972 AB:1935 PD:1952 MU:1952 OV:1965 OF" "Sol" #1=
#2_"*Ярмила:1843 Jarmila:Jarmila:1972 AB" "Sol" #2=
#3_"1972 AB:*Ярмила:1843 Jarmila:Jarmila" "Sol" #3=
".:Jarmila:1843 Jarmila:1972 AB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.87
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.321126860098
		SemiMajorAxis	2.652930521215
		Eccentricity	0.170393495699
		Inclination	8.42789760551
		AscendingNode	267.114464517882
		ArgOfPericenter	31.610200674867
		MeanAnomaly	153.834626658232
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0611
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1843"
}

#1_"1846 Bengt:Bengt:6553 P-L:1951 CW1:1957 YP" "Sol" #1=
#2_"*Бенгт:1846 Bengt:Bengt:1960-1846*:6553 P-L" "Sol" #2=
#3_"1960-1846*:*Бенгт:1846 Bengt:Bengt:6553 P-L" "Sol" #3=
".:Bengt:1846 Bengt:1960-1846*:6553 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.705
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.576014443327
		SemiMajorAxis	2.338446156781
		Eccentricity	0.141687586741
		Inclination	3.183916396287
		AscendingNode	19.105316194791
		ArgOfPericenter	75.356635712704
		MeanAnomaly	340.198346565352
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0781
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1846"
}

#1_"1847 Stobbe:Stobbe:A916 CA:1930 ML:1930 QT:1937 AH:1951 MG:1951 NF:1952 UC:1959 LA:1968 OM1: #1=
#1_A902 YB:A906 YN" "Sol" #1=
#2_"*Штоббе:1847 Stobbe:Stobbe:1916 CA" "Sol" #2=
#3_"1916 CA:*Штоббе:1847 Stobbe:Stobbe" "Sol" #3=
".:Stobbe:1847 Stobbe:1916 CA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.218537816524
		SemiMajorAxis	2.610773302014
		Eccentricity	0.020748239456
		Inclination	11.138570725841
		AscendingNode	106.936621605987
		ArgOfPericenter	141.502590637144
		MeanAnomaly	45.842229325704
	}
	UniformRotation
	{
		Period	5.617
	}
	LunarLambert	0.5
	Albedo	0.1231
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1847"
}

#1_"1851 Lacroute:Lacroute:1950 VA" "Sol" #1=
#2_"*Лакрут:1851 Lacroute:Lacroute:1950 VA" "Sol" #2=
#3_"1950 VA:*Лакрут:1851 Lacroute:Lacroute" "Sol" #3=
".:Lacroute:1851 Lacroute:1950 VA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.445
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.465900131889
		SemiMajorAxis	3.102908673733
		Eccentricity	0.192984658183
		Inclination	1.666218958173
		AscendingNode	24.778396642985
		ArgOfPericenter	343.396762510045
		MeanAnomaly	265.215940248519
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0745
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1851"
}

#1_"1852 Carpenter:Carpenter:1955 GA:1931 TT2:1937 WH:1939 FK" "Sol" #1=
#2_"*Карпентер:1852 Carpenter:Carpenter:1955 GA" "Sol" #2=
#3_"1955 GA:*Карпентер:1852 Carpenter:Carpenter" "Sol" #3=
".:Carpenter:1852 Carpenter:1955 GA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.445
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.239034507644
		SemiMajorAxis	3.016444722806
		Eccentricity	0.059791273708
		Inclination	11.176594490734
		AscendingNode	95.477394061805
		ArgOfPericenter	350.138552833231
		MeanAnomaly	256.241899467492
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1224
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1852"
}

#1_"1853 McElroy:McElroy:1957 XE:1930 YP:1950 NX:1950 OM" "Sol" #1=
#2_"*Макэлрой:1853 McElroy:McElroy:1957 XE" "Sol" #2=
#3_"1957 XE:*Макэлрой:1853 McElroy:McElroy" "Sol" #3=
".:McElroy:1853 McElroy:1957 XE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.57
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.366644346054
		SemiMajorAxis	3.065230054663
		Eccentricity	0.050231011075
		Inclination	15.757990101064
		AscendingNode	298.787039251539
		ArgOfPericenter	90.264165628638
		MeanAnomaly	282.846558110124
	}
	UniformRotation
	{
		Period	8.016
	}
	LunarLambert	0.5
	Albedo	0.2494
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1853"
}

#1_"1855 Korolev:Korolev:1969 TU1:1961 JD:1964 DD" "Sol" #1=
#2_"*Королёв:1855 Korolev:Korolev:1969 TU1" "Sol" #2=
#3_"1969 TU1:Korolev:*Королёв:1855 Korolev" "Sol" #3=
".:Korolev:1855 Korolev:1969 TU1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1855 korolev.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	3.394
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.369669140977
		SemiMajorAxis	2.247601805572
		Eccentricity	0.084085601244
		Inclination	3.079298169269
		AscendingNode	191.033194160964
		ArgOfPericenter	349.309832149242
		MeanAnomaly	228.393812018954
	}
	UniformRotation
	{
		Period	4.6568
	}
	LunarLambert	0.5
	Albedo	0.319
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1855"
}

#1_"1858 Lobachevskij:Lobachevskij:1972 QL:1928 SG:1936 MH:1955 VW:1957 BM:1964 YC" "Sol" #1=
#2_"*Лобачевский:1858 Lobachevskij:Lobachevskij:1972 QL" "Sol" #2=
#3_"1972 QL:Lobachevskij:*Лобачевский:1858 Lobachevskij" "Sol" #3=
".:Lobachevskij:1858 Lobachevskij:1972 QL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1858 lobachevskij.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.384
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.434035155359
		SemiMajorAxis	2.698944495252
		Eccentricity	0.077484209847
		Inclination	1.66065540613
		AscendingNode	271.920055608263
		ArgOfPericenter	17.67292246687
		MeanAnomaly	53.836185614883
	}
	UniformRotation
	{
		Period	5.413
	}
	LunarLambert	0.5
	Albedo	0.383
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1858"
}

#1_"1859 Kovalevskaya:Kovalevskaya:1972 RS2:1932 RD:1941 BQ:1942 HH:1949 PU:1949 QW:1950 TM4: #1=
#1_1953 EK1:1966 PC1:A915 TK" "Sol" #1=
#2_"*Ковалевская:1859 Kovalevskaya:Kovalevskaya:1972 RS2" "Sol" #2=
#3_"1972 RS2:*Ковалевская:1859 Kovalevskaya:Kovalevskaya" "Sol" #3=
".:Kovalevskaya:1859 Kovalevskaya:1972 RS2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.01
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.745911157895
		SemiMajorAxis	3.20799588834
		Eccentricity	0.101636162044
		Inclination	7.706984737815
		AscendingNode	343.339156080741
		ArgOfPericenter	246.045786380933
		MeanAnomaly	226.482029295213
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0694
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1859"
}

#1_"1860 Barbarossa:Barbarossa:1973 SK:1935 GG:1943 FD:1948 PE1:1948 PF:1948 QE:1951 EA2:1952 OC1: #1=
#1_1960 MA:1971 BM1:1972 JO:A911 QA" "Sol" #1=
#2_"*Барбаросса:1860 Barbarossa:Barbarossa:1973 SK" "Sol" #2=
#3_"1973 SK:Barbarossa:*Барбаросса:1860 Barbarossa" "Sol" #3=
".:Barbarossa:1860 Barbarossa:1973 SK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1860 barbarossa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.115930590494
		SemiMajorAxis	2.568265355456
		Eccentricity	0.201564118975
		Inclination	9.920639100947
		AscendingNode	132.913361112544
		ArgOfPericenter	161.915291822764
		MeanAnomaly	263.400979182561
	}
	UniformRotation
	{
		Period	3.255
	}
	LunarLambert	0.5
	Albedo	0.152
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1860"
}

#1_"1862 Apollo:Apollo:1932 HA" "Sol" #1=
#2_"*Аполлон:1862 Apollo:Apollo:1932 HA" "Sol" #2=
#3_"1932 HA:*Аполлон:1862 Apollo:Apollo" "Sol" #3=
".:Apollo:1862 Apollo:1932 HA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1862 apollo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2456600.5  # 2013 Nov 04
		Period	1.782464833559
		SemiMajorAxis	1.470082965914
		Eccentricity	0.559991975078
		Inclination	6.352765795470
		AscendingNode	35.704308297713
		ArgOfPericenter	285.873962750695
		MeanAnomaly	201.571073499392
	}
	UniformRotation
	{
		Period	3.065
	}
	LunarLambert	0.5
	Albedo	0.25
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1862"
}

#1_"2005 1862 I" "Sol/1862 Apollo" #1=
#2_"2005 1862 I" "Sol/1862 Apollo" #2=
#3_"2005 1862 I" "Sol/1862 Apollo" #3=
".:2005 1862 I" "Sol/1862 Apollo" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.095
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	1.14
		SemiMajorAxis	3.75
	}
	LunarLambert	0.5
	Albedo	0.25
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-01862.html"
}

#1_"1863 Antinous:Antinous:1948 EA" "Sol" #1=
#2_"*Антиной:1863 Antinous:Antinous:1948 EA" "Sol" #2=
#3_"1948 EA:*Антиной:1863 Antinous:Antinous" "Sol" #3=
".:Antinous:1863 Antinous:1948 EA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.395033088864
		SemiMajorAxis	2.258866368555
		Eccentricity	0.606628317522
		Inclination	18.398497973082
		AscendingNode	346.5028488987
		ArgOfPericenter	268.020705390855
		MeanAnomaly	209.322320929976
	}
	UniformRotation
	{
		Period	7.4568
	}
	LunarLambert	0.5
	Albedo	0.24
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1863"
}

#1_"1864 Daedalus:Daedalus:1971 FA" "Sol" #1=
#2_"*Дедал:1864 Daedalus:Daedalus:1971 FA" "Sol" #2=
#3_"1971 FA:*Дедал:1864 Daedalus:Daedalus" "Sol" #3=
".:Daedalus:1864 Daedalus:1971 FA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.765902600212
		SemiMajorAxis	1.460962367394
		Eccentricity	0.6145901967
		Inclination	22.205459357603
		AscendingNode	6.651565637667
		ArgOfPericenter	325.601444106394
		MeanAnomaly	184.900019293106
	}
	UniformRotation
	{
		Period	8.572
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1864"
}

#1_"1865 Cerberus:Cerberus:1971 UA" "Sol" #1=
#2_"*Цербер:1865 Cerberus:Cerberus:1971 UA" "Sol" #2=
#3_"1971 UA:*Цербер:1865 Cerberus:Cerberus" "Sol" #3=
".:Cerberus:1865 Cerberus:1971 UA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1865 cerberus.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.12247049334
		SemiMajorAxis	1.080051557276
		Eccentricity	0.466930126538
		Inclination	16.093581161858
		AscendingNode	212.938267719117
		ArgOfPericenter	325.22725157105
		MeanAnomaly	47.109115551877
	}
	UniformRotation
	{
		Period	6.8039
	}
	LunarLambert	0.5
	Albedo	0.22
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1865"
}

#1_"1866 Sisyphus:Sisyphus:1972 XA" "Sol" #1=
#2_"*Сизиф:1866 Sisyphus:Sisyphus:1972 XA" "Sol" #2=
#3_"1972 XA:*Сизиф:1866 Sisyphus:Sisyphus" "Sol" #3=
".:Sisyphus:1866 Sisyphus:1972 XA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.22
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.606444086165
		SemiMajorAxis	1.893913502678
		Eccentricity	0.538299092406
		Inclination	41.187366488173
		AscendingNode	63.556274421886
		ArgOfPericenter	293.056088345413
		MeanAnomaly	67.671162934634
	}
	UniformRotation
	{
		Period	2.3909
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1866"
}

#1_"1985 1866 I" "Sol/1866 Sisyphus" #1=
#2_"1985 1866 I" "Sol/1866 Sisyphus" #2=
#3_"1985 1866 I" "Sol/1866 Sisyphus" #3=
".:1985 1866 I" "Sol/1866 Sisyphus" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	1.13
		SemiMajorAxis	20
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-01866.html"
}

#1_"1867 Deiphobus:Deiphobus:1971 EA" "Sol" #1=
#2_"*Дейфоб:1867 Deiphobus:Deiphobus:1971 EA" "Sol" #2=
#3_"1971 EA:*Дейфоб:1867 Deiphobus:Deiphobus" "Sol" #3=
".:Deiphobus:1867 Deiphobus:1971 EA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	61.335
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.615191490777
		SemiMajorAxis	5.128756903378
		Eccentricity	0.04329489006
		Inclination	26.910574307757
		AscendingNode	283.703382411956
		ArgOfPericenter	0.493835392517
		MeanAnomaly	143.65601633874
	}
	UniformRotation
	{
		Period	58.66
	}
	LunarLambert	0.5
	Albedo	0.0422
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1867"
}

#1_"1873 Agenor:Agenor:1971 FH" "Sol" #1=
#2_"*Агенор:1873 Agenor:Agenor:1971 FH" "Sol" #2=
#3_"1971 FH:*Агенор:1873 Agenor:Agenor" "Sol" #3=
".:Agenor:1873 Agenor:1971 FH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.88
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.993175207657
		SemiMajorAxis	5.23942929515
		Eccentricity	0.091699387699
		Inclination	21.875004536509
		AscendingNode	197.90947414105
		ArgOfPericenter	356.389796216006
		MeanAnomaly	222.419361441126
	}
	UniformRotation
	{
		Period	20.6
	}
	LunarLambert	0.5
	Albedo	0.0386
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1873"
}

#1_"1878 Hughes:Hughes:1933 QC:1950 BA:1955 FK:1972 TO7" "Sol" #1=
#2_"*Хьюз:1878 Hughes:Hughes:1933 QC" "Sol" #2=
#3_"1933 QC:*Хьюз:1878 Hughes:Hughes" "Sol" #3=
".:Hughes:1878 Hughes:1933 QC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.801502948982
		SemiMajorAxis	2.846072758661
		Eccentricity	0.010051063506
		Inclination	1.782312716589
		AscendingNode	187.856913175363
		ArgOfPericenter	288.926355452468
		MeanAnomaly	193.880645294678
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1399
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1878"
}

#1_"1880 McCrosky:McCrosky:1940 AN:1955 QS:1977 TF" "Sol" #1=
#2_"*МакКроски:1880 McCrosky:McCrosky:1940 AN" "Sol" #2=
#3_"1940 AN:*МакКроски:1880 McCrosky:McCrosky" "Sol" #3=
".:McCrosky:1880 McCrosky:1940 AN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.89
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.37496401834
		SemiMajorAxis	2.674920354781
		Eccentricity	0.075616050621
		Inclination	4.851792835573
		AscendingNode	116.865512582822
		ArgOfPericenter	188.733099334089
		MeanAnomaly	228.6371073881
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1025
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1880"
}

#1_"1884 Skip:Skip:1943 EB1:1943 EC" "Sol" #1=
#2_"*Скип:1884 Skip:Skip:1943 EB1" "Sol" #2=
#3_"1943 EB1:*Скип:1884 Skip:Skip" "Sol" #3=
".:Skip:1884 Skip:1943 EB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.61
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.777423883171
		SemiMajorAxis	2.425446389674
		Eccentricity	0.261748617396
		Inclination	21.828380399341
		AscendingNode	353.639726363229
		ArgOfPericenter	110.945729627034
		MeanAnomaly	45.233756197048
	}
	UniformRotation
	{
		Period	3.079
	}
	LunarLambert	0.5
	Albedo	0.2934
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1884"
}

#1_"1889 Pakhmutova:Pakhmutova:1968 BE:1942 JM:1966 US:1969 JM" "Sol" #1=
#2_"*Пахмутова:1889 Pakhmutova:Pakhmutova:1968 BE" "Sol" #2=
#3_"1968 BE:*Пахмутова:1889 Pakhmutova:Pakhmutova" "Sol" #3=
".:Pakhmutova:1889 Pakhmutova:1968 BE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1889 pakhmutova.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	17.622
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.43243923935
		SemiMajorAxis	3.090232223574
		Eccentricity	0.111099336228
		Inclination	13.17969740773
		AscendingNode	55.169715186926
		ArgOfPericenter	84.178845645491
		MeanAnomaly	212.03589271457
	}
	UniformRotation
	{
		Period	17.49
	}
	LunarLambert	0.5
	Albedo	0.057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1889"
}

#1_"1890 Konoshenkova:Konoshenkova:1968 CD:1966 UW" "Sol" #1=
#2_"*Коношенкова:1890 Konoshenkova:Konoshenkova:1968 CD" "Sol" #2=
#3_"1968 CD:*Коношенкова:1890 Konoshenkova:Konoshenkova" "Sol" #3=
".:Konoshenkova:1890 Konoshenkova:1968 CD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.84
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.749144153028
		SemiMajorAxis	3.209199116451
		Eccentricity	0.139604755889
		Inclination	9.88514073104
		AscendingNode	70.378850359934
		ArgOfPericenter	16.466231093597
		MeanAnomaly	103.596532257432
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1283
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1890"
}

#1_"1892 Lucienne:Lucienne:1971 SD:1936 PO:1938 AC" "Sol" #1=
#2_"*Люсьен:1892 Lucienne:Lucienne:1971 SD" "Sol" #2=
#3_"1971 SD:Lucienne:*Люсьен:1892 Lucienne" "Sol" #3=
".:Lucienne:1892 Lucienne:1971 SD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1892 lucienne.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.862
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.862021945971
		SemiMajorAxis	2.461525599399
		Eccentricity	0.090317443063
		Inclination	13.949011182794
		AscendingNode	315.680727145617
		ArgOfPericenter	93.099971829181
		MeanAnomaly	228.3700927923
	}
	UniformRotation
	{
		Period	9.31
	}
	LunarLambert	0.5
	Albedo	0.27
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1892"
}

#1_"1895 Larink:Larink:1971 UZ:1937 UG:1939 CG" "Sol" #1=
#2_"*Ларинк:1895 Larink:Larink:1971 UZ" "Sol" #2=
#3_"1971 UZ:*Ларинк:1895 Larink:Larink" "Sol" #3=
".:Larink:1895 Larink:1971 UZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.755
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.703480998534
		SemiMajorAxis	3.19218361794
		Eccentricity	0.14918090448
		Inclination	1.819927415313
		AscendingNode	45.541230389287
		ArgOfPericenter	53.981805443197
		MeanAnomaly	175.941992483217
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1099
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1895"
}

#1_"1900 Katyusha:Katyusha:1971 YB:1938 WM:1941 SS1:1950 LS:1953 GL1:1961 WD:1969 DC" "Sol" #1=
#2_"*Катюша:1900 Katyusha:Katyusha:1971 YB" "Sol" #2=
#3_"1971 YB:Katyusha:*Катюша:1900 Katyusha" "Sol" #3=
".:Katyusha:1900 Katyusha:1971 YB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1900 katyusha.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.284475609813
		SemiMajorAxis	2.209557083443
		Eccentricity	0.134837900856
		Inclination	6.54264611662
		AscendingNode	281.909164190408
		ArgOfPericenter	142.401793101418
		MeanAnomaly	354.196242974448
	}
	UniformRotation
	{
		Period	9.4999
	}
	LunarLambert	0.5
	Albedo	0.299
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1900"
}

#1_"1901 Moravia:Moravia:1972 AD" "Sol" #1=
#2_"*Моравия:1901 Moravia:Moravia:1972 AD" "Sol" #2=
#3_"1972 AD:*Моравия:1901 Moravia:Moravia" "Sol" #3=
".:Moravia:1901 Moravia:1972 AD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.515
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.833182062396
		SemiMajorAxis	3.240396986199
		Eccentricity	0.070812817787
		Inclination	24.104438795271
		AscendingNode	94.311028953957
		ArgOfPericenter	147.045502122643
		MeanAnomaly	4.032786489192
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0801
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1901"
}

#1_"1902 Shaposhnikov:Shaposhnikov:1972 HU:1940 GK:1941 MC:1950 TD4:1951 WY1:1951 YD:1958 TP1: #1=
#1_1958 VB:1959 XA:1972 JA" "Sol" #1=
#2_"*Шапошников:1902 Shaposhnikov:Shaposhnikov:1972 HU" "Sol" #2=
#3_"1972 HU:*Шапошников:1902 Shaposhnikov:Shaposhnikov" "Sol" #3=
".:Shaposhnikov:1902 Shaposhnikov:1972 HU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1902 shaposhnikov.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	41.722
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	7.895807110464
		SemiMajorAxis	3.9651432819
		Eccentricity	0.221888715591
		Inclination	12.495448260173
		AscendingNode	59.315313891276
		ArgOfPericenter	268.15571753972
		MeanAnomaly	186.17414682274
	}
	UniformRotation
	{
		Period	21.2
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1902"
}

#1_"1903 Adzhimushkaj:Adzhimushkaj:1972 JL:1938 UL:1940 CJ:1940 EG:1942 PK:1950 CQ:1951 JM:1958 TT: #1=
#1_1961 CG:1968 OQ:1971 DH" "Sol" #1=
#2_"*Аджимушкай:1903 Adzhimushkaj:Adzhimushkaj:1972 JL" "Sol" #2=
#3_"1972 JL:*Аджимушкай:1903 Adzhimushkaj:Adzhimushkaj" "Sol" #3=
".:Adzhimushkaj:1903 Adzhimushkaj:1972 JL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.204837844906
		SemiMajorAxis	3.003304275277
		Eccentricity	0.045192461832
		Inclination	10.963737720305
		AscendingNode	135.225638959563
		ArgOfPericenter	351.700667450044
		MeanAnomaly	165.217854846231
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0837
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1903"
}

#1_"1904 Massevitch:Massevitch:1972 JM:1949 JH:1951 XN:1958 JA:1962 CE:1965 YH:1971 BF" "Sol" #1=
#2_"*Масевич:1904 Massevitch:Massevitch:1972 JM" "Sol" #2=
#3_"1972 JM:*Масевич:1904 Massevitch:Massevitch" "Sol" #3=
".:Massevitch:1904 Massevitch:1972 JM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.095
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.545636028413
		SemiMajorAxis	2.744043368126
		Eccentricity	0.073221613705
		Inclination	12.823195925761
		AscendingNode	106.51807507106
		ArgOfPericenter	260.094107414272
		MeanAnomaly	3.236988825395
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1613
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1904"
}

#1_"1905 Ambartsumian:Ambartsumian:1972 JZ:1932 FC:1952 HO3:1959 QD:1962 JX:1969 PF:1976 SS5" "Sol" #1=
#2_"*Амбарцумян:1905 Ambartsumian:Ambartsumian:1972 JZ" "Sol" #2=
#3_"1972 JZ:*Амбарцумян:1905 Ambartsumian:Ambartsumian" "Sol" #3=
".:Ambartsumian:1905 Ambartsumian:1972 JZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1905 ambartsumian.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.004
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.315659803446
		SemiMajorAxis	2.223520688579
		Eccentricity	0.161909331203
		Inclination	2.615317573556
		AscendingNode	201.371659538723
		ArgOfPericenter	61.589402244211
		MeanAnomaly	347.024237761941
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.229
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1905"
}

#1_"1906 Naef:Naef:1972 RC:1943 VF:1952 DG1:1965 WF" "Sol" #1=
#2_"*Неф:1906 Naef:Naef:1972 RC" "Sol" #2=
#3_"1972 RC:Naef:*Неф:1906 Naef" "Sol" #3=
".:Naef:1906 Naef:1972 RC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1906 naef.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"vesta.dds"
	Color	[ 1.000 0.951 0.842 ]
	BlendTexture	true
	Radius	3.962
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.656529864755
		SemiMajorAxis	2.373416451662
		Eccentricity	0.135451998478
		Inclination	6.475643346967
		AscendingNode	354.844878923154
		ArgOfPericenter	14.537362659778
		MeanAnomaly	40.865914824373
	}
	UniformRotation
	{
		Period	11.009
	}
	LunarLambert	0.5
	Albedo	0.234
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1906"
}

#1_"1907 Rudneva:Rudneva:1972 RC2:1935 QX:1938 EY:1938 FK:1942 EH:1942 EM1:1950 EP:1950 FB:1950 HL:1958 DD:1958 FN:1970 CP" "Sol" #1=
#2_"*Руднева:1907 Rudneva:Rudneva:1972 RC2" "Sol" #2=
#3_"1972 RC2:Rudneva:*Руднева:1907 Rudneva" "Sol" #3=
".:Rudneva:1907 Rudneva:1972 RC2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.488
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.063375275399
		SemiMajorAxis	2.546356193752
		Eccentricity	0.042317958564
		Inclination	3.219826561348
		AscendingNode	152.07017745269
		ArgOfPericenter	59.095789605693
		MeanAnomaly	181.053182752714
	}
	UniformRotation
	{
		Period	44
	}
	LunarLambert	0.5
	Albedo	0.232
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1907"
}

#1_"1908 Pobeda:Pobeda:1972 RL2:1940 CG:1952 SP:1952 TG:1960 EC:1970 GO1:1973 YN2" "Sol" #1=
#2_"*Победа:1908 Pobeda:Pobeda:1972 RL2" "Sol" #2=
#3_"1972 RL2:*Победа:1908 Pobeda:Pobeda" "Sol" #3=
".:Pobeda:1908 Pobeda:1972 RL2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.192
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.918600654689
		SemiMajorAxis	2.892159502856
		Eccentricity	0.034852569956
		Inclination	4.761658172402
		AscendingNode	14.349436816747
		ArgOfPericenter	223.24939628305
		MeanAnomaly	185.076720537725
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.208
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1908"
}

#1_"1909 Alekhin:Alekhin:1972 RW2:1926 GU:1930 KF:1930 KM:1934 NZ:1934 OC:1941 FJ:1960 FD:1969 UU: #1=
#1_1971 DL" "Sol" #1=
#2_"*Алехин:1909 Alekhin:Alekhin:1972 RW2" "Sol" #2=
#3_"1972 RW2:*Алехин:1909 Alekhin:Alekhin" "Sol" #3=
".:Alekhin:1909 Alekhin:1972 RW2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.71
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.770240754785
		SemiMajorAxis	2.42237060404
		Eccentricity	0.225905758667
		Inclination	1.79471842842
		AscendingNode	227.497380956007
		ArgOfPericenter	5.757434846272
		MeanAnomaly	152.327485527346
	}
	UniformRotation
	{
		Period	148.6
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1909"
}

#1_"1911 Schubart:Schubart:1973 UD:1928 DW:1933 UX1:1941 SU1:1951 AH1:1952 DS2:1960 EF:1968 FM: #1=
#1_1972 RO:1972 TY4" "Sol" #1=
#2_"*Шуберт:1911 Schubart:Schubart:1973 UD" "Sol" #2=
#3_"1973 UD:*Шуберт:1911 Schubart:Schubart" "Sol" #3=
".:Schubart:1911 Schubart:1973 UD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.045
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.980033581149
		SemiMajorAxis	3.993291475907
		Eccentricity	0.168790514562
		Inclination	1.648084232664
		AscendingNode	285.427023703202
		ArgOfPericenter	183.123850310453
		MeanAnomaly	11.193208884362
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0249
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1911"
}

#1_"1915 Quetzalcoatl:Quetzalcoatl:1953 EA" "Sol" #1=
#2_"*Кетцалькоатль:1915 Quetzalcoatl:Quetzalcoatl:1953 EA" "Sol" #2=
#3_"1953 EA:*Кетцалькоатль:1915 Quetzalcoatl:Quetzalcoatl" "Sol" #3=
".:Quetzalcoatl:1915 Quetzalcoatl:1953 EA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.059877907204
		SemiMajorAxis	2.544894876078
		Eccentricity	0.570541119264
		Inclination	20.400339938446
		AscendingNode	162.957941999597
		ArgOfPericenter	347.835000362624
		MeanAnomaly	129.796397134176
	}
	UniformRotation
	{
		Period	4.9
	}
	LunarLambert	0.5
	Albedo	0.21
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1915"
}

#1_"1916 Boreas:Boreas:1953 RA" "Sol" #1=
#2_"*Борей:1916 Boreas:Boreas:1953 RA" "Sol" #2=
#3_"1953 RA:*Борей:1916 Boreas:Boreas" "Sol" #3=
".:Boreas:1916 Boreas:1953 RA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.42434884204
		SemiMajorAxis	2.271851108342
		Eccentricity	0.450231162396
		Inclination	12.888770274979
		AscendingNode	340.640345083438
		ArgOfPericenter	335.893197389208
		MeanAnomaly	324.210931104006
	}
	UniformRotation
	{
		Period	3.49
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1916"
}

#1_"1917 Cuyo:Cuyo:1968 AA" "Sol" #1=
#2_"*Куйо:1917 Cuyo:Cuyo:1968 AA" "Sol" #2=
#3_"1968 AA:*Куйо:1917 Cuyo:Cuyo" "Sol" #3=
".:Cuyo:1917 Cuyo:1968 AA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.15406985873
		SemiMajorAxis	2.150678056258
		Eccentricity	0.504012074546
		Inclination	23.930948104193
		AscendingNode	188.335737337922
		ArgOfPericenter	194.412850254954
		MeanAnomaly	349.344126400998
	}
	UniformRotation
	{
		Period	2.689
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1917"
}

#1_"1923 Osiris:Osiris:4011 P-L:1964 TO2:1966 FR:1974 KN:1974 KP:1974 LE" "Sol" #1=
#2_"*Осирис:1923 Osiris:Osiris:1960-1923*:4011 P-L" "Sol" #2=
#3_"1960-1923*:*Осирис:1923 Osiris:Osiris:4011 P-L" "Sol" #3=
".:Osiris:1923 Osiris:1960-1923*:4011 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.555
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.801842918183
		SemiMajorAxis	2.435887973301
		Eccentricity	0.06330415367
		Inclination	4.957319313502
		AscendingNode	353.082108673024
		ArgOfPericenter	106.860172439111
		MeanAnomaly	9.262594100196
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0591
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1923"
}

#1_"1924 Horus:Horus:4023 P-L:1951 BD:1969 BA" "Sol" #1=
#2_"*Гор:1924 Horus:Horus:1960-1924*:4023 P-L" "Sol" #2=
#3_"1960-1924*:*Гор:1924 Horus:Horus:4023 P-L" "Sol" #3=
".:Horus:1924 Horus:1960-1924*:4023 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.14
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.578168425187
		SemiMajorAxis	2.339385091295
		Eccentricity	0.13120314696
		Inclination	2.729968465299
		AscendingNode	350.273815917346
		ArgOfPericenter	152.617876002243
		MeanAnomaly	287.960783652302
	}
	UniformRotation
	{
		Period	6.183
	}
	LunarLambert	0.5
	Albedo	0.0888
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1924"
}

#1_"1925 Franklin-Adams:Franklin-Adams:1934 RY:1969 EP1:1970 KH:1974 KK" "Sol" #1=
#2_"*Франклин-Адамс:1925 Franklin-Adams:Franklin-Adams:1934 RY" "Sol" #2=
#3_"1934 RY:Franklin-Adams:*Франклин-Адамс:1925 Franklin-Adams" "Sol" #3=
".:Franklin-Adams:1925 Franklin-Adams:1934 RY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1925 franklin-adams.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.432
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.074966618082
		SemiMajorAxis	2.551196450938
		Eccentricity	0.177076116227
		Inclination	7.732715069665
		AscendingNode	113.529155791813
		ArgOfPericenter	242.116910522878
		MeanAnomaly	81.457150859921
	}
	UniformRotation
	{
		Period	2.978
	}
	LunarLambert	0.5
	Albedo	0.356
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1925"
}

#1_"1927 Suvanto:Suvanto:1936 FP:1930 XN" "Sol" #1=
#2_"*Суванто:1927 Suvanto:Suvanto:1936 FP" "Sol" #2=
#3_"1936 FP:*Суванто:1927 Suvanto:Suvanto" "Sol" #3=
".:Suvanto:1927 Suvanto:1936 FP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1927 suvanto.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.92
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.318172259397
		SemiMajorAxis	2.651721076834
		Eccentricity	0.146758091513
		Inclination	13.370169277874
		AscendingNode	27.15453482365
		ArgOfPericenter	95.75568422586
		MeanAnomaly	170.034119384987
	}
	UniformRotation
	{
		Period	8.164
	}
	LunarLambert	0.5
	Albedo	0.289
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1927"
}

#1_"1930 Lucifer:Lucifer:1964 UA:1954 SQ:1954 TC" "Sol" #1=
#2_"*Люцифер:1930 Lucifer:Lucifer:1964 UA" "Sol" #2=
#3_"1964 UA:*Люцифер:1930 Lucifer:Lucifer" "Sol" #3=
".:Lucifer:1930 Lucifer:1964 UA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1930 lucifer.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	17.218
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.928510624458
		SemiMajorAxis	2.896042937659
		Eccentricity	0.144312386729
		Inclination	14.088235436948
		AscendingNode	318.626273797386
		ArgOfPericenter	340.795049531877
		MeanAnomaly	135.647365531493
	}
	UniformRotation
	{
		Period	13.056
	}
	LunarLambert	0.5
	Albedo	0.067
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1930"
}

#1_"1933 Tinchen:Tinchen:1972 AC:1956 TB:1956 VE:1962 JF:1962 JS" "Sol" #1=
#2_"*Тинхен:1933 Tinchen:Tinchen:1972 AC" "Sol" #2=
#3_"1972 AC:*Тинхен:1933 Tinchen:Tinchen" "Sol" #3=
".:Tinchen:1933 Tinchen:1972 AC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1933 tinchen.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"vesta.dds"
	Color	[ 1.000 0.951 0.842 ]
	BlendTexture	true
	Radius	2.254
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.61083509399
		SemiMajorAxis	2.353601695943
		Eccentricity	0.122648128645
		Inclination	6.880067276104
		AscendingNode	164.930701196204
		ArgOfPericenter	214.266609835948
		MeanAnomaly	96.910684923838
	}
	UniformRotation
	{
		Period	3.671
	}
	LunarLambert	0.5
	Albedo	0.2950
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1933"
}

#1_"1934 Jeffers:Jeffers:1972 XB:1951 AN1:1961 YA" "Sol" #1=
#2_"*Джефферс:1934 Jeffers:Jeffers:1972 XB" "Sol" #2=
#3_"1972 XB:*Джефферс:1934 Jeffers:Jeffers" "Sol" #3=
".:Jeffers:1934 Jeffers:1972 XB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.23
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.693227920376
		SemiMajorAxis	2.389270230141
		Eccentricity	0.300622337321
		Inclination	23.14601887804
		AscendingNode	86.528177082862
		ArgOfPericenter	294.802025962681
		MeanAnomaly	161.739207241335
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.3216
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1934"
}

#1_"1936 Lugano:Lugano:1973 WD:1936 LC:1949 KE1:1951 WX:1964 VA1:1970 AG1:1970 AL1:1970 CD" "Sol" #1=
#2_"*Лугано:1936 Lugano:Lugano:1973 WD" "Sol" #2=
#3_"1973 WD:*Лугано:1936 Lugano:Lugano" "Sol" #3=
".:Lugano:1936 Lugano:1973 WD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.377210102738
		SemiMajorAxis	2.675835803514
		Eccentricity	0.135900517453
		Inclination	10.255338395541
		AscendingNode	265.194890428805
		ArgOfPericenter	254.851630434824
		MeanAnomaly	66.651340638765
	}
	UniformRotation
	{
		Period	19.651
	}
	LunarLambert	0.5
	Albedo	0.1042
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1936"
}

#1_"1937 Locarno:Locarno:1973 YA:1936 VB:1951 YU:1962 XH1:1968 HJ1:1969 VT1" "Sol" #1=
#2_"*Локарно:1937 Locarno:Locarno:1973 YA" "Sol" #2=
#3_"1973 YA:*Локарно:1937 Locarno:Locarno" "Sol" #3=
".:Locarno:1937 Locarno:1973 YA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.555
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.66976117175
		SemiMajorAxis	2.379138542308
		Eccentricity	0.15544296218
		Inclination	12.459156581963
		AscendingNode	79.031032958229
		ArgOfPericenter	226.041130951325
		MeanAnomaly	187.805649139197
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1786
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1937"
}

#1_"1939 Loretta:Loretta:1974 UC:1934 JE:1934 LQ:1939 EH:1939 GP:1950 DT:1950 ES:1951 MF:1955 CA: #1=
#1_1969 TE5:1975 TZ5:1975 XW" "Sol" #1=
#2_"*Лоретта:1939 Loretta:Loretta:1974 UC" "Sol" #2=
#3_"1974 UC:*Лоретта:1939 Loretta:Loretta" "Sol" #3=
".:Loretta:1939 Loretta:1974 UC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"antiope.dds"
	Radius	14.98
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.512221122589
		SemiMajorAxis	3.120414489047
		Eccentricity	0.127443242242
		Inclination	0.907331136983
		AscendingNode	40.408080098791
		ArgOfPericenter	190.366339251181
		MeanAnomaly	205.521275566741
	}
	UniformRotation
	{
		Period	25
	}
	LunarLambert	0.5
	Albedo	0.0942
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1939"
}

#1_"1940 Whipple:Whipple:1975 CA:1932 AD:1950 LH:1962 SH:1970 EC1:1971 KD1:1971 KN:A916 AD" "Sol" #1=
#2_"*Уайпл:1940 Whipple:Whipple:1975 CA" "Sol" #2=
#3_"1975 CA:*Уайпл:1940 Whipple:Whipple" "Sol" #3=
".:Whipple:1940 Whipple:1975 CA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.935
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.356701195711
		SemiMajorAxis	3.06144277649
		Eccentricity	0.064422794543
		Inclination	6.558426202541
		AscendingNode	263.826609725523
		ArgOfPericenter	179.724399734488
		MeanAnomaly	194.70650721911
	}
	UniformRotation
	{
		Period	6.953
	}
	LunarLambert	0.5
	Albedo	0.0613
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1940"
}

#1_"1942 Jablunka:Jablunka:1972 SA" "Sol" #1=
#2_"*Яблунка:1942 Jablunka:Jablunka:1972 SA" "Sol" #2=
#3_"1972 SA:*Яблунка:1942 Jablunka:Jablunka" "Sol" #3=
".:Jablunka:1942 Jablunka:1972 SA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1942 jablunka.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	8.383
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.530145114724
		SemiMajorAxis	2.318406420123
		Eccentricity	0.18454898056
		Inclination	24.359868405187
		AscendingNode	346.38309897452
		ArgOfPericenter	11.563019945781
		MeanAnomaly	348.476388410198
	}
	UniformRotation
	{
		Period	8.9116
	}
	LunarLambert	0.5
	Albedo	0.039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1942"
}

#1_"1943 Anteros:Anteros:1973 EC" "Sol" #1=
#2_"*Антерос:1943 Anteros:Anteros:1973 EC" "Sol" #2=
#3_"1973 EC:*Антерос:1943 Anteros:Anteros" "Sol" #3=
".:Anteros:1943 Anteros:1973 EC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.710916245866
		SemiMajorAxis	1.430475306579
		Eccentricity	0.255953724283
		Inclination	8.705353307342
		AscendingNode	246.348569054768
		ArgOfPericenter	338.361301595818
		MeanAnomaly	116.079714968502
	}
	UniformRotation
	{
		Period	2.867
	}
	LunarLambert	0.5
	Albedo	0.17
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1943"
}

#1_"1945 Wesselink:Wesselink:1930 OL:1934 NL:1970 GA2:1974 HM3" "Sol" #1=
#2_"*Весселинк:1945 Wesselink:Wesselink:1930 OL" "Sol" #2=
#3_"1930 OL:Wesselink:*Весселинк:1945 Wesselink" "Sol" #3=
".:Wesselink:1945 Wesselink:1930 OL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1945 wesselink.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.598
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.080580034548
		SemiMajorAxis	2.553538824686
		Eccentricity	0.181365531378
		Inclination	4.225821749513
		AscendingNode	142.630658562223
		ArgOfPericenter	194.729614756023
		MeanAnomaly	47.924310170589
	}
	UniformRotation
	{
		Period	3.5457
	}
	LunarLambert	0.5
	Albedo	0.45
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1945"
}

#1_"1946 Walraven:Walraven:1931 PH:1952 PB:1959 RE1:1966 TC:1972 JE1" "Sol" #1=
#2_"*Вальравен:1946 Walraven:Walraven:1931 PH" "Sol" #2=
#3_"1931 PH:Walraven:*Вальравен:1946 Walraven" "Sol" #3=
".:Walraven:1946 Walraven:1931 PH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1946 walraven.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.602
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.47619116882
		SemiMajorAxis	2.294723164722
		Eccentricity	0.234837139726
		Inclination	8.163127370045
		AscendingNode	17.270734049801
		ArgOfPericenter	339.905614036103
		MeanAnomaly	185.784219027606
	}
	UniformRotation
	{
		Period	10.21
	}
	LunarLambert	0.5
	Albedo	0.362
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1946"
}

#1_"1947 Iso-Heikkila:Iso-Heikkila:1935 EA" "Sol" #1=
#2_"*Исо-Хейккиля:1947 Iso-Heikkila:Iso-Heikkila:1935 EA" "Sol" #2=
#3_"1935 EA:*Исо-Хейккиля:1947 Iso-Heikkila:Iso-Heikkila" "Sol" #3=
".:Iso-Heikkila:1947 Iso-Heikkila:1935 EA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.72
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.600392271791
		SemiMajorAxis	3.153601621555
		Eccentricity	0.036548502707
		Inclination	11.912366298669
		AscendingNode	90.931395923838
		ArgOfPericenter	143.508110856533
		MeanAnomaly	23.463603764801
	}
	UniformRotation
	{
		Period	5.0158
	}
	LunarLambert	0.5
	Albedo	0.0976
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1947"
}

#1_"1949 Messina:Messina:1936 NE:1940 RK:1951 SP:1951 TN" "Sol" #1=
#2_"*Мессина:1949 Messina:Messina:1936 NE" "Sol" #2=
#3_"1936 NE:Messina:*Мессина:1949 Messina" "Sol" #3=
".:Messina:1949 Messina:1936 NE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1949 messina.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.78
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.680396866056
		SemiMajorAxis	2.383733134384
		Eccentricity	0.228822132018
		Inclination	4.653367353696
		AscendingNode	264.996871456373
		ArgOfPericenter	66.47030943525
		MeanAnomaly	291.040428148793
	}
	UniformRotation
	{
		Period	3.6491
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1949"
}

#1_"1950 Wempe:Wempe:1942 EO:1968 HH1" "Sol" #1=
#2_"*Вемпе:1950 Wempe:Wempe:1942 EO" "Sol" #2=
#3_"1942 EO:*Вемпе:1950 Wempe:Wempe" "Sol" #3=
".:Wempe:1950 Wempe:1942 EO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1950 wempe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.814
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.215242424512
		SemiMajorAxis	2.178396919851
		Eccentricity	0.084110577925
		Inclination	4.222593575838
		AscendingNode	69.967179426965
		ArgOfPericenter	53.272155423655
		MeanAnomaly	337.31728873393
	}
	UniformRotation
	{
		Period	16.788
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1950"
}

#1_"1951 Lick:Lick:1949 OA" "Sol" #1=
#2_"*Лик:1951 Lick:Lick:1949 OA" "Sol" #2=
#3_"1949 OA:*Лик:1951 Lick:Lick" "Sol" #3=
".:Lick:1951 Lick:1949 OA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	2.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.639595503966
		SemiMajorAxis	1.390440292325
		Eccentricity	0.061526649942
		Inclination	39.09424649249
		AscendingNode	130.756590321596
		ArgOfPericenter	140.561432314807
		MeanAnomaly	340.148984472041
	}
	UniformRotation
	{
		Period	5.3016
	}
	LunarLambert	0.5
	Albedo	0.0895
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1951"
}

#1_"1952 Hesburgh:Hesburgh:1951 JC:1936 ND:1939 AB:1940 GQ:1954 XC:1974 KQ" "Sol" #1=
#2_"*Хесберг:1952 Hesburgh:Hesburgh:1951 JC" "Sol" #2=
#3_"1951 JC:*Хесберг:1952 Hesburgh:Hesburgh" "Sol" #3=
".:Hesburgh:1952 Hesburgh:1951 JC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	17.775
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.485823329885
		SemiMajorAxis	3.110444165606
		Eccentricity	0.139004143986
		Inclination	14.233544362773
		AscendingNode	78.423354122484
		ArgOfPericenter	338.349294687914
		MeanAnomaly	357.145139291687
	}
	UniformRotation
	{
		Period	47.7
	}
	LunarLambert	0.5
	Albedo	0.1041
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1952"
}

#New3
#1_"1954 Kukarkin:Kukarkin:1952 PH:1957 QB" "Sol" #1=
#2_"*Кукаркин:1954 Kukarkin:Kukarkin:1952 PH" "Sol" #2=
#3_"1952 PH:*Кукаркин:Kukarkin:1954 Kukarkin" "Sol" #3=
".:Kukarkin:1954 Kukarkin:1952 PH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.83
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.030862352973
		SemiMajorAxis	2.936000702334
		Eccentricity	0.312757607193
		Inclination	14.794283737946
		AscendingNode	278.02175074148
		ArgOfPericenter	70.426834892052
		MeanAnomaly	324.18064243883
	}
	UniformRotation
	{
		Period	136.4
	}
	LunarLambert	0.5
	Albedo	0.261
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1954"
}

#1_"1958 Chandra:Chandra (asteroid):1970 SB:1947 HD:1959 RG1:1965 UN:1971 XA" "Sol" #1=
#2_"*Чандра:1958 Chandra:Chandra (asteroid):1970 SB" "Sol" #2=
#3_"1970 SB:*Чандра:1958 Chandra:Chandra (asteroid)" "Sol" #3=
".:Chandra (asteroid):1958 Chandra:1970 SB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.01
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.466548629218
		SemiMajorAxis	3.103154096952
		Eccentricity	0.167626117586
		Inclination	10.56070848281
		AscendingNode	345.034307625586
		ArgOfPericenter	319.256961602479
		MeanAnomaly	52.951826208907
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0801
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1958"
}

#New3
#1_"1959 Karbyshev:Karbyshev:1972 NB:1971 DN1" "Sol" #1=
#2_"*Карбышев:1959 Karbyshev:Karbyshev:1972 NB" "Sol" #2=
#3_"1972 NB:*Карбышев:1959 Karbyshev:Karbyshev" "Sol" #3=
".:Karbyshev:1959 Karbyshev:1972 NB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.448
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.525737667738
		SemiMajorAxis	2.316476304786
		Eccentricity	0.133305224366
		Inclination	6.199577826206
		AscendingNode	285.031742878324
		ArgOfPericenter	31.85633891304
		MeanAnomaly	282.139632902835
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.257
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1959"
}

#1_"1960 Guisan:Guisan:1973 UA:1961 VC1:1969 UR2" "Sol" #1=
#2_"*Гизан:1960 Guisan:Guisan:1973 UA" "Sol" #2=
#3_"1973 UA:*Гизан:1960 Guisan:Guisan" "Sol" #3=
".:Guisan:1960 Guisan:1973 UA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.275
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.018019584345
		SemiMajorAxis	2.527372358162
		Eccentricity	0.122523636183
		Inclination	8.466782078241
		AscendingNode	22.285820650195
		ArgOfPericenter	263.364022775058
		MeanAnomaly	189.483253481841
	}
	UniformRotation
	{
		Period	8.46
	}
	LunarLambert	0.5
	Albedo	0.0496
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1960"
}

#1_"1961 Dufour:Dufour:1973 WA:1927 UM:1952 BQ1:1962 YG:1969 AH:1973 SY3" "Sol" #1=
#2_"*Дюфур:1961 Dufour:Dufour:1973 WA" "Sol" #2=
#3_"1973 WA:*Дюфур:1961 Dufour:Dufour" "Sol" #3=
".:Dufour:1961 Dufour:1973 WA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.155
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.711746177368
		SemiMajorAxis	3.195266834454
		Eccentricity	0.121954334478
		Inclination	6.640200254707
		AscendingNode	29.691716245969
		ArgOfPericenter	57.878416938583
		MeanAnomaly	13.541130793777
	}
	UniformRotation
	{
		Period	15.79
	}
	LunarLambert	0.5
	Albedo	0.0402
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1961"
}

#1_"1963 Bezovec:Bezovec:1975 CB:1952 BS:1971 BW1" "Sol" #1=
#2_"*Безовец:1963 Bezovec:Bezovec:1975 CB" "Sol" #2=
#3_"1975 CB:*Безовец:1963 Bezovec:Bezovec" "Sol" #3=
".:Bezovec:1963 Bezovec:1975 CB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1963 bezovec.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	17.768
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.770445671458
		SemiMajorAxis	2.422458375557
		Eccentricity	0.210340606797
		Inclination	25.05143607687
		AscendingNode	106.92281196616
		ArgOfPericenter	355.642766764245
		MeanAnomaly	244.22994975224
	}
	UniformRotation
	{
		Period	18.16
	}
	LunarLambert	0.5
	Albedo	0.049
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1963"
}

#1_"1969 Alain:Alain:1935 CG:1930 FZ:1952 HW3:1952 KH1" "Sol" #1=
#2_"*Ален:1969 Alain:Alain:1935 CG" "Sol" #2=
#3_"1935 CG:*Ален:1969 Alain:Alain" "Sol" #3=
".:Alain:1969 Alain:1935 CG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.426617895974
		SemiMajorAxis	3.088024189395
		Eccentricity	0.157835649863
		Inclination	3.336220774966
		AscendingNode	209.20515912294
		ArgOfPericenter	347.538601452532
		MeanAnomaly	199.575010793058
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0682
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1969"
}

#1_"1970 Sumeria:Sumeria:1954 ER:1949 BF" "Sol" #1=
#2_"*Шумерия:1970 Sumeria:Sumeria:1954 ER" "Sol" #2=
#3_"1954 ER:*Шумерия:1970 Sumeria:Sumeria" "Sol" #3=
".:Sumeria:1970 Sumeria:1954 ER" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.635555767382
		SemiMajorAxis	2.780112722999
		Eccentricity	0.158568619839
		Inclination	7.069144031839
		AscendingNode	312.420896461222
		ArgOfPericenter	192.636058092616
		MeanAnomaly	58.810059979604
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0585
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1970"
}

#New3
#1_"1977 Shura:Shura:1970 QY:1942 RW:1952 UT1:1968 DE" "Sol" #1=
#2_"*Шура:1977 Shura:Shura:1970 QY" "Sol" #2=
#3_"1970 QY:*Шура:1977 Shura:Shura" "Sol" #3=
".:Shura:1977 Shura:1970 QY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.606
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.638650999114
		SemiMajorAxis	2.781350134607
		Eccentricity	0.073047339285
		Inclination	7.764338813137
		AscendingNode	332.258690167676
		ArgOfPericenter	310.436194440074
		MeanAnomaly	120.986570215304
	}
	UniformRotation
	{
		Period	7.461
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1977"
}

#1_"1978 Patrice:Patrice:1971 LD:1942 PL:1952 WC:1955 RJ1:1965 VC:1968 OY:1975 VQ8" "Sol" #1=
#2_"*Патрис:1978 Patrice:Patrice:1971 LD" "Sol" #2=
#3_"1971 LD:Patrice:*Патрис:1978 Patrice" "Sol" #3=
".:Patrice:1978 Patrice:1971 LD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1978 patrice.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.366
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.250096715857
		SemiMajorAxis	2.19411164151
		Eccentricity	0.21367261636
		Inclination	4.343877213553
		AscendingNode	54.288375778453
		ArgOfPericenter	268.853658092441
		MeanAnomaly	330.973929166347
	}
	UniformRotation
	{
		Period	5.8812
	}
	LunarLambert	0.5
	Albedo	0.27
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1978"
}

#1_"1980 Tezcatlipoca:Tezcatlipoca:1950 LA" "Sol" #1=
#2_"*Тескатлипока:1980 Tezcatlipoca:Tezcatlipoca:1950 LA" "Sol" #2=
#3_"1950 LA:*Тескатлипока:1980 Tezcatlipoca:Tezcatlipoca" "Sol" #3=
".:Tezcatlipoca:1980 Tezcatlipoca:1950 LA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1980 tezcatlipoca.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.235110281705
		SemiMajorAxis	1.709466138944
		Eccentricity	0.364948421152
		Inclination	26.860866835452
		AscendingNode	246.617646265994
		ArgOfPericenter	115.399480606401
		MeanAnomaly	247.719504696417
	}
	UniformRotation
	{
		Period	7.2461
	}
	LunarLambert	0.5
	Albedo	0.25
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1980"
}

#1_"1981 Midas:Midas:1973 EA" "Sol" #1=
#2_"*Мидас:1981 Midas:Midas:1973 EA" "Sol" #2=
#3_"1973 EA:*Мидас:1981 Midas:Midas" "Sol" #3=
".:Midas:1981 Midas:1973 EA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.366691287282
		SemiMajorAxis	1.775915399457
		Eccentricity	0.650216336131
		Inclination	39.828678666914
		AscendingNode	356.920245970322
		ArgOfPericenter	267.803025655808
		MeanAnomaly	200.057838855993
	}
	UniformRotation
	{
		Period	5.22
	}
	LunarLambert	0.5
	Albedo	0.13
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1981"
}

#1_"1984 Fedynskij:Fedynskij:1926 TN:1931 RQ:1935 KA:1942 VU:1961 KB:1973 SE3" "Sol" #1=
#2_"*Федынский:1984 Fedynskij:Fedynskij:1926 TN" "Sol" #2=
#3_"1926 TN:*Федынский:1984 Fedynskij:Fedynskij" "Sol" #3=
".:Fedynskij:1984 Fedynskij:1926 TN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.99
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.225597764333
		SemiMajorAxis	3.011284924949
		Eccentricity	0.090053940407
		Inclination	4.79247561721
		AscendingNode	185.708995342766
		ArgOfPericenter	128.21641659742
		MeanAnomaly	9.828434668125
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0445
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1984"
}

#1_"1985 Hopmann:Hopmann:1929 AE:1951 CA2:1951 CP:1952 KE:1964 PJ:1973 AA4" "Sol" #1=
#2_"*Хопманн:1985 Hopmann:Hopmann:1929 AE" "Sol" #2=
#3_"1929 AE:*Хопманн:1985 Hopmann:Hopmann" "Sol" #3=
".:Hopmann:1985 Hopmann:1929 AE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1985 hopmann.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	17.755
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.520709358199
		SemiMajorAxis	3.123617072256
		Eccentricity	0.153468263725
		Inclination	17.157734497237
		AscendingNode	305.173517542084
		ArgOfPericenter	233.994523228092
		MeanAnomaly	155.876712379084
	}
	UniformRotation
	{
		Period	17.48
	}
	LunarLambert	0.5
	Albedo	0.039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1985"
}

#1_"1987 Kaplan:Kaplan:1952 RH" "Sol" #1=
#2_"*Каплан:1987 Kaplan:Kaplan:1952 RH" "Sol" #2=
#3_"1952 RH:*Каплан:1987 Kaplan:Kaplan" "Sol" #3=
".:Kaplan:1987 Kaplan:1952 RH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1987 kaplan.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.508
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.678263587518
		SemiMajorAxis	2.382811918855
		Eccentricity	0.22689028642
		Inclination	23.645107963874
		AscendingNode	314.230948498223
		ArgOfPericenter	38.176267226739
		MeanAnomaly	238.966052399067
	}
	UniformRotation
	{
		Period	9.453
	}
	LunarLambert	0.5
	Albedo	0.262
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1987"
}

#1_"1994 Shane:Shane:1961 TE:1939 RN" "Sol" #1=
#2_"*Шейн:1994 Shane:Shane:1961 TE" "Sol" #2=
#3_"1961 TE:*Шейн:1994 Shane:Shane" "Sol" #3=
".:Shane:1994 Shane:1961 TE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.575
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.385270631632
		SemiMajorAxis	2.679119788369
		Eccentricity	0.207899019918
		Inclination	10.205748191065
		AscendingNode	245.014899664923
		ArgOfPericenter	88.751991270559
		MeanAnomaly	75.177751510891
	}
	UniformRotation
	{
		Period	8.22
	}
	LunarLambert	0.5
	Albedo	0.064
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1994"
}

#1_"1996 Adams:Adams:1961 UA:1932 RM:1961 TB2:1969 TW2:1971 BY1:1973 SJ3" "Sol" #1=
#2_"*Адамс:1996 Adams:Adams:1961 UA" "Sol" #2=
#3_"1961 UA:*Адамс:1996 Adams:Adams" "Sol" #3=
".:Adams:1996 Adams:1961 UA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1996 adams.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.208
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.091278989099
		SemiMajorAxis	2.558000326225
		Eccentricity	0.138703834898
		Inclination	15.14006284024
		AscendingNode	1.113826152071
		ArgOfPericenter	354.245007683453
		MeanAnomaly	68.30405494617
	}
	UniformRotation
	{
		Period	3.311
	}
	LunarLambert	0.5
	Albedo	0.183
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1996"
}

#1_"1997 Leverrier:Leverrier:1963 RC:1940 SF:1950 TS3:1953 QB:1973 SX4:1973 UF" "Sol" #1=
#2_"*Леверье:1997 Leverrier:Leverrier:1963 RC" "Sol" #2=
#3_"1963 RC:*Леверье:1997 Leverrier:Leverrier" "Sol" #3=
".:Leverrier:1997 Leverrier:1963 RC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1997 leverrier.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	3.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.282951625545
		SemiMajorAxis	2.208873546486
		Eccentricity	0.206946590431
		Inclination	6.069346028182
		AscendingNode	353.220653265551
		ArgOfPericenter	0.744136714232
		MeanAnomaly	213.154337939612
	}
	UniformRotation
	{
		Period	8.0153
	}
	LunarLambert	0.5
	Albedo	0.1662
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1997"
}

#1_"1999 Hirayama:Hirayama:1973 DR:1935 GF:1940 EH:1951 EY1:1951 FA:1965 UF:1969 NB:1975 NE" "Sol" #1=
#2_"*Хираяма:1999 Hirayama:Hirayama:1973 DR" "Sol" #2=
#3_"1973 DR:*Хираяма:1999 Hirayama:Hirayama" "Sol" #3=
".:Hirayama:1999 Hirayama:1973 DR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.975
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.499220694918
		SemiMajorAxis	3.115506281795
		Eccentricity	0.114287339795
		Inclination	12.53379578074
		AscendingNode	148.044859603741
		ArgOfPericenter	356.683142585808
		MeanAnomaly	220.426395655008
	}
	UniformRotation
	{
		Period	15.63
	}
	LunarLambert	0.5
	Albedo	0.0882
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1999"
}

#1_"2001 Einstein:Einstein:1973 EB" "Sol" #1=
#2_"*Эйнштейн:2001 Einstein:Einstein:1973 EB" "Sol" #2=
#3_"1973 EB:Einstein:*Эйнштейн:2001 Einstein" "Sol" #3=
".:Einstein:2001 Einstein:1973 EB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2001 einstein.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.988
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.688282738513
		SemiMajorAxis	1.933353018443
		Eccentricity	0.098592919646
		Inclination	22.683935433081
		AscendingNode	357.083119968902
		ArgOfPericenter	217.673863889384
		MeanAnomaly	77.345206335716
	}
	UniformRotation
	{
		Period	5.487
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2001"
}

#1_"2002 Euler:Euler:1973 QQ1:1938 DW:1942 GJ:1953 EB:1973 SJ2" "Sol" #1=
#2_"*Эйлер:2002 Euler:Euler:1973 QQ1" "Sol" #2=
#3_"1973 QQ1:*Эйлер:2002 Euler:Euler" "Sol" #3=
".:Euler:2002 Euler:1973 QQ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2002 euler.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	9.419
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.759267215728
		SemiMajorAxis	2.417668006046
		Eccentricity	0.068737369164
		Inclination	8.501676547179
		AscendingNode	178.652258112806
		ArgOfPericenter	53.956360506175
		MeanAnomaly	97.46404969174
	}
	UniformRotation
	{
		Period	5.9929
	}
	LunarLambert	0.5
	Albedo	0.036
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2002"
}

#1_"2007 McCuskey:McCuskey:1963 SQ:1936 HP:1941 SW1:1943 EL:1947 GE:1951 LV:1952 SB1:1952 UR1: #1=
#1_1958 GB:1963 TL:1963 VC:1965 CA:1965 CC:1966 OB:1969 EC1:1970 QD1:A921 EK" "Sol" #1=
#2_"*МакКаски:2007 McCuskey:McCuskey:1963 SQ" "Sol" #2=
#3_"1963 SQ:*МакКаски:2007 McCuskey:McCuskey" "Sol" #3=
".:McCuskey:2007 McCuskey:1963 SQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.681815350505
		SemiMajorAxis	2.384345581237
		Eccentricity	0.114857785912
		Inclination	3.04246839505
		AscendingNode	17.046297896044
		ArgOfPericenter	185.534276726067
		MeanAnomaly	139.369377906479
	}
	UniformRotation
	{
		Period	8.603
	}
	LunarLambert	0.5
	Albedo	0.0703
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007"
}

#1_"2008 Konstitutsiya:Konstitutsiya:1973 SV4:1938 SV:1950 VG:1953 EH:1953 FE:1967 RY:1973 UE:1976 ED" "Sol" #1=
#2_"*Конституция:2008 Konstitutsiya:Konstitutsiya:1973 SV4" "Sol" #2=
#3_"1973 SV4:*Конституция:2008 Konstitutsiya:Konstitutsiya" "Sol" #3=
".:Konstitutsiya:2008 Konstitutsiya:1973 SV4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.13
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.759309351034
		SemiMajorAxis	3.212980843239
		Eccentricity	0.099200286397
		Inclination	20.656148030068
		AscendingNode	15.667204518352
		ArgOfPericenter	203.104321750197
		MeanAnomaly	223.312810520235
	}
	UniformRotation
	{
		Period	11.2692
	}
	LunarLambert	0.5
	Albedo	0.0531
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2008"
}

#1_"2009 Voloshina:Voloshina:1968 UL:1926 FF:1929 TO:1957 WF2:1959 EC:1970 EL1:1973 SP6:1973 SU3" "Sol" #1=
#2_"*Волошина:2009 Voloshina:Voloshina:1968 UL" "Sol" #2=
#3_"1968 UL:*Волошина:2009 Voloshina:Voloshina" "Sol" #3=
".:Voloshina:2009 Voloshina:1968 UL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.279
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.500431762056
		SemiMajorAxis	3.115963673731
		Eccentricity	0.142326209643
		Inclination	2.86087034762
		AscendingNode	107.552690324587
		ArgOfPericenter	6.203795935918
		MeanAnomaly	261.359024136535
	}
	UniformRotation
	{
		Period	5.896
	}
	LunarLambert	0.5
	Albedo	0.12
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2009"
}

#New3
#1_"2011 Veteraniya:Veteraniya:1970 QB1:1955 RE:1955 SN1:1959 UA" "Sol" #1=
#2_"*Ветерания:2011 Veteraniya:Veteraniya:1970 QB1" "Sol" #2=
#3_"1970 QB1:*Ветерания:2011 Veteraniya:Veteraniya" "Sol" #3=
".:Veteraniya:2011 Veteraniya:1970 QB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"vesta.dds"
	Color	[ 1.000 0.951 0.842 ]
	BlendTexture	true
	Radius	2.596
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.688074260237
		SemiMajorAxis	2.387046998402
		Eccentricity	0.148469633568
		Inclination	6.178864096377
		AscendingNode	338.52308067826
		ArgOfPericenter	3.745605260234
		MeanAnomaly	282.052379312121
	}
	UniformRotation
	{
		Period	8.209
	}
	LunarLambert	0.5
	Albedo	0.463
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011"
}

#New3
#1_"2015 Kachuevskaya:Kachuevskaya:1972 RA3:1939 FQ:1940 SA:1958 UK:1971 HA" "Sol" #1=
#2_"*Качуевська:2015 Kachuevskaya:Kachuevskaya:1972 RA3" "Sol" #2=
#3_"1972 RA3:*Качуевська:2015 Kachuevskaya:Kachuevskaya" "Sol" #3=
".:Kachuevskaya:2015 Kachuevskaya:1972 RA3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.904
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.569572618208
		SemiMajorAxis	2.335636998201
		Eccentricity	0.104239632333
		Inclination	11.911448278983
		AscendingNode	344.496448707813
		ArgOfPericenter	274.486299983132
		MeanAnomaly	291.395719403909
	}
	UniformRotation
	{
		Period	42.532
	}
	LunarLambert	0.5
	Albedo	0.143
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2015"
}


#1_"2016 Heinemann:Heinemann:1938 SE:1927 SM:1930 DF:1949 SB1:1971 OB1:1971 QP2:1972 VY:1977 RZ7: #1=
#1_A905 UF" "Sol" #1=
#2_"*Хойнеманн:2016 Heinemann:Heinemann:1938 SE" "Sol" #2=
#3_"1938 SE:*Хойнеманн:2016 Heinemann:Heinemann" "Sol" #3=
".:Heinemann:2016 Heinemann:1938 SE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	10.925
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.534018740423
		SemiMajorAxis	3.128635355771
		Eccentricity	0.191702902529
		Inclination	0.919490066262
		AscendingNode	16.996331536467
		ArgOfPericenter	341.204474594088
		MeanAnomaly	254.348240280768
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1019
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2016"
}

#1_"2020 Ukko:Ukko:1936 FR:1952 HA2:1973 FP1" "Sol" #1=
#2_"*Укко:2020 Ukko:Ukko:1936 FR" "Sol" #2=
#3_"1936 FR:*Укко:2020 Ukko:Ukko" "Sol" #3=
".:Ukko:2020 Ukko:1936 FR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.76
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.252195803744
		SemiMajorAxis	3.021494472383
		Eccentricity	0.06933691224
		Inclination	11.140941383233
		AscendingNode	148.846720807126
		ArgOfPericenter	329.925444926638
		MeanAnomaly	47.471555496067
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1051
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2020"
}

#1_"2025 Nortia:Nortia:1953 LG:1935 EQ:1937 RR:1951 AP1:1952 FB1:1959 PF:1974 CR:1976 SQ" "Sol" #1=
#2_"*Нортия:2025 Nortia:Nortia:1953 LG" "Sol" #2=
#3_"1953 LG:*Нортия:2025 Nortia:Nortia" "Sol" #3=
".:Nortia:2025 Nortia:1953 LG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.115
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.628319287753
		SemiMajorAxis	3.164076798352
		Eccentricity	0.11117297623
		Inclination	7.021897973768
		AscendingNode	329.073022899917
		ArgOfPericenter	310.0558468725
		MeanAnomaly	316.663484486613
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0689
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2025"
}

#1_"2032 Ethel:Ethel:1970 OH:1952 DU:1960 WM:1965 UG1:1971 UD3" "Sol" #1=
#2_"*Этель:2032 Ethel:Ethel:1970 OH" "Sol" #2=
#3_"1970 OH:*Этель:2032 Ethel:Ethel" "Sol" #3=
".:Ethel:2032 Ethel:1970 OH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.155
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.368054794106
		SemiMajorAxis	3.065767095208
		Eccentricity	0.130511098286
		Inclination	1.514325474113
		AscendingNode	30.118823139853
		ArgOfPericenter	295.13516959324
		MeanAnomaly	87.509827977731
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0233
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2032"
}

#1_"2038 Bistro:Bistro:1973 WF:1941 KD" "Sol" #1=
#2_"*Бистро:2038 Bistro:Bistro:1973 WF" "Sol" #2=
#3_"1973 WF:*Бистро:2038 Bistro:Bistro" "Sol" #3=
".:Bistro:2038 Bistro:1973 WF:1941 KD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.29
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.799276960443
		SemiMajorAxis	2.434791822647
		Eccentricity	0.091311846878
		Inclination	14.805622810301
		AscendingNode	73.520722153771
		ArgOfPericenter	184.075407392881
		MeanAnomaly	105.213199229772
	}
	UniformRotation
	{
		Period	17.051
	}
	LunarLambert	0.5
	Albedo	0.1342
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2038"
}

#1_"2039 Payne-Gaposchkin:Payne-Gaposchkin:1974 CA" "Sol" #1=
#2_"*Пейн-Гапошкин:2039 Payne-Gaposchkin:Payne-Gaposchkin:1974 CA" "Sol" #2=
#3_"1974 CA:*Пейн-Гапошкин:2039 Payne-Gaposchkin:Payne-Gaposchkin" "Sol" #3=
".:Payne-Gaposchkin:2039 Payne-Gaposchkin:1974 CA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.662372656015
		SemiMajorAxis	3.176826502861
		Eccentricity	0.133794970405
		Inclination	2.525754502677
		AscendingNode	95.876607471793
		ArgOfPericenter	41.787259898909
		MeanAnomaly	83.896724405848
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0253
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2039"
}

#1_"2041 Lancelot:Lancelot:2523 P-L:1972 XO2:1973 AP3" "Sol" #1=
#2_"*Ланселот:2041 Lancelot:Lancelot:1960-2041*:2523 P-L" "Sol" #2=
#3_"1960-2041*:*Ланселот:2041 Lancelot:Lancelot:2523 P-L" "Sol" #3=
".:Lancelot:2041 Lancelot:1960-2041*:2523 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.685
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.602908132879
		SemiMajorAxis	3.154546011318
		Eccentricity	0.19988055224
		Inclination	2.98067467683
		AscendingNode	134.082482501948
		ArgOfPericenter	274.348615649342
		MeanAnomaly	212.904015453998
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1303
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2041"
}

#1_"2043 Ortutay:Ortutay:1936 TH:1935 PE:1947 TD:1947 VA:1951 LQ:1952 QG:1958 UN:1958 XR:1963 SN: #1=
#1_1969 UY:1971 DB:1972 HS1:1974 SW1:1975 XT5:A908 QB" "Sol" #1=
#2_"*Ортутай:2043 Ortutay:Ortutay:1936 TH" "Sol" #2=
#3_"1936 TH:*Ортутай:2043 Ortutay:Ortutay" "Sol" #3=
".:Ortutay:2043 Ortutay:1936 TH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.345
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.493479431093
		SemiMajorAxis	3.113337482697
		Eccentricity	0.107946101527
		Inclination	3.078754705572
		AscendingNode	321.297452498901
		ArgOfPericenter	60.439890919768
		MeanAnomaly	102.924980204943
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0423
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2043"
}

#1_"2044 Wirt:Wirt:1950 VE" "Sol" #1=
#2_"*Вирт:2044 Wirt:Wirt:1950 VE" "Sol" #2=
#3_"1950 VE:*Вирт:2044 Wirt:Wirt" "Sol" #3=
".:Wirt:2044 Wirt:1950 VE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.23
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.673217347644
		SemiMajorAxis	2.380632087481
		Eccentricity	0.343685631112
		Inclination	23.97148955726
		AscendingNode	53.670879776342
		ArgOfPericenter	50.407652705525
		MeanAnomaly	145.066144620575
	}
	UniformRotation
	{
		Period	3.6898
	}
	LunarLambert	0.5
	Albedo	0.1907
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2044"
}

#1_"2005 2044 I" "Sol/2044 Wirt" #1=
#2_"2005 2044 I" "Sol/2044 Wirt" #2=
#3_"2005 2044 I" "Sol/2044 Wirt" #3=
".:2005 2044 I" "Sol/2044 Wirt" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.7904
		SemiMajorAxis	12
	}
	LunarLambert	0.5
	Albedo	0.1907
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-02044.html"
}

#New3
#1_"2046 Leningrad:Leningrad:1968 UD1:1929 VK:1934 RK:1940 UF:1955 HN:1957 YV:1973 QS:1973 SH3" "Sol" #1=
#2_"*Ленинград:2046 Leningrad:Leningrad:1968 UD1" "Sol" #2=
#3_"1968 UD1:*Ленинград:2046 Leningrad:Leningrad" "Sol" #3=
".:Leningrad:2046 Leningrad:1968 UD1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.984
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.607992457806
		SemiMajorAxis	3.156454105211
		Eccentricity	0.17940304557
		Inclination	2.735579456612
		AscendingNode	73.570034712901
		ArgOfPericenter	284.257581344922
		MeanAnomaly	288.846333179204
	}
	UniformRotation
	{
		Period	5.296
	}
	LunarLambert	0.5
	Albedo	0.085
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2046"
}

#1_"2052 Tamriko:Tamriko:1976 UN:1928 TD:1939 YA:1942 JE:1949 UV:1951 CP1:1952 FL:1952 HL2:1954 TS: #1=
#1_1975 WB2:A902 UB" "Sol" #1=
#2_"*Тамрико:2052 Tamriko:Tamriko:1976 UN" "Sol" #2=
#3_"1976 UN:*Тамрико:2052 Tamriko:Tamriko" "Sol" #3=
".:Tamriko:2052 Tamriko:1976 UN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	15.225
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.211281917763
		SemiMajorAxis	3.0057826772
		Eccentricity	0.085273627947
		Inclination	9.501927131124
		AscendingNode	213.877311896308
		ArgOfPericenter	205.155230908915
		MeanAnomaly	150.88447556614
	}
	UniformRotation
	{
		Period	7.462
	}
	LunarLambert	0.5
	Albedo	0.1225
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2052"
}

#1_"2054 Gawain:Gawain:4097 P-L:1973 FG1" "Sol" #1=
#2_"*Гаваин:2054 Gawain:Gawain:1960-2054*:4097 P-L" "Sol" #2=
#3_"1960-2054*:*Гаваин:2054 Gawain:Gawain:4097 P-L" "Sol" #3=
".:Gawain:2054 Gawain:1960-2054*:4097 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.104009594499
		SemiMajorAxis	2.964391230899
		Eccentricity	0.099703341986
		Inclination	3.789873869396
		AscendingNode	293.266326711534
		ArgOfPericenter	183.771882767131
		MeanAnomaly	122.477808489935
	}
	UniformRotation
	{
		Period	11.1098
	}
	LunarLambert	0.5
	Albedo	0.0697
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2054"
}

#1_"2057 Rosemary:Rosemary:1934 RQ:1967 TH:1977 SR" "Sol" #1=
#2_"*Розмари:2057 Rosemary:Rosemary:1934 RQ" "Sol" #2=
#3_"1934 RQ:*Розмари:2057 Rosemary:Rosemary" "Sol" #3=
".:Rosemary:2057 Rosemary:1934 RQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.404001809954
		SemiMajorAxis	3.079438409382
		Eccentricity	0.234628790296
		Inclination	1.438699305567
		AscendingNode	15.351057811926
		ArgOfPericenter	17.787929309241
		MeanAnomaly	285.717018580967
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1185
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2057"
}

#1_"2058 Roka:Roka:1938 BH:1951 NP:1962 NA:1963 UM:1974 SZ1:1978 AE:1985 UL3" "Sol" #1=
#2_"*Рока:2058 Roka:Roka:1938 BH" "Sol" #2=
#3_"1938 BH:*Рока:2058 Roka:Roka" "Sol" #3=
".:Roka:2058 Roka:1938 BH:1951 NP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.68
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.523000730821
		SemiMajorAxis	3.124481318154
		Eccentricity	0.149358563711
		Inclination	2.539380799643
		AscendingNode	95.481567611425
		ArgOfPericenter	179.825386429137
		MeanAnomaly	199.778938517341
	}
	UniformRotation
	{
		Period	10.04
	}
	LunarLambert	0.5
	Albedo	0.1542
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2058"
}

#1_"2060 Chiron:Chiron:1977 UB:95P" "Sol" #1=
#2_"*Хирон:2060 Chiron:Chiron:1977 UB:95P" "Sol" #2=
#3_"1977 UB:*Хирон:2060 Chiron:Chiron:95P" "Sol" #3=
".:Chiron:2060 Chiron:1977 UB:95P" "Sol" #4=
{
	Class	"asteroid"  # Классифицируется и как комета

	# Class	"comet"
	Mesh	"roughsphere.cmod"
	Texture	"comet.dds"
	Radius	83
	OrbitColor	[ 0.611765 0.317647 0.12549 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	50.367656524406
		SemiMajorAxis	13.63836664794301
		Eccentricity	0.3820988962489677
		Inclination	6.93836227190589
		AscendingNode	209.2780463186957
		ArgOfPericenter	339.3496505871891
		MeanAnomaly	134.5261255874151
	}
	Rings
	{
		Inner	291
		Outer	313
		Texture	"centaur-rings.png"
	}
	UniformRotation
	{
		Period	5.918
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"https://en.wikipedia.org/wiki/2060_Chiron"
}

#1_"2061 Anza:Anza:1960 UA" "Sol" #1=
#2_"*Анса:2061 Anza:Anza:1960 UA" "Sol" #2=
#3_"1960 UA:*Анса:2061 Anza:Anza" "Sol" #3=
".:Anza:2061 Anza:1960 UA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.408329315377
		SemiMajorAxis	2.264760239165
		Eccentricity	0.536978784928
		Inclination	3.773192863534
		AscendingNode	207.625282814944
		ArgOfPericenter	156.470083428713
		MeanAnomaly	323.275030080048
	}
	UniformRotation
	{
		Period	11.5
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2061"
}

#1_"2062 Aten:Aten:1976 AA" "Sol" #1=
#2_"*Атон:2062 Aten:Aten:1976 AA" "Sol" #2=
#3_"1976 AA:*Атон:2062 Aten:Aten" "Sol" #3=
".:Aten:2062 Aten:1976 AA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.55
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.950814625508
		SemiMajorAxis	0.966922725339
		Eccentricity	0.182745636711
		Inclination	18.934889418424
		AscendingNode	108.572096845824
		ArgOfPericenter	147.94903169844
		MeanAnomaly	205.778589072609
	}
	UniformRotation
	{
		Period	40.77
	}
	LunarLambert	0.5
	Albedo	0.26
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2062"
}

#1_"2063 Bacchus:Bacchus:1977 HB" "Sol" #1=
#2_"*Бахус:2063 Bacchus:Bacchus:1977 HB" "Sol" #2=
#3_"1977 HB:*Бахус:2063 Bacchus:Bacchus" "Sol" #3=
".:Bacchus:2063 Bacchus:1977 HB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2063 bacchus.cmod"
	MeshCenter	[ -0.00936 -0.00610 0.00289 ]
	Texture	"bacchus.jpg"
	Radius	1.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.1189823567767
		SemiMajorAxis	1.077812851809965
		Eccentricity	0.3493591230032135
		Inclination	9.432425275473552
		AscendingNode	33.1108977627244
		ArgOfPericenter	55.29954702156508
		MeanAnomaly	312.4660429303114
	}
	UniformRotation
	{
		Period	14.904
		Inclination	116
		AscendingNode	114
	}
	LunarLambert	0.5
	Albedo	0.56
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2063"
}

#1_"2064 Thomsen:Thomsen:1942 RQ:1958 RO:1974 OK:1977 FE3:1977 KA:A913 QB" "Sol" #1=
#2_"*Томсен:2064 Thomsen:Thomsen:1942 RQ" "Sol" #2=
#3_"1942 RQ:*Томсен:2064 Thomsen:Thomsen" "Sol" #3=
".:Thomsen:2064 Thomsen:1942 RQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2064 thomsen.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	6.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.218804202903
		SemiMajorAxis	2.180005411368
		Eccentricity	0.329407344386
		Inclination	5.698096591148
		AscendingNode	302.197209579796
		ArgOfPericenter	2.581442483014
		MeanAnomaly	196.027362719397
	}
	UniformRotation
	{
		Period	4.233
	}
	LunarLambert	0.5
	Albedo	0.0549
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2064"
}

#1_"2066 Palala:Palala:1934 LB:1931 TZ:1934 LH:1952 DH2:1967 GC:1974 CZ:1975 NZ:1975 QM" "Sol" #1=
#2_"*Палала:2066 Palala:Palala:1934 LB" "Sol" #2=
#3_"1934 LB:*Палала:2066 Palala:Palala" "Sol" #3=
".:Palala:2066 Palala:1934 LB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.705667147094
		SemiMajorAxis	2.394632118777
		Eccentricity	0.128050178236
		Inclination	3.753718487133
		AscendingNode	117.226494929061
		ArgOfPericenter	109.311778121308
		MeanAnomaly	288.636713432625
	}
	UniformRotation
	{
		Period	9.732
	}
	LunarLambert	0.5
	Albedo	0.0491
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2066"
}

#1_"2067 Aksnes:Aksnes:1936 DD:1951 AG:1965 UV:1971 QH2:1973 UR2:1975 BD1" "Sol" #1=
#2_"*Акснес:2067 Aksnes:Aksnes:1936 DD" "Sol" #2=
#3_"1936 DD:*Акснес:2067 Aksnes:Aksnes" "Sol" #3=
".:Aksnes:2067 Aksnes:1936 DD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	21.295
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.903124683835
		SemiMajorAxis	3.967592746247
		Eccentricity	0.181886186367
		Inclination	3.079279085432
		AscendingNode	150.242273408773
		ArgOfPericenter	297.740245182293
		MeanAnomaly	65.914116961414
	}
	UniformRotation
	{
		Period	17.75
	}
	LunarLambert	0.5
	Albedo	0.0626
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2067"
}

#1_"2068 Dangreen:Dangreen:1948 AD:1931 KJ:1939 DJ:1955 TA1:1972 JS:1974 VR2" "Sol" #1=
#2_"*Дангрин:2068 Dangreen:Dangreen:1948 AD" "Sol" #2=
#3_"1948 AD:*Дангрин:2068 Dangreen:Dangreen" "Sol" #3=
".:Dangreen:2068 Dangreen:1948 AD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.616318653377
		SemiMajorAxis	2.772415925047
		Eccentricity	0.098649725728
		Inclination	12.893614329511
		AscendingNode	96.01322286871
		ArgOfPericenter	319.360915693208
		MeanAnomaly	233.958583920674
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0393
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2068"
}

#1_"2069 Hubble:Hubble (asteroid):1955 FT:1953 VN1:1969 TB1:1970 WA1:1975 TT3" "Sol" #1=
#2_"*Хаббл (астероид):2069 Hubble:Hubble (asteroid):1955 FT" "Sol" #2=
#3_"1955 FT:*Хаббл (астероид):2069 Hubble:Hubble (asteroid)" "Sol" #3=
".:Hubble (asteroid):2069 Hubble:1955 FT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.612821733125
		SemiMajorAxis	3.158265947752
		Eccentricity	0.184561568411
		Inclination	9.100076840844
		AscendingNode	46.437764737135
		ArgOfPericenter	69.968311812945
		MeanAnomaly	266.621898669168
	}
	UniformRotation
	{
		Period	32.52
	}
	LunarLambert	0.5
	Albedo	0.0538
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2069"
}

#New3
#1_"2072 Kosmodemyanskaya:Kosmodemyanskaya:1973 QE2:1944 BD:1958 XY:1962 XL1:1975 EL" "Sol" #1=
#2_"*Космодемьянская:2072 Kosmodemyanskaya:Kosmodemyanskaya:1973 QE2" "Sol" #2=
#3_"1973 QE2:*Космодемьянская:2072 Kosmodemyanskaya:Kosmodemyanskaya" "Sol" #3=
".:Kosmodemyanskaya:2072 Kosmodemyanskaya:1973 QE2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.422
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.837304711332
		SemiMajorAxis	2.451011730244
		Eccentricity	0.163267122169
		Inclination	4.741921316595
		AscendingNode	26.200044800377
		ArgOfPericenter	38.426026997645
		MeanAnomaly	113.247989572529
	}
	UniformRotation
	{
		Period	4.4
	}
	LunarLambert	0.5
	Albedo	0.522
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2072"
}

#1_"2081 Sazava:Sazava:1976 DH:1946 LA:1950 NH:1950 NP:1958 RJ:1968 DD:1974 XM" "Sol" #1=
#2_"*Сазава:2081 Sazava:Sazava:1976 DH:1946 LA" "Sol" #2=
#3_"1976 DH:*Сазава:2081 Sazava:Sazava:1946 LA" "Sol" #3=
".:Sazava:2081 Sazava:1976 DH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.335
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.837770590805
		SemiMajorAxis	2.451210107844
		Eccentricity	0.162114481664
		Inclination	3.903565279847
		AscendingNode	66.34646905997
		ArgOfPericenter	223.975703674102
		MeanAnomaly	282.984847967248
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0479
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2081"
}

#1_"2084 Okayama:Okayama:1935 CK:1931 AD1:1939 GV:1944 QN:1948 RA1:1948 TH:1950 EL:1952 YC: #1=
#1_1959 SA:1963 UV:1965 HA:1969 KD:1970 PK:1974 UK:1976 GR" "Sol" #1=
#2_"*Окаяма:2084 Okayama:Okayama:1935 CK" "Sol" #2=
#3_"1935 CK:*Окаяма:2084 Okayama:Okayama" "Sol" #3=
".:Okayama:2084 Okayama:1935 CK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.685
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.707878490708
		SemiMajorAxis	2.39558468282
		Eccentricity	0.102411904844
		Inclination	4.840731929128
		AscendingNode	149.012937105133
		ArgOfPericenter	247.79676665898
		MeanAnomaly	285.19730502403
	}
	UniformRotation
	{
		Period	4.547
	}
	LunarLambert	0.5
	Albedo	0.0621
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2084"
}

#1_"2091 Sampo:Sampo:1941 HO:1931 MG:1938 UF1:1951 GA1:1952 LB:1956 EP:1971 BH1:1978 NB:A924 BB" "Sol" #1=
#2_"*Сампо:2091 Sampo:Sampo:1941 HO" "Sol" #2=
#3_"1941 HO:*Сампо:2091 Sampo:Sampo" "Sol" #3=
".:Sampo:2091 Sampo:1941 HO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	15.24
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.231238798652
		SemiMajorAxis	3.013451657207
		Eccentricity	0.061812594418
		Inclination	11.379577190749
		AscendingNode	114.545947256728
		ArgOfPericenter	319.009123225074
		MeanAnomaly	171.136966617123
	}
	UniformRotation
	{
		Period	71.3
	}
	LunarLambert	0.5
	Albedo	0.1582
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2091"
}

#1_"2094 Magnitka:Magnitka:1971 TC2:1941 WK:1951 WP:1956 EB:1964 TD:1968 WE:1977 FG" "Sol" #1=
#2_"*Магнитка:2094 Magnitka:Magnitka:1971 TC2" "Sol" #2=
#3_"1971 TC2:*Магнитка:2094 Magnitka:Magnitka" "Sol" #3=
".:Magnitka:2094 Magnitka:1971 TC2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2094 magnitka.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	5.06
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.335030992877
		SemiMajorAxis	2.232172643473
		Eccentricity	0.096428414237
		Inclination	5.030070564638
		AscendingNode	281.968931475396
		ArgOfPericenter	251.816999363487
		MeanAnomaly	213.23056162066
	}
	UniformRotation
	{
		Period	6.1124
	}
	LunarLambert	0.5
	Albedo	0.132
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2094"
}

#1_"2100 Ra-Shalom:Ra-Shalom:1978 RA:1975 TB" "Sol" #1=
#2_"*Ра-Шалом:2100 Ra-Shalom:Ra-Shalom:1978 RA" "Sol" #2=
#3_"1978 RA:*Ра-Шалом:2100 Ra-Shalom:Ra-Shalom" "Sol" #3=
".:Ra-Shalom:2100 Ra-Shalom:1978 RA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2100 ra-shalom.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.758996433759
		SemiMajorAxis	0.832059446099
		Eccentricity	0.436495229451
		Inclination	15.757416163767
		AscendingNode	170.836274371353
		ArgOfPericenter	356.041085239861
		MeanAnomaly	94.406224933711
	}
	UniformRotation
	{
		Period	19.797
	}
	LunarLambert	0.5
	Albedo	0.13
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2100"
}

#1_"2101 Adonis:Adonis:1936 CA" "Sol" #1=
#2_"*Адонис:2101 Adonis:Adonis:1936 CA" "Sol" #2=
#3_"1936 CA:*Адонис:2101 Adonis:Adonis" "Sol" #3=
".:Adonis:2101 Adonis:1936 CA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.425
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.566679492806
		SemiMajorAxis	1.874601494645
		Eccentricity	0.763735433886
		Inclination	1.330877099752
		AscendingNode	349.84885291236
		ArgOfPericenter	43.241938782277
		MeanAnomaly	288.020438387159
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2101"
}

#1_"2102 Tantalus:Tantalus:1975 YA" "Sol" #1=
#2_"*Тантал:2102 Tantalus:Tantalus:1975 YA" "Sol" #2=
#3_"1975 YA:*Тантал:2102 Tantalus:Tantalus" "Sol" #3=
".:Tantalus:2102 Tantalus:1975 YA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	1.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.46528868946
		SemiMajorAxis	1.290060258802
		Eccentricity	0.299100005817
		Inclination	64.006307751473
		AscendingNode	94.372107361536
		ArgOfPericenter	61.550938719123
		MeanAnomaly	176.718426955751
	}
	UniformRotation
	{
		Period	2.391
	}
	LunarLambert	0.5
	Albedo	0.11
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2102"
}

#1_"2103 Laverna:Laverna:1960 FL:1930 XM:1932 EC1:1932 EZ:1936 YE:1958 XV:1971 BR1:1974 RD1:1977 EW: #1=
#1_A915 CB" "Sol" #1=
#2_"*Лаверна:2103 Laverna:Laverna:1960 FL" "Sol" #2=
#3_"1960 FL:*Лаверна:2103 Laverna:Laverna" "Sol" #3=
".:Laverna:2103 Laverna:1960 FL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.566784081658
		SemiMajorAxis	3.140972371469
		Eccentricity	0.192786921638
		Inclination	7.698716310154
		AscendingNode	292.128678081285
		ArgOfPericenter	238.632636331354
		MeanAnomaly	270.533498994379
	}
	UniformRotation
	{
		Period	9.249
	}
	LunarLambert	0.5
	Albedo	0.1625
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2103"
}

#1_"2105 Gudy:Gudy:1976 DA" "Sol" #1=
#2_"*Гуди:2105 Gudy:Gudy:1976 DA" "Sol" #2=
#3_"1976 DA:*Гуди:2105 Gudy:Gudy" "Sol" #3=
".:Gudy:2105 Gudy:1976 DA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.125
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.692392463853
		SemiMajorAxis	2.388909893744
		Eccentricity	0.150195588602
		Inclination	29.341504068851
		AscendingNode	273.660316142198
		ArgOfPericenter	156.035234424076
		MeanAnomaly	269.746129158939
	}
	UniformRotation
	{
		Period	15.795
	}
	LunarLambert	0.5
	Albedo	0.1078
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2105"
}

#1_"2107 Ilmari:Ilmari:1941 VA:1948 LJ:1966 RD:1975 VA3:2004 RO344" "Sol" #1=
#2_"*Ильмари:2107 Ilmari:Ilmari:1941 VA" "Sol" #2=
#3_"1941 VA:*Ильмари:2107 Ilmari:Ilmari" "Sol" #3=
".:Ilmari:2107 Ilmari:1941 VA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.815
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.259517138851
		SemiMajorAxis	2.627653597815
		Eccentricity	0.077073406288
		Inclination	8.8194485065
		AscendingNode	221.337376413819
		ArgOfPericenter	178.212520465293
		MeanAnomaly	62.389599116223
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1992
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2107"
}

#1_"2108 Otto Schmidt:Otto Schmidt:1948 TR1:1935 FN:1956 XC:1973 FD1" "Sol" #1=
#2_"*Отто Шмидт:2108 Otto Schmidt:Otto Schmidt:1948 TR1" "Sol" #2=
#3_"1948 TR1:*Отто Шмидт:2108 Otto Schmidt:Otto Schmidt" "Sol" #3=
".:Otto Schmidt:2108 Otto Schmidt:1948 TR1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.555
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.802516912032
		SemiMajorAxis	2.436175855615
		Eccentricity	0.00530573332
		Inclination	10.797935529697
		AscendingNode	327.966761453693
		ArgOfPericenter	70.012860351673
		MeanAnomaly	137.100694104592
	}
	UniformRotation
	{
		Period	15.24
	}
	LunarLambert	0.5
	Albedo	0.1215
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2108"
}

#1_"2111 Tselina:Tselina:1969 LG:1928 RS:1928 SO:1951 AR1:1968 HB1:1975 RE:1976 YF" "Sol" #1=
#2_"*Целина:2111 Tselina:Tselina:1969 LG" "Sol" #2=
#3_"1969 LG:*Целина:2111 Tselina:Tselina" "Sol" #3=
".:Tselina:2111 Tselina:1969 LG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.239253860863
		SemiMajorAxis	3.016528919266
		Eccentricity	0.094940475726
		Inclination	10.503001722442
		AscendingNode	167.172146453678
		ArgOfPericenter	233.04631373118
		MeanAnomaly	129.291482357438
	}
	UniformRotation
	{
		Period	6.563
	}
	LunarLambert	0.5
	Albedo	0.1938
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2111"
}

#1_"2112 Ulyanov:1972 NP:1949 YC:1952 UU1:1962 RA:1968 KB:1969 UB2:1976 YD1:A908 SC" "Sol" #1=
#2_"*Ульянов:2112 Ulyanov:Ulyanov:1972 NP" "Sol" #2=
#3_"1972 NP:*Ульянов:2112 Ulyanov:Ulyanov" "Sol" #3=
".:Ulyanov:2112 Ulyanov:1972 NP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2112 ulyanov.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.74
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.382722559289
		SemiMajorAxis	2.253402568342
		Eccentricity	0.137868402266
		Inclination	3.372356217936
		AscendingNode	243.703662842882
		ArgOfPericenter	156.250074001411
		MeanAnomaly	167.687630683992
	}
	UniformRotation
	{
		Period	3.041
	}
	LunarLambert	0.5
	Albedo	0.38
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2112"
}

#1_"2114 Wallenquist:Wallenquist:1976 HA:1930 DG:1942 LD:1953 GZ:1964 FA:1970 EO3:1970 EZ2" "Sol" #1=
#2_"*Валленквист:2114 Wallenquist:Wallenquist:1976 HA" "Sol" #2=
#3_"1976 HA:*Валленквист:2114 Wallenquist:Wallenquist" "Sol" #3=
".:Wallenquist:2114 Wallenquist:1976 HA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.835
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.729833185059
		SemiMajorAxis	3.202008772374
		Eccentricity	0.143233574171
		Inclination	0.557540915997
		AscendingNode	1.484252243752
		ArgOfPericenter	216.944687739194
		MeanAnomaly	279.256215201659
	}
	UniformRotation
	{
		Period	5.51
	}
	LunarLambert	0.5
	Albedo	0.0838
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2114"
}

#1_"2115 Irakli:Irakli:1976 UD:1948 PY:1952 HZ3" "Sol" #1=
#2_"*Ираклий:2115 Irakli:Irakli:1976 UD" "Sol" #2=
#3_"1976 UD:*Ираклий:2115 Irakli:Irakli" "Sol" #3=
".:Irakli:2115 Irakli:1976 UD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.535
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.22522827075
		SemiMajorAxis	3.011142974545
		Eccentricity	0.049973497318
		Inclination	8.977128778842
		AscendingNode	241.448994607897
		ArgOfPericenter	337.969002836892
		MeanAnomaly	0.988203374014
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1585
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2115"
}

#1_"2116 Mtskheta:Mtskheta:1976 UM:1929 RM1:1933 OM:1949 KP:1950 TC2:1952 BN1:1975 VB2:1977 DE" "Sol" #1=
#2_"*Мцхета:2116 Mtskheta:Mtskheta:1976 UM" "Sol" #2=
#3_"1976 UM:*Мцхета:2116 Mtskheta:Mtskheta" "Sol" #3=
".:Mtskheta:2116 Mtskheta:1976 UM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.925
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.166922988527
		SemiMajorAxis	2.589434010475
		Eccentricity	0.058459676934
		Inclination	9.080517747635
		AscendingNode	170.639405594646
		ArgOfPericenter	175.906171872236
		MeanAnomaly	169.040837270651
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0648
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2116"
}

#1_"2120 Tyumenia:Tyumenia:1967 RM:1941 WS:1971 KA" "Sol" #1=
#2_"*Тюмения:2120 Tyumenia:Tyumenia:1967 RM" "Sol" #2=
#3_"1967 RM:*Тюмения:2120 Tyumenia:Tyumenia" "Sol" #3=
".:Tyumenia:2120 Tyumenia:1967 RM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.59
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.352391891857
		SemiMajorAxis	3.059800664282
		Eccentricity	0.127175839075
		Inclination	17.569171450804
		AscendingNode	222.470328925675
		ArgOfPericenter	75.73305534759
		MeanAnomaly	337.941394474541
	}
	UniformRotation
	{
		Period	2.769
	}
	LunarLambert	0.5
	Albedo	0.0721
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2120"
}

#New3
#1_"2121 Sevastopol:Sevastopol:1971 ME:1932 HM:1936 WD:1938 DY:1939 TO:1952 SZ:1968 QJ1:1977 ED2:1978 WG" "Sol" #1=
#2_"*Севастополь:2121 Sevastopol:Sevastopol:1971 ME" "Sol" #2=
#3_"1932 HM:*Севастополь:2121 Sevastopol:Sevastopol" "Sol" #3=
".:Sevastopol:2121 Sevastopol:1971 ME" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.31
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.227225733483
		SemiMajorAxis	2.183806198819
		Eccentricity	0.178277784369
		Inclination	4.377982079086
		AscendingNode	145.715566925776
		ArgOfPericenter	160.376463470518
		MeanAnomaly	94.888836530762
	}
	UniformRotation
	{
		Period	2.9064
	}
	LunarLambert	0.5
	Albedo	0.308
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2121"
}

#New3
#1_"2010 2121 I" "Sol/2121 Sevastopol" #1=
#2_"2010 2121 I" "Sol/2121 Sevastopol" #2=
#3_"2010 2121 I" "Sol/2121 Sevastopol" #3=
".:2010 2121 I" "Sol/2121 Sevastopol" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid.dds"
	Radius	1.77
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	1.546
		SemiMajorAxis	26
	}
	LunarLambert	0.5
	Albedo	0.308
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-02121.html"
}

#1_"2123 Vltava:Vltava:1973 SL2:1934 PB:1936 AE:1942 EV:1951 AQ1:1954 UL:1956 AJ:1956 CE:1964 VZ: #1=
#1_1975 AR:1977 JB1:1978 SO" "Sol" #1=
#2_"*Влтава:2123 Vltava:Vltava:1973 SL2" "Sol" #2=
#3_"1973 SL2:*Влтава:2123 Vltava:Vltava" "Sol" #3=
".:Vltava:2123 Vltava:1973 SL2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.834572691117
		SemiMajorAxis	2.859125780318
		Eccentricity	0.078661883938
		Inclination	1.01114915056
		AscendingNode	311.639242928856
		ArgOfPericenter	59.252461528245
		MeanAnomaly	167.546228893478
	}
	UniformRotation
	{
		Period	34
	}
	LunarLambert	0.5
	Albedo	0.2135
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2123"
}

#1_"2125 Karl-Ontjes:Karl-Ontjes:2005 P-L:1951 WD:1969 PW:1969 RJ2:1977 ES1" "Sol" #1=
#2_"*Карл-Онтьес:2125 Karl-Ontjes:Karl-Ontjes:1960-2125*:2005 P-L" "Sol" #2=
#3_"1960-2125*:*Карл-Онтьес:2125 Karl-Ontjes:Karl-Ontjes:2005 P-L" "Sol" #3=
".:Karl-Ontjes:2125 Karl-Ontjes:1960-2125*:2005 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.845
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.647951543928
		SemiMajorAxis	2.78506665118
		Eccentricity	0.108734469013
		Inclination	1.689743219954
		AscendingNode	315.60227378079
		ArgOfPericenter	17.187169254821
		MeanAnomaly	262.478096936537
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1033
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2125"
}

#1_"2127 Tanya:Tanya:1971 KB1:1953 GH1" "Sol" #1=
#2_"*Таня:2127 Tanya:Tanya:1971 KB1" "Sol" #2=
#3_"1971 KB1:*Таня:2127 Tanya:Tanya" "Sol" #3=
".:Tanya:2127 Tanya:1971 KB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.868
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.751429755393
		SemiMajorAxis	3.210049616047
		Eccentricity	0.031914942633
		Inclination	13.093882691941
		AscendingNode	106.390215953745
		ArgOfPericenter	185.53902682929
		MeanAnomaly	343.143122669395
	}
	UniformRotation
	{
		Period	7.864
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2127"
}

#1_"2131 Mayall:Mayall:1975 RA" "Sol" #1=
#2_"*Мейол:2131 Mayall:Mayall:1975 RA" "Sol" #2=
#3_"1975 RA:*Мейол:2131 Mayall:Mayall" "Sol" #3=
".:Mayall:2131 Mayall:1975 RA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.14
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.592361445905
		SemiMajorAxis	1.887085457248
		Eccentricity	0.110941005226
		Inclination	33.996127224799
		AscendingNode	306.062824180963
		ArgOfPericenter	38.359908676745
		MeanAnomaly	58.093552922728
	}
	UniformRotation
	{
		Period	2.5678
	}
	LunarLambert	0.5
	Albedo	0.2391
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2131"
}

#1_"2009 2131 I" "Sol/2131 Mayall" #1=
#2_"2009 2131 I" "Sol/2131 Mayall" #2=
#3_"2009 2131 I" "Sol/2131 Mayall" #3=
".:2009 2131 I" "Sol/2131 Mayall" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid.dds"
	Radius	1.075
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.9783
		SemiMajorAxis	18
	}
	LunarLambert	0.5
	Albedo	0.2391
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-02131.html"
}

#1_"2132 Zhukov:Zhukov:1975 TW3:1929 WR:1931 GA:1950 HC1:1951 OC:1955 MJ1:1956 RK:1966 UX:1970 SE: #1=
#1_1972 BQ:1977 EK:1980 XY" "Sol" #1=
#2_"*Жуков:2132 Zhukov:Zhukov:1975 TW3" "Sol" #2=
#3_"1975 TW3:*Жуков:2132 Zhukov:Zhukov" "Sol" #3=
".:Zhukov:2132 Zhukov:1975 TW3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.394
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.637239293825
		SemiMajorAxis	2.780785797277
		Eccentricity	0.083078349276
		Inclination	5.868093029678
		AscendingNode	82.44510545299
		ArgOfPericenter	337.304369077147
		MeanAnomaly	341.275497937306
	}
	UniformRotation
	{
		Period	6.836
	}
	LunarLambert	0.5
	Albedo	0.051
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2132"
}

#1_"2135 Aristaeus:Aristaeus:1977 HA" "Sol" #1=
#2_"*Аристей:2135 Aristaeus:Aristaeus:1977 HA" "Sol" #2=
#3_"1977 HA:*Аристей:2135 Aristaeus:Aristaeus" "Sol" #3=
".:Aristaeus:2135 Aristaeus:1977 HA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.5553
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.023178800256
		SemiMajorAxis	1.599622026217
		Eccentricity	0.503056818737
		Inclination	23.059923157148
		AscendingNode	191.22373555171
		ArgOfPericenter	290.866849198835
		MeanAnomaly	248.565602384495
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2135"
}

#1_"2137 Priscilla:Priscilla:1936 QZ:1939 BR:1950 BD:1951 GY:1970 QM1:1971 TX2:1979 DL:A905 CJ" "Sol" #1=
#2_"*Присцилла:2137 Priscilla:Priscilla:1936 QZ" "Sol" #2=
#3_"1936 QZ:*Присцилла:2137 Priscilla:Priscilla" "Sol" #3=
".:Priscilla:2137 Priscilla:1936 QZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.505
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.690589879932
		SemiMajorAxis	3.18737178053
		Eccentricity	0.053426535668
		Inclination	11.663985077448
		AscendingNode	319.814445914753
		ArgOfPericenter	136.717373797333
		MeanAnomaly	173.805021829529
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0382
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2137"
}

#1_"2138 Swissair:Swissair:1968 HB:1938 OH:1942 JD:1946 GA:1977 KE" "Sol" #1=
#2_"*Свиссэйр:2138 Swissair:Swissair:1968 HB" "Sol" #2=
#3_"1968 HB:*Свиссэйр:2138 Swissair:Swissair" "Sol" #3=
".:Swissair:2138 Swissair:1968 HB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.400672770468
		SemiMajorAxis	2.685389269558
		Eccentricity	0.067250322895
		Inclination	5.928865690483
		AscendingNode	105.714745841146
		ArgOfPericenter	168.630291496617
		MeanAnomaly	144.443624022882
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1741
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2138"
}

#1_"2140 Kemerovo:Kemerovo:1970 PE:1926 AJ:1940 WB:1952 BH1:1957 BB:1973 FY:1974 MP:1975 NM1: #1=
#1_1975 QJ:1975 RM1" "Sol" #1=
#2_"*Кемерово:2140 Kemerovo:Kemerovo:1970 PE" "Sol" #2=
#3_"1970 PE:*Кемерово:2140 Kemerovo:Kemerovo" "Sol" #3=
".:Kemerovo:2140 Kemerovo:1970 PE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.745
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.161442696274
		SemiMajorAxis	2.98658769791
		Eccentricity	0.058101581291
		Inclination	6.986534602725
		AscendingNode	274.766109901429
		ArgOfPericenter	120.425033799879
		MeanAnomaly	142.987618438842
	}
	UniformRotation
	{
		Period	9.2
	}
	LunarLambert	0.5
	Albedo	0.0887
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2140"
}

#1_"2145 Blaauw:Blaauw:1976 UF:1929 XS:1963 RK:1980 TW" "Sol" #1=
#2_"*Блаув:2145 Blaauw:Blaauw:1976 UF" "Sol" #2=
#3_"1976 UF:*Блаув:2145 Blaauw:Blaauw" "Sol" #3=
".:Blaauw:2145 Blaauw:1976 UF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.775568183971
		SemiMajorAxis	3.219024944167
		Eccentricity	0.096047174196
		Inclination	15.008133770794
		AscendingNode	264.363970844158
		ArgOfPericenter	278.615935456351
		MeanAnomaly	143.830619977321
	}
	UniformRotation
	{
		Period	12.141
	}
	LunarLambert	0.5
	Albedo	0.0869
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2145"
}

#1_"2147 Kharadze:Kharadze:1976 US:1966 CT" "Sol" #1=
#2_"*Харадзе:2147 Kharadze:Kharadze:1976 US" "Sol" #2=
#3_"1976 US:*Харадзе:2147 Kharadze:Kharadze" "Sol" #3=
".:Kharadze:2147 Kharadze:1976 US" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.495
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.652650386961
		SemiMajorAxis	3.173189063324
		Eccentricity	0.053445461073
		Inclination	10.084510675914
		AscendingNode	144.486223575869
		ArgOfPericenter	307.431030861585
		MeanAnomaly	277.086121919537
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0439
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2147"
}

#1_"2152 Hannibal:Hannibal:1978 WK:1939 RM:1952 BG1:1977 OB" "Sol" #1=
#2_"*Ганнибал:2152 Hannibal:Hannibal:1978 WK" "Sol" #2=
#3_"1978 WK:*Ганнибал:2152 Hannibal:Hannibal" "Sol" #3=
".:Hannibal:2152 Hannibal:1978 WK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.522729995569
		SemiMajorAxis	3.124379210116
		Eccentricity	0.220523985287
		Inclination	13.966988048525
		AscendingNode	250.942767990581
		ArgOfPericenter	142.401846176627
		MeanAnomaly	176.215568495124
	}
	UniformRotation
	{
		Period	5.978
	}
	LunarLambert	0.5
	Albedo	0.0508
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2152"
}

#1_"2153 Akiyama:Akiyama:1978 XD:1955 UQ1:1972 YA:1973 AK3:1977 VW:1979 FS" "Sol" #1=
#2_"*Акияма:2153 Akiyama:Akiyama:1978 XD" "Sol" #2=
#3_"1978 XD:*Акияма:2153 Akiyama:Akiyama" "Sol" #3=
".:Akiyama:2153 Akiyama:1978 XD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	8.395
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.525176119394
		SemiMajorAxis	3.125301707307
		Eccentricity	0.152550087918
		Inclination	1.184293274866
		AscendingNode	47.749417644082
		ArgOfPericenter	31.598297824614
		MeanAnomaly	239.973351265209
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1089
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2153"
}

#1_"2156 Kate:Kate:A917 SH:1937 PK:1954 UT2:1956 GP:1957 QK:1969 BE:1970 LK:1974 RL1:1976 GK1: #1=
#1_1979 BC" "Sol" #1=
#2_"*Кейт:2156 Kate:Kate:1917 SH" "Sol" #2=
#3_"1917 SH:*Кейт:2156 Kate:Kate" "Sol" #3=
".:Kate:2156 Kate:1917 SH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2156 kate.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.066
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.357546205648
		SemiMajorAxis	2.242207824881
		Eccentricity	0.200981524772
		Inclination	5.347683737135
		AscendingNode	17.190198369289
		ArgOfPericenter	4.343848048321
		MeanAnomaly	29.919353681932
	}
	UniformRotation
	{
		Period	5.6228
	}
	LunarLambert	0.5
	Albedo	0.189
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2156"
}

#New3
#1_"2164 Lyalya:Lyalya:1972 RM2:1949 QF1:1953 FJ:1955 RW:1955 SB2:1976 GO7" "Sol" #1=
#2_"*Ляля:2164 Lyalya:Lyalya:1972 RM2" "Sol" #2=
#3_"1972 RM2:*Ляля:2164 Lyalya:Lyalya" "Sol" #3=
".:Lyalya:2164 Lyalya:1972 RM2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.988
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.688900279647
		SemiMajorAxis	3.18674083823
		Eccentricity	0.131237728501
		Inclination	2.625419778015
		AscendingNode	115.726860070743
		ArgOfPericenter	196.874937726423
		MeanAnomaly	13.361150226647
	}
	UniformRotation
	{
		Period	11.57
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2164"
}


#1_"2169 Taiwan:Taiwan:1964 VP1:1938 DV1:1975 BH1:1977 RF8:1979 FG" "Sol" #1=
#2_"*Тайвань:2169 Taiwan:Taiwan:1964 VP1" "Sol" #2=
#3_"1964 VP1:*Тайвань:2169 Taiwan:Taiwan" "Sol" #3=
".:Taiwan:2169 Taiwan:1964 VP1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.658657970736
		SemiMajorAxis	2.789341893172
		Eccentricity	0.048361282903
		Inclination	1.528648637423
		AscendingNode	71.856725799323
		ArgOfPericenter	357.177783268668
		MeanAnomaly	266.629117703778
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0991
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2169"
}

#1_"2171 Kiev:Kiev:1973 QD1:1949 MN:1949 MQ:1956 RP:1969 FK:1970 XB" "Sol" #1=
#2_"*Киев:2171 Kiev:Kiev:1973 QD1" "Sol" #2=
#3_"1973 QD1:*Киев:2171 Kiev:Kiev" "Sol" #3=
".:Kiev:2171 Kiev:1973 QD1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.018
	Visible	false
	Clickable	false
	EllipticalOrbit
	{

		Epoch	2458000.5  # 2017 Sept 04
		Period	3.387487893038
		SemiMajorAxis	2.25551835831
		Eccentricity	0.166187267571
		Inclination	7.51581993956
		AscendingNode	102.058476731218
		ArgOfPericenter	180.151892579967
		MeanAnomaly	38.908745293702
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.108
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2171"
}

#1_"2173 Maresjev:Maresjev:1974 QG1:1933 FN:1938 DD2:1963 SW:1968 OM:1974 RZ1:1974 TG" "Sol" #1=
#2_"*Маресьев:2173 Maresjev:Maresjev:1974 QG1" "Sol" #2=
#3_"1974 QG1:*Маресьев:2173 Maresjev:Maresjev" "Sol" #3=
".:Maresjev:2173 Maresjev:1974 QG1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.162
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.5630923247
		SemiMajorAxis	3.139583539847
		Eccentricity	0.114542397015
		Inclination	14.424555716462
		AscendingNode	174.666920560944
		ArgOfPericenter	166.111551705627
		MeanAnomaly	277.975077031321
	}
	UniformRotation
	{
		Period	11.6
	}
	LunarLambert	0.5
	Albedo	0.061
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2173"
}

#1_"2177 Oliver:Oliver:6551 P-L:1971 QE:1975 EP3:1977 QS2:1978 VD6" "Sol" #1=
#2_"*Оливер:2177 Oliver:Oliver:1960-2177*:6551 P-L" "Sol" #2=
#3_"1960-2177*:*Оливер:2177 Oliver:Oliver:6551 P-L" "Sol" #3=
".:Oliver:2177 Oliver:1960-2177*:6551 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.705989240295
		SemiMajorAxis	3.19311944193
		Eccentricity	0.102071488241
		Inclination	1.5247281058
		AscendingNode	51.491347409601
		ArgOfPericenter	274.340270484584
		MeanAnomaly	203.702270963614
	}
	UniformRotation
	{
		Period	6.1065
	}
	LunarLambert	0.5
	Albedo	0.1279
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2177"
}

#1_"2179 Platzeck:Platzeck:1965 MA:1930 WG:1935 TH:1940 TK:1951 WU1:1956 VQ:1976 QU1:1976 SG10: #1=
#1_1987 SL2:A906 FH" "Sol" #1=
#2_"*Платцек:2179 Platzeck:Platzeck:1965 MA" "Sol" #2=
#3_"1965 MA:*Платцек:2179 Platzeck:Platzeck" "Sol" #3=
".:Platzeck:2179 Platzeck:1965 MA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.825
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.225374725533
		SemiMajorAxis	3.011199239294
		Eccentricity	0.09620825952
		Inclination	10.462643316943
		AscendingNode	14.973030282179
		ArgOfPericenter	58.45606161502
		MeanAnomaly	15.443310548558
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1149
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2179"
}

#1_"2180 Marjaleena:Marjaleena:1940 RJ:1950 NQ1:1970 JL:1970 JR:1971 OL1:1976 NM:1977 TT3" "Sol" #1=
#2_"*Марьялина:2180 Marjaleena:Marjaleena:1940 RJ" "Sol" #2=
#3_"1940 RJ:Marjaleena:*Марьялина:2180 Marjaleena" "Sol" #3=
".:Marjaleena:2180 Marjaleena:1940 RJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2180 marjaleena.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	10.678
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.236178643437
		SemiMajorAxis	3.015348421653
		Eccentricity	0.079469351785
		Inclination	9.243252442918
		AscendingNode	233.291749254267
		ArgOfPericenter	87.225878261671
		MeanAnomaly	252.106013567744
	}
	UniformRotation
	{
		Period	7.396
	}
	LunarLambert	0.5
	Albedo	0.154
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2180"
}

#1_"2182 Semirot:Semirot:1953 FH1:1937 KF:1942 FN:1953 GY:1955 UT:1972 TM4:1975 EU1:1975 EU3: #1=
#1_1978 VB8" "Sol" #1=
#2_"*Семирот:2182 Semirot:Semirot:1953 FH1" "Sol" #2=
#3_"1953 FH1:*Семирот:2182 Semirot:Semirot" "Sol" #3=
".:Semirot:2182 Semirot:1953 FH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.565
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.539632703762
		SemiMajorAxis	3.130750885999
		Eccentricity	0.131699997763
		Inclination	2.259231226349
		AscendingNode	51.059120927813
		ArgOfPericenter	201.685307744079
		MeanAnomaly	355.313993461907
	}
	UniformRotation
	{
		Period	8.328
	}
	LunarLambert	0.5
	Albedo	0.0845
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2182"
}

#1_"2183 Neufang:Neufang:1959 OB:1933 MC" "Sol" #1=
#2_"*Нойфан:2183 Neufang:Neufang:1959 OB" "Sol" #2=
#3_"1959 OB:*Нойфан:2183 Neufang:Neufang" "Sol" #3=
".:Neufang:2183 Neufang:1959 OB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.184068780904
		SemiMajorAxis	2.99530948559
		Eccentricity	0.375188407094
		Inclination	18.10543345248
		AscendingNode	87.325522619797
		ArgOfPericenter	239.881232026274
		MeanAnomaly	227.993134053398
	}
	UniformRotation
	{
		Period	3.8662
	}
	LunarLambert	0.5
	Albedo	0.0472
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2183"
}

#1_"2184 Fujian:Fujian:1964 TV2:1930 UP:1953 VH:1976 YK3" "Sol" #1=
#2_"*ФуЦзянь:2184 Fujian:Fujian:1964 TV2" "Sol" #2=
#3_"1964 TV2:*ФуЦзянь:2184 Fujian:Fujian" "Sol" #3=
".:Fujian:2184 Fujian:1964 TV2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.14
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.665398385374
		SemiMajorAxis	3.17795810875
		Eccentricity	0.100274908386
		Inclination	5.192742671805
		AscendingNode	256.594671658267
		ArgOfPericenter	120.322595962541
		MeanAnomaly	322.048019697596
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0642
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2184"
}

#1_"2185 Guangdong:Guangdong:1965 WO:1929 WE:1950 HZ:1959 JU:1968 HX:1969 TK3:1974 YM" "Sol" #1=
#2_"*ГуанДун:2185 Guangdong:Guangdong:1965 WO" "Sol" #2=
#3_"1965 WO:*ГуанДун:2185 Guangdong:Guangdong" "Sol" #3=
".:Guangdong:2185 Guangdong:1965 WO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.515
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.457052578271
		SemiMajorAxis	2.708276720638
		Eccentricity	0.161844349302
		Inclination	9.588375484944
		AscendingNode	60.761050550181
		ArgOfPericenter	261.491782514979
		MeanAnomaly	87.639950493932
	}
	UniformRotation
	{
		Period	21.089
	}
	LunarLambert	0.5
	Albedo	0.184
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2185"
}

#1_"2191 Uppsala:Uppsala:1977 PA1:1925 VL:1957 WJ2:1972 RP3:1978 VB1" "Sol" #1=
#2_"*Уппсала:2191 Uppsala:Uppsala:1977 PA1" "Sol" #2=
#3_"1977 PA1:*Уппсала:2191 Uppsala:Uppsala" "Sol" #3=
".:Uppsala:2191 Uppsala:1977 PA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.77
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.247771667498
		SemiMajorAxis	3.019797483025
		Eccentricity	0.08201673968
		Inclination	9.024052946965
		AscendingNode	247.427507103541
		ArgOfPericenter	178.87393707875
		MeanAnomaly	306.093770969775
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1734
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2191"
}

#1_"2192 Pyatigoriya:Pyatigoriya:1972 HP:1971 DY1:1974 VY1:1977 EJ1:1979 SL" "Sol" #1=
#2_"*Пятигория:2192 Pyatigoriya:Pyatigoriya:1972 HP" "Sol" #2=
#3_"1972 HP:*Пятигория:2192 Pyatigoriya:Pyatigoriya" "Sol" #3=
".:Pyatigoriya:2192 Pyatigoriya:1972 HP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.573783625582
		SemiMajorAxis	3.143604743411
		Eccentricity	0.076341968728
		Inclination	9.755160866395
		AscendingNode	201.671334800896
		ArgOfPericenter	144.230181152545
		MeanAnomaly	128.336272323492
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0535
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2192"
}

#1_"2196 Ellicott:Ellicott:1965 BC:1934 GG:1947 FF:1948 LD:1951 YD2:1953 FF1:1954 JN:1954 KN:1966 FC: #1=
#1_1969 TM5:1972 FL:1976 UH4:1976 YQ4:A906 VJ:A911 QC" "Sol" #1=
#2_"*Элликотт:2196 Ellicott:Ellicott:1965 BC" "Sol" #2=
#3_"1965 BC:*Элликотт:2196 Ellicott:Ellicott" "Sol" #3=
".:Ellicott:2196 Ellicott:1965 BC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.605
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.368784467842
		SemiMajorAxis	3.435834474475
		Eccentricity	0.053098912481
		Inclination	10.308855304929
		AscendingNode	212.230983377598
		ArgOfPericenter	310.226803600024
		MeanAnomaly	255.640695071745
	}
	UniformRotation
	{
		Period	9.0706
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2196"
}

#1_"2197 Shanghai:Shanghai:1965 YN:1942 VN:1955 DA:1964 UN:1967 JT:1975 SD" "Sol" #1=
#2_"*Шанхай:2197 Shanghai:Shanghai:1965 YN" "Sol" #2=
#3_"1965 YN:*Шанхай:2197 Shanghai:Shanghai" "Sol" #3=
".:Shanghai:2197 Shanghai:1965 YN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.18
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.597984660343
		SemiMajorAxis	3.152697733504
		Eccentricity	0.124298131201
		Inclination	2.49765803423
		AscendingNode	56.378102383901
		ArgOfPericenter	70.530656296787
		MeanAnomaly	245.287448736088
	}
	UniformRotation
	{
		Period	5.99
	}
	LunarLambert	0.5
	Albedo	0.117
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2197"
}

#1_"2201 Oljato:Oljato:1979 XA:1979 VU2:1947 XC" "Sol" #1=
#2_"*Ольято:2201 Oljato:Oljato:1979 XA" "Sol" #2=
#3_"1979 XA:*Ольято:2201 Oljato:Oljato" "Sol" #3=
".:Oljato:2201 Oljato:1979 XA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.200572611235
		SemiMajorAxis	2.17176579181
		Eccentricity	0.712798274026
		Inclination	2.523614007946
		AscendingNode	74.99677036896
		ArgOfPericenter	98.212436632103
		MeanAnomaly	308.344460836956
	}
	UniformRotation
	{
		Period	26
	}
	LunarLambert	0.5
	Albedo	0.4328
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2201"
}

#1_"2204 Lyyli:Lyyli:1943 EQ:1968 DN" "Sol" #1=
#2_"*Люли:2204 Lyyli:Lyyli:1943 EQ" "Sol" #2=
#3_"1943 EQ:*Люли:2204 Lyyli:Lyyli" "Sol" #3=
".:Lyyli:2204 Lyyli:1943 EQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.163894965119
		SemiMajorAxis	2.588179396977
		Eccentricity	0.407665481837
		Inclination	20.562236125913
		AscendingNode	160.460517678502
		ArgOfPericenter	283.273025267872
		MeanAnomaly	113.624262108742
	}
	UniformRotation
	{
		Period	11.063
	}
	LunarLambert	0.5
	Albedo	0.0232
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2204"
}

#1_"2207 Antenor:Antenor:1977 QH1:1959 EM:1971 BE1:1978 UU" "Sol" #1=
#2_"*Антенор:2207 Antenor:Antenor:1977 QH1" "Sol" #2=
#3_"1977 QH1:*Антенор:2207 Antenor:Antenor" "Sol" #3=
".:Antenor:2207 Antenor:1977 QH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	42.555
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.644240723043
		SemiMajorAxis	5.13730458382
		Eccentricity	0.016577614126
		Inclination	6.808028372829
		AscendingNode	159.139760993801
		ArgOfPericenter	296.582739051739
		MeanAnomaly	339.894333219926
	}
	UniformRotation
	{
		Period	7.965
	}
	LunarLambert	0.5
	Albedo	0.0678
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2207"
}

#1_"2208 Pushkin:Pushkin:1977 QL3:1968 HU:1971 SN3:1971 UG2:1973 AN3:1978 WJ14" "Sol" #1=
#2_"*Пушкин:2208 Pushkin:Pushkin:1977 QL3" "Sol" #2=
#3_"1977 QL3:*Пушкин:2208 Pushkin:Pushkin" "Sol" #3=
".:Pushkin:2208 Pushkin:1977 QL3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.155
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.537044628654
		SemiMajorAxis	3.496086465522
		Eccentricity	0.031998305324
		Inclination	5.403419521948
		AscendingNode	78.569904959382
		ArgOfPericenter	6.453096530323
		MeanAnomaly	157.537133414133
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0497
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2208"
}

#1_"2209 Tianjin:Tianjin:1978 US1:1927 CC:1935 WC:1942 EN1:1952 HR2:1957 JO:1959 UP:1966 GA: #1=
#1_1971 FW:1971 JB:1973 QU:1973 SW2:1973 UT3:1976 GP7:1976 KB" "Sol" #1=
#2_"*ТяньЦзинь:2209 Tianjin:Tianjin:1978 US1" "Sol" #2=
#3_"1978 US1:*ТяньЦзинь:2209 Tianjin:Tianjin" "Sol" #3=
".:Tianjin:2209 Tianjin:1978 US1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.22
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.79900392416
		SemiMajorAxis	2.845085147956
		Eccentricity	0.067932380942
		Inclination	2.612702289465
		AscendingNode	150.904392600085
		ArgOfPericenter	262.026314465497
		MeanAnomaly	172.620452956779
	}
	UniformRotation
	{
		Period	9.47
	}
	LunarLambert	0.5
	Albedo	0.2854
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2209"
}

#1_"2212 Hephaistos:Hephaistos:1978 SB" "Sol" #1=
#2_"*Гефест:2212 Hephaistos:Hephaistos:1978 SB" "Sol" #2=
#3_"1978 SB:*Гефест:2212 Hephaistos:Hephaistos" "Sol" #3=
".:Hephaistos:2212 Hephaistos:1978 SB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.172713090373
		SemiMajorAxis	2.159144618417
		Eccentricity	0.837431575275
		Inclination	11.555294705011
		AscendingNode	27.559254700055
		ArgOfPericenter	209.346815362432
		MeanAnomaly	147.780447857257
	}
	UniformRotation
	{
		Period	20
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2212"
}

#1_"2214 Carol:Carol:1953 GF:1977 RF7:1977 TE7:2519 P-L" "Sol" #1=
#2_"*Кэрол:2214 Carol:Carol:1953 GF" "Sol" #2=
#3_"1953 GF:*Кэрол:2214 Carol:Carol" "Sol" #3=
".:Carol:2214 Carol:1953 GF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.61
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.610599215297
		SemiMajorAxis	3.157432170372
		Eccentricity	0.266556139405
		Inclination	14.266160690705
		AscendingNode	187.411591599956
		ArgOfPericenter	137.435267803379
		MeanAnomaly	231.532236082908
	}
	UniformRotation
	{
		Period	4.987
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2214"
}

#1_"2215 Sichuan:Sichuan:1964 VX2:1942 GO:1950 XO:1978 WO12" "Sol" #1=
#2_"*Сычуань:2215 Sichuan:Sichuan:1964 VX2" "Sol" #2=
#3_"1964 VX2:*Сычуань:2215 Sichuan:Sichuan" "Sol" #3=
".:Sichuan:2215 Sichuan:1964 VX2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.669569048939
		SemiMajorAxis	2.793695487396
		Eccentricity	0.262865330859
		Inclination	10.748866882482
		AscendingNode	71.183987857825
		ArgOfPericenter	332.046851071807
		MeanAnomaly	274.634823954424
	}
	UniformRotation
	{
		Period	3.975
	}
	LunarLambert	0.5
	Albedo	0.1398
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2215"
}

#1_"2216 Kerch:Kerch:1971 LF:1930 QF:1935 QF1:1938 DJ:1959 CG1:1970 FK:1975 ES2:1977 RB4" "Sol" #1=
#2_"*Керчь:2216 Kerch:Kerch:1971 LF" "Sol" #2=
#3_"2216 Kerch:*Керчь:Kerch:1971 LF" "Sol" #3=
".:Kerch:2216 Kerch:1971 LF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.012
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.252705478201
		SemiMajorAxis	3.021689940299
		Eccentricity	0.098170721678
		Inclination	10.443177763329
		AscendingNode	155.740526401209
		ArgOfPericenter	181.916566959955
		MeanAnomaly	218.8341323101
	}
	UniformRotation
	{
		Period	9.462
	}
	LunarLambert	0.5
	Albedo	0.12
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2216"
}


#1_"2217 Eltigen:Eltigen:1971 SK2:1942 LG:1958 FJ:1959 NP:1970 LD:1974 CL:1976 NN:1976 OB1:1977 TH5" "Sol" #1=
#2_"*Элтиген:2217 Eltigen:Eltigen:1971 SK2" "Sol" #2=
#3_"1971 SK2:*Элтиген:2217 Eltigen:Eltigen" "Sol" #3=
".:Eltigen:2217 Eltigen:1971 SK2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.600637861993
		SemiMajorAxis	3.15369381605
		Eccentricity	0.166987925504
		Inclination	2.248188699003
		AscendingNode	127.499784584102
		ArgOfPericenter	173.602869641174
		MeanAnomaly	285.97481012782
	}
	UniformRotation
	{
		Period	6.924
	}
	LunarLambert	0.5
	Albedo	0.1242
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2217"
}

#1_"2218 Wotho:Wotho:1975 AK:1931 XU:1970 ED1:1975 BG1" "Sol" #1=
#2_"*Вото:2218 Wotho:Wotho:1975 AK" "Sol" #2=
#3_"1975 AK:*Вото:2218 Wotho:Wotho" "Sol" #3=
".:Wotho:2218 Wotho:1975 AK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.745
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.311433961642
		SemiMajorAxis	3.044171080979
		Eccentricity	0.162908856083
		Inclination	14.945691836056
		AscendingNode	96.585092581945
		ArgOfPericenter	322.534248696755
		MeanAnomaly	237.237557189593
	}
	UniformRotation
	{
		Period	4.9267
	}
	LunarLambert	0.5
	Albedo	0.0673
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2218"
}

#1_"2219 Mannucci:Mannucci:1975 LU:1931 TJ3:1936 OK:1948 TM:1952 JC:1965 VE:1965 WX:1971 UM3: #1=
#1_1974 HD" "Sol" #1=
#2_"*Мануччи:2219 Mannucci:Mannucci:1975 LU" "Sol" #2=
#3_"1975 LU:*Мануччи:2219 Mannucci:Mannucci" "Sol" #3=
".:Mannucci:2219 Mannucci:1975 LU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.745
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.595862842718
		SemiMajorAxis	3.15190103342
		Eccentricity	0.11935669166
		Inclination	7.583638207574
		AscendingNode	72.588806170047
		ArgOfPericenter	294.725805353902
		MeanAnomaly	302.805179159921
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0594
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2219"
}

#1_"2222 Lermontov:Lermontov:1977 ST1:1933 UO:1940 AG:1951 AD1:1961 XN:1966 UR:1972 YH1:1973 AS2: #1=
#1_1974 FA:1974 HM1:1976 OM" "Sol" #1=
#2_"*Лермонтов:2222 Lermontov:Lermontov:1977 ST1" "Sol" #2=
#3_"1977 ST1:*Лермонтов:2222 Lermontov:Lermontov" "Sol" #3=
".:Lermontov:2222 Lermontov:1977 ST1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.520258564596
		SemiMajorAxis	3.12344703061
		Eccentricity	0.166124916108
		Inclination	2.573715024452
		AscendingNode	94.918772125628
		ArgOfPericenter	337.009742350755
		MeanAnomaly	244.705195565446
	}
	UniformRotation
	{
		Period	4.344
	}
	LunarLambert	0.5
	Albedo	0.0761
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2222"
}

#1_"2223 Sarpedon:Sarpedon:1977 TL3" "Sol" #1=
#2_"*Сарпедон:2223 Sarpedon:Sarpedon:1977 TL3" "Sol" #2=
#3_"1977 TL3:*Сарпедон:2223 Sarpedon:Sarpedon" "Sol" #3=
".:Sarpedon:2223 Sarpedon:1977 TL3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	47.315
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.958037643547
		SemiMajorAxis	5.229190650079
		Eccentricity	0.015509997041
		Inclination	15.961240887045
		AscendingNode	220.90633354527
		ArgOfPericenter	60.075768704391
		MeanAnomaly	159.332576430132
	}
	UniformRotation
	{
		Period	22.741
	}
	LunarLambert	0.5
	Albedo	0.034
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2223"
}

#1_"2224 Tucson:Tucson:2528 P-L:1975 VO4" "Sol" #1=
#2_"*Тусон:2224 Tucson:Tucson:1960-2224*:2528 P-L" "Sol" #2=
#3_"1960-2224*:*Тусон:2224 Tucson:Tucson:2528 P-L" "Sol" #3=
".:Tucson:2224 Tucson:1960-2224*:2528 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.887367371818
		SemiMajorAxis	2.879902966967
		Eccentricity	0.047190294343
		Inclination	2.66668113863
		AscendingNode	51.259255563825
		ArgOfPericenter	243.5670341937
		MeanAnomaly	97.856022765126
	}
	UniformRotation
	{
		Period	27.01
	}
	LunarLambert	0.5
	Albedo	0.1242
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2224"
}

#New3
#1_"2233 Kuznetsov:Kuznetsov:1972 XE1:1957 LL:1958 XA:1965 YC:1968 QF1:1973 AO3:1977 FS2:1979 XD" "Sol" #1=
#2_"*Кузнецов:2233 Kuznetsov:Kuznetsov:1972 XE1" "Sol" #2=
#3_"1972 XE1:*Кузнецов:2233 Kuznetsov:Kuznetsov" "Sol" #3=
".:Kuznetsov:1972 XE1:2233 Kuznetsov" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.352
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.438557990152
		SemiMajorAxis	2.278131384621
		Eccentricity	0.081405688591
		Inclination	3.414255586766
		AscendingNode	247.250263876236
		ArgOfPericenter	159.120858105557
		MeanAnomaly	45.393738639051
	}
	UniformRotation
	{
		Period	5.031
	}
	LunarLambert	0.5
	Albedo	0.473
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2233"
}

#1_"2235 Vittore:Vittore:A924 GA:1933 UL:1933 WM:1939 VE:1950 TT:1959 GS:1962 SM:1968 TP:1976 EN: #1=
#1_1976 FC:1979 SA" "Sol" #1=
#2_"*Витторе:2235 Vittore:Vittore:1924 GA" "Sol" #2=
#3_"1924 GA:*Витторе:2235 Vittore:Vittore" "Sol" #3=
".:Vittore:2235 Vittore:1924 GA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.225
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.746800591597
		SemiMajorAxis	3.208326932565
		Eccentricity	0.212466501655
		Inclination	18.7672452148
		AscendingNode	205.071231921957
		ArgOfPericenter	274.874600933778
		MeanAnomaly	288.663110768939
	}
	UniformRotation
	{
		Period	32.1
	}
	LunarLambert	0.5
	Albedo	0.0469
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2235"
}

#1_"2237 Melnikov:Melnikov:1938 TB:1949 SO1:1972 TB2:1977 RU3" "Sol" #1=
#2_"*Мельников:2237 Melnikov:Melnikov:1938 TB" "Sol" #2=
#3_"1938 TB:*Мельников:2237 Melnikov:Melnikov" "Sol" #3=
".:Melnikov:2237 Melnikov:1938 TB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.27
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.568098055322
		SemiMajorAxis	3.141466611659
		Eccentricity	0.217629234234
		Inclination	2.400568082554
		AscendingNode	118.479521887316
		ArgOfPericenter	266.595311101073
		MeanAnomaly	197.924683019364
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1265
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2237"
}

#1_"2238 Steshenko:Steshenko:1972 RQ1:1976 HA1:1977 RV3:1978 VP5" "Sol" #1=
#2_"*Стешенко:2238 Steshenko:Steshenko:1972 RQ1" "Sol" #2=
#3_"1972 RQ1:*Стешенко:2238 Steshenko:Steshenko" "Sol" #3=
".:Steshenko:2238 Steshenko:1972 RQ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.35623079905
		SemiMajorAxis	3.061263547585
		Eccentricity	0.178967348042
		Inclination	1.311176258419
		AscendingNode	33.45897980912
		ArgOfPericenter	294.25747485529
		MeanAnomaly	338.060684500584
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0937
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2238"
}

#1_"2239 Paracelsus:Paracelsus:1978 RC:1938 UT1:1961 UO:1976 JX" "Sol" #1=
#2_"*Парацельс:2239 Paracelsus:Paracelsus:1978 RC" "Sol" #2=
#3_"1978 RC:*Парацельс:2239 Paracelsus:Paracelsus" "Sol" #3=
".:Paracelsus:2239 Paracelsus:1978 RC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.465
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.731457125487
		SemiMajorAxis	3.20261374937
		Eccentricity	0.101070440269
		Inclination	10.9087179208
		AscendingNode	20.224030496386
		ArgOfPericenter	3.06060988742
		MeanAnomaly	98.541427461327
	}
	UniformRotation
	{
		Period	6.101
	}
	LunarLambert	0.5
	Albedo	0.0293
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2239"
}

#1_"2240 Tsai:Tsai:1978 YA:1952 FP:1966 RH:1972 TV1" "Sol" #1=
#2_"*Цай:2240 Tsai:Tsai:1978 YA" "Sol" #2=
#3_"1978 YA:*Цай:2240 Tsai:Tsai" "Sol" #3=
".:Tsai:2240 Tsai:1978 YA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.589637636681
		SemiMajorAxis	3.149563011721
		Eccentricity	0.154269222571
		Inclination	0.842369403032
		AscendingNode	60.888706674052
		ArgOfPericenter	24.666797280117
		MeanAnomaly	154.642761549832
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0544
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2240"
}

#1_"2241 Alcathous:Alcathous:1979 WM:1950 NC:1968 WF" "Sol" #1=
#2_"*Алкафой:2241 Alcathous:Alcathous:1979 WM" "Sol" #2=
#3_"1979 WM:*Алкафой:2241 Alcathous:Alcathous" "Sol" #3=
".:Alcathous:2241 Alcathous:1979 WM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	57.315
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.823218901394
		SemiMajorAxis	5.189812711539
		Eccentricity	0.06642114479
		Inclination	16.614942294036
		AscendingNode	267.988832289544
		ArgOfPericenter	290.718855712315
		MeanAnomaly	214.794913884035
	}
	UniformRotation
	{
		Period	7.695
	}
	LunarLambert	0.5
	Albedo	0.0471
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2241"
}

#1_"2245 Hekatostos:Hekatostos:1968 BC:1930 FA:1958 XC:1966 QV:1971 XC" "Sol" #1=
#2_"*Гекатост:2245 Hekatostos:Hekatostos:1968 BC" "Sol" #2=
#3_"1968 BC:*Гекатост:2245 Hekatostos:Hekatostos" "Sol" #3=
".:Hekatostos:2245 Hekatostos:1968 BC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.283404192059
		SemiMajorAxis	2.637468228543
		Eccentricity	0.131663159304
		Inclination	11.853708555458
		AscendingNode	85.296717100881
		ArgOfPericenter	316.998247154486
		MeanAnomaly	44.634234848228
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0622
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2245"
}

#1_"2246 Bowell:Bowell:1979 XH:1942 GP:1973 FH2:1973 FR:1976 SL6:1977 SM3" "Sol" #1=
#2_"*Боуэлл:2246 Bowell:Bowell:1979 XH" "Sol" #2=
#3_"1979 XH:*Боуэлл:2246 Bowell:Bowell" "Sol" #3=
".:Bowell:2246 Bowell:1979 XH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.105
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.875016161021
		SemiMajorAxis	3.958179643771
		Eccentricity	0.093711975699
		Inclination	6.494226882434
		AscendingNode	155.668823580886
		ArgOfPericenter	21.085060274935
		MeanAnomaly	119.743318944691
	}
	UniformRotation
	{
		Period	4.992
	}
	LunarLambert	0.5
	Albedo	0.054
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2246"
}

#1_"2248 Kanda:Kanda:1933 DE:1944 FA:1949 BD:1949 DG:1958 XC1:1974 SO4:1974 WE:1975 XX5:1977 FY" "Sol" #1=
#2_"*Канда:2248 Kanda:Kanda:1933 DE" "Sol" #2=
#3_"1933 DE:*Канда:2248 Kanda:Kanda" "Sol" #3=
".:Kanda:2248 Kanda:1933 DE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.457276118468
		SemiMajorAxis	3.099644000379
		Eccentricity	0.116889645322
		Inclination	1.633948816531
		AscendingNode	33.793066529529
		ArgOfPericenter	145.643514211141
		MeanAnomaly	350.146580175383
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.093
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2248"
}

#1_"2249 Yamamoto:Yamamoto:1942 GA:1932 PK:1949 OX:1968 WA:1971 HY:1972 RM:1976 GX5:1978 RJ5" "Sol" #1=
#2_"*Ямамото:2249 Yamamoto:Yamamoto:1942 GA" "Sol" #2=
#3_"1942 GA:*Ямамото:2249 Yamamoto:Yamamoto" "Sol" #3=
".:Yamamoto:2249 Yamamoto:1942 GA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.355
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.71258353911
		SemiMajorAxis	3.195579118269
		Eccentricity	0.082881586969
		Inclination	4.099334803031
		AscendingNode	147.924755852554
		ArgOfPericenter	110.460431496761
		MeanAnomaly	234.162501430242
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0352
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2249"
}

#New3
#1_"2250 Stalingrad:Stalingrad:1972 HN:1951 UL:1968 UK" "Sol" #1=
#2_"*Сталинград:2250 Stalingrad:Stalingrad:1972 HN" "Sol" #2=
#3_"1972 HN:*Сталинград:2250 Stalingrad:Stalingrad" "Sol" #3=
".:Stalingrad:2250 Stalingrad:1972 HN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.635
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.707725939903
		SemiMajorAxis	3.193767323513
		Eccentricity	0.180331839154
		Inclination	1.52394231843
		AscendingNode	157.914708503519
		ArgOfPericenter	176.27464505206
		MeanAnomaly	276.97281256706
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.119
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2250"
}

#1_"2251 Tikhov:Tikhov:1977 SU1:1941 QF:1950 SS:1952 BO1:1955 XV:1975 ED5:1976 ND" "Sol" #1=
#2_"*Тихов:2251 Tikhov:Tikhov:1977 SU1" "Sol" #2=
#3_"1977 SU1:*Тихов:2251 Tikhov:Tikhov" "Sol" #3=
".:Tikhov:2251 Tikhov:1977 SU1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.466402386444
		SemiMajorAxis	2.712062933228
		Eccentricity	0.147804039965
		Inclination	7.43268609254
		AscendingNode	193.015931784898
		ArgOfPericenter	183.838224122144
		MeanAnomaly	124.156368143812
	}
	UniformRotation
	{
		Period	5.67
	}
	LunarLambert	0.5
	Albedo	0.0697
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2251"
}

#1_"2255 Qinghai:Qinghai:1977 VK1:1950 XB:1973 AP2:1977 UR:1977 VE" "Sol" #1=
#2_"*ЦинХай:2255 Qinghai:Qinghai:1977 VK1" "Sol" #2=
#3_"1977 VK1:*ЦинХай:2255 Qinghai:Qinghai" "Sol" #3=
".:Qinghai:2255 Qinghai:1977 VK1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.459003453035
		SemiMajorAxis	3.100298031157
		Eccentricity	0.152916954398
		Inclination	14.192034371731
		AscendingNode	41.136566563619
		ArgOfPericenter	346.845175531583
		MeanAnomaly	289.937647305061
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1018
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2255"
}

#1_"2258 Viipuri:Viipuri:1939 TA:1928 FL:1950 DU:1956 PG:1969 ON:1970 RS:1972 BK:1975 XD2:1979 UU" "Sol" #1=
#2_"*Виипури:2258 Viipuri:Viipuri:1939 TA" "Sol" #2=
#3_"1939 TA:*Виипури:2258 Viipuri:Viipuri" "Sol" #3=
".:Viipuri:2258 Viipuri:1939 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.735
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.420501704944
		SemiMajorAxis	2.69344993088
		Eccentricity	0.079668991734
		Inclination	1.480654412369
		AscendingNode	307.504256458609
		ArgOfPericenter	174.850363053474
		MeanAnomaly	265.340754912677
	}
	UniformRotation
	{
		Period	3.81
	}
	LunarLambert	0.5
	Albedo	0.0883
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2258"
}

#1_"2259 Sofievka:Sofievka:1971 OG:1929 JM:1936 KJ:1956 AF:1970 CJ:1972 YC:1972 YN1:1975 WE1" "Sol" #1=
#2_"*Софиевка:2259 Sofievka:Sofievka:1971 OG" "Sol" #2=
#3_"1971 OG:*Софиевка:2259 Sofievka:Sofievka" "Sol" #3=
".:Sofievka:2259 Sofievka:1971 OG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.476200386822
		SemiMajorAxis	2.294727221414
		Eccentricity	0.185601429973
		Inclination	4.68449682547
		AscendingNode	280.355909193826
		ArgOfPericenter	11.748942408594
		MeanAnomaly	183.965505289948
	}
	UniformRotation
	{
		Period	31.6
	}
	LunarLambert	0.5
	Albedo	0.0365
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2259"
}

#1_"2260 Neoptolemus:Neoptolemus:1975 WM1:1951 XK" "Sol" #1=
#2_"*Неоптолем:2260 Neoptolemus:Neoptolemus:1975 WM1" "Sol" #2=
#3_"1975 WM1:*Неоптолем:2260 Neoptolemus:Neoptolemus" "Sol" #3=
".:Neoptolemus:2260 Neoptolemus:1975 WM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	35.825
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.837857233402
		SemiMajorAxis	5.194095500872
		Eccentricity	0.043709178357
		Inclination	17.779217829708
		AscendingNode	86.573828594798
		ArgOfPericenter	321.795124165984
		MeanAnomaly	141.434501907413
	}
	UniformRotation
	{
		Period	8.18
	}
	LunarLambert	0.5
	Albedo	0.065
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2260"
}

#1_"2263 Shaanxi:Shaanxi:1978 UW1:1936 WJ:1943 AA:1957 UA1:1969 AE:1973 YT1" "Sol" #1=
#2_"*Шанси:2263 Shaanxi:Shaanxi:1978 UW1" "Sol" #2=
#3_"1978 UW1:*Шанси:2263 Shaanxi:Shaanxi" "Sol" #3=
".:Shaanxi:2263 Shaanxi:1978 UW1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.239554086547
		SemiMajorAxis	3.01664415588
		Eccentricity	0.111757285165
		Inclination	11.399168393166
		AscendingNode	54.436159119316
		ArgOfPericenter	314.011187291204
		MeanAnomaly	354.452238070602
	}
	UniformRotation
	{
		Period	41.7
	}
	LunarLambert	0.5
	Albedo	0.1803
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2263"
}

#1_"2264 Sabrina:Sabrina:1979 YK:1932 JD:1932 KB:1933 SU:1939 VJ:1944 RJ:1949 MW:1966 QK:1966 RP: #1=
#1_1970 HM:1972 TL7:1975 ED2:1976 GZ3:1976 JT1:1977 FJ:1977 RS1:1978 WY4" "Sol" #1=
#2_"*Сабрина:2264 Sabrina:Sabrina:1979 YK" "Sol" #2=
#3_"1979 YK:*Сабрина:2264 Sabrina:Sabrina" "Sol" #3=
".:Sabrina:2264 Sabrina:1979 YK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.76
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.524764599056
		SemiMajorAxis	3.125146521764
		Eccentricity	0.176218507602
		Inclination	0.158353406397
		AscendingNode	240.232770599519
		ArgOfPericenter	79.075873434913
		MeanAnomaly	261.149661568507
	}
	UniformRotation
	{
		Period	43.41
	}
	LunarLambert	0.5
	Albedo	0.1472
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2264"
}

#1_"2266 Tchaikovsky:Tchaikovsky:1974 VK:1937 VM:1937 VQ:1943 UH:1951 AY1:1955 QY:1962 WM2:1973 QH" "Sol" #1=
#2_"*Чайковский:2266 Tchaikovsky:Tchaikovsky:1974 VK" "Sol" #2=
#3_"1974 VK:*Чайковский:2266 Tchaikovsky:Tchaikovsky" "Sol" #3=
".:Tchaikovsky:2266 Tchaikovsky:1974 VK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.47
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.263592724139
		SemiMajorAxis	3.397896966939
		Eccentricity	0.182447815117
		Inclination	13.251855337986
		AscendingNode	229.469427650698
		ArgOfPericenter	205.897957143149
		MeanAnomaly	140.88501310884
	}
	UniformRotation
	{
		Period	37.7
	}
	LunarLambert	0.5
	Albedo	0.0384
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2266"
}

#1_"2269 Efremiana:Efremiana:1976 JA2:1929 XP:1951 WO1:1962 XA:1978 VE" "Sol" #1=
#2_"*Ефремиана:2269 Efremiana:Efremiana:1976 JA2" "Sol" #2=
#3_"1976 JA2:*Ефремиана:2269 Efremiana:Efremiana" "Sol" #3=
".:Efremiana:2269 Efremiana:1976 JA2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.46
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.526575275262
		SemiMajorAxis	3.125829304327
		Eccentricity	0.085480238836
		Inclination	15.382251170134
		AscendingNode	66.766539178519
		ArgOfPericenter	34.982752669339
		MeanAnomaly	107.061771329092
	}
	UniformRotation
	{
		Period	6.458
	}
	LunarLambert	0.5
	Albedo	0.2123
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2269"
}

#1_"2271 Kiso:Kiso:1976 UV5:1928 DB1:1929 LB:1939 RL:1942 EG:1948 PR:1951 EF2:1952 LA:1952 MN: #1=
#1_1953 TP2:1956 GH:1960 EB:1965 FA:1972 WA:1972 XM2:1974 ES:1976 SC6" "Sol" #1=
#2_"*Кисо:2271 Kiso:Kiso:1976 UV5" "Sol" #2=
#3_"1976 UV5:*Кисо:2271 Kiso:Kiso" "Sol" #3=
".:Kiso:2271 Kiso:1976 UV5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.590872427011
		SemiMajorAxis	2.762218406171
		Eccentricity	0.057943094696
		Inclination	3.387704297824
		AscendingNode	136.473433310163
		ArgOfPericenter	178.329582562712
		MeanAnomaly	181.232757788115
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0612
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2271"
}

#1_"2275 Cuitlahuac:Cuitlahuac:1979 MH:1931 XS:1948 PX:1955 QF:1969 TH:1972 LS:1976 WF:1982 HH" "Sol" #1=
#2_"*Куитлахуак:2275 Cuitlahuac:Cuitlahuac:1979 MH" "Sol" #2=
#3_"1979 MH:Cuitlahuac:*Куитлахуак:2275 Cuitlahuac" "Sol" #3=
".:Cuitlahuac:2275 Cuitlahuac:1979 MH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2275 cuitlahuac.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.506
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.481320185613
		SemiMajorAxis	2.29697980725
		Eccentricity	0.169236633352
		Inclination	6.393357295763
		AscendingNode	197.203908261624
		ArgOfPericenter	154.115374456369
		MeanAnomaly	232.712491497788
	}
	UniformRotation
	{
		Period	6.2891
	}
	LunarLambert	0.5
	Albedo	0.177
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2275"
}

#1_"2279 Barto:Barto:1968 DL:1949 KA1:1969 QS:1976 JJ2" "Sol" #1=
#2_"*Барто:2279 Barto:Barto:1968 DL" "Sol" #2=
#3_"1968 DL:*Барто:2279 Barto:Barto" "Sol" #3=
".:Barto:2279 Barto:1968 DL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.765
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.8553942047
		SemiMajorAxis	2.458708590613
		Eccentricity	0.156753865253
		Inclination	2.983729859808
		AscendingNode	139.949554089567
		ArgOfPericenter	61.99612353768
		MeanAnomaly	24.267085725394
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0475
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2279"
}

#New3
#1_"2280 Kunikov:Kunikov:1971 SL2:1970 GY1" "Sol" #1=
#2_"*Куников:2280 Kunikov:Kunikov:1971 SL2" "Sol" #2=
#3_"1971 SL2:*Куников:2280 Kunikov:Kunikov" "Sol" #3=
".:Kunikov:2280 Kunikov:1971 SL2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.07
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.215436208019
		SemiMajorAxis	2.178484447343
		Eccentricity	0.14158537976
		Inclination	3.567972702156
		AscendingNode	106.510925502563
		ArgOfPericenter	264.136757726981
		MeanAnomaly	97.430020218187
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.27
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2280"
}

#1_"2291 Kevo:Kevo:1941 FS:1938 RC:1967 EO:1970 TD:1975 RT1:1978 GT2:1980 PE:A909 HC" "Sol" #1=
#2_"*Кево:2291 Kevo:Kevo:1941 FS" "Sol" #2=
#3_"1941 FS:*Кево:2291 Kevo:Kevo" "Sol" #3=
".:Kevo:2291 Kevo:1941 FS:1938 RC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.285
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.313335335849
		SemiMajorAxis	3.044897534279
		Eccentricity	0.06597414701
		Inclination	24.487351534424
		AscendingNode	169.502675883104
		ArgOfPericenter	297.882523410557
		MeanAnomaly	37.070257479472
	}
	UniformRotation
	{
		Period	11.971
	}
	LunarLambert	0.5
	Albedo	0.0708
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2291"
}

#1_"2295 Matusovskij:Matusovskij:1977 QD1:1952 PF:1952 RA:1967 RR:1972 TB5:1975 EO5:1977 TQ5" "Sol" #1=
#2_"*Матусовский:2295 Matusovskij:Matusovskij:1977 QD1" "Sol" #2=
#3_"1977 QD1:*Матусовский:2295 Matusovskij:Matusovskij" "Sol" #3=
".:Matusovskij:2295 Matusovskij:1977 QD1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.525
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.941058416092
		SemiMajorAxis	2.900956327517
		Eccentricity	0.09589764053
		Inclination	2.51021079437
		AscendingNode	313.556415514024
		ArgOfPericenter	70.983971588441
		MeanAnomaly	166.83447862543
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0632
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2295"
}

#1_"2297 Daghestan:Daghestan:1978 RE:1931 EJ:1954 HL:1956 TF:1956 UP:1959 EG:1971 HF:1973 UB1: #1=
#1_1975 AP:1976 GD:1977 MA" "Sol" #1=
#2_"*Дагестан:2297 Daghestan:Daghestan:1978 RE" "Sol" #2=
#3_"1978 RE:*Дагестан:2297 Daghestan:Daghestan" "Sol" #3=
".:Daghestan:2297 Daghestan:1978 RE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.650142062808
		SemiMajorAxis	3.172250273554
		Eccentricity	0.128304729739
		Inclination	1.610322990719
		AscendingNode	140.49924143884
		ArgOfPericenter	92.281758469975
		MeanAnomaly	273.102039247005
	}
	UniformRotation
	{
		Period	7.75
	}
	LunarLambert	0.5
	Albedo	0.1057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2297"
}

#1_"2304 Slavia:Slavia:1979 KB:1962 JM:1970 GF1:1980 RF1" "Sol" #1=
#2_"*Славия:2304 Slavia:Slavia:1979 KB" "Sol" #2=
#3_"1979 KB:*Славия:2304 Slavia:Slavia" "Sol" #3=
".:Slavia:2304 Slavia:1979 KB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	5.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.221965415894
		SemiMajorAxis	2.612187294877
		Eccentricity	0.133111032285
		Inclination	13.594322955635
		AscendingNode	195.940867237682
		ArgOfPericenter	59.425085594876
		MeanAnomaly	147.111900445522
	}
	UniformRotation
	{
		Period	3.14
	}
	LunarLambert	0.5
	Albedo	0.1372
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2304"
}

#1_"2306 Bauschinger:Bauschinger:1939 PM:1967 TK:1971 SC3:1982 BO12" "Sol" #1=
#2_"*Баушингер:2306 Bauschinger:Bauschinger:1939 PM" "Sol" #2=
#3_"1939 PM:*Баушингер:2306 Bauschinger:Bauschinger" "Sol" #3=
".:Bauschinger:2306 Bauschinger:1939 PM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2306 bauschinger.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	8.882
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.513011072657
		SemiMajorAxis	2.730897906563
		Eccentricity	0.064295089179
		Inclination	4.234596473181
		AscendingNode	236.749193260196
		ArgOfPericenter	103.827222692597
		MeanAnomaly	243.332253033078
	}
	UniformRotation
	{
		Period	21.64
	}
	LunarLambert	0.5
	Albedo	0.077
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2306"
}

#1_"2307 Garuda:Garuda:1957 HJ:1976 YY2:1977 AH:1981 WE4" "Sol" #1=
#2_"*Гаруда:2307 Garuda:Garuda:1957 HJ" "Sol" #2=
#3_"1957 HJ:*Гаруда:2307 Garuda:Garuda" "Sol" #3=
".:Garuda:2307 Garuda:1957 HJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.61
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.32704780416
		SemiMajorAxis	3.05013405958
		Eccentricity	0.056386070438
		Inclination	7.709540711455
		AscendingNode	251.653543245802
		ArgOfPericenter	338.704775550233
		MeanAnomaly	272.972143262822
	}
	UniformRotation
	{
		Period	29.64
	}
	LunarLambert	0.5
	Albedo	0.0454
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2307"
}

#1_"2308 Schilt:Schilt:1967 JM:1926 GP:1930 DR:1972 TX7:1976 UH12:1980 VF:1981 YM" "Sol" #1=
#2_"*Шилт:2308 Schilt:Schilt:1967 JM" "Sol" #2=
#3_"1967 JM:*Шилт:2308 Schilt:Schilt" "Sol" #3=
".:Schilt:2308 Schilt:1967 JM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.77
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.073117274631
		SemiMajorAxis	2.550424518989
		Eccentricity	0.171917937225
		Inclination	14.167674573588
		AscendingNode	34.325791506921
		ArgOfPericenter	233.239968957405
		MeanAnomaly	235.900891893901
	}
	UniformRotation
	{
		Period	9.759
	}
	LunarLambert	0.5
	Albedo	0.1094
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2308"
}

#1_"2309 Mr. Spock:Mr. Spock:1971 QX1:1935 SN1:1948 EJ1:1956 TL:1974 CU:1977 SF3" "Sol" #1=
#2_"*М. Спок:2309 Mr. Spock:Mr. Spock:1971 QX1" "Sol" #2=
#3_"1971 QX1:*М. Спок:2309 Mr. Spock:Mr. Spock" "Sol" #3=
".:Mr. Spock:2309 Mr. Spock:1971 QX1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.227567026346
		SemiMajorAxis	3.012041410859
		Eccentricity	0.088616132459
		Inclination	10.985266672946
		AscendingNode	157.267330662952
		ArgOfPericenter	271.922369238916
		MeanAnomaly	357.971886174726
	}
	UniformRotation
	{
		Period	6.722
	}
	LunarLambert	0.5
	Albedo	0.1177
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2309"
}

#1_"2310 Olshaniya:Olshaniya:1974 SU4:1959 CZ:1971 FS:1977 JJ" "Sol" #1=
#2_"*Ольшания:2310 Olshaniya:Olshaniya:1974 SU4" "Sol" #2=
#3_"1974 SU4:*Ольшания:2310 Olshaniya:Olshaniya" "Sol" #3=
".:Olshaniya:2310 Olshaniya:1974 SU4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.198
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.569673298237
		SemiMajorAxis	3.142059074851
		Eccentricity	0.161321501167
		Inclination	2.650013467082
		AscendingNode	124.133873256739
		ArgOfPericenter	331.02246330052
		MeanAnomaly	185.455496129284
	}
	UniformRotation
	{
		Period	16.169
	}
	LunarLambert	0.5
	Albedo	0.065
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2310"
}

#1_"2311 El Leoncito:El Leoncito:1974 TA1:1928 DM:1944 KD:1972 KH:1972 LM:1976 AE" "Sol" #1=
#2_"*Эль-Леонсито:2311 El Leoncito:El Leoncito:1974 TA1" "Sol" #2=
#3_"1974 TA1:*Эль-Леонсито:2311 El Leoncito:El Leoncito" "Sol" #3=
".:El Leoncito:2311 El Leoncito:1974 TA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.57
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.942671469015
		SemiMajorAxis	3.639253220116
		Eccentricity	0.041430669174
		Inclination	6.616790104213
		AscendingNode	156.686138966429
		ArgOfPericenter	190.841690191402
		MeanAnomaly	323.881137280813
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0388
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2311"
}

#1_"2312 Duboshin:Duboshin:1976 GU2:1943 DH:1971 QJ:1972 TJ7:1973 YE2:1975 CF:1976 JN" "Sol" #1=
#2_"*Дубошин:2312 Duboshin:Duboshin:1976 GU2" "Sol" #2=
#3_"1976 GU2:*Дубошин:2312 Duboshin:Duboshin" "Sol" #3=
".:Duboshin:2312 Duboshin:1976 GU2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.47
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.932786374633
		SemiMajorAxis	3.977513886813
		Eccentricity	0.153351978604
		Inclination	5.156186733557
		AscendingNode	61.564143398302
		ArgOfPericenter	342.787487266342
		MeanAnomaly	99.507695284579
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0496
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2312"
}

#1_"2313 Aruna:Aruna:1976 TA:1949 TE:1972 RA1:1980 QB" "Sol" #1=
#2_"*Аруна:2313 Aruna:Aruna:1976 TA" "Sol" #2=
#3_"1976 TA:*Аруна:2313 Aruna:Aruna" "Sol" #3=
".:Aruna:2313 Aruna:1976 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2313 aruna.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	7.528
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.851487909762
		SemiMajorAxis	2.457047530288
		Eccentricity	0.190341430756
		Inclination	1.835466889691
		AscendingNode	229.751190363026
		ArgOfPericenter	108.159783299286
		MeanAnomaly	348.658173985018
	}
	UniformRotation
	{
		Period	8.9
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2313"
}

#1_"2315 Czechoslovakia:Czechoslovakia:1980 DZ:1946 SE:1951 RZ1:1972 RS3:1975 FC:1975 GG:1975 JP" "Sol" #1=
#2_"*Чехословакия:2315 Czechoslovakia:Czechoslovakia:1980 DZ" "Sol" #2=
#3_"1980 DZ:*Чехословакия:2315 Czechoslovakia:Czechoslovakia" "Sol" #3=
".:Czechoslovakia:2315 Czechoslovakia:1980 DZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.725
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.224914211954
		SemiMajorAxis	3.011022318201
		Eccentricity	0.104700575964
		Inclination	10.699836499067
		AscendingNode	30.176871528696
		ArgOfPericenter	11.778635858734
		MeanAnomaly	355.475856651303
	}
	UniformRotation
	{
		Period	10.0253
	}
	LunarLambert	0.5
	Albedo	0.1686
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2315"
}

#1_"2320 Blarney:Blarney:1979 QJ:1929 WF1:1931 DP:1942 CE:1950 NF1:1951 VG:1955 ME:1968 UE3:1972 LN: #1=
#1_1975 AQ" "Sol" #1=
#2_"*Бларни:2320 Blarney:Blarney:1979 QJ" "Sol" #2=
#3_"1979 QJ:*Бларни:2320 Blarney:Blarney" "Sol" #3=
".:Blarney:2320 Blarney:1979 QJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.650863629041
		SemiMajorAxis	3.172520348174
		Eccentricity	0.12759585894
		Inclination	11.514870944124
		AscendingNode	118.302466004636
		ArgOfPericenter	260.109853540446
		MeanAnomaly	88.309023560904
	}
	UniformRotation
	{
		Period	5.097
	}
	LunarLambert	0.5
	Albedo	0.074
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2320"
}

#1_"2321 Luznice:Luznice:1980 DB1:1957 WF1:1972 RZ3:1973 YT2:1975 GN:1977 QX3:1977 RG1:1977 TN1" "Sol" #1=
#2_"*Лужнице:2321 Luznice:Luznice:1980 DB1" "Sol" #2=
#3_"1980 DB1:*Лужнице:2321 Luznice:Luznice" "Sol" #3=
".:Luznice:2321 Luznice:1980 DB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.835
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.20970836743
		SemiMajorAxis	3.005177581248
		Eccentricity	0.061143608936
		Inclination	7.789355760255
		AscendingNode	45.79601977325
		ArgOfPericenter	3.897446085187
		MeanAnomaly	357.580285274628
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1421
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2321"
}

#1_"2322 Kitt Peak:Kitt Peak:1954 UQ2:1954 WC:1970 GU:1975 VP1:1975 YF:1977 JC" "Sol" #1=
#2_"*Китт-Пик:2322 Kitt Peak:Kitt Peak:1954 UQ2" "Sol" #2=
#3_"1954 UQ2:*Китт-Пик:2322 Kitt Peak:Kitt Peak" "Sol" #3=
".:Kitt Peak:2322 Kitt Peak:1954 UQ2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.02
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.471801191673
		SemiMajorAxis	2.292790800003
		Eccentricity	0.041759160905
		Inclination	2.404296473994
		AscendingNode	194.808567514423
		ArgOfPericenter	191.8075960508
		MeanAnomaly	125.929685152571
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0571
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2322"
}

#1_"2326 Tololo:Tololo:1965 QC:1931 RZ:1936 SF:1941 SF2:1969 MB:1973 GH1:1979 MB" "Sol" #1=
#2_"*Тололо:2326 Tololo:Tololo:1965 QC" "Sol" #2=
#3_"1965 QC:*Тололо:2326 Tololo:Tololo" "Sol" #3=
".:Tololo:2326 Tololo:1965 QC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.445
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.840298309353
		SemiMajorAxis	2.861382723411
		Eccentricity	0.155214332686
		Inclination	15.153320527666
		AscendingNode	155.880102029356
		ArgOfPericenter	259.494684928467
		MeanAnomaly	10.344457422974
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0384
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2326"
}

#1_"2328 Robeson:Robeson:1972 HW" "Sol" #1=
#2_"*Робсон:2328 Robeson:Robeson:1972 HW" "Sol" #2=
#3_"1972 HW:*Робсон:2328 Robeson:Robeson" "Sol" #3=
".:Robeson:2328 Robeson:1972 HW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.582286316254
		SemiMajorAxis	2.341179582225
		Eccentricity	0.145685362801
		Inclination	10.015935562319
		AscendingNode	182.202166987377
		ArgOfPericenter	340.70788915168
		MeanAnomaly	11.172920209973
	}
	UniformRotation
	{
		Period	18.632
	}
	LunarLambert	0.5
	Albedo	0.1281
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2328"
}

#1_"2329 Orthos:Orthos:1976 WA" "Sol" #1=
#2_"*Орф:2329 Orthos:Orthos:1976 WA" "Sol" #2=
#3_"1976 WA:*Орф:2329 Orthos:Orthos" "Sol" #3=
".:Orthos:2329 Orthos:1976 WA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.731795732232
		SemiMajorAxis	2.405875267564
		Eccentricity	0.656675620249
		Inclination	24.426678501277
		AscendingNode	169.415146016892
		ArgOfPericenter	145.888479970562
		MeanAnomaly	97.470813519387
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.14
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2329"
}

#1_"2330 Ontake:Ontake:1977 DS3:1972 FG:1978 JF:1979 ON15" "Sol" #1=
#2_"*Онтакэ:2330 Ontake:Ontake:1977 DS3" "Sol" #2=
#3_"1977 DS3:*Онтакэ:2330 Ontake:Ontake" "Sol" #3=
".:Ontake:2330 Ontake:1977 DS3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.525
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.668094046812
		SemiMajorAxis	3.178966101402
		Eccentricity	0.038837409656
		Inclination	8.665485491084
		AscendingNode	140.600566449849
		ArgOfPericenter	133.643568283622
		MeanAnomaly	120.602670210217
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0488
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2330"
}

#1_"2332 Kalm:Kalm:1940 GH:1935 JE:1951 JT:1962 JY:1975 VY1:1975 XM3:1975 XZ1" "Sol" #1=
#2_"*Кальм:2332 Kalm:Kalm:1940 GH" "Sol" #2=
#3_"1940 GH:*Кальм:2332 Kalm:Kalm" "Sol" #3=
".:Kalm:2332 Kalm:1940 GH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.79
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.396859059183
		SemiMajorAxis	3.076724308467
		Eccentricity	0.058868021004
		Inclination	14.54641575106
		AscendingNode	61.254718457839
		ArgOfPericenter	242.206583048738
		MeanAnomaly	211.404105950663
	}
	UniformRotation
	{
		Period	22.8
	}
	LunarLambert	0.5
	Albedo	0.1162
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2332"
}

#1_"2333 Porthan:Porthan:1943 EP:1926 GZ:1939 HJ:1952 HS3:1954 UK2:1973 GT" "Sol" #1=
#2_"*Портан:2333 Porthan:Porthan:1943 EP" "Sol" #2=
#3_"1943 EP:*Портан:2333 Porthan:Porthan" "Sol" #3=
".:Porthan:2333 Porthan:1943 EP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.795
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.300910535891
		SemiMajorAxis	2.64464959323
		Eccentricity	0.137075708135
		Inclination	11.938081152425
		AscendingNode	39.959051894193
		ArgOfPericenter	99.775768674232
		MeanAnomaly	265.730532868728
	}
	UniformRotation
	{
		Period	27.78
	}
	LunarLambert	0.5
	Albedo	0.0952
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2333"
}

#1_"2340 Hathor:Hathor:1976 UA" "Sol" #1=
#2_"*Хатхор:2340 Hathor:Hathor:1976 UA" "Sol" #2=
#3_"1976 UA:*Хатхор:2340 Hathor:Hathor" "Sol" #3=
".:Hathor:2340 Hathor:1976 UA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2456600.5  # 2013 Nov 04
		Period	0.775685369621
		SemiMajorAxis	0.844212150610
		Eccentricity	0.449820401348
		Inclination	5.853930899445
		AscendingNode	211.461772865034
		ArgOfPericenter	40.023600743192
		MeanAnomaly	7.604342862359
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.2
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2340"
}

#New3
#1_"2342 Lebedev:Lebedev:1968 UQ:1950 OC:1950 PG:1951 YM:1962 VJ:1963 WF" "Sol" #1=
#2_"*Лебедев:2342 Lebedev:Lebedev:1968 UQ" "Sol" #2=
#3_"1968 UQ:*Лебедев:2342 Lebedev:Lebedev" "Sol" #3=
".:Lebedev:2342 Lebedev:1968 UQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.962
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.804685800964
		SemiMajorAxis	3.229835049912
		Eccentricity	0.132882831759
		Inclination	0.36248802125
		AscendingNode	195.179081812746
		ArgOfPericenter	215.593532845101
		MeanAnomaly	154.116989248636
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.051
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2342"
}


#1_"2345 Fucik:Fucik:1974 OS:1935 BE:1935 DK:1938 UH1:1951 EC2:1969 QJ:1972 EG:1972 GP:1972 GT: #1=
#1_1975 XH2" "Sol" #1=
#2_"*Фучик:2345 Fucik:Fucik:1974 OS" "Sol" #2=
#3_"1974 OS:*Фучик:2345 Fucik:Fucik" "Sol" #3=
".:Fucik:2345 Fucik:1974 OS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.315
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.234393442799
		SemiMajorAxis	3.014663022597
		Eccentricity	0.078332356848
		Inclination	9.154753889407
		AscendingNode	303.880497514789
		ArgOfPericenter	135.935468834472
		MeanAnomaly	135.258396347758
	}
	UniformRotation
	{
		Period	17.12
	}
	LunarLambert	0.5
	Albedo	0.1192
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2345"
}

#1_"2349 Kurchenko:Kurchenko:1970 OG:1957 WM1:1969 LC:1979 NA" "Sol" #1=
#2_"*Курченко:2349 Kurchenko:Kurchenko:1970 OG" "Sol" #2=
#3_"1970 OG:*Курченко:2349 Kurchenko:Kurchenko" "Sol" #3=
".:Kurchenko:2349 Kurchenko:1970 OG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.76
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.606298547068
		SemiMajorAxis	2.768402631647
		Eccentricity	0.119521053343
		Inclination	17.487300923069
		AscendingNode	133.144936022486
		ArgOfPericenter	218.666238725991
		MeanAnomaly	194.255987842074
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0663
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2349"
}

#1_"2355 Nei Monggol:Nei Monggol:1978 UV1:1973 YE1:1976 JB3" "Sol" #1=
#2_"*Ней Монгол:2355 Nei Monggol:Nei Monggol:1978 UV1" "Sol" #2=
#3_"1978 UV1:*Ней Монгол:2355 Nei Monggol:Nei Monggol" "Sol" #3=
".:Nei Monggol:2355 Nei Monggol:1978 UV1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.48
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.248025983186
		SemiMajorAxis	3.019895045155
		Eccentricity	0.116683091393
		Inclination	9.999838016373
		AscendingNode	53.857869168887
		ArgOfPericenter	278.075877780592
		MeanAnomaly	18.981490505021
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1692
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2355"
}

#1_"2356 Hirons:Hirons:1979 UJ:1970 GG1:1972 QD:1972 RO3:1976 GM5" "Sol" #1=
#2_"*Хиронс:2356 Hirons:Hirons:1979 UJ" "Sol" #2=
#3_"1979 UJ:*Хиронс:2356 Hirons:Hirons" "Sol" #3=
".:Hirons:2356 Hirons:1979 UJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.97
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.813093550232
		SemiMajorAxis	3.232953116116
		Eccentricity	0.040043363627
		Inclination	15.597031470739
		AscendingNode	189.136098631516
		ArgOfPericenter	2.187191550039
		MeanAnomaly	233.901343229896
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0401
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2356"
}

#1_"2357 Phereclos:Phereclos:1981 AC:1929 SM:1959 EU:1965 UQ1:1972 JP1:1976 SC1:1977 RM7:1978 VN16" "Sol" #1=
#2_"*Ферекл:2357 Phereclos:Phereclos:1981 AC" "Sol" #2=
#3_"1981 AC:*Ферекл:2357 Phereclos:Phereclos" "Sol" #3=
".:Phereclos:2357 Phereclos:1981 AC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	47.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.888776866222
		SemiMajorAxis	5.208979511514
		Eccentricity	0.043989837671
		Inclination	2.668873806292
		AscendingNode	179.251397189352
		ArgOfPericenter	75.536516944655
		MeanAnomaly	178.788651981036
	}
	UniformRotation
	{
		Period	14.394
	}
	LunarLambert	0.5
	Albedo	0.0521
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2357"
}

#1_"2358 Bahner:Bahner:1929 RE:1945 TB:1950 ST:1964 JD:1966 UN:1968 BB:1971 TO1:1973 AB:1974 EE: #1=
#1_1976 SP" "Sol" #1=
#2_"*Бэнер:2358 Bahner:Bahner:1929 RE" "Sol" #2=
#3_"1929 RE:Bahner:*Бэнер:2358 Bahner" "Sol" #3=
".:Bahner:2358 Bahner:1929 RE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2358 bahner.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.293
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.260175792041
		SemiMajorAxis	3.024554194433
		Eccentricity	0.096993853366
		Inclination	9.686316812478
		AscendingNode	344.512615094369
		ArgOfPericenter	51.390757146526
		MeanAnomaly	192.036330449771
	}
	UniformRotation
	{
		Period	10.848
	}
	LunarLambert	0.5
	Albedo	0.132
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2358"
}

#1_"2363 Cebriones:Cebriones:1977 TJ3" "Sol" #1=
#2_"*Кебрионес:2363 Cebriones:Cebriones:1977 TJ3" "Sol" #2=
#3_"1977 TJ3:*Кебрионес:2363 Cebriones:Cebriones" "Sol" #3=
".:Cebriones:2363 Cebriones:1977 TJ3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.92
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.852090261537
		SemiMajorAxis	5.198258016638
		Eccentricity	0.035345518493
		Inclination	32.135132824952
		AscendingNode	211.759879624197
		ArgOfPericenter	57.460051271046
		MeanAnomaly	176.752616142543
	}
	UniformRotation
	{
		Period	20.05
	}
	LunarLambert	0.5
	Albedo	0.0599
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2363"
}

#1_"2364 Seillier:Seillier:1978 GD:1966 DX:1971 BH:1978 HA" "Sol" #1=
#2_"*Селлер:2364 Seillier:Seillier:1978 GD" "Sol" #2=
#3_"1978 GD:*Селлер:2364 Seillier:Seillier" "Sol" #3=
".:Seillier:2364 Seillier:1978 GD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.654879446156
		SemiMajorAxis	3.174023216153
		Eccentricity	0.139866997376
		Inclination	10.709499375002
		AscendingNode	42.821437059936
		ArgOfPericenter	168.787134774256
		MeanAnomaly	168.95182523064
	}
	UniformRotation
	{
		Period	6.7
	}
	LunarLambert	0.5
	Albedo	0.2747
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2364"
}

#1_"2368 Beltrovata:Beltrovata:1977 RA" "Sol" #1=
#2_"*Бельтровата:2368 Beltrovata:Beltrovata:1977 RA" "Sol" #2=
#3_"1977 RA:*Бельтровата:2368 Beltrovata:Beltrovata" "Sol" #3=
".:Beltrovata:2368 Beltrovata:1977 RA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.053842311516
		SemiMajorAxis	2.104871577763
		Eccentricity	0.413646603602
		Inclination	5.236287633603
		AscendingNode	287.53276899348
		ArgOfPericenter	42.65306943517
		MeanAnomaly	77.451354245447
	}
	UniformRotation
	{
		Period	5.9
	}
	LunarLambert	0.5
	Albedo	0.27
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2368"
}

#1_"2370 van Altena:van Altena:1965 LA:1974 OY" "Sol" #1=
#2_"*ван Алтена:2370 van Altena:van Altena:1965 LA" "Sol" #2=
#3_"1965 LA:*ван Алтена:2370 van Altena:van Altena" "Sol" #3=
".:van Altena:2370 van Altena:1965 LA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.69
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.470803820407
		SemiMajorAxis	2.713844382841
		Eccentricity	0.184314177953
		Inclination	8.275910913183
		AscendingNode	10.379014754512
		ArgOfPericenter	315.54233163515
		MeanAnomaly	346.635148912115
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0899
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2370"
}

#1_"2372 Proskurin:Proskurin:1977 RA8:1949 QK2:1950 XR:1961 XW:1972 VR1:A906 VD" "Sol" #1=
#2_"*Проскурин:2372 Proskurin:Proskurin:1977 RA8" "Sol" #2=
#3_"1977 RA8:*Проскурин:2372 Proskurin:Proskurin" "Sol" #3=
".:Proskurin:2372 Proskurin:1977 RA8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.385
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.497024123634
		SemiMajorAxis	3.11467660214
		Eccentricity	0.177676402528
		Inclination	2.743516180547
		AscendingNode	98.221521894265
		ArgOfPericenter	317.434383841549
		MeanAnomaly	255.816554728823
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.078
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2372"
}

#1_"2376 Martynov:Martynov:1977 QG3:1937 TK:1942 PC:1948 QF:1954 SC1:1959 NC:1969 ED2:1970 LM: #1=
#1_1971 QK:1974 CA1:1975 FF:1981 GK" "Sol" #1=
#2_"*Мартынов:2376 Martynov:Martynov:1977 QG3" "Sol" #2=
#3_"1977 QG3:*Мартынов:2376 Martynov:Martynov" "Sol" #3=
".:Martynov:2376 Martynov:1977 QG3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.74033883717
		SemiMajorAxis	3.205921500479
		Eccentricity	0.115378643598
		Inclination	3.836511163797
		AscendingNode	61.241486532418
		ArgOfPericenter	301.026789341566
		MeanAnomaly	154.676771963652
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0536
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2376"
}

#1_"2378 Pannekoek:Pannekoek:1935 CY:1935 EP:1938 UD1:1960 HD:1967 RB1:1970 GP1:1970 JG:1972 RH3: #1=
#1_1975 JH:1977 RR5:1977 XJ:A918 RE" "Sol" #1=
#2_"*Паннекук:2378 Pannekoek:Pannekoek:1935 CY" "Sol" #2=
#3_"1935 CY:*Паннекук:2378 Pannekoek:Pannekoek" "Sol" #3=
".:Pannekoek:2378 Pannekoek:1935 CY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.13
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.908525543016
		SemiMajorAxis	2.888208679044
		Eccentricity	0.143680570897
		Inclination	14.2469323033
		AscendingNode	181.180568045291
		ArgOfPericenter	265.190249365874
		MeanAnomaly	145.448406780134
	}
	UniformRotation
	{
		Period	11.8806
	}
	LunarLambert	0.5
	Albedo	0.0891
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2378"
}

#1_"2379 Heiskanen:Heiskanen:1941 ST:1935 QD1:1953 VL:1953 XT:1964 RD:1965 YD:1966 BH:1970 RM: #1=
#1_1971 YA:1974 FR:1975 NK:1976 US5:2010 VT27" "Sol" #1=
#2_"*Хейсканен:2379 Heiskanen:Heiskanen:1941 ST" "Sol" #2=
#3_"1941 ST:*Хейсканен:2379 Heiskanen:Heiskanen" "Sol" #3=
".:Heiskanen:2379 Heiskanen:1941 ST" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.632360649655
		SemiMajorAxis	3.165591240939
		Eccentricity	0.276251346854
		Inclination	0.469254499236
		AscendingNode	151.300115225713
		ArgOfPericenter	177.074822677136
		MeanAnomaly	320.327043721732
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0772
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2379"
}

#1_"2381 Landi:Landi:1976 AF:1951 EG1:1953 QP:1968 FF:1970 SD:1978 NN3" "Sol" #1=
#2_"*Ланди:2381 Landi:Landi:1976 AF" "Sol" #2=
#3_"1976 AF:*Ланди:2381 Landi:Landi" "Sol" #3=
".:Landi:2381 Landi:1976 AF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2381 landi.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.527
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.214418725448
		SemiMajorAxis	2.609073540261
		Eccentricity	0.1691884855
		Inclination	13.629329074279
		AscendingNode	150.22848719194
		ArgOfPericenter	277.985611872201
		MeanAnomaly	111.188641507436
	}
	UniformRotation
	{
		Period	3.989
	}
	LunarLambert	0.5
	Albedo	0.286
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2381"
}

#1_"2382 Nonie:Nonie:1977 GA:1979 YT" "Sol" #1=
#2_"*Нони:2382 Nonie:Nonie:1977 GA" "Sol" #2=
#3_"1977 GA:Nonie:*Нони:2382 Nonie" "Sol" #3=
".:Nonie:2382 Nonie:1977 GA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2382 nonie.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.634
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.58475918973
		SemiMajorAxis	2.759765735626
		Eccentricity	0.330097143758
		Inclination	30.981798090747
		AscendingNode	246.029713216821
		ArgOfPericenter	66.771877549874
		MeanAnomaly	201.830144744544
	}
	UniformRotation
	{
		Period	15.085
	}
	LunarLambert	0.5
	Albedo	0.113
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2382"
}

#1_"2384 Schulhof:Schulhof:1943 EC1:1943 GV:1960 FE:1962 WL1:1970 RP:1981 FF:A909 BF" "Sol" #1=
#2_"*Шульгоф:2384 Schulhof:Schulhof:1943 EC1" "Sol" #2=
#3_"1943 EC1:*Шульгоф:2384 Schulhof:Schulhof" "Sol" #3=
".:Schulhof:2384 Schulhof:1943 EC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2384 schulhof.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.742
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.218456451554
		SemiMajorAxis	2.610739731745
		Eccentricity	0.119293346397
		Inclination	13.531449587795
		AscendingNode	7.918244625071
		ArgOfPericenter	205.432458461546
		MeanAnomaly	23.106084584919
	}
	UniformRotation
	{
		Period	3.294
	}
	LunarLambert	0.5
	Albedo	0.28
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2384"
}

#1_"2386 Nikonov:Nikonov:1974 SN1:1941 SY:1951 WB1:1979 UB2:1982 FD2" "Sol" #1=
#2_"*Никонов:2386 Nikonov:Nikonov:1974 SN1" "Sol" #2=
#3_"1974 SN1:*Никонов:2386 Nikonov:Nikonov" "Sol" #3=
".:Nikonov:2386 Nikonov:1974 SN1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.325
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.724405883281
		SemiMajorAxis	2.815524643378
		Eccentricity	0.157392096284
		Inclination	9.082558936683
		AscendingNode	4.90537514077
		ArgOfPericenter	311.554367035227
		MeanAnomaly	216.063210448604
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1456
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2386"
}

#1_"2390 Nezarka:Nezarka:1980 PA1:1942 RS:A904 RC" "Sol" #1=
#2_"*Нежарка:2390 Nezarka:Nezarka:1980 PA1" "Sol" #2=
#3_"1980 PA1:*Нежарка:2390 Nezarka:Nezarka" "Sol" #3=
".:Nezarka:2390 Nezarka:1980 PA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.37
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.239898104357
		SemiMajorAxis	2.619578866919
		Eccentricity	0.145848391259
		Inclination	10.343778497522
		AscendingNode	325.901777793348
		ArgOfPericenter	354.761187167788
		MeanAnomaly	44.411243194125
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2390"
}

#1_"2393 Suzuki:Suzuki:1955 WB:1931 MH:1942 JL:1955 XR:1960 QA:1966 UG:1972 XH1:1976 GQ8:1976 JW: #1=
#1_1978 US2:A898 VC" "Sol" #1=
#2_"*Судзуки:2393 Suzuki:Suzuki:1955 WB" "Sol" #2=
#3_"1955 WB:*Судзуки:2393 Suzuki:Suzuki" "Sol" #3=
".:Suzuki:2393 Suzuki:1955 WB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2393 suzuki.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	24.203
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.82136018779
		SemiMajorAxis	3.236017384865
		Eccentricity	0.189492479395
		Inclination	10.214698364921
		AscendingNode	224.801909236109
		ArgOfPericenter	111.41559275
		MeanAnomaly	138.293935631519
	}
	UniformRotation
	{
		Period	9.31
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2393"
}

#1_"2394 Nadeev:Nadeev:1973 SZ2:1950 TH4:1969 AR:1975 BT:1978 PC1" "Sol" #1=
#2_"*Надеев:2394 Nadeev:Nadeev:1973 SZ2" "Sol" #2=
#3_"1973 SZ2:*Надеев:2394 Nadeev:Nadeev" "Sol" #3=
".:Nadeev:2394 Nadeev:1973 SZ2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.669557417831
		SemiMajorAxis	3.179513234962
		Eccentricity	0.211616771898
		Inclination	1.626385797623
		AscendingNode	127.518421712628
		ArgOfPericenter	301.57633707085
		MeanAnomaly	41.924763289179
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0209
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2394"
}

#1_"2395 Aho:Aho:1977 FA:1967 JB:1974 SS1:1977 DC2:1979 QO1:1982 BN1" "Sol" #1=
#2_"*Ахо:2395 Aho:Aho:1977 FA" "Sol" #2=
#3_"1977 FA:Aho:*Ахо:2395 Aho" "Sol" #3=
".:Aho:2395 Aho:1977 FA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2395 aho.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	10.182
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.410385725559
		SemiMajorAxis	3.081863156453
		Eccentricity	0.043814484412
		Inclination	0.302825643302
		AscendingNode	100.395232608831
		ArgOfPericenter	161.294508797892
		MeanAnomaly	36.748270053165
	}
	UniformRotation
	{
		Period	7.8803
	}
	LunarLambert	0.5
	Albedo	0.036
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2395"
}

#1_"2405 Welch:Welch:1963 UF:1965 AG1:1969 VV:1972 JQ1:1974 RR:1975 WG1:1977 DN9:1977 FV1:1979 OJ6: #1=
#1_1980 RC2:1980 TF:1981 YB2" "Sol" #1=
#2_"*Уэлш:2405 Welch:Welch:1963 UF" "Sol" #2=
#3_"1963 UF:*Уэлш:2405 Welch:Welch" "Sol" #3=
".:Welch:2405 Welch:1963 UF:" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.715
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.735495611144
		SemiMajorAxis	3.204117984796
		Eccentricity	0.133611144745
		Inclination	2.247775846194
		AscendingNode	128.257603224642
		ArgOfPericenter	2.466909550587
		MeanAnomaly	220.15206084733
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0399
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2405"
}

#1_"2408 Astapovich:Astapovich:1978 QK1:1943 GR:1948 RH:1977 DG5:1977 FW1" "Sol" #1=
#2_"*Астапович:2408 Astapovich:Astapovich:1978 QK1" "Sol" #2=
#3_"1978 QK1:*Астапович:2408 Astapovich:Astapovich" "Sol" #3=
".:Astapovich:2408 Astapovich:1978 QK1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.415
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.288589130113
		SemiMajorAxis	2.639596185867
		Eccentricity	0.241752909386
		Inclination	17.696548908431
		AscendingNode	164.410187631441
		ArgOfPericenter	103.065554570245
		MeanAnomaly	220.176098782493
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0407
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2408"
}

#1_"2413 van de Hulst:van de Hulst:6816 P-L:1931 EM:1952 DV1:1973 FY1:1978 ER4" "Sol" #1=
#2_"*ван де Холст:2413 van de Hulst:van de Hulst:1960-2413*:6816 P-L" "Sol" #2=
#3_"1960-2413*:*ван де Холст:2413 van de Hulst:van de Hulst:6816 P-L" "Sol" #3=
".:van de Hulst:2413 van de Hulst:1960-2413*:6816 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.242407619839
		SemiMajorAxis	3.017739327113
		Eccentricity	0.11446943679
		Inclination	10.64853960447
		AscendingNode	166.514276462372
		ArgOfPericenter	254.107713942707
		MeanAnomaly	74.732849670061
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1624
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2413"
}

#1_"2414 Vibeke:Vibeke:1931 UG:1971 QX:1971 SE:1977 RP4" "Sol" #1=
#2_"*Вибеке:2414 Vibeke:Vibeke:1931 UG" "Sol" #2=
#3_"1931 UG:*Вибеке:2414 Vibeke:Vibeke" "Sol" #3=
".:Vibeke:2414 Vibeke:1931 UG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.715114359804
		SemiMajorAxis	3.196522864144
		Eccentricity	0.129401826502
		Inclination	16.758248301302
		AscendingNode	357.054810415167
		ArgOfPericenter	47.49396339387
		MeanAnomaly	146.453238226706
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0369
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2414"
}

#1_"2421 Nininger:Nininger:1979 UD:1932 RP:1962 XJ1:1971 HH" "Sol" #1=
#2_"*Нинингер:2421 Nininger:Nininger:1979 UD" "Sol" #2=
#3_"1979 UD:*Нинингер:2421 Nininger:Nininger" "Sol" #3=
".:Nininger:2421 Nininger:1979 UD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.445
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.814947851722
		SemiMajorAxis	3.233640592994
		Eccentricity	0.045175642075
		Inclination	10.188714195641
		AscendingNode	77.679902610566
		ArgOfPericenter	275.489568862099
		MeanAnomaly	59.291809982279
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0559
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2421"
}

#New3
#1_"2423 Ibarruri:Ibarruri:1972 NC:1930 SV:1943 TB:1956 VC:1972 PB" "Sol" #1=
#2_"*Ибаррури:2423 Ibarruri:Ibarruri:1972 NC" "Sol" #2=
#3_"1972 NC:*Ибаррури:2423 Ibarruri:Ibarruri" "Sol" #3=
".:Ibarruri:2423 Ibarruri:1972 NC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.237599315475
		SemiMajorAxis	2.188483440802
		Eccentricity	0.282531227369
		Inclination	4.057120917951
		AscendingNode	264.957433846712
		ArgOfPericenter	80.645317302405
		MeanAnomaly	315.415130141642
	}
	UniformRotation
	{
		Period	139.79
	}
	LunarLambert	0.5
	Albedo	0.33
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2423"
}

#1_"2425 Shenzhen:Shenzhen:1975 FW:1950 LU:1955 HF:1961 PD:1962 WV:1965 GB:1969 AL" "Sol" #1=
#2_"*ШэньЧжэнь:2425 Shenzhen:Shenzhen:1975 FW" "Sol" #2=
#3_"1975 FW:Shenzhen:*ШэньЧжэнь:2425 Shenzhen" "Sol" #3=
".:Shenzhen:2425 Shenzhen:1975 FW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2425 shenzhen.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.341
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.206187759059
		SemiMajorAxis	3.003823539321
		Eccentricity	0.094143689473
		Inclination	10.863696536639
		AscendingNode	52.592547172974
		ArgOfPericenter	242.607948469677
		MeanAnomaly	257.065610727746
	}
	UniformRotation
	{
		Period	14.715
	}
	LunarLambert	0.5
	Albedo	0.184
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2425"
}

#1_"2426 Simonov:Simonov:1976 KV:1951 GK1:1953 XQ:1958 VA1:1962 QE:1968 UK3:1970 CA:1971 KK" "Sol" #1=
#2_"*Симонов:2426 Simonov:Simonov:1976 KV" "Sol" #2=
#3_"1976 KV:*Симонов:2426 Simonov:Simonov" "Sol" #3=
".:Simonov:2426 Simonov:1976 KV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.02
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.976837661579
		SemiMajorAxis	2.914943771174
		Eccentricity	0.113808727801
		Inclination	8.463356511483
		AscendingNode	237.222903796329
		ArgOfPericenter	3.858535486495
		MeanAnomaly	270.985069129045
	}
	UniformRotation
	{
		Period	5.811
	}
	LunarLambert	0.5
	Albedo	0.0842
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2426"
}

#1_"2428 Kamenyar:Kamenyar:1977 RZ6:1937 RM:1966 VM:1971 SN:1974 DM1" "Sol" #1=
#2_"*Каменяр:2428 Kamenyar:Kamenyar:1977 RZ6" "Sol" #2=
#3_"1977 RZ6:*Каменяр:2428 Kamenyar:Kamenyar" "Sol" #3=
".:Kamenyar:2428 Kamenyar:1977 RZ6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.27
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.628004132631
		SemiMajorAxis	3.163958683244
		Eccentricity	0.0957345999
		Inclination	9.313779700584
		AscendingNode	8.315497371303
		ArgOfPericenter	352.101689808078
		MeanAnomaly	224.235732530162
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0864
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2428"
}

#1_"2430 Bruce Helin:Bruce Helin:1977 VC:1976 JU1:A908 WC" "Sol" #1=
#2_"*Брюс Хелин:2430 Bruce Helin:Bruce Helin:1977 VC" "Sol" #2=
#3_"1977 VC:*Брюс Хелин:2430 Bruce Helin:Bruce Helin" "Sol" #3=
".:Bruce Helin:2430 Bruce Helin:1977 VC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2430 bruce helin.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.234
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.633418160076
		SemiMajorAxis	2.363404837665
		Eccentricity	0.213894956506
		Inclination	23.446276982803
		AscendingNode	45.881092813405
		ArgOfPericenter	309.805581493123
		MeanAnomaly	164.765741000976
	}
	UniformRotation
	{
		Period	128
	}
	LunarLambert	0.5
	Albedo	0.238
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2430"
}

#1_"2439 Ulugbek:Ulugbek:1977 QX2:1952 DT2:1955 UD:1972 TC4:1974 CM1:1979 BE:1980 GN" "Sol" #1=
#2_"*Улугбек:2439 Ulugbek:Ulugbek:1977 QX2" "Sol" #2=
#3_"1977 QX2:*Улугбек:2439 Ulugbek:Ulugbek" "Sol" #3=
".:Ulugbek:2439 Ulugbek:1977 QX2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.205
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.55084360551
		SemiMajorAxis	3.134973393709
		Eccentricity	0.157227149378
		Inclination	0.283012507955
		AscendingNode	114.392288417153
		ArgOfPericenter	334.471340063466
		MeanAnomaly	188.237657990072
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1065
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2439"
}

#1_"2441 Hibbs:Hibbs:1979 MN2:1957 UK:1972 TH2:1976 YA3:1977 AJ" "Sol" #1=
#2_"*Хиббс:2441 Hibbs:Hibbs:1979 MN2" "Sol" #2=
#3_"1979 MN2:*Хиббс:2441 Hibbs:Hibbs" "Sol" #3=
".:Hibbs:2441 Hibbs:1979 MN2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.965
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.743551219749
		SemiMajorAxis	2.410925098952
		Eccentricity	0.191916580701
		Inclination	3.741188820104
		AscendingNode	140.132756055787
		ArgOfPericenter	216.933292523736
		MeanAnomaly	124.059324021123
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0494
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2441"
}

#1_"2443 Tomeileen:Tomeileen:A906 BJ:1927 DD:1934 PS:1949 MV:1950 RD1:1950 TF3:1953 CH:1953 EO: #1=
#1_1957 WH:1959 JR:1961 TE1:1961 TW1:1965 OE:1974 DQ1:1974 FC1:1981 NN1" "Sol" #1=
#2_"*Томейлен:2443 Tomeileen:Tomeileen:1906 BJ" "Sol" #2=
#3_"1906 BJ:*Томейлен:2443 Tomeileen:Tomeileen" "Sol" #3=
".:Tomeileen:2443 Tomeileen:1906 BJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	15.445
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.209261311441
		SemiMajorAxis	3.0050056584
		Eccentricity	0.059584919808
		Inclination	11.455409861644
		AscendingNode	118.833062868843
		ArgOfPericenter	70.124698652762
		MeanAnomaly	269.487756695158
	}
	UniformRotation
	{
		Period	3.974
	}
	LunarLambert	0.5
	Albedo	0.1541
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2443"
}

#1_"2448 Sholokhov:Sholokhov:1975 BU" "Sol" #1=
#2_"*Шолохов:2448 Sholokhov:Sholokhov:1975 BU" "Sol" #2=
#3_"1975 BU:*Шолохов:2448 Sholokhov:Sholokhov" "Sol" #3=
".:Sholokhov:2448 Sholokhov:1975 BU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	15.12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.664546764663
		SemiMajorAxis	2.791691983566
		Eccentricity	0.116758115821
		Inclination	17.686935584655
		AscendingNode	131.156101163899
		ArgOfPericenter	73.025461887219
		MeanAnomaly	138.637347333566
	}
	UniformRotation
	{
		Period	10.061
	}
	LunarLambert	0.5
	Albedo	0.1337
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2448"
}

#1_"2450 Ioannisiani:Ioannisiani:1978 RP:1979 YT1" "Sol" #1=
#2_"*Иоаннисиани:2450 Ioannisiani:Ioannisiani:1978 RP" "Sol" #2=
#3_"1978 RP:*Иоаннисиани:2450 Ioannisiani:Ioannisiani" "Sol" #3=
".:Ioannisiani:2450 Ioannisiani:1978 RP:1979 YT1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.515810454767
		SemiMajorAxis	3.121768932651
		Eccentricity	0.10225118963
		Inclination	2.5277422883
		AscendingNode	117.029109558585
		ArgOfPericenter	96.875158689086
		MeanAnomaly	350.922552384224
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0621
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2450"
}

#1_"2453 Wabash:Wabash:A921 SA:1936 MG:1974 XD:1979 UC2" "Sol" #1=
#2_"*Вабасх:2453 Wabash:Wabash:1921 SA" "Sol" #2=
#3_"1921 SA:*Вабасх:2453 Wabash:Wabash" "Sol" #3=
".:Wabash:2453 Wabash:1921 SA:1936 MG:1974 XD:1979 UC2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.241372234383
		SemiMajorAxis	3.017341974536
		Eccentricity	0.114726975728
		Inclination	10.321681990448
		AscendingNode	11.841671871776
		ArgOfPericenter	340.966820166544
		MeanAnomaly	281.408129117
	}
	UniformRotation
	{
		Period	6.878
	}
	LunarLambert	0.5
	Albedo	0.086
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2453"
}

#1_"2455 Somville:Somville:1950 TO4:1934 CA1:1941 SM1:1950 TU:1952 BT1:1959 SM:1964 VQ:1968 QA1: #1=
#1_1972 NR:1973 YO:1979 BB2:1979 BO:1981 PH:1988 CN1" "Sol" #1=
#2_"*Сомвилль:2455 Somville:Somville:1950 TO4" "Sol" #2=
#3_"1950 TO4:*Сомвилль:2455 Somville:Somville" "Sol" #3=
".:Somville:2455 Somville:1950 TO4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2455 somville.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.509180288856
		SemiMajorAxis	2.729352307279
		Eccentricity	0.086611167779
		Inclination	7.54432597224
		AscendingNode	300.797023757306
		ArgOfPericenter	117.327687257021
		MeanAnomaly	86.34017899101
	}
	UniformRotation
	{
		Period	2.8287
	}
	LunarLambert	0.5
	Albedo	0.142
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2455"
}

#1_"2456 Palamedes:Palamedes:1966 BA1:1973 TJ:1977 AK1:1979 EF" "Sol" #1=
#2_"*Паламед:2456 Palamedes:Palamedes:1966 BA1" "Sol" #2=
#3_"1966 BA1:*Паламед:2456 Palamedes:Palamedes" "Sol" #3=
".:Palamedes:2456 Palamedes:1966 BA1:1973 TJ:1977 AK1:1979 EF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	45.83
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.616537066811
		SemiMajorAxis	5.129152993799
		Eccentricity	0.074121601081
		Inclination	13.90843675746
		AscendingNode	327.401093564142
		ArgOfPericenter	95.619450801585
		MeanAnomaly	123.506019041735
	}
	UniformRotation
	{
		Period	7.24
	}
	LunarLambert	0.5
	Albedo	0.0304
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2456"
}

#1_"2458 Veniakaverin:Veniakaverin:1977 RC7:1974 DG2:1975 ER5:1980 DT:1985 AD" "Sol" #1=
#2_"*Вениакаверин:2458 Veniakaverin:Veniakaverin:1977 RC7" "Sol" #2=
#3_"1977 RC7:*Вениакаверин:2458 Veniakaverin:Veniakaverin" "Sol" #3=
".:Veniakaverin:2458 Veniakaverin:1977 RC7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.533261335374
		SemiMajorAxis	3.128349885316
		Eccentricity	0.14122594152
		Inclination	2.085037890117
		AscendingNode	128.1813676318
		ArgOfPericenter	183.797927959153
		MeanAnomaly	296.896933227474
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0584
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2458"
}

#1_"2459 Spellmann:Spellmann:1980 LB1:1929 TV:1931 BM:1931 BO:1940 WN:1950 TT1:1971 UZ1:1974 HH2: #1=
#1_1979 DU" "Sol" #1=
#2_"*Спеллманн:2459 Spellmann:Spellmann:1980 LB1" "Sol" #2=
#3_"1980 LB1:*Спеллманн:2459 Spellmann:Spellmann" "Sol" #3=
".:Spellmann:2459 Spellmann:1980 LB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.83
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.250909389308
		SemiMajorAxis	3.021001084736
		Eccentricity	0.070561342016
		Inclination	9.678358208684
		AscendingNode	216.346436629356
		ArgOfPericenter	221.807342503431
		MeanAnomaly	23.927168055585
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2459"
}

#1_"2461 Clavel:Clavel:1981 EC1:1955 SN2:1955 UJ:1955 VG:1972 TH9:1976 JM1:1978 UM2" "Sol" #1=
#2_"*Клавэль:2461 Clavel:Clavel:1981 EC1" "Sol" #2=
#3_"1981 EC1:*Клавэль:2461 Clavel:Clavel" "Sol" #3=
".:Clavel:2461 Clavel:1981 EC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.065
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.692829681751
		SemiMajorAxis	3.188208086668
		Eccentricity	0.164160622648
		Inclination	2.510071878353
		AscendingNode	116.06666042311
		ArgOfPericenter	231.558077432977
		MeanAnomaly	161.244656679196
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0835
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2461"
}

#1_"2463 Sterpin:Sterpin:1934 FF:1930 FF:1930 FN:1949 UT:1978 PO4" "Sol" #1=
#2_"*Стерпин:2463 Sterpin:Sterpin:1934 FF" "Sol" #2=
#3_"1934 FF:*Стерпин:2463 Sterpin:Sterpin" "Sol" #3=
".:Sterpin:2463 Sterpin:1934 FF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.455
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.191964969283
		SemiMajorAxis	2.599798137716
		Eccentricity	0.155168604447
		Inclination	13.383596900837
		AscendingNode	178.962519098239
		ArgOfPericenter	264.691233681652
		MeanAnomaly	150.272746542309
	}
	UniformRotation
	{
		Period	13.44
	}
	LunarLambert	0.5
	Albedo	0.2831
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2463"
}

#1_"2464 Nordenskiold:Nordenskiold:1939 BF:1939 CP:1971 SY2:1973 GD:1976 SY9:A905 CD" "Sol" #1=
#2_"*Норденшёльд:2464 Nordenskiold:Nordenskiold:1939 BF" "Sol" #2=
#3_"1939 BF:*Норденшёльд:2464 Nordenskiold:Nordenskiold" "Sol" #3=
".:Nordenskiold:2464 Nordenskiold:1939 BF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.669263188444
		SemiMajorAxis	3.17940323057
		Eccentricity	0.204126396119
		Inclination	0.848136501252
		AscendingNode	8.621079519508
		ArgOfPericenter	77.934401588682
		MeanAnomaly	205.604759524605
	}
	UniformRotation
	{
		Period	5.209
	}
	LunarLambert	0.5
	Albedo	0.1496
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2464"
}

#1_"2465 Wilson:Wilson:1949 PK:1949 QS:1949 SK:1968 XD:1971 KH:1981 PT" "Sol" #1=
#2_"*Вильсон:2465 Wilson:Wilson:1949 PK" "Sol" #2=
#3_"1949 PK:*Вильсон:2465 Wilson:Wilson" "Sol" #3=
".:Wilson:2465 Wilson:1949 PK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.955
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.566292057706
		SemiMajorAxis	2.752349972305
		Eccentricity	0.075072218373
		Inclination	3.860537537935
		AscendingNode	294.145141403344
		ArgOfPericenter	4.422792775726
		MeanAnomaly	132.88441220652
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0706
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2465"
}

#1_"2466 Golson:Golson:1959 RJ:1929 SL:1951 YL1:1959 TC:1964 YD:1976 QT" "Sol" #1=
#2_"*Голсон:2466 Golson:Golson:1959 RJ" "Sol" #2=
#3_"1959 RJ:*Голсон:2466 Golson:Golson" "Sol" #3=
".:Golson:2466 Golson:1959 RJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.283658425023
		SemiMajorAxis	2.637572588643
		Eccentricity	0.165550908027
		Inclination	5.092181989743
		AscendingNode	159.817794543408
		ArgOfPericenter	194.936380381936
		MeanAnomaly	322.876492837637
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0611
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2466"
}

#1_"2474 Ruby:Ruby:1979 PB:1926 NA:1948 NC:1948 PS:1952 HL:1962 SK:1978 EE7" "Sol" #1=
#2_"*Руби:2474 Ruby:Ruby:1979 PB" "Sol" #2=
#3_"1979 PB:*Руби:2474 Ruby:Ruby" "Sol" #3=
".:Ruby:2474 Ruby:1979 PB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.895
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.395992977002
		SemiMajorAxis	2.683485121984
		Eccentricity	0.220857861061
		Inclination	7.52383014323
		AscendingNode	237.823790799604
		ArgOfPericenter	14.501084797621
		MeanAnomaly	57.099824198871
	}
	UniformRotation
	{
		Period	7.42
	}
	LunarLambert	0.5
	Albedo	0.1064
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2474"
}

#1_"2476 Andersen:Andersen:1976 JF2:1935 QH1:1939 HD:1973 YC3" "Sol" #1=
#2_"*Андерсен:2476 Andersen:Andersen:1976 JF2" "Sol" #2=
#3_"1976 JF2:*Андерсен:2476 Andersen:Andersen" "Sol" #3=
".:Andersen:2476 Andersen:1976 JF2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.66
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.257580770083
		SemiMajorAxis	3.023559369628
		Eccentricity	0.117425216299
		Inclination	10.81874983285
		AscendingNode	82.392853099077
		ArgOfPericenter	265.11145572475
		MeanAnomaly	11.589450078902
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1696
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2476"
}

#1_"2483 Guinevere:Guinevere:1928 QB:1929 VR:1955 FZ1:1961 VM:1961 XR:1971 BM:1971 FN:1977 XL: #1=
#1_A921 WF" "Sol" #1=
#2_"*Гуиневере:2483 Guinevere:Guinevere:1928 QB" "Sol" #2=
#3_"1928 QB:*Гуиневере:2483 Guinevere:Guinevere" "Sol" #3=
".:Guinevere:2483 Guinevere:1928 QB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2483 guinevere.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	17.844
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.917519902632
		SemiMajorAxis	3.97240915692
		Eccentricity	0.278325655984
		Inclination	4.500037439359
		AscendingNode	252.079611217302
		ArgOfPericenter	183.337949219965
		MeanAnomaly	240.313507789469
	}
	UniformRotation
	{
		Period	14.733
	}
	LunarLambert	0.5
	Albedo	0.067
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2483"
}

#1_"2490 Bussolini:Bussolini:1976 AG:1962 WN2:1977 KK:1978 NT3:1978 QH" "Sol" #1=
#2_"*Буссолини:2490 Bussolini:Bussolini:1976 AG" "Sol" #2=
#3_"1976 AG:*Буссолини:2490 Bussolini:Bussolini" "Sol" #3=
".:Bussolini:2490 Bussolini:1976 AG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.21247861301
		SemiMajorAxis	2.608272752171
		Eccentricity	0.133669250446
		Inclination	12.96448112316
		AscendingNode	212.618262823736
		ArgOfPericenter	210.600532124222
		MeanAnomaly	135.830209142306
	}
	UniformRotation
	{
		Period	24
	}
	LunarLambert	0.5
	Albedo	0.2268
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2490"
}

#1_"2492 Kutuzov:Kutuzov:1977 NT:1937 JK:1937 KE:1948 JF:1955 RT:1955 SC1:1959 GD:1970 FA:1977 TS" "Sol" #1=
#2_"*Кутузов:2492 Kutuzov:Kutuzov:1977 NT" "Sol" #2=
#3_"1977 NT:*Кутузов:2492 Kutuzov:Kutuzov" "Sol" #3=
".:Kutuzov:2492 Kutuzov:1977 NT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.695
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.719613104889
		SemiMajorAxis	3.198200107404
		Eccentricity	0.140068590838
		Inclination	0.827634566595
		AscendingNode	20.677934814378
		ArgOfPericenter	267.493412098313
		MeanAnomaly	227.298930706671
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0975
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2492"
}

#1_"2494 Inge:Inge:1981 LF:1935 HG:1935 JC:1935 KM:1936 NF:1952 KK1:1954 UO1:1955 YE:1961 CN: #1=
#1_1971 SR2:1977 XG" "Sol" #1=
#2_"*Инге:2494 Inge:Inge:1981 LF" "Sol" #2=
#3_"1981 LF:*Инге:2494 Inge:Inge" "Sol" #3=
".:Inge:2494 Inge:1981 LF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.615855237984
		SemiMajorAxis	3.15940378926
		Eccentricity	0.067730905167
		Inclination	11.540782788136
		AscendingNode	283.286392225076
		ArgOfPericenter	97.824681213655
		MeanAnomaly	263.900375785958
	}
	UniformRotation
	{
		Period	6.79
	}
	LunarLambert	0.5
	Albedo	0.0329
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2494"
}

#1_"2495 Noviomagum:Noviomagum:7071 P-L:1976 UG13" "Sol" #1=
#2_"*Неймеген:2495 Noviomagum:Noviomagum:1961-2495*:7071 P-L" "Sol" #2=
#3_"1961-2495*:Noviomagum:*Неймеген:2495 Noviomagum:7071 P-L" "Sol" #3=
".:Noviomagum:2495 Noviomagum:1961-2495*:7071 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2495 noviomagum.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.848
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.655329815667
		SemiMajorAxis	1.917521224972
		Eccentricity	0.102748425934
		Inclination	21.125610877271
		AscendingNode	199.74111468145
		ArgOfPericenter	136.446678305261
		MeanAnomaly	108.056717035615
	}
	UniformRotation
	{
		Period	6.645
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2495"
}

#1_"2502 Nummela:Nummela:1943 EO:1933 GC:1943 FF:1953 DG:1971 SY3" "Sol" #1=
#2_"*Нуммела:2502 Nummela:Nummela:1943 EO" "Sol" #2=
#3_"1943 EO:*Нуммела:2502 Nummela:Nummela" "Sol" #3=
".:Nummela:2502 Nummela:1943 EO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.27
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.040423902522
		SemiMajorAxis	2.939719591771
		Eccentricity	0.220263746421
		Inclination	17.7668081527
		AscendingNode	14.848164413924
		ArgOfPericenter	130.095883728478
		MeanAnomaly	103.676973991481
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1349
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2502"
}

#1_"2510 Shandong:Shandong:1979 TH:1942 VQ:1952 TA:1969 TK6:1981 AD4:1981 CD" "Sol" #1=
#2_"*Шаньдун:2510 Shandong:Shandong:1979 TH" "Sol" #2=
#3_"1979 TH:*Шаньдун:2510 Shandong:Shandong" "Sol" #3=
".:Shandong:2510 Shandong:1979 TH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2510 shandong.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.554
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.383201876817
		SemiMajorAxis	2.253615428412
		Eccentricity	0.196065368255
		Inclination	5.264793284751
		AscendingNode	102.924746145818
		ArgOfPericenter	209.733469771406
		MeanAnomaly	240.513625627271
	}
	UniformRotation
	{
		Period	5.9463
	}
	LunarLambert	0.5
	Albedo	0.194
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2510"
}

#New3
#1_"2511 Patterson:Patterson:1980 LM:1934 CK:1965 AD:1974 VE2:1979 BS" "Sol" #1=
#2_"*Паттерсон:2511 Patterson:Patterson:1980 LM" "Sol" #2=
#3_"1980 LM:*Паттерсон:2511 Patterson:Patterson" "Sol" #3=
".:Patterson:2511 Patterson:1980 LM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2511 patterson.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.924
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.484162831357
		SemiMajorAxis	2.298230024839
		Eccentricity	0.104113384268
		Inclination	8.046501967611
		AscendingNode	85.549496348706
		ArgOfPericenter	190.453519379151
		MeanAnomaly	227.771162196516
	}
	UniformRotation
	{
		Period	4.144
	}
	LunarLambert	0.5
	Albedo	0.287
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2511"
}

#1_"2512 Tavastia:Tavastia:1940 GG:1943 DN:1965 UC2:1965 VF:1965 WY:1970 ER:1972 XC1:1975 VP2: #1=
#1_1977 FW" "Sol" #1=
#2_"*Тавастия:2512 Tavastia:Tavastia:1940 GG" "Sol" #2=
#3_"1940 GG:*Тавастия:2512 Tavastia:Tavastia" "Sol" #3=
".:Tavastia:2512 Tavastia:1940 GG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.895
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.361309915245
		SemiMajorAxis	2.243883144242
		Eccentricity	0.120705120268
		Inclination	6.378862728904
		AscendingNode	69.551957934169
		ArgOfPericenter	14.751685128925
		MeanAnomaly	178.065856193856
	}
	UniformRotation
	{
		Period	7.296
	}
	LunarLambert	0.5
	Albedo	0.1057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2512"
}

#1_"2513 Baetsle:Baetsle:1950 SH:1936 PC:1943 RA:1943 RC:1950 TK:1950 TW2:1964 VO2:1971 UH3:1974 QV: #1=
#1_1981 QO" "Sol" #1=
#2_"*Баетсле:2513 Baetsle:Baetsle:1950 SH" "Sol" #2=
#3_"1950 SH:*Баетсле:2513 Baetsle:Baetsle" "Sol" #3=
".:Baetsle:2513 Baetsle:1950 SH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.335
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.456019218035
		SemiMajorAxis	2.285837207898
		Eccentricity	0.181382170428
		Inclination	3.161761199486
		AscendingNode	257.625226465488
		ArgOfPericenter	97.921469411336
		MeanAnomaly	212.954702466087
	}
	UniformRotation
	{
		Period	6.0792
	}
	LunarLambert	0.5
	Albedo	0.0278
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2513"
}

#New3
#1_"2520 Novorossijsk:Novorossijsk:1976 QF1:1971 UP3:1979 DC" "Sol" #1=
#2_"*Новороссийск:2520 Novorossijsk:Novorossijsk:1976 QF1" "Sol" #2=
#3_"1976 QF1:*Новороссийск:2520 Novorossijsk:Novorossijsk" "Sol" #3=
".:Novorossijsk:2520 Novorossijsk:1976 QF1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.973
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.470214395529
		SemiMajorAxis	3.104541220411
		Eccentricity	0.096157817511
		Inclination	6.237865826505
		AscendingNode	6.767815844066
		ArgOfPericenter	315.502350714384
		MeanAnomaly	199.462034999492
	}
	UniformRotation
	{
		Period	9.19
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2520"
}

#1_"2522 Triglav:Triglav:1980 PP:1929 XJ:1942 HF:1976 UU3" "Sol" #1=
#2_"*Триглав:2522 Triglav:Triglav:1980 PP" "Sol" #2=
#3_"1980 PP:*Триглав:2522 Triglav:Triglav" "Sol" #3=
".:Triglav:2522 Triglav:1980 PP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.245
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.246635706424
		SemiMajorAxis	3.01936167949
		Eccentricity	0.056909314852
		Inclination	8.761375967815
		AscendingNode	272.823002677785
		ArgOfPericenter	237.908894267097
		MeanAnomaly	0.040216277418
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0964
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2522"
}

#1_"2523 Ryba:Ryba:1980 PV:1952 DW1:1977 UL:1978 EO4" "Sol" #1=
#2_"*Рыба:2523 Ryba:Ryba:1980 PV" "Sol" #2=
#3_"1980 PV:*Рыба:2523 Ryba:Ryba" "Sol" #3=
".:Ryba:2523 Ryba:1980 PV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.246667173747
		SemiMajorAxis	3.019373752132
		Eccentricity	0.037801156006
		Inclination	8.890452599234
		AscendingNode	282.791222159546
		ArgOfPericenter	276.971027967974
		MeanAnomaly	312.635659967003
	}
	UniformRotation
	{
		Period	9.39
	}
	LunarLambert	0.5
	Albedo	0.1183
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2523"
}

#1_"2524 Budovicium:Budovicium:1981 QB1:1931 PB:1937 RU:1942 PE:1948 RO1:1952 FE:1954 UE2:1954 WH: #1=
#1_1956 AO:1970 SH1:1973 AE4:1973 EF:1976 UM3" "Sol" #1=
#2_"*Будовициум:2524 Budovicium:Budovicium:1981 QB1" "Sol" #2=
#3_"1981 QB1:*Будовициум:2524 Budovicium:Budovicium" "Sol" #3=
".:Budovicium:2524 Budovicium:1981 QB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.695
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.498017493091
		SemiMajorAxis	3.115051827153
		Eccentricity	0.159480990323
		Inclination	0.289528717281
		AscendingNode	278.774704275141
		ArgOfPericenter	20.20261296971
		MeanAnomaly	51.331193869132
	}
	UniformRotation
	{
		Period	10.0819
	}
	LunarLambert	0.5
	Albedo	0.0783
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2524"
}

#1_"2528 Mohler:Mohler:1953 TF1:1933 BQ:1936 SK:1942 VJ:1961 CP:1970 SL1:1970 WE1:1975 RQ" "Sol" #1=
#2_"*Молер:2528 Mohler:Mohler:1953 TF1" "Sol" #2=
#3_"1953 TF1:Mohler:*Молер:2528 Mohler" "Sol" #3=
".:Mohler:2528 Mohler:1953 TF1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2528 mohler.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	9.722
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.574886344931
		SemiMajorAxis	3.144019351
		Eccentricity	0.17553513902
		Inclination	0.509691725642
		AscendingNode	162.631137916163
		ArgOfPericenter	182.290592934659
		MeanAnomaly	154.043655591208
	}
	UniformRotation
	{
		Period	6.4913
	}
	LunarLambert	0.5
	Albedo	0.057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2528"
}

#1_"2531 Cambridge:Cambridge:1980 LD:1931 AP:1942 EQ:1952 BG:1963 FK:1963 HD:1971 VY:1974 KH: #1=
#1_A916 FE" "Sol" #1=
#2_"*Кембридж:2531 Cambridge:Cambridge:1980 LD" "Sol" #2=
#3_"1980 LD:*Кембридж:2531 Cambridge:Cambridge" "Sol" #3=
".:Cambridge:2531 Cambridge:1980 LD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.575
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.223458450686
		SemiMajorAxis	3.010463006531
		Eccentricity	0.05770478569
		Inclination	11.035239806864
		AscendingNode	104.387371046342
		ArgOfPericenter	33.020430253863
		MeanAnomaly	9.666718450392
	}
	UniformRotation
	{
		Period	8.8
	}
	LunarLambert	0.5
	Albedo	0.2104
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2531"
}

#1_"2534 Houzeau:Houzeau:1931 VD:1936 PP:1942 RK1:1950 AC:1952 MQ:1957 HM:1969 OL:1970 RL:1975 NF1: #1=
#1_1976 YK:1981 QL" "Sol" #1=
#2_"*Хаузеау:2534 Houzeau:Houzeau:1931 VD" "Sol" #2=
#3_"1931 VD:*Хаузеау:2534 Houzeau:Houzeau" "Sol" #3=
".:Houzeau:2534 Houzeau:1931 VD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.578021019825
		SemiMajorAxis	3.145197797165
		Eccentricity	0.173768710043
		Inclination	0.808488739686
		AscendingNode	167.928280496844
		ArgOfPericenter	200.615404669072
		MeanAnomaly	346.457879258728
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0794
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2534"
}

#1_"2542 Calpurnia:Calpurnia:1980 CF:1972 XN2:1976 OE" "Sol" #1=
#2_"*Кальпурния:2542 Calpurnia:Calpurnia:1980 CF" "Sol" #2=
#3_"1980 CF:*Кальпурния:2542 Calpurnia:Calpurnia" "Sol" #3=
".:Calpurnia:2542 Calpurnia:1980 CF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.540737595902
		SemiMajorAxis	3.131167162343
		Eccentricity	0.07361799225
		Inclination	4.620736929506
		AscendingNode	145.721109428172
		ArgOfPericenter	47.41046108114
		MeanAnomaly	71.598796956614
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0639
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2542"
}

#1_"2544 Gubarev:Gubarev:1980 PS:1950 BK1:1979 BP:A917 CA2" "Sol" #1=
#2_"*Губарев:2544 Gubarev:Gubarev:1980 PS" "Sol" #2=
#3_"1980 PS:*Губарев:2544 Gubarev:Gubarev" "Sol" #3=
".:Gubarev:2544 Gubarev:1980 PS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.675
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.655470430211
		SemiMajorAxis	2.372957984042
		Eccentricity	0.240778880024
		Inclination	22.5185907384
		AscendingNode	305.515448972541
		ArgOfPericenter	262.097609342147
		MeanAnomaly	220.751699689929
	}
	UniformRotation
	{
		Period	4.75
	}
	LunarLambert	0.5
	Albedo	0.243
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2544"
}

#1_"2546 Libitina:Libitina:1950 FC:1937 AG:3516 P-L" "Sol" #1=
#2_"*Либитина:2546 Libitina:Libitina:1950 FC" "Sol" #2=
#3_"1950 FC:*Либитина:2546 Libitina:Libitina" "Sol" #3=
".:Libitina:2546 Libitina:1950 FC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.194289824714
		SemiMajorAxis	2.600759277471
		Eccentricity	0.191687171266
		Inclination	10.327174679952
		AscendingNode	315.19020064
		ArgOfPericenter	234.92303822002
		MeanAnomaly	151.540759751701
	}
	UniformRotation
	{
		Period	132.71
	}
	LunarLambert	0.5
	Albedo	0.1188
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2546"
}

#1_"2559 Svoboda:Svoboda:1981 UH:1930 XJ:1948 RF:1976 SC7" "Sol" #1=
#2_"*Свобода:2559 Svoboda:Svoboda:1981 UH" "Sol" #2=
#3_"1981 UH:*Свобода:2559 Svoboda:Svoboda" "Sol" #3=
".:Svoboda:2559 Svoboda:1981 UH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.765
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.654690038384
		SemiMajorAxis	2.787757818709
		Eccentricity	0.153026482744
		Inclination	8.887098327495
		AscendingNode	350.251160231904
		ArgOfPericenter	88.410427870369
		MeanAnomaly	4.873198416526
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0297
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2559"
}

#1_"2562 Chaliapin:Chaliapin:1973 FF1:1952 DZ2:1954 SM:1978 DB:1980 RP1" "Sol" #1=
#2_"*Шаляпин:2562 Chaliapin:Chaliapin:1973 FF1" "Sol" #2=
#3_"1973 FF1:*Шаляпин:2562 Chaliapin:Chaliapin" "Sol" #3=
".:Chaliapin:2562 Chaliapin:1973 FF1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.21987839534
		SemiMajorAxis	3.009087308063
		Eccentricity	0.041669379707
		Inclination	10.263866589309
		AscendingNode	339.86524643016
		ArgOfPericenter	237.736371174392
		MeanAnomaly	329.536097259489
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1232
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2562"
}

#1_"2563 Boyarchuk:Boyarchuk:1977 FZ:1959 CN:1963 YB:1980 WC" "Sol" #1=
#2_"*Боярчук:2563 Boyarchuk:Boyarchuk:1977 FZ" "Sol" #2=
#3_"1977 FZ:*Боярчук:2563 Boyarchuk:Boyarchuk" "Sol" #3=
".:Boyarchuk:2563 Boyarchuk:1977 FZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.745
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.706852006326
		SemiMajorAxis	3.193441307891
		Eccentricity	0.14238087364
		Inclination	2.041646759358
		AscendingNode	114.627166045845
		ArgOfPericenter	40.845287307684
		MeanAnomaly	247.023720385459
	}
	UniformRotation
	{
		Period	11.04
	}
	LunarLambert	0.5
	Albedo	0.0614
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2563"
}

#1_"2569 Madeline:Madeline:1980 MA:1951 WF2:1953 EM:1963 NB" "Sol" #1=
#2_"*Маделейн:2569 Madeline:Madeline:1980 MA" "Sol" #2=
#3_"1980 MA:*Маделейн:2569 Madeline:Madeline" "Sol" #3=
".:Madeline:2569 Madeline:1980 MA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.045
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.257634451157
		SemiMajorAxis	2.626879266605
		Eccentricity	0.162234407202
		Inclination	11.478010122457
		AscendingNode	76.377082441277
		ArgOfPericenter	313.205163514392
		MeanAnomaly	317.259429235452
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0741
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2569"
}

#1_"2570 Porphyro:Porphyro:1980 PG:1941 DC:1941 DO:1941 FE:1978 GP:1980 SA" "Sol" #1=
#2_"*Порфиро:2570 Porphyro:Porphyro:1980 PG" "Sol" #2=
#3_"1980 PG:*Порфиро:2570 Porphyro:Porphyro" "Sol" #3=
".:Porphyro:2570 Porphyro:1980 PG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.995
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.600563614066
		SemiMajorAxis	2.76610434381
		Eccentricity	0.107601442572
		Inclination	16.24412764897
		AscendingNode	324.366114595345
		ArgOfPericenter	97.304152423583
		MeanAnomaly	89.890870907943
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0297
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2570"
}

#1_"2577 Litva:Litva:1975 EE3:1934 VY:1954 JD:1976 SA2" "Sol" #1=
#2_"*Литва:2577 Litva:Litva:1975 EE3" "Sol" #2=
#3_"1975 EE3:*Литва:2577 Litva:Litva" "Sol" #3=
".:Litva:2577 Litva:1975 EE3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.627786017403
		SemiMajorAxis	1.904237865355
		Eccentricity	0.137859443067
		Inclination	22.909225733024
		AscendingNode	182.607652241289
		ArgOfPericenter	283.948461181
		MeanAnomaly	101.624948684902
	}
	UniformRotation
	{
		Period	2.813
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2577"
}

#1_"2009 2577 I" "Sol/2577 Litva" #1=
#2_"2009 2577 I" "Sol/2577 Litva" #2=
#3_"2009 2577 I" "Sol/2577 Litva" #3=
".:2009 2577 I" "Sol/2577 Litva" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	1.495
		SemiMajorAxis	21
	}
	UniformRotation
	{
		Period	5.6842
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-02577.html"
}

#1_"2012 2577 I" "Sol/2577 Litva" #1=
#2_"2012 2577 I" "Sol/2577 Litva" #2=
#3_"2012 2577 I" "Sol/2577 Litva" #3=
".:2012 2577 I" "Sol/2577 Litva" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	214
		SemiMajorAxis	378
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-02577.html"
}

#1_"2581 Radegast:Radegast:1980 VX:1928 DV:1960 YA:1973 SU5:1975 EH5:1978 CB:1979 MQ" "Sol" #1=
#2_"*Радегаст:2581 Radegast:Radegast:1980 VX" "Sol" #2=
#3_"1980 VX:Radegast:*Радегаст:2581 Radegast" "Sol" #3=
".:Radegast:2581 Radegast:1980 VX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2581 radegast.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.37
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.344121732017
		SemiMajorAxis	2.236227156829
		Eccentricity	0.098007812708
		Inclination	2.492440941324
		AscendingNode	260.607907454409
		ArgOfPericenter	192.637369945615
		MeanAnomaly	270.854557243313
	}
	UniformRotation
	{
		Period	8.7505
	}
	LunarLambert	0.5
	Albedo	0.245
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2581"
}

#1_"2582 Harimaya-Bashi:Harimaya-Bashi:1981 SA:1927 JC:1935 WA:1938 HB:1958 VH:1975 XT" "Sol" #1=
#2_"*Харимая-Баси:2582 Harimaya-Bashi:Harimaya-Bashi:1981 SA" "Sol" #2=
#3_"1981 SA:*Харимая-Баси:2582 Harimaya-Bashi:Harimaya-Bashi" "Sol" #3=
".:Harimaya-Bashi:2582 Harimaya-Bashi:1981 SA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.729804787824
		SemiMajorAxis	3.20199819286
		Eccentricity	0.065058248926
		Inclination	18.145789405301
		AscendingNode	56.322260218336
		ArgOfPericenter	237.397076558682
		MeanAnomaly	33.220796446021
	}
	UniformRotation
	{
		Period	7.238
	}
	LunarLambert	0.5
	Albedo	0.1337
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2582"
}

#1_"2595 Gudiachvili:Gudiachvili:1979 KL:1952 SE:1959 ET" "Sol" #1=
#2_"*Гудиашвили:2595 Gudiachvili:Gudiachvili:1979 KL" "Sol" #2=
#3_"1979 KL:*Гудиашвили:2595 Gudiachvili:Gudiachvili" "Sol" #3=
".:Gudiachvili:2595 Gudiachvili:1979 KL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.649073661144
		SemiMajorAxis	2.785514883836
		Eccentricity	0.146250293134
		Inclination	9.873735770203
		AscendingNode	148.419994762828
		ArgOfPericenter	278.298973410268
		MeanAnomaly	75.174440991529
	}
	UniformRotation
	{
		Period	4.72
	}
	LunarLambert	0.5
	Albedo	0.0223
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2595"
}

#1_"2601 Bologna:Bologna:1980 XA:1965 AC1:1971 DD1" "Sol" #1=
#2_"*Болонья:2601 Bologna:Bologna:1980 XA" "Sol" #2=
#3_"1980 XA:*Болонья:2601 Bologna:Bologna" "Sol" #3=
".:Bologna:2601 Bologna:1980 XA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.537683671906
		SemiMajorAxis	3.130016506255
		Eccentricity	0.06544265683
		Inclination	9.597260604917
		AscendingNode	288.27104073212
		ArgOfPericenter	195.61716035672
		MeanAnomaly	357.596373865849
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1626
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2601"
}

#1_"2604 Marshak:Marshak:1972 LD1:1950 NW:1979 FD" "Sol" #1=
#2_"*Маршак:2604 Marshak:Marshak:1972 LD1" "Sol" #2=
#3_"1972 LD1:*Маршак:2604 Marshak:Marshak" "Sol" #3=
".:Marshak:2604 Marshak:1972 LD1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.686944422228
		SemiMajorAxis	2.386559460469
		Eccentricity	0.233950417882
		Inclination	14.848486464337
		AscendingNode	122.981987663614
		ArgOfPericenter	134.615995366866
		MeanAnomaly	190.779635676668
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0552
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2604"
}

#1_"2606 Odessa:Odessa:1976 GX2:1955 VE" "Sol" #1=
#2_"*Одесса:2606 Odessa:Odessa:1976 GX2" "Sol" #2=
#3_"1976 GX2:*Одесса:2606 Odessa:Odessa" "Sol" #3=
".:Odessa:2606 Odessa:1976 GX2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2606 odessa.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.955
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4.584469792074
		SemiMajorAxis	2.75964960039
		Eccentricity	0.264778773963
		Inclination	12.452954818013
		AscendingNode	197.3134874
		ArgOfPericenter	353.235379918812
		MeanAnomaly	7.779515797798
	}
	UniformRotation
	{
		Period	8.2426
	}
	LunarLambert	0.5
	Albedo	0.175
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2606"
}

#1_"2608 Seneca:Seneca:1978 DA" "Sol" #1=
#2_"*Сенека:2608 Seneca:Seneca:1978 DA" "Sol" #2=
#3_"1978 DA:*Сенека:2608 Seneca:Seneca" "Sol" #3=
".:Seneca:2608 Seneca:1978 DA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.992165273732
		SemiMajorAxis	2.516518960333
		Eccentricity	0.571041960049
		Inclination	14.679836542546
		AscendingNode	167.368794279355
		ArgOfPericenter	37.317446357336
		MeanAnomaly	106.189808629868
	}
	UniformRotation
	{
		Period	8
	}
	LunarLambert	0.5
	Albedo	0.21
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2608"
}

#1_"2613 Plzen:Plzen:1979 QE:1969 XA" "Sol" #1=
#2_"*Пльзень:2613 Plzen:Plzen:1979 QE" "Sol" #2=
#3_"1979 QE:*Пльзень:2613 Plzen:Plzen" "Sol" #3=
".:Plzen:2613 Plzen:1979 QE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.09
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.299204042447
		SemiMajorAxis	3.039496352379
		Eccentricity	0.046079258064
		Inclination	13.019747095565
		AscendingNode	277.605740575543
		ArgOfPericenter	191.850229497506
		MeanAnomaly	124.936897616778
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0737
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2613"
}

#1_"2615 Saito:Saito:1951 RJ:1955 FC2:1967 JS:1979 OD13:1979 QB8" "Sol" #1=
#2_"*Сайто:2615 Saito:Saito:1951 RJ" "Sol" #2=
#3_"1951 RJ:*Сайто:2615 Saito:Saito" "Sol" #3=
".:Saito:2615 Saito:1951 RJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.22
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.650854116445
		SemiMajorAxis	3.172516787785
		Eccentricity	0.15653913634
		Inclination	4.265908754608
		AscendingNode	322.926209779012
		ArgOfPericenter	343.215146294017
		MeanAnomaly	112.029489100427
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2615"
}

#1_"2617 Jiangxi:Jiangxi:1975 WO1:1935 QW:1972 JU" "Sol" #1=
#2_"*Янцзы:2617 Jiangxi:Jiangxi:1975 WO1:1935 QW:1972 JU" "Sol" #2=
#3_"1975 WO1:*Янцзы:2617 Jiangxi:Jiangxi:1935 QW:1972 JU" "Sol" #3=
".:Jiangxi:2617 Jiangxi:1975 WO1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2617 jiangxi.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	24.542
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.620680727585
		SemiMajorAxis	3.161213366725
		Eccentricity	0.230692858399
		Inclination	12.904629988295
		AscendingNode	73.577432230121
		ArgOfPericenter	349.124211171703
		MeanAnomaly	343.015319465823
	}
	UniformRotation
	{
		Period	11.7743
	}
	LunarLambert	0.5
	Albedo	0.051
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2617"
}

#1_"2621 Goto:Goto:1981 CA:1971 HQ:1982 DO2" "Sol" #1=
#2_"*Гото:2621 Goto:Goto:1981 CA" "Sol" #2=
#3_"1981 CA:2621 Goto:Goto" "Sol" #3=
".:Goto:2621 Goto:1981 CA" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.405467715092
		SemiMajorAxis	3.079995275779
		Eccentricity	0.175715601584
		Inclination	13.045169259703
		AscendingNode	95.756566413781
		ArgOfPericenter	272.858352034824
		MeanAnomaly	230.524238269354
	}
	UniformRotation
	{
		Period	22.006
	}
	LunarLambert	0.5
	Albedo	0.0428
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2621"
}

#1_"2630 Hermod:Hermod:1980 TF3:1953 RA1:1964 TK:1969 RO:1975 WP:1977 DY:1978 GB4:1982 BN:A915 RJ" "Sol" #1=
#2_"*Хермод:2630 Hermod:Hermod:1980 TF3" "Sol" #2=
#3_"1980 TF3:Hermod:*Хермод:2630 Hermod" "Sol" #3=
".:Hermod:2630 Hermod:1980 TF3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2630 hermod.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	12.24
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.386332455671
		SemiMajorAxis	3.072722228202
		Eccentricity	0.125396919394
		Inclination	1.915029419705
		AscendingNode	2.848490095755
		ArgOfPericenter	24.243622375688
		MeanAnomaly	254.43295073724
	}
	UniformRotation
	{
		Period	19.4283
	}
	LunarLambert	0.5
	Albedo	0.056
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2630"
}

#1_"2632 Guizhou:Guizhou:1980 VJ1:1948 TC2:1948 TN1:1957 JA1:1964 VE2:1969 TW:1974 RA:1975 VN6: #1=
#1_1975 XQ3:1978 GF4" "Sol" #1=
#2_"*ГуйЧжоу:2632 Guizhou:Guizhou:1980 VJ1" "Sol" #2=
#3_"1980 VJ1:*ГуйЧжоу:2632 Guizhou:Guizhou" "Sol" #3=
".:Guizhou:2632 Guizhou:1980 VJ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.535
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.294880835966
		SemiMajorAxis	3.037843002483
		Eccentricity	0.108004172438
		Inclination	10.452107319926
		AscendingNode	18.294097077903
		ArgOfPericenter	312.320607074891
		MeanAnomaly	220.712007471959
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0576
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2632"
}

#1_"2634 James Bradley:James Bradley:1982 DL:1931 FL:1961 XH:1963 FC:1975 AO:1976 GB1:1977 KP:A905 CC" "Sol" #1=
#2_"*Джеймс Брэдли:2634 James Bradley:James Bradley:1982 DL" "Sol" #2=
#3_"1982 DL:*Джеймс Брэдли:2634 James Bradley:James Bradley" "Sol" #3=
".:James Bradley:2634 James Bradley:1982 DL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.955
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.428591755222
		SemiMajorAxis	3.457310855464
		Eccentricity	0.049945581846
		Inclination	6.422162494188
		AscendingNode	133.372103228937
		ArgOfPericenter	334.906922915083
		MeanAnomaly	67.060055682263
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0923
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2634"
}

#1_"2645 Daphne Plane:Daphne Plane:1976 QD:1965 SG" "Sol" #1=
#2_"*Дафни Плэйн:2645 Daphne Plane:Daphne Plane:1976 QD" "Sol" #2=
#3_"1976 QD:*Дафни Плэйн:2645 Daphne Plane:Daphne Plane" "Sol" #3=
".:Daphne Plane:2645 Daphne Plane:1976 QD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.79
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.700103165067
		SemiMajorAxis	2.392234525042
		Eccentricity	0.106188116531
		Inclination	13.785448847913
		AscendingNode	349.846500507862
		ArgOfPericenter	79.809453843196
		MeanAnomaly	57.198935920764
	}
	UniformRotation
	{
		Period	8.36
	}
	LunarLambert	0.5
	Albedo	0.0875
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2645"
}

#1_"2646 Abetti:2646 Abetti:Abetti:1977 EC1:1943 VE:1948 UA:1953 TZ1:1971 BZ:1979 QP7:1979 SJ3:1982 FB" "Sol" #1=
#2_"*Абетти:2646 Abetti:2646 Abetti:Abetti:1977 EC1" "Sol" #2=
#3_"1977 EC1:*Абетти:2646 Abetti:2646 Abetti:Abetti" "Sol" #3=
".:Abetti:2646 Abetti:1977 EC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.19
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.227228183064
		SemiMajorAxis	3.011911252028
		Eccentricity	0.098384775968
		Inclination	9.665399231279
		AscendingNode	352.409773616174
		ArgOfPericenter	38.195365973121
		MeanAnomaly	225.397195531192
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0808
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2646"
}

#1_"2654 Ristenpart:Ristenpart:1968 OG:1978 JA1" "Sol" #1=
#2_"*Ристенпарт:2654 Ristenpart:Ristenpart:1968 OG" "Sol" #2=
#3_"1968 OG:*Ристенпарт:2654 Ristenpart:Ristenpart" "Sol" #3=
".:Ristenpart:2654 Ristenpart:1968 OG:1978 JA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.26
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.325209687911
		SemiMajorAxis	3.049432379694
		Eccentricity	0.091766294661
		Inclination	7.433260134605
		AscendingNode	206.448728059535
		ArgOfPericenter	38.920079603894
		MeanAnomaly	313.25337650902
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0419
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2654"
}

#1_"2659 Millis:Millis:1981 JX:1958 DX:1972 TP2:1978 UK2:1978 WX14" "Sol" #1=
#2_"*Миллис:2659 Millis:Millis:1981 JX" "Sol" #2=
#3_"1981 JX:*Миллис:2659 Millis:Millis" "Sol" #3=
".:Millis:2659 Millis:1981 JX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2659 millis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	13.873
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.534215591046
		SemiMajorAxis	3.128709547806
		Eccentricity	0.104457355044
		Inclination	1.320885045547
		AscendingNode	157.230381162828
		ArgOfPericenter	329.315263556619
		MeanAnomaly	130.169187285082
	}
	UniformRotation
	{
		Period	6.132
	}
	LunarLambert	0.5
	Albedo	0.039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2659"
}

#1_"2660 Wasserman:Wasserman:1982 FG:1974 KG:1975 VZ2:1979 SC2:A924 SA" "Sol" #1=
#2_"*Вассерман:2660 Wasserman:Wasserman:1982 FG" "Sol" #2=
#3_"1982 FG:*Вассерман:2660 Wasserman:Wasserman" "Sol" #3=
".:Wasserman:2660 Wasserman:1982 FG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.175
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.239109519337
		SemiMajorAxis	2.619254043909
		Eccentricity	0.169279570409
		Inclination	12.32086366882
		AscendingNode	203.987071637078
		ArgOfPericenter	86.266819068307
		MeanAnomaly	168.12603427834
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.2384
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2660"
}

#1_"2664 Everhart:Everhart:1934 RR:1967 RT:1978 PQ3" "Sol" #1=
#2_"*Эверхарт:2664 Everhart:Everhart:1934 RR" "Sol" #2=
#3_"1934 RR:*Эверхарт:2664 Everhart:Everhart" "Sol" #3=
".:Everhart:2664 Everhart:1934 RR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.67297215445
		SemiMajorAxis	2.38052614561
		Eccentricity	0.182511186256
		Inclination	3.259563283405
		AscendingNode	167.737460752763
		ArgOfPericenter	206.504403820002
		MeanAnomaly	292.302750727372
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0452
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2664"
}

#1_"2667 Oikawa:Oikawa:1967 UO:1955 UR1:1972 RJ3:1978 ST5:1978 VU16" "Sol" #1=
#2_"*Оикава:2667 Oikawa:Oikawa:1967 UO" "Sol" #2=
#3_"1967 UO:*Оикава:2667 Oikawa:Oikawa" "Sol" #3=
".:Oikawa:2667 Oikawa:1967 UO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.8155185203
		SemiMajorAxis	3.233852152002
		Eccentricity	0.182974321256
		Inclination	2.234962191615
		AscendingNode	60.5823792625
		ArgOfPericenter	304.111217419202
		MeanAnomaly	89.273566717959
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0429
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2667"
}

#1_"2672 Pisek:Pisek:1979 KC:1937 NP:1953 EJ1:1953 ET1:1978 EF1" "Sol" #1=
#2_"*Писек:2672 Pisek:Pisek:1979 KC" "Sol" #2=
#3_"1979 KC:2672 Pisek:Pisek" "Sol" #3=
".:Pisek:2672 Pisek:1979 KC" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.09
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.221578835449
		SemiMajorAxis	2.612027837399
		Eccentricity	0.149931485734
		Inclination	14.151957349723
		AscendingNode	129.065410019199
		ArgOfPericenter	152.340015394293
		MeanAnomaly	124.726255605338
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0907
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2672"
}

#1_"2674 Pandarus:Pandarus:1982 BC3:1972 GE:1976 SM6:1977 RB6" "Sol" #1=
#2_"*Пандар:2674 Pandarus:Pandarus:1982 BC3" "Sol" #2=
#3_"1982 BC3:*Пандар:2674 Pandarus:Pandarus" "Sol" #3=
".:Pandarus:2674 Pandarus:1982 BC3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	49.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.797172466709
		SemiMajorAxis	5.18218783941
		Eccentricity	0.067219201151
		Inclination	1.854909971522
		AscendingNode	179.802874315117
		ArgOfPericenter	39.344100808558
		MeanAnomaly	211.206080083732
	}
	UniformRotation
	{
		Period	8.48
	}
	LunarLambert	0.5
	Albedo	0.0461
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2674"
}

#1_"2677 Joan:Joan:1935 FF:1930 FO:1951 JL:1974 VV1:1977 JO:1982 HC" "Sol" #1=
#2_"*Джоан:2677 Joan:Joan:1935 FF" "Sol" #2=
#3_"1935 FF:*Джоан:2677 Joan:Joan" "Sol" #3=
".:Joan:2677 Joan:1935 FF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.295
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.177845867011
		SemiMajorAxis	2.992911975716
		Eccentricity	0.050345254724
		Inclination	10.102964342849
		AscendingNode	194.755610741102
		ArgOfPericenter	20.803116851633
		MeanAnomaly	99.511164362549
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0955
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2677"
}

#1_"2685 Masursky:Masursky:1981 JN:1950 VO:1973 QF:1975 XJ5:1977 KU" "Sol" #1=
#2_"*Мазурский:2685 Masursky:Masursky:1981 JN" "Sol" #2=
#3_"1981 JN:*Мазурский:2685 Masursky:Masursky" "Sol" #3=
".:Masursky:2685 Masursky:1981 JN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2451566.5  # 2000 Jan 23
		Period	4.1207208620348
		SemiMajorAxis	2.570257663638510
		Eccentricity	0.1113734785392097
		Inclination	12.13354852982020
		AscendingNode	215.4673461045547
		ArgOfPericenter	288.2458889872455
		MeanAnomaly	266.9228460828900
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.085
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2685"
}

#1_"2687 Tortali:Tortali:1982 HG:1927 TH:1931 TK3:1934 GU:1942 GK:1959 TQ:1963 SV:1970 GB:1977 AN1" "Sol" #1=
#2_"*Тортали:2687 Tortali:Tortali:1982 HG" "Sol" #2=
#3_"1982 HG:*Тортали:2687 Tortali:Tortali" "Sol" #3=
".:Tortali:2687 Tortali:1982 HG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.975
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.996880232181
		SemiMajorAxis	2.518499998551
		Eccentricity	0.125060738597
		Inclination	10.083981236637
		AscendingNode	49.746602888804
		ArgOfPericenter	255.618000689411
		MeanAnomaly	332.321021465975
	}
	UniformRotation
	{
		Period	21.75
	}
	LunarLambert	0.5
	Albedo	0.217
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2687"
}

#1_"2690 Ristiina:Ristiina:1938 DG1:1935 QT:1975 EM:1977 PW:1980 DK2:1980 EW" "Sol" #1=
#2_"*Ристиина:2690 Ristiina:Ristiina:1938 DG1" "Sol" #2=
#3_"1938 DG1:*Ристиина:2690 Ristiina:Ristiina" "Sol" #3=
".:Ristiina:2690 Ristiina:1938 DG1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.06
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.291882935953
		SemiMajorAxis	3.036696233308
		Eccentricity	0.113225789385
		Inclination	11.43932037066
		AscendingNode	136.270736777081
		ArgOfPericenter	260.211559404754
		MeanAnomaly	310.049912993872
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1585
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2690"
}

#1_"2695 Christabel:Christabel:1979 UE:1961 TG1:1961 TY1" "Sol" #1=
#2_"*Христабель:2695 Christabel:Christabel:1979 UE" "Sol" #2=
#3_"1979 UE:*Христабель:2695 Christabel:Christabel" "Sol" #3=
".:Christabel:2695 Christabel:1979 UE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.305
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.46042453049
		SemiMajorAxis	2.709642500443
		Eccentricity	0.077567541433
		Inclination	14.879186695764
		AscendingNode	63.059798599356
		ArgOfPericenter	288.350874864304
		MeanAnomaly	357.68137097647
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0995
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2695"
}

#1_"2696 Magion:Magion:1980 HB:1951 SK:1953 GC:1978 TN7" "Sol" #1=
#2_"*Мажион:2696 Magion:Magion:1980 HB" "Sol" #2=
#3_"1980 HB:*Мажион:2696 Magion:Magion" "Sol" #3=
".:Magion:2696 Magion:1980 HB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.09
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.83415704687
		SemiMajorAxis	2.449671202934
		Eccentricity	0.114429165207
		Inclination	25.350783511347
		AscendingNode	186.243748686294
		ArgOfPericenter	283.213653282836
		MeanAnomaly	87.266148212141
	}
	UniformRotation
	{
		Period	480
	}
	LunarLambert	0.5
	Albedo	0.0687
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2696"
}

#1_"2697 Albina:Albina:1969 TC3:1929 TB:1936 TL:1938 BE:1939 DE:1942 RV:1949 SC1:1950 YA:1952 DU1: #1=
#1_1968 OT:1972 BJ:1975 QR:1975 RG:1979 FK2:1983 VR1" "Sol" #1=
#2_"*Альбина:2697 Albina:Albina:1969 TC3" "Sol" #2=
#3_"1969 TC3:*Альбина:2697 Albina:Albina" "Sol" #3=
".:Albina:2697 Albina:1969 TC3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.77
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.719433917046
		SemiMajorAxis	3.560817015829
		Eccentricity	0.079670889903
		Inclination	3.581887274387
		AscendingNode	270.991891564349
		ArgOfPericenter	132.486529644002
		MeanAnomaly	227.319879671697
	}
	UniformRotation
	{
		Period	9.6
	}
	LunarLambert	0.5
	Albedo	0.0553
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2697"
}

#1_"2705 Wu:Wu:1980 TD4:1967 TC:1976 GF8:1976 JE1" "Sol" #1=
#2_"*У:2705 Wu:Wu:1980 TD4" "Sol" #2=
#3_"1980 TD4:*У:2705 Wu:Wu" "Sol" #3=
".:Wu:2705 Wu:1980 TD4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.814
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.240213920961
		SemiMajorAxis	2.189661525831
		Eccentricity	0.160252203131
		Inclination	4.52552291387
		AscendingNode	8.327315495602
		ArgOfPericenter	334.774883611162
		MeanAnomaly	216.382151076714
	}
	UniformRotation
	{
		Period	150.5
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2705"
}

#1_"2707 Ueferji:Ueferji:1981 QS3:1927 CE:1950 EK:1953 TY1:1971 YF:1972 BS:1973 GX:1976 UD3:1977 UH: #1=
#1_1979 GT:1979 HQ3" "Sol" #1=
#2_"*Уефержи:2707 Ueferji:Ueferji:1981 QS3" "Sol" #2=
#3_"1981 QS3:*Уефержи:2707 Ueferji:Ueferji" "Sol" #3=
".:Ueferji:2707 Ueferji:1981 QS3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.701286932613
		SemiMajorAxis	3.191364900339
		Eccentricity	0.125724069839
		Inclination	2.672831986687
		AscendingNode	79.612614971624
		ArgOfPericenter	342.599093140558
		MeanAnomaly	237.808918880194
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0578
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2707"
}

#1_"2709 Sagan:Sagan:1982 FH:1951 WF1:1959 CC:1959 EA1:1964 WT:1982 FE2" "Sol" #1=
#2_"*Саган:2709 Sagan:Sagan:1982 FH" "Sol" #2=
#3_"1982 FH:*Саган:2709 Sagan:Sagan" "Sol" #3=
".:Sagan:2709 Sagan:1982 FH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2709 sagan.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	3.28
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.25305746996
		SemiMajorAxis	2.195443958606
		Eccentricity	0.069246788695
		Inclination	2.731388111625
		AscendingNode	241.144638314581
		ArgOfPericenter	308.169551720901
		MeanAnomaly	77.034204974777
	}
	UniformRotation
	{
		Period	5.2564
	}
	LunarLambert	0.5
	Albedo	0.259
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2709"
}

#1_"2713 Luxembourg:Luxembourg:1938 EA:1935 QZ:1958 HE:1969 RX1:1969 TF8:1977 EA1:1977 FB3:1979 SS9: #1=
#1_1981 BL:1982 HG2" "Sol" #1=
#2_"*Люксембург:2713 Luxembourg:Luxembourg:1938 EA" "Sol" #2=
#3_"1938 EA:Luxembourg:*Люксембург:2713 Luxembourg" "Sol" #3=
".:Luxembourg:2713 Luxembourg:1938 EA2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2713 luxembourg.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.546
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.821432764884
		SemiMajorAxis	2.853942869247
		Eccentricity	0.02238151513
		Inclination	1.350162539117
		AscendingNode	339.651571540348
		ArgOfPericenter	297.556632131727
		MeanAnomaly	8.465152628518
	}
	UniformRotation
	{
		Period	3.579
	}
	LunarLambert	0.5
	Albedo	0.195
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2713"
}

#1_"2715 Mielikki:Mielikki:1938 US:1929 VM:1933 SN:1951 PM:1951 RN1:1955 MF:1956 TT:1978 NZ2:1982 KL" "Sol" #1=
#2_"*Милики:2715 Mielikki:Mielikki:1938 US" "Sol" #2=
#3_"1938 US:*Милики:2715 Mielikki:Mielikki" "Sol" #3=
".:Mielikki:2715 Mielikki:1938 US" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.545
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.524001825169
		SemiMajorAxis	2.73532990005
		Eccentricity	0.152719500881
		Inclination	6.748321972285
		AscendingNode	200.67990078
		ArgOfPericenter	143.934761321204
		MeanAnomaly	342.014490520164
	}
	UniformRotation
	{
		Period	33.62
	}
	LunarLambert	0.5
	Albedo	0.1791
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2715"
}

#1_"2718 Handley:Handley:1951 OM:1935 SL:1972 JT1:1974 WB1:1979 SF1" "Sol" #1=
#2_"*Хэндли:2718 Handley:Handley:1951 OM" "Sol" #2=
#3_"1951 OM:*Хэндли:2718 Handley:Handley" "Sol" #3=
".:Handley:2718 Handley:1951 OM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.985
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.532501896786
		SemiMajorAxis	3.12806363533
		Eccentricity	0.152973311981
		Inclination	1.49184253269
		AscendingNode	44.617471371617
		ArgOfPericenter	264.204261542301
		MeanAnomaly	195.227397688214
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0547
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2718"
}

#1_"2724 Orlov:Orlov:1978 RZ5:1948 TF1:1956 EF:1972 LB:1974 YQ:1976 GO" "Sol" #1=
#2_"*Орлов:2724 Orlov:Orlov:1978 RZ5" "Sol" #2=
#3_"1978 RZ5:*Орлов:2724 Orlov:Orlov" "Sol" #3=
".:Orlov:2724 Orlov:1978 RZ5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.87
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.000666667244
		SemiMajorAxis	2.924240826178
		Eccentricity	0.122670879486
		Inclination	3.978240152713
		AscendingNode	153.695701920354
		ArgOfPericenter	142.830226305688
		MeanAnomaly	153.552019596829
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0947
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2724"
}

#1_"2725 David Bender:David Bender:1978 VG3:1941 WW:1943 GA:1959 FA:1962 XB:1969 EE1:1980 FA12: #1=
#1_A904 VC" "Sol" #1=
#2_"*Дэвид Бендер:2725 David Bender:David Bender:1978 VG3" "Sol" #2=
#3_"1978 VG3:*Дэвид Бендер:2725 David Bender:David Bender" "Sol" #3=
".:David Bender:2725 David Bender:1978 VG3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2725 david bender.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	18.487
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.293212943231
		SemiMajorAxis	3.037205019939
		Eccentricity	0.147465080676
		Inclination	15.531505769725
		AscendingNode	61.62223333862
		ArgOfPericenter	27.624335564564
		MeanAnomaly	279.581359679762
	}
	UniformRotation
	{
		Period	9.956
	}
	LunarLambert	0.5
	Albedo	0.068
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2725"
}

#1_"2728 Yatskiv:Yatskiv:1979 ST9:1935 DA:1936 LF:1936 MD:1940 NA:1964 VT2:1965 AN1:1966 CV:1972 XJ2: #1=
#1_1972 YM1:1973 AF3:1978 JO2:1981 BP:1982 HJ1" "Sol" #1=
#2_"*Яцкив:2728 Yatskiv:Yatskiv:1979 ST9" "Sol" #2=
#3_"1979 ST9:*Яцкив:2728 Yatskiv:Yatskiv" "Sol" #3=
".:Yatskiv:2728 Yatskiv:1979 ST9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.76
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.848829632975
		SemiMajorAxis	2.455916839304
		Eccentricity	0.167341211149
		Inclination	2.604219016106
		AscendingNode	201.391295918366
		ArgOfPericenter	96.790143551427
		MeanAnomaly	110.785826233325
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0804
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2728"
}

#1_"2729 Urumqi:Urumqi:1979 UA2:1934 NN:1952 DN1:1969 UR1:1975 XZ5:1981 BO" "Sol" #1=
#2_"*Урумчи:2729 Urumqi:Urumqi:1979 UA2" "Sol" #2=
#3_"1979 UA2:*Урумчи:2729 Urumqi:Urumqi" "Sol" #3=
".:Urumqi:2729 Urumqi:1979 UA2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.48
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.906908204822
		SemiMajorAxis	2.887574209252
		Eccentricity	0.068246239029
		Inclination	3.170037487768
		AscendingNode	64.196003485411
		ArgOfPericenter	263.774218902794
		MeanAnomaly	106.046577673025
	}
	UniformRotation
	{
		Period	3.127
	}
	LunarLambert	0.5
	Albedo	0.1353
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2729"
}

#1_"2731 Cucula:Cucula:1982 KJ:1937 GO:1964 CK:1966 SA:1978 TM8:1981 AR:1981 FO" "Sol" #1=
#2_"*Кукула:2731 Cucula:Cucula:1982 KJ" "Sol" #2=
#3_"1982 KJ:*Кукула:2731 Cucula:Cucula" "Sol" #3=
".:Cucula:2731 Cucula:1982 KJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.718356002532
		SemiMajorAxis	3.197731472888
		Eccentricity	0.189046336854
		Inclination	13.333583300991
		AscendingNode	150.704146893455
		ArgOfPericenter	131.919396422169
		MeanAnomaly	228.014127856735
	}
	UniformRotation
	{
		Period	61.55
	}
	LunarLambert	0.5
	Albedo	0.0358
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2731"
}

#1_"2734 Hasek:Hasek:1976 GJ3" "Sol" #1=
#2_"*Гашек:2734 Hasek:Hasek:1976 GJ3" "Sol" #2=
#3_"1976 GJ3:*Гашек:2734 Hasek:Hasek" "Sol" #3=
".:Hasek:2734 Hasek:1976 GJ3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.27
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.626700121029
		SemiMajorAxis	3.163469937077
		Eccentricity	0.018418027904
		Inclination	16.538416029876
		AscendingNode	37.010527989721
		ArgOfPericenter	140.048530291186
		MeanAnomaly	342.569864208864
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0958
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2734"
}
###### Исправление ошибки
#1_"2739 Taguacipa:Taguacipa:1952 UZ1:1951 KJ:1959 NH" "Sol" #1=
#2_"*Тагуаципа:2739 Taguacipa:Taguacipa:1952 UZ1" "Sol" #2=
#3_"1952 UZ1:2739 Taguacipa:Taguacipa" "Sol" #3=
".:Taguacipa:2739 Taguacipa:1952 UZ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.849882078614
		SemiMajorAxis	2.456364525386
		Eccentricity	0.129707399319
		Inclination	1.168882687155
		AscendingNode	267.596955077438
		ArgOfPericenter	35.646218486733
		MeanAnomaly	131.143702601519
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0731
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2739"
}

#1_"2740 Tsoj:Tsoj:1974 SY4:1951 GW:1953 TY:1958 TB1:1972 GD:1974 TD1:1977 EB1:1979 SC9" "Sol" #1=
#2_"*Цой:2740 Tsoj:Tsoj:1974 SY4" "Sol" #2=
#3_"1974 SY4:*Цой:2740 Tsoj:Tsoj" "Sol" #3=
".:Tsoj:2740 Tsoj:1974 SY4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	5.198787216499
		SemiMajorAxis	3.000976261568
		Eccentricity	0.070947362323
		Inclination	9.374288444619
		AscendingNode	197.883573185414
		ArgOfPericenter	96.48661766583
		MeanAnomaly	101.877347703882
	}
	UniformRotation
	{
		Period	22.0415
	}
	LunarLambert	0.5
	Albedo	0.122
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2740"
}

#1_"2741 Valdivia:Valdivia:1975 XG:1935 CM:1952 DJ2:1953 QS:1969 EB1:1969 FC:1973 FX1:1979 UA1:1990 FO3" "Sol" #1=
#2_"*Вальдивия:2741 Valdivia:Valdivia:1975 XG" "Sol" #2=
#3_"1975 XG:Valdivia:*Вальдивия:2741 Valdivia" "Sol" #3=
".:Valdivia:2741 Valdivia:1975 XG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2741 valdivia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.84
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.214745734223
		SemiMajorAxis	2.609208502156
		Eccentricity	0.181695614603
		Inclination	10.28825190949
		AscendingNode	151.130699647413
		ArgOfPericenter	91.440556139288
		MeanAnomaly	95.602025441568
	}
	UniformRotation
	{
		Period	4.096
	}
	LunarLambert	0.5
	Albedo	0.205
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2741"
}

#1_"2747 Cesky Krumlov:Cesky Krumlov:1980 DW:1953 FO1:1975 EK5:1977 SV2:1977 TM3:1977 TS7:1982 OM" "Sol" #1=
#2_"*Чески Крумлов:2747 Cesky Krumlov:Cesky Krumlov:1980 DW" "Sol" #2=
#3_"1980 DW:*Чески Крумлов:2747 Cesky Krumlov:Cesky Krumlov" "Sol" #3=
".:Cesky Krumlov:2747 Cesky Krumlov:1980 DW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.315
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.456864635407
		SemiMajorAxis	3.099488187967
		Eccentricity	0.127936985825
		Inclination	5.818161259939
		AscendingNode	344.897760205264
		ArgOfPericenter	302.251880026021
		MeanAnomaly	2.527670078006
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.038
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2747"
}

#1_"2753 Duncan:Duncan:1966 DH:1952 DH1:1966 FL:1973 UP:1976 JC1:1978 WM:1980 ES" "Sol" #1=
#2_"*Дункан:2753 Duncan:Duncan:1966 DH" "Sol" #2=
#3_"1966 DH:*Дункан:2753 Duncan:Duncan" "Sol" #3=
".:Duncan:2753 Duncan:1966 DH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.965
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.662187229292
		SemiMajorAxis	2.790750462802
		Eccentricity	0.035622792966
		Inclination	6.863347063924
		AscendingNode	344.585429755176
		ArgOfPericenter	126.714415344906
		MeanAnomaly	202.710221143465
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.066
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2753"
}

#1_"2757 Crisser:Crisser:1977 VN:1949 XO:1956 AM:1966 VJ:1973 AC2:1979 FR" "Sol" #1=
#2_"*Криссер:2757 Crisser:Crisser:1977 VN" "Sol" #2=
#3_"1977 VN:*Криссер:2757 Crisser:Crisser" "Sol" #3=
".:Crisser:2757 Crisser:1977 VN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.68
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.63716873573
		SemiMajorAxis	3.167392530716
		Eccentricity	0.200014163901
		Inclination	0.68024742858
		AscendingNode	10.125801686395
		ArgOfPericenter	50.568925159514
		MeanAnomaly	200.433544875567
	}
	UniformRotation
	{
		Period	8.0882
	}
	LunarLambert	0.5
	Albedo	0.1423
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2757"
}

#1_"2759 Idomeneus:Idomeneus:1980 GC" "Sol" #1=
#2_"*Идоменей:2759 Idomeneus:Idomeneus:1980 GC" "Sol" #2=
#3_"1980 GC:*Идоменей:2759 Idomeneus:Idomeneus" "Sol" #3=
".:Idomeneus:2759 Idomeneus:1980 GC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	30.505
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.789558018923
		SemiMajorAxis	5.179957714924
		Eccentricity	0.066586148156
		Inclination	21.954097365574
		AscendingNode	171.238017961384
		ArgOfPericenter	8.07662913625
		MeanAnomaly	17.951879867396
	}
	UniformRotation
	{
		Period	32.4
	}
	LunarLambert	0.5
	Albedo	0.0571
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2759"
}

#1_"2760 Kacha:Kacha:1980 TU6:1952 DJ:1960 DC:1965 UP:1968 DH:1981 UB21" "Sol" #1=
#2_"*Кача:2760 Kacha:Kacha:1980 TU6" "Sol" #2=
#3_"1980 TU6:*Кача:2760 Kacha:Kacha" "Sol" #3=
".:Kacha:2760 Kacha:1980 TU6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	8.008079843394
		SemiMajorAxis	4.002642430627
		Eccentricity	0.12115889834
		Inclination	13.459090094891
		AscendingNode	352.60254326069
		ArgOfPericenter	153.563337196339
		MeanAnomaly	342.462204909392
	}
	UniformRotation
	{
		Period	13
	}
	LunarLambert	0.5
	Albedo	0.0508
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2760"
}

#1_"2774 Tenojoki:Tenojoki:1942 TJ:1948 TO1:1981 LE:2000 XO55" "Sol" #1=
#2_"*Тенойоки:2774 Tenojoki:Tenojoki:1942 TJ" "Sol" #2=
#3_"1942 TJ:*Тенойоки:2774 Tenojoki:Tenojoki" "Sol" #3=
".:Tenojoki:2774 Tenojoki:1942 TJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.681594162696
		SemiMajorAxis	3.184011817795
		Eccentricity	0.141774182607
		Inclination	8.527849400935
		AscendingNode	290.957834823096
		ArgOfPericenter	108.599020024903
		MeanAnomaly	227.146286063859
	}
	UniformRotation
	{
		Period	11.2
	}
	LunarLambert	0.5
	Albedo	0.0506
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2774"
}

#1_"2785 Sedov:Sedov:1978 QN2:1932 CX:1954 UO:1966 CG" "Sol" #1=
#2_"*Седов:2785 Sedov:Sedov:1978 QN2" "Sol" #2=
#3_"1978 QN2:Sedov:*Седов:2785 Sedov" "Sol" #3=
".:Sedov:2785 Sedov:1978 QN2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2785 sedov.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.719
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.868208857183
		SemiMajorAxis	2.872371881293
		Eccentricity	0.044473424393
		Inclination	1.438330948555
		AscendingNode	334.433983471071
		ArgOfPericenter	95.707970903723
		MeanAnomaly	244.799123784352
	}
	UniformRotation
	{
		Period	5.49
	}
	LunarLambert	0.5
	Albedo	0.261
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2785"
}

#1_"2791 Paradise:Paradise:1977 CA" "Sol" #1=
#2_"*Парадайс:2791 Paradise:Paradise:1977 CA" "Sol" #2=
#3_"1977 CA:Paradise:*Парадайс:2791 Paradise" "Sol" #3=
".:Paradise:2791 Paradise:1977 CA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2791 paradise.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.192
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.709275190237
		SemiMajorAxis	2.396186231114
		Eccentricity	0.172200981397
		Inclination	31.084690471795
		AscendingNode	336.103764250446
		ArgOfPericenter	165.734239703514
		MeanAnomaly	278.465182560549
	}
	UniformRotation
	{
		Period	9.81
	}
	LunarLambert	0.5
	Albedo	0.247
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2791"
}

#1_"2793 Valdaj:Valdaj:1977 QV:1941 FT:1949 SG:1966 UH:1969 EJ1:1980 BM1" "Sol" #1=
#2_"*Валдай:2793 Valdaj:Valdaj:1977 QV" "Sol" #2=
#3_"1977 QV:*Валдай:2793 Valdaj:Valdaj" "Sol" #3=
".:Valdaj:2793 Valdaj:1977 QV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.865
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.63239588104
		SemiMajorAxis	3.165604441804
		Eccentricity	0.030504273086
		Inclination	22.099550259267
		AscendingNode	356.367204525118
		ArgOfPericenter	185.76724239149
		MeanAnomaly	33.177365607705
	}
	UniformRotation
	{
		Period	10.594
	}
	LunarLambert	0.5
	Albedo	0.11
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2793"
}

#1_"2797 Teucer:Teucer:1981 LK:1940 YG:1975 VA1:1975 XQ2:1978 EQ" "Sol" #1=
#2_"*Тевкр:2797 Teucer:Teucer:1981 LK" "Sol" #2=
#3_"1981 LK:*Тевкр:2797 Teucer:Teucer" "Sol" #3=
".:Teucer:2797 Teucer:1981 LK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	55.57
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.519780691462
		SemiMajorAxis	5.100632173576
		Eccentricity	0.088587431852
		Inclination	22.402321872388
		AscendingNode	69.935573812025
		ArgOfPericenter	48.857659602715
		MeanAnomaly	71.38585369864
	}
	UniformRotation
	{
		Period	10.145
	}
	LunarLambert	0.5
	Albedo	0.0624
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2797"
}

#1_"2802 Weisell:Weisell:1939 BU:1945 GA:1951 KZ:1952 OT:1962 JO:1969 RQ:1975 VB6:1977 AL:1978 GM2: #1=
#1_1983 CZ1" "Sol" #1=
#2_"*Вейселл:2802 Weisell:Weisell:1939 BU" "Sol" #2=
#3_"1939 BU:Weisell:*Вейселл:2802 Weisell" "Sol" #3=
".:Weisell:2802 Weisell:1939 BU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2802 weisell.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.406
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.493661712078
		SemiMajorAxis	3.113406352113
		Eccentricity	0.124487593584
		Inclination	9.613197705264
		AscendingNode	129.378377120639
		ArgOfPericenter	59.724438789977
		MeanAnomaly	18.211764325651
	}
	UniformRotation
	{
		Period	14.683
	}
	LunarLambert	0.5
	Albedo	0.199
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2802"
}

#1_"2804 Yrjo:Yrjo:1941 HF:1951 EK2:1979 QD:1979 QJ8:1982 BY6" "Sol" #1=
#2_"*Ирьё:2804 Yrjo:Yrjo:1941 HF" "Sol" #2=
#3_"1941 HF:*Ирьё:2804 Yrjo:Yrjo" "Sol" #3=
".:Yrjo:2804 Yrjo:1941 HF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.42
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.230355298928
		SemiMajorAxis	3.013112354701
		Eccentricity	0.076296112254
		Inclination	11.229909304904
		AscendingNode	109.181683001794
		ArgOfPericenter	174.38746374312
		MeanAnomaly	315.00293369455
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0708
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2804"
}

#1_"2813 Zappala:Zappala:1981 WZ:1931 VZ:1949 FC:1964 TH:1979 OS14" "Sol" #1=
#2_"*Дзаппала:2813 Zappala:Zappala:1981 WZ" "Sol" #2=
#3_"1981 WZ:*Дзаппала:2813 Zappala:Zappala" "Sol" #3=
".:Zappala:2813 Zappala:1981 WZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.285
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.555961277045
		SemiMajorAxis	3.136899983726
		Eccentricity	0.150653528209
		Inclination	14.739788459838
		AscendingNode	231.848587459034
		ArgOfPericenter	248.063311562104
		MeanAnomaly	283.088280490771
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0663
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2813"
}

#1_"2816 Pien:Pien:1982 SO:1950 NG:1951 YX:1955 TU:1959 ND:1964 RL:1964 TQ2:1976 JW2:1978 YS" "Sol" #1=
#2_"*Пин:2816 Pien:Pien:1982 SO" "Sol" #2=
#3_"1982 SO:*Пин:2816 Pien:Pien" "Sol" #3=
".:Pien:2816 Pien:1982 SO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.955
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.502807117893
		SemiMajorAxis	2.726779965543
		Eccentricity	0.187660597237
		Inclination	7.717490659236
		AscendingNode	93.954850354562
		ArgOfPericenter	263.431767635321
		MeanAnomaly	56.272154708363
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0769
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2816"
}

#1_"2819 Ensor:Ensor:1933 UR:1942 RC:1965 UB:1970 XG:1977 ES3:1977 GR:1979 UZ1" "Sol" #1=
#2_"*Энсо:2819 Ensor:Ensor:1933 UR" "Sol" #2=
#3_"1933 UR:*Энсо:2819 Ensor:Ensor" "Sol" #3=
".:Ensor:2819 Ensor:1933 UR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.578531450143
		SemiMajorAxis	2.757266004815
		Eccentricity	0.204616078756
		Inclination	2.436442329737
		AscendingNode	18.401221622288
		ArgOfPericenter	344.343469970799
		MeanAnomaly	268.342416050904
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1928
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2819"
}

#1_"2826 Ahti:Ahti:1939 UJ:1942 FH:1950 TG3:1968 UT2:1979 RG:1980 VK1" "Sol" #1=
#2_"*Ахти:2826 Ahti:Ahti:1939 UJ" "Sol" #2=
#3_"1939 UJ:*Ахти:2826 Ahti:Ahti" "Sol" #3=
".:Ahti:2826 Ahti:1939 UJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.355
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.786106322323
		SemiMajorAxis	3.22293938994
		Eccentricity	0.046410396878
		Inclination	15.462269112143
		AscendingNode	33.675720785538
		ArgOfPericenter	150.975609941413
		MeanAnomaly	191.741156039818
	}
	UniformRotation
	{
		Period	24
	}
	LunarLambert	0.5
	Albedo	0.0628
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2826"
}

#1_"2829 Bobhope:Bobhope:1948 PK:1942 JH:1952 DU2:1952 HR:1959 RV:1972 YZ" "Sol" #1=
#2_"*Бобхоуп:2829 Bobhope:Bobhope:1948 PK" "Sol" #2=
#3_"1948 PK:*Бобхоуп:2829 Bobhope:Bobhope" "Sol" #3=
".:Bobhope:2829 Bobhope:1948 PK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.125
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.41950650244
		SemiMajorAxis	3.085325767799
		Eccentricity	0.190729326408
		Inclination	14.32532066485
		AscendingNode	324.096220982528
		ArgOfPericenter	339.530426060034
		MeanAnomaly	90.449945715103
	}
	UniformRotation
	{
		Period	6.0888
	}
	LunarLambert	0.5
	Albedo	0.0916
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2829"
}

#1_"2835 Ryoma:Ryoma:1982 WF:1932 YB:1941 WB:1961 CB1:1963 QC:1972 NT:1975 EX3:1977 QF5: #1=
#1_1977 RY7:1979 AA:1980 GP:1989 GQ8" "Sol" #1=
#2_"*Рёма:2835 Ryoma:Ryoma:1982 WF" "Sol" #2=
#3_"1982 WF:*Рёма:2835 Ryoma:Ryoma" "Sol" #3=
".:Ryoma:2835 Ryoma:1982 WF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.548667453754
		SemiMajorAxis	2.745263210374
		Eccentricity	0.079399906305
		Inclination	1.335748055313
		AscendingNode	5.308472153617
		ArgOfPericenter	348.030585063311
		MeanAnomaly	72.410316918405
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0404
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2835"
}

#1_"2836 Sobolev:Sobolev:1978 YQ:1930 QM:1951 RH1:1959 CE:1969 AM:1975 EQ2:1977 RH3:1980 EM" "Sol" #1=
#2_"*Соболев:2836 Sobolev:Sobolev:1978 YQ" "Sol" #2=
#3_"1978 YQ:Sobolev:*Соболев:2836 Sobolev" "Sol" #3=
".:Sobolev:2836 Sobolev:1978 YQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2836 sobolev.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.298
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.206501262255
		SemiMajorAxis	3.003944126447
		Eccentricity	0.093306165914
		Inclination	9.673295714508
		AscendingNode	348.182251195804
		ArgOfPericenter	319.112297571919
		MeanAnomaly	242.18178428934
	}
	UniformRotation
	{
		Period	4.7549
	}
	LunarLambert	0.5
	Albedo	0.141
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2836"
}

#1_"2839 Annette:Annette:1929 TP:1937 AB1:1939 UL:1962 TE:1970 BB:1972 XF1:1982 VP" "Sol" #1=
#2_"*Аннет:2839 Annette:Annette:1929 TP" "Sol" #2=
#3_"1929 TP:*Аннет:2839 Annette:Annette" "Sol" #3=
".:Annette:2839 Annette:1929 TP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2839 annette.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	3.656
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.300337706055
		SemiMajorAxis	2.216665281983
		Eccentricity	0.149603723397
		Inclination	4.807202199745
		AscendingNode	44.584072421623
		ArgOfPericenter	6.538519849006
		MeanAnomaly	321.985259270456
	}
	UniformRotation
	{
		Period	10.4595
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2839"
}

#1_"2843 Yeti:Yeti:1975 XQ:1950 TV:1978 SM7" "Sol" #1=
#2_"*Йети:2843 Yeti:Yeti:1975 XQ" "Sol" #2=
#3_"1975 XQ:*Йети:2843 Yeti:Yeti" "Sol" #3=
".:Yeti:2843 Yeti:1975 XQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.484527842942
		SemiMajorAxis	2.298390535121
		Eccentricity	0.129481780159
		Inclination	5.461442572439
		AscendingNode	256.081941866238
		ArgOfPericenter	255.553282084773
		MeanAnomaly	13.043987904278
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.103
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2843"
}

#1_"2846 Ylppo:Ylppo:1942 CJ:1968 TK:1971 BT1:1972 JN1:1974 UG:1975 XK5:1979 OE13:1979 QB6: #1=
#1_1979 QF8" "Sol" #1=
#2_"*Улппо:2846 Ylppo:Ylppo:1942 CJ" "Sol" #2=
#3_"1942 CJ:*Улппо:2846 Ylppo:Ylppo" "Sol" #3=
".:Ylppo:2846 Ylppo:1942 CJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.075
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.787923708187
		SemiMajorAxis	3.223614226935
		Eccentricity	0.071204747997
		Inclination	11.426488535004
		AscendingNode	144.666466006132
		ArgOfPericenter	74.588026749364
		MeanAnomaly	139.647251743243
	}
	UniformRotation
	{
		Period	12
	}
	LunarLambert	0.5
	Albedo	0.117
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2846"
}

#1_"2849 Shklovskij:Shklovskij:1976 GN3:1968 KE:1972 HA:1980 GU" "Sol" #1=
#2_"*Шкловский:2849 Shklovskij:Shklovskij:1976 GN3" "Sol" #2=
#3_"1976 GN3:*Шкловский:2849 Shklovskij:Shklovskij" "Sol" #3=
".:Shklovskij:2849 Shklovskij:1976 GN3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.55
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.110876265557
		SemiMajorAxis	2.566162387404
		Eccentricity	0.01021797312
		Inclination	6.808687620359
		AscendingNode	44.07443585229
		ArgOfPericenter	292.6682029902
		MeanAnomaly	15.080343997517
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0642
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2849"
}

#1_"2856 Roser:Roser:1933 GB:1935 SV:1941 WL:1946 UC:1959 CM:1962 WK:1970 GG:1972 RR3:1975 EK: #1=
#1_1977 QX1" "Sol" #1=
#2_"*Росер:2856 Roser:Roser:1933 GB" "Sol" #2=
#3_"1933 GB:*Росер:2856 Roser:Roser" "Sol" #3=
".:Roser:2856 Roser:1933 GB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.995
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.26738504659
		SemiMajorAxis	3.027317068308
		Eccentricity	0.009343718052
		Inclination	9.909620882164
		AscendingNode	16.881844964924
		ArgOfPericenter	224.417301928066
		MeanAnomaly	122.862086377608
	}
	UniformRotation
	{
		Period	13.73
	}
	LunarLambert	0.5
	Albedo	0.1223
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2856"
}

#1_"2864 Soderblom:Soderblom:1983 AZ:1965 CG:1965 DE:1970 JF:1972 TO9:1974 CO" "Sol" #1=
#2_"*Содерблом:2864 Soderblom:Soderblom:1983 AZ" "Sol" #2=
#3_"1983 AZ:*Содерблом:2864 Soderblom:Soderblom" "Sol" #3=
".:Soderblom:2864 Soderblom:1983 AZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.36
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.553829967453
		SemiMajorAxis	2.747339976751
		Eccentricity	0.150441399786
		Inclination	3.142362407024
		AscendingNode	135.183990410835
		ArgOfPericenter	11.022149492933
		MeanAnomaly	339.907326032104
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0632
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2864"
}

#1_"2865 Laurel:Laurel:1935 OK:1939 PA:1947 NF:1951 ML:1972 QH" "Sol" #1=
#2_"*Лорел:2865 Laurel:Laurel:1935 OK" "Sol" #2=
#3_"1935 OK:*Лорел:2865 Laurel:Laurel" "Sol" #3=
".:Laurel:2865 Laurel:1935 OK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.096911083173
		SemiMajorAxis	2.560347366534
		Eccentricity	0.071465653602
		Inclination	14.301500306396
		AscendingNode	321.803232693996
		ArgOfPericenter	293.171572414306
		MeanAnomaly	191.074588824382
	}
	UniformRotation
	{
		Period	21.5
	}
	LunarLambert	0.5
	Albedo	0.2242
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2865"
}

#1_"2867 Steins:Steins:1969 VC:1954 QL:1979 FJ4:1980 VV1:1980 WB" "Sol" #1=
#2_"*Штейнс:2867 Steins:Steins:1969 VC" "Sol" #2=
#3_"1969 VC:*Штейнс:2867 Steins:Steins" "Sol" #3=
".:Steins:2867 Steins:1969 VC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2867 steins.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"steins.jpg"
	Radius	3.335
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2454714.5  # 2008 Sept 05
		Period	3.6332341337077
		SemiMajorAxis	2.363325035403005
		Eccentricity	0.1462213379829717
		Inclination	9.944941616831395
		AscendingNode	55.52931056779465
		ArgOfPericenter	250.5168619972865
		MeanAnomaly	317.3097878957633
	}
	UniformRotation
	{
		Period	6.049
		Inclination	169.5
	}
	LunarLambert	0.5
	Albedo	0.34
	InfoURL	"https://en.wikipedia.org/wiki/2867_Steins"
}

#1_"2872 Gentelec:Gentelec:1981 RU:1972 TZ3:1977 XB" "Sol" #1=
#2_"*Гентелек:2872 Gentelec:Gentelec:1981 RU" "Sol" #2=
#3_"1981 RU:*Гентелек:2872 Gentelec:Gentelec" "Sol" #3=
".:Gentelec:2872 Gentelec:1981 RU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.538167279947
		SemiMajorAxis	2.741036794206
		Eccentricity	0.12207563594
		Inclination	2.872895701898
		AscendingNode	241.538624136176
		ArgOfPericenter	239.096734984811
		MeanAnomaly	16.34422224171
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2872"
}

#1_"2879 Shimizu:Shimizu:1932 CB1:1928 JA:1975 RG1:1978 EV6:1980 TN1" "Sol" #1=
#2_"*Симицу:2879 Shimizu:Shimizu:1932 CB1" "Sol" #2=
#3_"1932 CB1:*Симицу:2879 Shimizu:Shimizu" "Sol" #3=
".:Shimizu:2879 Shimizu:1932 CB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.610137754031
		SemiMajorAxis	2.769940669861
		Eccentricity	0.142626460604
		Inclination	10.717302833309
		AscendingNode	149.261801656359
		ArgOfPericenter	24.92965496615
		MeanAnomaly	340.418909111785
	}
	UniformRotation
	{
		Period	18.72
	}
	LunarLambert	0.5
	Albedo	0.0463
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2879"
}

#1_"2892 Filipenko:Filipenko:1983 AX2:1936 QK1:1953 SB:1953 SL:1955 DO:1957 KP:1964 PA:A910 CK" "Sol" #1=
#2_"*Филипенко:2892 Filipenko:Filipenko:1983 AX2" "Sol" #2=
#3_"1983 AX2:*Филипенко:2892 Filipenko:Filipenko" "Sol" #3=
".:Filipenko:2892 Filipenko:1983 AX2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.065
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.65452490873
		SemiMajorAxis	3.173890549395
		Eccentricity	0.206207950686
		Inclination	16.963016742649
		AscendingNode	326.550191392268
		ArgOfPericenter	91.714634113439
		MeanAnomaly	283.087153328773
	}
	UniformRotation
	{
		Period	14
	}
	LunarLambert	0.5
	Albedo	0.0466
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2892"
}

#1_"2893 Peiroos:Peiroos:1975 QD:1933 BJ:1970 EE:1979 YV4:1981 AP" "Sol" #1=
#2_"*Пейрус:2893 Peiroos:Peiroos:1975 QD" "Sol" #2=
#3_"1975 QD:*Пейрус:2893 Peiroos:Peiroos" "Sol" #3=
".:Peiroos:2893 Peiroos:1975 QD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	43.73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.709948449092
		SemiMajorAxis	5.15661277984
		Eccentricity	0.075242873056
		Inclination	14.654369797308
		AscendingNode	108.771552266179
		ArgOfPericenter	172.218715190583
		MeanAnomaly	132.310618370447
	}
	UniformRotation
	{
		Period	8.96
	}
	LunarLambert	0.5
	Albedo	0.0469
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2893"
}

#1_"2904 Millman:Millman:1981 YB:1939 VF:1939 XG:1960 WO:1960 XB:1981 WK9" "Sol" #1=
#2_"*Мильман:2904 Millman:Millman:1981 YB" "Sol" #2=
#3_"1981 YB:*Мильман:2904 Millman:Millman" "Sol" #3=
".:Millman:2904 Millman:1981 YB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.201977092287
		SemiMajorAxis	2.603936077545
		Eccentricity	0.137893349695
		Inclination	15.378420359825
		AscendingNode	79.618523526916
		ArgOfPericenter	331.551330819021
		MeanAnomaly	316.416909393823
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1421
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2904"
}

#1_"2906 Caltech:Caltech:1983 AE2:1957 KJ:1957 MA:1974 LC:1976 YS2:1983 CD" "Sol" #1=
#2_"*Салтех:2906 Caltech:Caltech:1983 AE2" "Sol" #2=
#3_"1983 AE2:*Салтех:2906 Caltech:Caltech" "Sol" #3=
".:Caltech:2906 Caltech:1983 AE2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.99
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.637228245617
		SemiMajorAxis	3.167414822147
		Eccentricity	0.108315715266
		Inclination	30.644900328125
		AscendingNode	84.511907396959
		ArgOfPericenter	295.339915899548
		MeanAnomaly	330.007497985469
	}
	UniformRotation
	{
		Period	12.99
	}
	LunarLambert	0.5
	Albedo	0.0526
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2906"
}

#1_"2908 Shimoyama:Shimoyama:1981 WA:1950 TJ4:1955 TQ:1976 YA4:1981 UH10" "Sol" #1=
#2_"*Симояма:2908 Shimoyama:Shimoyama:1981 WA" "Sol" #2=
#3_"1981 WA:*Симояма:2908 Shimoyama:Shimoyama" "Sol" #3=
".:Shimoyama:2908 Shimoyama:1981 WA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.69
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.132363056666
		SemiMajorAxis	2.975359487089
		Eccentricity	0.154857884131
		Inclination	13.368884152116
		AscendingNode	233.32583821177
		ArgOfPericenter	154.528878616476
		MeanAnomaly	166.173521270248
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0514
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2908"
}

#1_"2909 Hoshi-no-ie:Hoshi-no-ie:1983 JA:1948 UF:1948 WG:1957 LG:1961 DK:1969 VV2:1972 JN:1974 UH" "Sol" #1=
#2_"*Носи-но-иэ:2909 Hoshi-no-ie:Hoshi-no-ie:1983 JA" "Sol" #2=
#3_"1983 JA:*Носи-но-иэ:2909 Hoshi-no-ie:Hoshi-no-ie" "Sol" #3=
".:Hoshi-no-ie:2909 Hoshi-no-ie:1983 JA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.242956464233
		SemiMajorAxis	3.01794994795
		Eccentricity	0.119328665121
		Inclination	11.451867565513
		AscendingNode	85.406704986512
		ArgOfPericenter	285.387068334164
		MeanAnomaly	244.865305327761
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1671
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2909"
}

#1_"2920 Automedon:Automedon:1981 JR" "Sol" #1=
#2_"*Автомедон:2920 Automedon:Automedon:1981 JR" "Sol" #2=
#3_"1981 JR:*Автомедон:2920 Automedon:Automedon" "Sol" #3=
".:Automedon:2920 Automedon:1981 JR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	55.505
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.543502894817
		SemiMajorAxis	5.107632118401
		Eccentricity	0.026514852676
		Inclination	21.123947337388
		AscendingNode	230.951406073808
		ArgOfPericenter	199.840661091732
		MeanAnomaly	116.287042296864
	}
	UniformRotation
	{
		Period	10.212
	}
	LunarLambert	0.5
	Albedo	0.0433
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2920"
}

#1_"2933 Amber:Amber:1983 HN:1938 RB:1940 CE:1949 FT:1950 NE1:1951 WT:1978 EB1:1980 TE2:A917 TE" "Sol" #1=
#2_"*Амбер:2933 Amber:Amber:1983 HN" "Sol" #2=
#3_"1983 HN:*Амбер:2933 Amber:Amber" "Sol" #3=
".:Amber:2933 Amber:1983 HN:1938 RB:1940 CE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.31
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.213004378461
		SemiMajorAxis	2.608489775813
		Eccentricity	0.047467254199
		Inclination	7.218431884656
		AscendingNode	121.500708641208
		ArgOfPericenter	220.198482688868
		MeanAnomaly	56.103068751887
	}
	UniformRotation
	{
		Period	13.482
	}
	LunarLambert	0.5
	Albedo	0.0869
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2933"
}

#1_"2934 Aristophanes:Aristophanes:4006 P-L:1971 OQ1:1977 RM5:1980 FC9" "Sol" #1=
#2_"*Аристофан:2934 Aristophanes:Aristophanes:1960-2934*:4006 P-L" "Sol" #2=
#3_"1960-2934*:*Аристофан:2934 Aristophanes:Aristophanes:4006 P-L" "Sol" #3=
".:Aristophanes:2934 Aristophanes:1960-2934*:4006 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.86
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.639651164844
		SemiMajorAxis	3.168322341504
		Eccentricity	0.05037230139
		Inclination	8.796786813139
		AscendingNode	202.247417466944
		ArgOfPericenter	89.981258742164
		MeanAnomaly	284.594353649462
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0761
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2934"
}

#1_"2945 Zanstra:Zanstra:1935 ST1:1957 UC1:1970 SY:1970 WM:1975 XY5:1983 TN" "Sol" #1=
#2_"*Зантра:2945 Zanstra:Zanstra:1935 ST1" "Sol" #2=
#3_"1935 ST1:*Зантра:2945 Zanstra:Zanstra" "Sol" #3=
".:Zanstra:2945 Zanstra:1935 ST1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.56
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.360030472987
		SemiMajorAxis	2.668829820218
		Eccentricity	0.138692189594
		Inclination	2.626268403306
		AscendingNode	95.894709102524
		ArgOfPericenter	242.770588783197
		MeanAnomaly	85.266344900694
	}
	UniformRotation
	{
		Period	10.05
	}
	LunarLambert	0.5
	Albedo	0.0522
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2945"
}

#1_"2948 Amosov:Amosov:1969 TD2:1979 WJ3:1979 YT6:1981 EW4" "Sol" #1=
#2_"*Амосов:2948 Amosov:Amosov:1969 TD2" "Sol" #2=
#3_"1969 TD2:Amosov:*Амосов:2948 Amosov" "Sol" #3=
".:Amosov:2948 Amosov:1969 TD2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2948 amosov.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.213
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.841454753665
		SemiMajorAxis	2.8618384664
		Eccentricity	0.108498424055
		Inclination	12.330207908957
		AscendingNode	208.840637778264
		ArgOfPericenter	245.867591457725
		MeanAnomaly	221.255197119718
	}
	UniformRotation
	{
		Period	7.3996
	}
	LunarLambert	0.5
	Albedo	0.162
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2948"
}

#1_"2950 Rousseau:Rousseau:1974 VQ2:1939 CE:1962 CG:1978 NU5:1980 AG" "Sol" #1=
#2_"*Руссо:2950 Rousseau:Rousseau:1974 VQ2" "Sol" #2=
#3_"1974 VQ2:*Руссо:2950 Rousseau:Rousseau" "Sol" #3=
".:Rousseau:2950 Rousseau:1974 VQ2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.665
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.579565759088
		SemiMajorAxis	2.757681240946
		Eccentricity	0.260545146857
		Inclination	9.601453812513
		AscendingNode	112.087708131983
		ArgOfPericenter	294.227084560476
		MeanAnomaly	269.002300150912
	}
	UniformRotation
	{
		Period	18.228
	}
	LunarLambert	0.5
	Albedo	0.1728
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2950"
}

#1_"2951 Perepadin:Perepadin:1977 RB8:1930 FD:1933 UW1:1944 UA:1950 WE:1952 DM2:1955 UG:1958 HC: #1=
#1_1969 JF:1971 SA4:1971 UU1:1980 JP" "Sol" #1=
#2_"*Перепадин:2951 Perepadin:Perepadin:1977 RB8" "Sol" #2=
#3_"1977 RB8:*Перепадин:2951 Perepadin:Perepadin" "Sol" #3=
".:Perepadin:2951 Perepadin:1977 RB8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.52
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.548831752508
		SemiMajorAxis	3.134215852797
		Eccentricity	0.11421355087
		Inclination	14.762239987766
		AscendingNode	24.884655517556
		ArgOfPericenter	118.933896522861
		MeanAnomaly	143.375897199157
	}
	UniformRotation
	{
		Period	4.781
	}
	LunarLambert	0.5
	Albedo	0.0735
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2951"
}

#1_"2952 Lilliputia:Lilliputia:1979 SF2:1965 UL:1974 HK3" "Sol" #1=
#2_"*Лиллипутия:2952 Lilliputia:Lilliputia:1979 SF2" "Sol" #2=
#3_"1979 SF2:*Лиллипутия:2952 Lilliputia:Lilliputia" "Sol" #3=
".:Lilliputia:2952 Lilliputia:1979 SF2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.518924193128
		SemiMajorAxis	2.313490954984
		Eccentricity	0.170237519376
		Inclination	3.321738484456
		AscendingNode	323.292652971214
		ArgOfPericenter	78.682809482092
		MeanAnomaly	334.938267599838
	}
	UniformRotation
	{
		Period	3.26
	}
	LunarLambert	0.5
	Albedo	0.0505
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2952"
}

#1_"2957 Tatsuo:Tatsuo:1934 CB1:1935 FM:1937 TM:1952 OD:1957 MB:1958 TM1:1962 KC:1978 LO:1983 LA: #1=
#1_A899 JA" "Sol" #1=
#2_"*Тацуо:2957 Tatsuo:Tatsuo:1934 CB1" "Sol" #2=
#3_"1934 CB1:*Тацуо:2957 Tatsuo:Tatsuo" "Sol" #3=
".:Tatsuo:2957 Tatsuo:1934 CB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2957 tatsuo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	11.236
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.248143190665
		SemiMajorAxis	3.01994000847
		Eccentricity	0.092187505621
		Inclination	8.713195139729
		AscendingNode	249.437356876666
		ArgOfPericenter	62.638631527598
		MeanAnomaly	305.115101385366
	}
	UniformRotation
	{
		Period	6.8191
	}
	LunarLambert	0.5
	Albedo	0.211
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2957"
}

#1_"2959 Scholl:Scholl:1983 RE2:1968 UB3:1977 UK:1978 EY1" "Sol" #1=
#2_"*Шолль:2959 Scholl:Scholl:1983 RE2" "Sol" #2=
#3_"1983 RE2:*Шолль:2959 Scholl:Scholl" "Sol" #3=
".:Scholl:2959 Scholl:1983 RE2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.055
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.840025097419
		SemiMajorAxis	3.946446022508
		Eccentricity	0.275704263958
		Inclination	5.233460602024
		AscendingNode	121.244481924474
		ArgOfPericenter	285.008323870214
		MeanAnomaly	314.022417951809
	}
	UniformRotation
	{
		Period	16
	}
	LunarLambert	0.5
	Albedo	0.0503
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2959"
}

#1_"2962 Otto:Otto:1940 YF:1931 TV2:1942 JB:1950 GC:1979 HJ5" "Sol" #1=
#2_"*Отто:2962 Otto:Otto:1940 YF" "Sol" #2=
#3_"1940 YF:Otto:*Отто:2962 Otto" "Sol" #3=
".:Otto:2962 Otto:1940 YF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2962 otto.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.506
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.114400392609
		SemiMajorAxis	2.567628772359
		Eccentricity	0.039503630353
		Inclination	15.643484208649
		AscendingNode	54.217964624947
		ArgOfPericenter	117.08003547186
		MeanAnomaly	117.222768912672
	}
	UniformRotation
	{
		Period	2.6776
	}
	LunarLambert	0.5
	Albedo	0.222
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2962"
}

#1_"2965 Surikov:Surikov:1975 BX:1980 UK" "Sol" #1=
#2_"*Суриков:2965 Surikov:Surikov:1975 BX" "Sol" #2=
#3_"1975 BX:*Суриков:2965 Surikov:Surikov" "Sol" #3=
".:Surikov:2965 Surikov:1975 BX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.69691831159
		SemiMajorAxis	2.390861588574
		Eccentricity	0.220668053786
		Inclination	24.218261096679
		AscendingNode	126.899935986951
		ArgOfPericenter	72.641874719022
		MeanAnomaly	236.723780260118
	}
	UniformRotation
	{
		Period	9.061
	}
	LunarLambert	0.5
	Albedo	0.0857
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2965"
}

#1_"2967 Vladisvyat:Vladisvyat:1977 SS1:1948 TJ:1977 TF8:1977 YB" "Sol" #1=
#2_"*Владисвиат:2967 Vladisvyat:Vladisvyat:1977 SS1" "Sol" #2=
#3_"1977 SS1:*Владисвиат:2967 Vladisvyat:Vladisvyat" "Sol" #3=
".:Vladisvyat:2967 Vladisvyat:1977 SS1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.62
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.716338264942
		SemiMajorAxis	3.196979209767
		Eccentricity	0.13496121805
		Inclination	17.999694016227
		AscendingNode	32.443818319063
		ArgOfPericenter	0.338841068032
		MeanAnomaly	170.016168106071
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0721
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2967"
}

#1_"2976 Lautaro:Lautaro:1974 HR:1953 XA:1957 NB:1965 XA:1972 YP1:1977 VV:1983 TR:A903 UG" "Sol" #1=
#2_"*Лаутаро:2976 Lautaro:Lautaro:1974 HR" "Sol" #2=
#3_"1974 HR:*Лаутаро:2976 Lautaro:Lautaro" "Sol" #3=
".:Lautaro:2976 Lautaro:1974 HR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.103360688409
		SemiMajorAxis	3.339698200337
		Eccentricity	0.143765208894
		Inclination	9.811038436623
		AscendingNode	206.980660829082
		ArgOfPericenter	183.238638326909
		MeanAnomaly	20.520453132552
	}
	UniformRotation
	{
		Period	17.41
	}
	LunarLambert	0.5
	Albedo	0.0522
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2976"
}

#1_"2979 Murmansk:Murmansk:1978 TB7:1976 HM:1982 KM1" "Sol" #1=
#2_"*Мурманск:2979 Murmansk:Murmansk:1978 TB7" "Sol" #2=
#3_"1978 TB7:*Мурманск:2979 Murmansk:Murmansk" "Sol" #3=
".:Murmansk:2979 Murmansk:1978 TB7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.279
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.51729991183
		SemiMajorAxis	3.122330896795
		Eccentricity	0.157759895352
		Inclination	11.418305030262
		AscendingNode	148.512430913791
		ArgOfPericenter	196.855112468579
		MeanAnomaly	39.044180691196
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2979"
}

#1_"2983 Poltava:Poltava:1981 RW2:1933 SM:1955 FM:1962 SF:1971 OD:1972 VE:1972 XK1:1977 UO1:1977 VR2" "Sol" #1=
#2_"*Полтава:2983 Poltava:Poltava:1981 RW2" "Sol" #2=
#3_"1981 RW2:*Полтава:2983 Poltava:Poltava" "Sol" #3=
".:Poltava:2983 Poltava:1981 RW2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.43
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.804159896561
		SemiMajorAxis	2.84712259229
		Eccentricity	0.060725319883
		Inclination	4.267075599783
		AscendingNode	247.801700517798
		ArgOfPericenter	86.959778373087
		MeanAnomaly	333.279298912831
	}
	UniformRotation
	{
		Period	8.865
	}
	LunarLambert	0.5
	Albedo	0.0614
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2983"
}

#1_"2986 Mrinalini:Mrinalini:2525 P-L:1977 QG1:1980 DB4:1986 ET3" "Sol" #1=
#2_"*Мриналини:2986 Mrinalini:Mrinalini:1960-2986*:2525 P-L" "Sol" #2=
#3_"1960-2986*:*Мриналини:2986 Mrinalini:Mrinalini:2525 P-L" "Sol" #3=
".:Mrinalini:2986 Mrinalini:1960-2986*:2525 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.640117891116
		SemiMajorAxis	3.168497141781
		Eccentricity	0.160952300713
		Inclination	2.536968855372
		AscendingNode	51.273433381015
		ArgOfPericenter	303.497909080818
		MeanAnomaly	200.591517149209
	}
	UniformRotation
	{
		Period	15.9
	}
	LunarLambert	0.5
	Albedo	0.0729
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2986"
}

#1_"2987 Sarabhai:Sarabhai:4583 P-L:1978 JY1:1980 UB1:1982 CB" "Sol" #1=
#2_"*Сарабхаи:2987 Sarabhai:Sarabhai:1960-2987*:4583 P-L" "Sol" #2=
#3_"1960-2987*:*Сарабхаи:2987 Sarabhai:Sarabhai:4583 P-L" "Sol" #3=
".:Sarabhai:2987 Sarabhai:1960-2987*:4583 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.985
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.902955957982
		SemiMajorAxis	2.886023478714
		Eccentricity	0.065805344019
		Inclination	1.018906601207
		AscendingNode	167.365007860337
		ArgOfPericenter	337.402969664067
		MeanAnomaly	242.433975144776
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0791
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2987"
}

#1_"2989 Imago:Imago:1976 UF1:1952 JL:1952 KW:1966 UD1:1972 JK:1982 HA2" "Sol" #1=
#2_"*Имаго:2989 Imago:Imago:1976 UF1" "Sol" #2=
#3_"1976 UF1:*Имаго:2989 Imago:Imago" "Sol" #3=
".:Imago:2989 Imago:1976 UF1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.351073669124
		SemiMajorAxis	2.239325275542
		Eccentricity	0.173351614557
		Inclination	3.627202675835
		AscendingNode	75.791106441717
		ArgOfPericenter	247.4330292085
		MeanAnomaly	183.05007118442
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0595
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2989"
}

#1_"2991 Bilbo:Bilbo:1982 HV:1975 JC:1979 SY3:1982 KB2" "Sol" #1=
#2_"*Бильбо:2991 Bilbo:Bilbo:1982 HV" "Sol" #2=
#3_"1982 HV:*Бильбо:2991 Bilbo:Bilbo" "Sol" #3=
".:Bilbo:2991 Bilbo:1982 HV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"2991 bilbo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.909
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.573648707575
		SemiMajorAxis	2.337414700129
		Eccentricity	0.221246688496
		Inclination	5.151119152795
		AscendingNode	96.644103763027
		ArgOfPericenter	198.180896963514
		MeanAnomaly	44.4951190657
	}
	UniformRotation
	{
		Period	4.0637
	}
	LunarLambert	0.5
	Albedo	0.115
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2991"
}

#1_"2993 Wendy:Wendy:1970 PA:1979 YJ2:1981 DG1:A916 QA" "Sol" #1=
#2_"*Венди:2993 Wendy:Wendy:1970 PA" "Sol" #2=
#3_"1970 PA:*Венди:2993 Wendy:Wendy" "Sol" #3=
".:Wendy:2993 Wendy:1970 PA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.32
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.1567219508499
		SemiMajorAxis	2.58520615802257
		Eccentricity	0.1959484193798784
		Inclination	12.29449033358742
		AscendingNode	313.381998728548
		ArgOfPericenter	74.75969275816831
		MeanAnomaly	185.0226300073707
	}
	UniformRotation
	{
		Period	4.42
	}
	LunarLambert	0.5
	Albedo	0.1876
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2993"
}

#1_"2995 Taratuta:Taratuta:1978 QK:1951 JS:1955 FD2:1955 FU:1959 EE" "Sol" #1=
#2_"*Таратута:2995 Taratuta:Taratuta:1978 QK" "Sol" #2=
#3_"1978 QK:*Таратута:2995 Taratuta:Taratuta" "Sol" #3=
".:Taratuta:2995 Taratuta:1978 QK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.295
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.230347495937
		SemiMajorAxis	2.615643556304
		Eccentricity	0.135687556551
		Inclination	14.836312921236
		AscendingNode	169.784180025048
		ArgOfPericenter	329.298931504314
		MeanAnomaly	77.285880706069
	}
	UniformRotation
	{
		Period	6.6
	}
	LunarLambert	0.5
	Albedo	0.0704
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2995"
}

#1_"2996 Bowman:Bowman:1954 RJ:1938 FO:1940 RW:1949 QW1:1956 AC:1961 EE:1977 RF3:1977 TC2:1984 BD" "Sol" #1=
#2_"*Боуман:2996 Bowman:Bowman:1954 RJ" "Sol" #2=
#3_"1954 RJ:*Боуман:2996 Bowman:Bowman" "Sol" #3=
".:Bowman:2996 Bowman:1954 RJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.640472389378
		SemiMajorAxis	2.782078161295
		Eccentricity	0.03328006595
		Inclination	3.666808207826
		AscendingNode	334.439089102342
		ArgOfPericenter	302.790104269626
		MeanAnomaly	70.864013845366
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0689
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2996"
}

#1_"3003 Koncek:Koncek:1983 YH:1937 AE:1938 GH:1951 WR1:1970 HC:1974 DC1:1979 BJ" "Sol" #1=
#2_"*Кончек:3003 Koncek:Koncek:1983 YH" "Sol" #2=
#3_"1983 YH:*Кончек:3003 Koncek:Koncek" "Sol" #3=
".:Koncek:3003 Koncek:1983 YH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.260323523671
		SemiMajorAxis	3.024610823748
		Eccentricity	0.114094447264
		Inclination	11.601669800776
		AscendingNode	103.999480080196
		ArgOfPericenter	283.211906568892
		MeanAnomaly	19.783488062111
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0852
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3003"
}

#1_"3006 Livadia:Livadia:1979 SF11:1956 RQ:1964 YA:1977 DT6" "Sol" #1=
#2_"*Ливадия:3006 Livadia:Livadia:1979 SF11" "Sol" #2=
#3_"1979 SF11:*Ливадия:3006 Livadia:Livadia" "Sol" #3=
".:Livadia:3006 Livadia:1979 SF11" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.798361232868
		SemiMajorAxis	2.434400573538
		Eccentricity	0.187952621755
		Inclination	3.045543596233
		AscendingNode	8.605789706858
		ArgOfPericenter	6.440051391892
		MeanAnomaly	101.254245863339
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0803
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3006"
}

#1_"3009 Coventry:Coventry:1973 SM2:1979 JB:1982 FV3" "Sol" #1=
#2_"*Ковентри:3009 Coventry:Coventry:1973 SM2" "Sol" #2=
#3_"1973 SM2:*Ковентри:3009 Coventry:Coventry" "Sol" #3=
".:Coventry:3009 Coventry:1973 SM2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.04
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.254604949307
		SemiMajorAxis	2.196140151836
		Eccentricity	0.205454947867
		Inclination	4.559100568184
		AscendingNode	8.48817647049
		ArgOfPericenter	316.59772999648
		MeanAnomaly	254.044489595744
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1096
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3009"
}

#New3
#1_"3012 Minsk:Minsk:1979 QU9:1950 SU:1953 GA2:1973 SN2" "Sol" #1=
#2_"*Минск:3012 Minsk:Minsk:1979 QU9" "Sol" #2=
#3_"1979 QU9:*Минск:3012 Minsk:Minsk" "Sol" #3=
".:Minsk:3012 Minsk:1979 QU9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.53
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.804282436244
		SemiMajorAxis	3.229685421761
		Eccentricity	0.067617075874
		Inclination	18.206106321085
		AscendingNode	355.031621183274
		ArgOfPericenter	91.354218572809
		MeanAnomaly	118.735770756195
	}
	UniformRotation
	{
		Period	3.9122
	}
	LunarLambert	0.5
	Albedo	0.174
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3012"
}

#1_"3013 Dobrovoleva:Dobrovoleva:1979 SD7:1981 GS" "Sol" #1=
#2_"*Доброволева:3013 Dobrovoleva:Dobrovoleva:1979 SD7" "Sol" #2=
#3_"1979 SD7:*Доброволева:3013 Dobrovoleva:Dobrovoleva" "Sol" #3=
".:Dobrovoleva:3013 Dobrovoleva:1979 SD7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.51
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.622507146295
		SemiMajorAxis	2.358670991064
		Eccentricity	0.140764209572
		Inclination	3.662157100632
		AscendingNode	7.105156046642
		ArgOfPericenter	94.66554815745
		MeanAnomaly	182.033618799855
	}
	UniformRotation
	{
		Period	8.3025
	}
	LunarLambert	0.5
	Albedo	0.0696
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3013"
}

#1_"3015 Candy:Candy:1980 VN:1974 VL2:1974 XC:1984 HS" "Sol" #1=
#2_"*Канди:3015 Candy:Candy:1980 VN" "Sol" #2=
#3_"1980 VN:Candy:*Канди:3015 Candy" "Sol" #3=
".:Candy:3015 Candy:1980 VN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3015 candy.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	12.258
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	6.229735018822
		SemiMajorAxis	3.385641073283
		Eccentricity	0.173476998755
		Inclination	17.402429858974
		AscendingNode	38.163041752653
		ArgOfPericenter	300.980176387037
		MeanAnomaly	329.087231277339
	}
	UniformRotation
	{
		Period	4.625
	}
	LunarLambert	0.5
	Albedo	0.107
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3015"
}

#1_"3017 Petrovic:Petrovic:1981 UL:1970 CQ" "Sol" #1=
#2_"*Петровик:3017 Petrovic:Petrovic:1981 UL" "Sol" #2=
#3_"1981 UL:*Петровик:3017 Petrovic:Petrovic" "Sol" #3=
".:Petrovic:3017 Petrovic:1981 UL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.975
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.212441099944
		SemiMajorAxis	2.608257267313
		Eccentricity	0.127631078657
		Inclination	11.825621756275
		AscendingNode	257.611513278433
		ArgOfPericenter	216.946965070486
		MeanAnomaly	247.378353421867
	}
	UniformRotation
	{
		Period	4.0803
	}
	LunarLambert	0.5
	Albedo	0.1912
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3017"
}

#1_"3024 Hainan:Hainan:1981 UW9:1943 VG:1949 SD1:1956 VP:1962 WH:1968 TA" "Sol" #1=
#2_"*ХайНань:3024 Hainan:Hainan:1981 UW9" "Sol" #2=
#3_"1981 UW9:*ХайНань:3024 Hainan:Hainan" "Sol" #3=
".:Hainan:3024 Hainan:1981 UW9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.815
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.343834503774
		SemiMajorAxis	3.426855260734
		Eccentricity	0.124269899029
		Inclination	14.762107208757
		AscendingNode	27.76257084648
		ArgOfPericenter	339.801937496261
		MeanAnomaly	108.45077472164
	}
	UniformRotation
	{
		Period	11.746
	}
	LunarLambert	0.5
	Albedo	0.0731
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3024"
}

#1_"3026 Sarastro:Sarastro:1977 TA1:1961 UE:1969 DB:1971 OM1:1975 HA:1982 RQ" "Sol" #1=
#2_"*Сарастро:3026 Sarastro:Sarastro:1977 TA1" "Sol" #2=
#3_"1977 TA1:*Сарастро:3026 Sarastro:Sarastro" "Sol" #3=
".:Sarastro:3026 Sarastro:1977 TA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.272373452689
		SemiMajorAxis	3.029228086671
		Eccentricity	0.024284211447
		Inclination	9.640576851436
		AscendingNode	215.882562934851
		ArgOfPericenter	105.576326416897
		MeanAnomaly	76.284069419989
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0986
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3026"
}

#1_"3027 Shavarsh:Shavarsh:1978 PQ2:1952 SA1:1974 VV" "Sol" #1=
#2_"*Шаварш:3027 Shavarsh:Shavarsh:1978 PQ2" "Sol" #2=
#3_"1978 PQ2:*Шаварш:3027 Shavarsh:Shavarsh" "Sol" #3=
".:Shavarsh:3027 Shavarsh:1978 PQ2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.374514513513
		SemiMajorAxis	2.674737128862
		Eccentricity	0.218417555711
		Inclination	1.963043831191
		AscendingNode	194.658054148884
		ArgOfPericenter	153.98629308278
		MeanAnomaly	100.806408253871
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0585
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3027"
}

#1_"3028 Zhangguoxi:Zhangguoxi:1978 TA2:1931 XP:1941 VD:1949 FB1:1950 LC1:1965 JJ:1970 FL:1970 GQ: #1=
#1_1971 KC1:1983 TO:A902 GC:A904 SG" "Sol" #1=
#2_"*ЧжанГоуСи:3028 Zhangguoxi:Zhangguoxi:1978 TA2" "Sol" #2=
#3_"1978 TA2:*ЧжанГоуСи:3028 Zhangguoxi:Zhangguoxi" "Sol" #3=
".:Zhangguoxi:3028 Zhangguoxi:1978 TA2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.79
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.244860908175
		SemiMajorAxis	3.01868072757
		Eccentricity	0.029954381431
		Inclination	9.520016453376
		AscendingNode	189.530406237046
		ArgOfPericenter	10.50537137021
		MeanAnomaly	161.659267985623
	}
	UniformRotation
	{
		Period	4.826
	}
	LunarLambert	0.5
	Albedo	0.1417
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3028"
}

#1_"3032 Evans:Evans:1984 CA1:1935 FD:1952 VA:1957 TL:1957 UO:1969 BF:1972 XT1:1976 PK:1979 FV2" "Sol" #1=
#2_"*Эванс:3032 Evans:Evans:1984 CA1" "Sol" #2=
#3_"1984 CA1:*Эванс:3032 Evans:Evans" "Sol" #3=
".:Evans:3032 Evans:1984 CA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.485
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.918390288034
		SemiMajorAxis	2.892077037903
		Eccentricity	0.084671086954
		Inclination	3.225623080803
		AscendingNode	88.408326638834
		ArgOfPericenter	275.762272181783
		MeanAnomaly	244.835277144441
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0923
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3032"
}

#1_"3036 Krat:Krat:1937 TO:1931 TH4:1952 HY1:1958 HB:1966 VK:1977 RQ:1977 TY6" "Sol" #1=
#2_"*Крат:3036 Krat:Krat:1937 TO" "Sol" #2=
#3_"1937 TO:*Крат:3036 Krat:Krat" "Sol" #3=
".:Krat:3036 Krat:1937 TO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	21.195
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.759851795805
		SemiMajorAxis	3.213182584708
		Eccentricity	0.097779533457
		Inclination	22.864931923928
		AscendingNode	23.737885489565
		ArgOfPericenter	319.526048165857
		MeanAnomaly	171.506499782588
	}
	UniformRotation
	{
		Period	9.61
	}
	LunarLambert	0.5
	Albedo	0.1182
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3036"
}

#1_"3037 Alku:Alku:1944 BA:1979 BH" "Sol" #1=
#2_"*Алку:3037 Alku:Alku:1944 BA" "Sol" #2=
#3_"1944 BA:*Алку:3037 Alku:Alku" "Sol" #3=
".:Alku:3037 Alku:1944 BA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.455
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.368034521373
		SemiMajorAxis	2.672095074542
		Eccentricity	0.189954461874
		Inclination	19.026829395802
		AscendingNode	107.806328543494
		ArgOfPericenter	330.41159549
		MeanAnomaly	103.477413576439
	}
	UniformRotation
	{
		Period	11.844
	}
	LunarLambert	0.5
	Albedo	0.1131
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3037"
}

#1_"3044 Saltykov:Saltykov:1983 RE3:1978 NS3:1978 QG:1979 XP1" "Sol" #1=
#2_"*Салтыков:3044 Saltykov:Saltykov:1983 RE3" "Sol" #2=
#3_"1983 RE3:*Салтыков:3044 Saltykov:Saltykov" "Sol" #3=
".:Saltykov:3044 Saltykov:1983 RE3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.855
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.823461846993
		SemiMajorAxis	2.85474352728
		Eccentricity	0.158548716175
		Inclination	13.490480032888
		AscendingNode	242.396203557134
		ArgOfPericenter	70.86107285033
		MeanAnomaly	202.082071870005
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0594
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3044"
}

#1_"3046 Moliere:Moliere:4120 P-L:1982 RC1" "Sol" #1=
#2_"*Мольер:3046 Moliere:Moliere:1960-3046*:4120 P-L" "Sol" #2=
#3_"1960-3046*:*Мольер:3046 Moliere:Moliere:4120 P-L" "Sol" #3=
".:Moliere:3046 Moliere:1960-3046*:4120 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.18
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.566514796349
		SemiMajorAxis	3.140871077254
		Eccentricity	0.144630666959
		Inclination	18.383255277077
		AscendingNode	188.46601600954
		ArgOfPericenter	264.631239262337
		MeanAnomaly	211.64545172845
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0562
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3046"
}

#1_"3051 Nantong:Nantong:1974 YP:1954 BE:1961 TA2:1982 WH" "Sol" #1=
#2_"*НаньТун:3051 Nantong:Nantong:1974 YP" "Sol" #2=
#3_"1974 YP:*НаньТун:3051 Nantong:Nantong" "Sol" #3=
".:Nantong:3051 Nantong:1974 YP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.175579333732
		SemiMajorAxis	2.593018954903
		Eccentricity	0.258111737483
		Inclination	13.358368278924
		AscendingNode	280.18481654499
		ArgOfPericenter	93.461216230533
		MeanAnomaly	264.953763905747
	}
	UniformRotation
	{
		Period	3.69
	}
	LunarLambert	0.5
	Albedo	0.0752
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3051"
}

#1_"3052 Herzen:Herzen:1976 YJ3:1952 HH3:1972 TE4" "Sol" #1=
#2_"*Герцен:3052 Herzen:Herzen:1976 YJ3" "Sol" #2=
#3_"1976 YJ3:*Герцен:3052 Herzen:Herzen" "Sol" #3=
".:Herzen:3052 Herzen:1976 YJ3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.59
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.65789741563
		SemiMajorAxis	2.374008190383
		Eccentricity	0.18320721706
		Inclination	3.898831911277
		AscendingNode	238.547580277719
		ArgOfPericenter	279.122133146419
		MeanAnomaly	85.277703364798
	}
	UniformRotation
	{
		Period	11.605
	}
	LunarLambert	0.5
	Albedo	0.0441
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3052"
}

#1_"3054 Strugatskia:Strugatskia:1977 RE7:1928 UC:1959 JQ:1960 OE:1961 VG" "Sol" #1=
#2_"*Стругацкия:3054 Strugatskia:Strugatskia:1977 RE7" "Sol" #2=
#3_"1977 RE7:*Стругацкия:3054 Strugatskia:Strugatskia" "Sol" #3=
".:Strugatskia:3054 Strugatskia:1977 RE7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.57
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.442737017612
		SemiMajorAxis	3.094136237889
		Eccentricity	0.210891218888
		Inclination	2.07988869585
		AscendingNode	146.262878375251
		ArgOfPericenter	187.728873342667
		MeanAnomaly	318.404809988124
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0845
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3054"
}

#1_"3056 INAG:INAG:1978 VD1:1925 SB:1929 UN:1955 QU:1980 DW4:1984 FD:A914 TD" "Sol" #1=
#2_"INAG:3056 INAG:1978 VD1" "Sol" #2=
#3_"1978 VD1:INAG:3056 INAG" "Sol" #3=
".:INAG:3056 INAG:1978 VD1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.655
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.762606566657
		SemiMajorAxis	2.419099534522
		Eccentricity	0.116913295601
		Inclination	5.636534912649
		AscendingNode	11.382513286189
		ArgOfPericenter	346.426745744974
		MeanAnomaly	254.986890256939
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0408
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3056"
}

#1_"3062 Wren:Wren:1982 XC:1942 EF1:1950 TQ2:1953 GG1:1955 RP1:1959 LJ:1981 NP1" "Sol" #1=
#2_"*Рен:3062 Wren:Wren:1982 XC" "Sol" #2=
#3_"1982 XC:*Рен:3062 Wren:Wren" "Sol" #3=
".:Wren:3062 Wren:1982 XC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.485
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.254019712293
		SemiMajorAxis	3.022193939919
		Eccentricity	0.110486088967
		Inclination	11.336990225365
		AscendingNode	110.368585724644
		ArgOfPericenter	272.081122771837
		MeanAnomaly	81.788524213005
	}
	UniformRotation
	{
		Period	7.097
	}
	LunarLambert	0.5
	Albedo	0.1357
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3062"
}

#1_"3063 Makhaon:Makhaon:1983 PV:1931 DT:1964 YL:1971 OE:1971 QK1:1975 VT6" "Sol" #1=
#2_"*Махаон:3063 Makhaon:Makhaon:1983 PV" "Sol" #2=
#3_"1983 PV:*Махаон:3063 Makhaon:Makhaon" "Sol" #3=
".:Makhaon:3063 Makhaon:1983 PV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58.07
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.865889411445
		SemiMajorAxis	5.202292052153
		Eccentricity	0.059743868635
		Inclination	12.16616687888
		AscendingNode	287.876607524243
		ArgOfPericenter	204.87352690465
		MeanAnomaly	69.025305214123
	}
	UniformRotation
	{
		Period	8.64
	}
	LunarLambert	0.5
	Albedo	0.0476
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3063"
}

#1_"3078 Horrocks:Horrocks:1984 FG:1964 TS1:1970 SE1:1973 GS:1976 YX6:1978 ET4:1982 YQ1" "Sol" #1=
#2_"*Хоррокс:3078 Horrocks:Horrocks:1984 FG" "Sol" #2=
#3_"1984 FG:*Хоррокс:3078 Horrocks:Horrocks" "Sol" #3=
".:Horrocks:3078 Horrocks:1984 FG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.588628654957
		SemiMajorAxis	3.149183983319
		Eccentricity	0.10159987085
		Inclination	7.095325520809
		AscendingNode	32.476856143781
		ArgOfPericenter	141.726129775666
		MeanAnomaly	184.591454468015
	}
	UniformRotation
	{
		Period	13.62
	}
	LunarLambert	0.5
	Albedo	0.0452
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3078"
}

#1_"3082 Dzhalil:Dzhalil:1972 KE:1936 XB:1972 LJ:1983 BB" "Sol" #1=
#2_"*Джалиль:3082 Dzhalil:Dzhalil:1972 KE" "Sol" #2=
#3_"1972 KE:*Джалиль:3082 Dzhalil:Dzhalil" "Sol" #3=
".:Dzhalil:3082 Dzhalil:1972 KE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.325
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.137511484633
		SemiMajorAxis	2.577234917187
		Eccentricity	0.076211893005
		Inclination	10.333981851999
		AscendingNode	117.667305387246
		ArgOfPericenter	230.901682158576
		MeanAnomaly	15.581193717988
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0766
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3082"
}

#1_"3086 Kalbaugh:Kalbaugh:1980 XE:1980 YD" "Sol" #1=
#2_"*Калбауг:3086 Kalbaugh:Kalbaugh:1980 XE" "Sol" #2=
#3_"1980 XE:Kalbaugh:*Калбауг:3086 Kalbaugh" "Sol" #3=
".:Kalbaugh:3086 Kalbaugh:1980 XE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3086 kalbaugh.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.39
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.693000108123
		SemiMajorAxis	1.935614108851
		Eccentricity	0.026560483589
		Inclination	19.003546501827
		AscendingNode	300.771988759327
		ArgOfPericenter	281.540497403448
		MeanAnomaly	42.567501337543
	}
	UniformRotation
	{
		Period	5.18
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3086"
}

#1_"3089 Oujianquan:Oujianquan:1981 XK2:1934 NF:1944 MD:1964 LA:1974 ML:1976 YU2" "Sol" #1=
#2_"*ОуЦзяньЦюань:3089 Oujianquan:Oujianquan:1981 XK2" "Sol" #2=
#3_"1981 XK2:*ОуЦзяньЦюань:3089 Oujianquan:Oujianquan" "Sol" #3=
".:Oujianquan:3089 Oujianquan:1981 XK2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.86
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.016138409439
		SemiMajorAxis	2.930269329354
		Eccentricity	0.186030192154
		Inclination	16.694806227529
		AscendingNode	88.241515707103
		ArgOfPericenter	184.593396751882
		MeanAnomaly	20.752826852786
	}
	UniformRotation
	{
		Period	11.198
	}
	LunarLambert	0.5
	Albedo	0.0618
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3089"
}

#1_"3092 Herodotus:Herodotus:6550 P-L:1980 TH10:1983 CC1:A907 VN" "Sol" #1=
#2_"*Геродот:3092 Herodotus:Herodotus:1960-3092*:6550 P-L" "Sol" #2=
#3_"1960-3092*:*Геродот:3092 Herodotus:Herodotus:6550 P-L" "Sol" #3=
".:Herodotus:3092 Herodotus:1960-3092*:6550 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.535
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.631119215165
		SemiMajorAxis	3.529547972101
		Eccentricity	0.121885576043
		Inclination	10.941261409099
		AscendingNode	8.58170388524
		ArgOfPericenter	3.402191095005
		MeanAnomaly	39.519568167878
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0572
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3092"
}

#1_"3094 Chukokkala:Chukokkala:1979 FE2:1936 HG:1949 HR1:1968 UM1:1983 CE3" "Sol" #1=
#2_"*Чукоккала:3094 Chukokkala:Chukokkala:1979 FE2" "Sol" #2=
#3_"1979 FE2:*Чукоккала:3094 Chukokkala:Chukokkala" "Sol" #3=
".:Chukokkala:3094 Chukokkala:1979 FE2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.309927284649
		SemiMajorAxis	2.648344596315
		Eccentricity	0.073140630147
		Inclination	14.562537855708
		AscendingNode	172.484618670721
		ArgOfPericenter	51.573344299654
		MeanAnomaly	66.542535291579
	}
	UniformRotation
	{
		Period	8.3711
	}
	LunarLambert	0.5
	Albedo	0.0555
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3094"
}

#1_"3097 Tacitus:Tacitus:2011 P-L:1965 SX:1975 TL:1979 MH9:1980 RW2:1980 TR6" "Sol" #1=
#2_"*Тацит:3097 Tacitus:Tacitus:1960-3097*:2011 P-L" "Sol" #2=
#3_"1960-3097*:*Тацит:3097 Tacitus:Tacitus:2011 P-L" "Sol" #3=
".:Tacitus:3097 Tacitus:1960-3097*:2011 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3097 tacitus.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	10.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	5.014203170979
		SemiMajorAxis	2.929515610837
		Eccentricity	0.090023089727
		Inclination	7.46553335244
		AscendingNode	196.767742290952
		ArgOfPericenter	88.117925931007
		MeanAnomaly	44.04945979005
	}
	UniformRotation
	{
		Period	7.417
	}
	LunarLambert	0.5
	Albedo	0.054
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3097"
}

#1_"3102 Krok:Krok:1981 QA" "Sol" #1=
#2_"*Крок:3102 Krok:Krok:1981 QA" "Sol" #2=
#3_"1981 QA:*Крок:3102 Krok:Krok" "Sol" #3=
".:Krok:3102 Krok:1981 QA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.1570734504906
		SemiMajorAxis	2.152043220283979
		Eccentricity	0.4489021390146284
		Inclination	8.437090374873552
		AscendingNode	172.0915022517466
		ArgOfPericenter	154.7155130571668
		MeanAnomaly	196.9668913049919
	}
	UniformRotation
	{
		Period	149.4
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3102"
}

#1_"3103 Eger:Eger:1982 BB" "Sol" #1=
#2_"*Эгер:3103 Eger:Eger:1982 BB" "Sol" #2=
#3_"1982 BB:*Эгер:3103 Eger:Eger" "Sol" #3=
".:Eger:3103 Eger:1982 BB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3103 eger.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"steins.jpg"
	Radius	0.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.664605258644
		SemiMajorAxis	1.404544079216
		Eccentricity	0.354225488484
		Inclination	20.932304196566
		AscendingNode	129.798245949598
		ArgOfPericenter	253.992952463148
		MeanAnomaly	331.779065736981
	}
	UniformRotation
	{
		Period	5.7059
		Inclination	140
		AscendingNode	100
	}
	LunarLambert	0.5
	Albedo	0.64
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3103"
}

#1_"3104 Durer:Durer:1982 BB1:1955 XG1:1980 VM2" "Sol" #1=
#2_"*Дюрер:3104 Durer:Durer:1982 BB1" "Sol" #2=
#3_"1982 BB1:*Дюрер:3104 Durer:Durer" "Sol" #3=
".:Durer:3104 Durer:1982 BB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.10390631867
		SemiMajorAxis	2.9643512426
		Eccentricity	0.089371211054
		Inclination	24.163198840826
		AscendingNode	162.225338607016
		ArgOfPericenter	242.524390141392
		MeanAnomaly	240.021460714929
	}
	UniformRotation
	{
		Period	6.327
	}
	LunarLambert	0.5
	Albedo	0.1858
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3104"
}

#1_"3109 Machin:Machin:1974 DC:1930 YL:1936 HA:1956 SB:1964 VF1:1974 DO1:1974 FB1:1978 GZ2: #1=
#1_1979 OQ14:1982 FO3:A924 EB" "Sol" #1=
#2_"*Махин:3109 Machin:Machin:1974 DC" "Sol" #2=
#3_"1974 DC:*Махин:3109 Machin:Machin" "Sol" #3=
".:Machin:3109 Machin:1974 DC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.47
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.836098659277
		SemiMajorAxis	2.450498140137
		Eccentricity	0.089508990846
		Inclination	7.182142492147
		AscendingNode	22.799500206541
		ArgOfPericenter	256.462127181957
		MeanAnomaly	110.091005373453
	}
	UniformRotation
	{
		Period	20.3
	}
	LunarLambert	0.5
	Albedo	0.0769
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3109"
}

#1_"3115 Baily:Baily:1981 PL:1954 AF:1961 XT" "Sol" #1=
#2_"*Бейли:3115 Baily:Baily:1981 PL" "Sol" #2=
#3_"1981 PL:*Бейли:3115 Baily:Baily" "Sol" #3=
".:Baily:3115 Baily:1981 PL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.02
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.145717033462
		SemiMajorAxis	2.580641255057
		Eccentricity	0.141062282948
		Inclination	10.168429437414
		AscendingNode	258.718712534331
		ArgOfPericenter	171.753348556223
		MeanAnomaly	282.098964277422
	}
	UniformRotation
	{
		Period	16.22
	}
	LunarLambert	0.5
	Albedo	0.1639
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3115"
}

#1_"3118 Claytonsmith:Claytonsmith:1974 OD:1938 XH:1948 OK:1951 AP:1957 EM:1957 EP:1969 OZ:1974 QX2: #1=
#1_1978 ED8:1982 YF" "Sol" #1=
#2_"*Клайтонсмит:3118 Claytonsmith:Claytonsmith:1974 OD" "Sol" #2=
#3_"1974 OD:*Клайтонсмит:3118 Claytonsmith:Claytonsmith" "Sol" #3=
".:Claytonsmith:3118 Claytonsmith:1974 OD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.43
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.296698492563
		SemiMajorAxis	3.038538194647
		Eccentricity	0.059153918373
		Inclination	13.267498734173
		AscendingNode	304.934917846415
		ArgOfPericenter	257.661115847423
		MeanAnomaly	306.613290530628
	}
	UniformRotation
	{
		Period	15.794
	}
	LunarLambert	0.5
	Albedo	0.0714
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3118"
}

#1_"3122 Florence:Florence:1981 ET3:1983 CN1" "Sol" #1=
#2_"*Флоренс:3122 Florence:Florence:1981 ET3" "Sol" #2=
#3_"1981 ET3:*Флоренс:3122 Florence:Florence" "Sol" #3=
".:Florence:3122 Florence:1981 ET3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	2.353145191896
		SemiMajorAxis	1.76913244843
		Eccentricity	0.423300373462
		Inclination	22.150779939152
		AscendingNode	336.095130831665
		ArgOfPericenter	27.846984479559
		MeanAnomaly	351.438515983014
	}
	UniformRotation
	{
		Period	2.3581
	}
	LunarLambert	0.5
	Albedo	0.231
	InfoURL	"https://en.wikipedia.org/wiki/3122_Florence"
}

#New4
#1_"2017 3122 II" "Sol/3122 Florence" #1=
#2_"2017 3122 II" "Sol" #2=
#3_"2017 3122 II" "Sol" #3=
".:2017 3122 II" "Sol" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.3
		SemiMajorAxis	4.7
	}
	LunarLambert	0.5
	Albedo	0.231
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-03122.html"
}

#New4
#1_"2017 3122 I" "Sol/3122 Florence" #1=
#2_"2017 3122 I" "Sol" #2=
#3_"2017 3122 I" "Sol" #3=
".:2017 3122 I" "Sol" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	1.0
		SemiMajorAxis	9.8
	}
	LunarLambert	0.5
	Albedo	0.231
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-03122.html"
}

#1_"3132 Landgraf:Landgraf:1940 WL:1929 WU:1973 UF3:1975 BC:1977 KQ:1978 NO2:1978 PE1:1978 SH: #1=
#1_1981 CT" "Sol" #1=
#2_"*Ландграф:3132 Landgraf:Landgraf:1940 WL" "Sol" #2=
#3_"1940 WL:*Ландграф:3132 Landgraf:Landgraf" "Sol" #3=
".:Landgraf:3132 Landgraf:1940 WL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.595129461771
		SemiMajorAxis	3.151625640125
		Eccentricity	0.12446417047
		Inclination	4.457756782961
		AscendingNode	113.037983130944
		ArgOfPericenter	266.552243869563
		MeanAnomaly	120.564886611837
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0564
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3132"
}

#1_"3134 Kostinsky:Kostinsky:A921 VA:1929 WK:1931 DO:1952 ST:1976 UT3:1978 CO" "Sol" #1=
#2_"*Костинский:3134 Kostinsky:Kostinsky:1921 VA" "Sol" #2=
#3_"1921 VA:*Костинский:3134 Kostinsky:Kostinsky" "Sol" #3=
".:Kostinsky:3134 Kostinsky:1921 VA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.956572887755
		SemiMajorAxis	3.98546098658
		Eccentricity	0.221719723775
		Inclination	7.639642202404
		AscendingNode	257.000244634846
		ArgOfPericenter	163.360495022178
		MeanAnomaly	283.407276109217
	}
	UniformRotation
	{
		Period	14.7
	}
	LunarLambert	0.5
	Albedo	0.0371
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3134"
}

#1_"3139 Shantou:Shantou:1980 VL1:1963 YC" "Sol" #1=
#2_"*ШаньТоу:3139 Shantou:Shantou:1980 VL1" "Sol" #2=
#3_"1980 VL1:*ШаньТоу:3139 Shantou:Shantou" "Sol" #3=
".:Shantou:3139 Shantou:1980 VL1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.625
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.706875416064
		SemiMajorAxis	3.193450040969
		Eccentricity	0.022846245594
		Inclination	20.534451192713
		AscendingNode	252.916647503439
		ArgOfPericenter	106.657098219923
		MeanAnomaly	42.088040572699
	}
	UniformRotation
	{
		Period	8.33
	}
	LunarLambert	0.5
	Albedo	0.0598
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3139"
}

#1_"3140 Stellafane:Stellafane:1983 AO:1949 PA:1952 DR1:1962 CP:1976 UW3:1978 EU3:1979 HR5" "Sol" #1=
#2_"*Стеллафане:3140 Stellafane:Stellafane:1983 AO" "Sol" #2=
#3_"1983 AO:*Стеллафане:3140 Stellafane:Stellafane" "Sol" #3=
".:Stellafane:3140 Stellafane:1983 AO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.375
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.247786735188
		SemiMajorAxis	3.019803263427
		Eccentricity	0.107698095247
		Inclination	11.263410223832
		AscendingNode	101.62062954398
		ArgOfPericenter	268.577827878858
		MeanAnomaly	125.757677440796
	}
	UniformRotation
	{
		Period	19.23
	}
	LunarLambert	0.5
	Albedo	0.1259
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3140"
}

#1_"3141 Buchar:Buchar:1984 RH:1952 PE:1952 RQ:1953 UF:1953 VK2:1977 NM:1977 OE:1979 YW9:A905 CE" "Sol" #1=
#2_"*Бухар:3141 Buchar:Buchar:1984 RH" "Sol" #2=
#3_"1984 RH:*Бухар:3141 Buchar:Buchar" "Sol" #3=
".:Buchar:3141 Buchar:1984 RH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.025
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.269907465783
		SemiMajorAxis	3.400180346324
		Eccentricity	0.077253962449
		Inclination	10.99694116949
		AscendingNode	321.14970424154
		ArgOfPericenter	152.195588865905
		MeanAnomaly	181.778166584298
	}
	UniformRotation
	{
		Period	11.41
	}
	LunarLambert	0.5
	Albedo	0.0858
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3141"
}

#1_"3150 Tosa:Tosa:1983 CB:1966 FB:1968 QE1:1971 BX1:1982 DQ2" "Sol" #1=
#2_"*Тоса:3150 Tosa:Tosa:1983 CB" "Sol" #2=
#3_"1983 CB:*Тоса:3150 Tosa:Tosa" "Sol" #3=
".:Tosa:3150 Tosa:1983 CB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.175
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.72355161718
		SemiMajorAxis	3.199668121065
		Eccentricity	0.118464243824
		Inclination	22.075719392176
		AscendingNode	350.329768019203
		ArgOfPericenter	272.846570491168
		MeanAnomaly	111.580618436021
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0875
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3150"
}

#1_"3152 Jones:Jones:1983 LF:1951 YC:1980 TP8" "Sol" #1=
#2_"*Джонс:3152 Jones:Jones:1983 LF" "Sol" #2=
#3_"1983 LF:*Джонс:3152 Jones:Jones" "Sol" #3=
".:Jones:3152 Jones:1983 LF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.59
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.254800461384
		SemiMajorAxis	2.625713458817
		Eccentricity	0.09082167562
		Inclination	11.310914077487
		AscendingNode	301.471598048387
		ArgOfPericenter	290.254556097134
		MeanAnomaly	134.9734154097
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0485
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3152"
}

#1_"3156 Ellington:Ellington:1953 EE:1934 GV:1953 FD1:1970 RH:1982 FL:1982 GA" "Sol" #1=
#2_"*Эллингтон:3156 Ellington:Ellington:1953 EE" "Sol" #2=
#3_"1953 EE:*Эллингтон:3156 Ellington:Ellington" "Sol" #3=
".:Ellington:3156 Ellington:1953 EE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.83
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.825284800005
		SemiMajorAxis	2.85546275284
		Eccentricity	0.1974514285
		Inclination	15.806710898037
		AscendingNode	6.970141403542
		ArgOfPericenter	119.65230104
		MeanAnomaly	320.984061468922
	}
	UniformRotation
	{
		Period	8.33
	}
	LunarLambert	0.5
	Albedo	0.0698
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3156"
}

#1_"3157 Novikov:Novikov:1973 SX3:1957 YO:1976 GN4:1979 VG3:1982 HX2" "Sol" #1=
#2_"*Новиков:3157 Novikov:Novikov:1973 SX3" "Sol" #2=
#3_"1973 SX3:*Новиков:3157 Novikov:Novikov" "Sol" #3=
".:Novikov:3157 Novikov:1973 SX3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.895
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.60721881911
		SemiMajorAxis	3.156163803919
		Eccentricity	0.143453014449
		Inclination	7.58603079248
		AscendingNode	41.774259705531
		ArgOfPericenter	322.209685101651
		MeanAnomaly	134.871908028003
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3157"
}

#1_"3161 Beadell:Beadell:1980 TB5" "Sol" #1=
#2_"*Беделл:3161 Beadell:Beadell:1980 TB5" "Sol" #2=
#3_"1980 TB5:*Беделл:3161 Beadell:Beadell" "Sol" #3=
".:Beadell:3161 Beadell:1980 TB5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.26
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.124307934486
		SemiMajorAxis	2.571749047252
		Eccentricity	0.170995832247
		Inclination	14.932229785531
		AscendingNode	351.583319391318
		ArgOfPericenter	255.540126267993
		MeanAnomaly	212.128225470565
	}
	UniformRotation
	{
		Period	36.253
	}
	LunarLambert	0.5
	Albedo	0.1629
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3161"
}

#1_"3162 Nostalgia:Nostalgia:1980 YH" "Sol" #1=
#2_"*Ностальгия:3162 Nostalgia:Nostalgia:1980 YH" "Sol" #2=
#3_"1980 YH:*Ностальгия:3162 Nostalgia:Nostalgia" "Sol" #3=
".:Nostalgia:3162 Nostalgia:1980 YH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.548
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.612300344862
		SemiMajorAxis	3.15807035887
		Eccentricity	0.155651925051
		Inclination	17.918520125572
		AscendingNode	128.685233836666
		ArgOfPericenter	316.525579767103
		MeanAnomaly	43.282448952837
	}
	UniformRotation
	{
		Period	6.412
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3162"
}

#1_"3164 Prast:Prast:6562 P-L:1971 SW:1972 VX:1979 BX1" "Sol" #1=
#2_"*Праст:3164 Prast:Prast:1960-3164*:6562 P-L" "Sol" #2=
#3_"1960-3164*:*Праст:3164 Prast:Prast:6562 P-L" "Sol" #3=
".:Prast:3164 Prast:1960-3164*:6562 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.545
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.626109543775
		SemiMajorAxis	3.163248575114
		Eccentricity	0.153517361306
		Inclination	2.339540241168
		AscendingNode	64.486778510563
		ArgOfPericenter	55.292864385819
		MeanAnomaly	153.478224117115
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0843
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3164"
}

#1_"3167 Babcock:Babcock:1955 RS:1943 TH:1955 SC2:1966 FF:1971 QL1:1971 SB4:1974 FS:1974 HB1:1979 SX1" "Sol" #1=
#2_"*Бэбкок:3167 Babcock:Babcock:1955 RS" "Sol" #2=
#3_"1955 RS:*Бэбкок:3167 Babcock:Babcock" "Sol" #3=
".:Babcock:3167 Babcock:1955 RS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.135
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.050620152471
		SemiMajorAxis	2.541024648745
		Eccentricity	0.106385649424
		Inclination	15.563039829368
		AscendingNode	17.649861904633
		ArgOfPericenter	257.842440997988
		MeanAnomaly	303.660073956096
	}
	UniformRotation
	{
		Period	15.45
	}
	LunarLambert	0.5
	Albedo	0.3233
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3167"
}

#1_"3168 Lomnicky Stit:Lomnicky Stit:1980 XM:1952 HA3" "Sol" #1=
#2_"*Ломницкий Штит:3168 Lomnicky Stit:Lomnicky Stit:1980 XM" "Sol" #2=
#3_"1980 XM:*Ломницкий Штит:3168 Lomnicky Stit:Lomnicky Stit" "Sol" #3=
".:Lomnicky Stit:3168 Lomnicky Stit:1980 XM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.175076476922
		SemiMajorAxis	2.991844700507
		Eccentricity	0.099630888513
		Inclination	10.543171469555
		AscendingNode	22.736007384304
		ArgOfPericenter	286.589252601242
		MeanAnomaly	309.549992511837
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0535
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3168"
}

#1_"3170 Dzhanibekov:Dzhanibekov:1979 SS11:1966 DV:1971 DW:1974 ST4" "Sol" #1=
#2_"*Джанибеков:3170 Dzhanibekov:Dzhanibekov:1979 SS11" "Sol" #2=
#3_"1979 SS11:*Джанибеков:3170 Dzhanibekov:Dzhanibekov" "Sol" #3=
".:Dzhanibekov:3170 Dzhanibekov:1979 SS11" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3170 dzhanibekov.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.798
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	5.010189473528
		SemiMajorAxis	2.927952084435
		Eccentricity	0.085999898663
		Inclination	2.018113394634
		AscendingNode	26.806622928167
		ArgOfPericenter	80.76501633324
		MeanAnomaly	334.638475098192
	}
	UniformRotation
	{
		Period	6.0724
	}
	LunarLambert	0.5
	Albedo	0.304
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3170"
}

#1_"3176 Paolicchi:Paolicchi:1980 VR1:1931 UP:1941 WC:1941 WG1:1951 XF1:1956 XD:1965 UD:1968 HM1: #1=
#1_1975 XU:1978 JG:1978 LQ:A902 WG" "Sol" #1=
#2_"*Паоликчи:3176 Paolicchi:Paolicchi:1980 VR1" "Sol" #2=
#3_"1980 VR1:*Паоликчи:3176 Paolicchi:Paolicchi" "Sol" #3=
".:Paolicchi:3176 Paolicchi:1980 VR1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.97
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.875790836515
		SemiMajorAxis	2.875353486465
		Eccentricity	0.029577800318
		Inclination	18.09683652668
		AscendingNode	53.292207250427
		ArgOfPericenter	24.291365144979
		MeanAnomaly	329.81921159875
	}
	UniformRotation
	{
		Period	20.4
	}
	LunarLambert	0.5
	Albedo	0.0669
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3176"
}

#1_"3197 Weissman:Weissman:1981 AD:1971 UO3" "Sol" #1=
#2_"*Вайсман:3197 Weissman:Weissman:1981 AD" "Sol" #2=
#3_"1981 AD:*Вайсман:3197 Weissman:Weissman" "Sol" #3=
".:Weissman:3197 Weissman:1981 AD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.354539179313
		SemiMajorAxis	2.666588489348
		Eccentricity	0.179048402714
		Inclination	16.409801743623
		AscendingNode	111.775733047328
		ArgOfPericenter	313.218119170567
		MeanAnomaly	318.322123512279
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.079
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3197"
}

#1_"3199 Nefertiti:Nefertiti:1982 RA" "Sol" #1=
#2_"*Нефертити:3199 Nefertiti:Nefertiti:1982 RA" "Sol" #2=
#3_"1982 RA:*Нефертити:3199 Nefertiti:Nefertiti" "Sol" #3=
".:Nefertiti:3199 Nefertiti:1982 RA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.97584671477
		SemiMajorAxis	1.574575046732
		Eccentricity	0.283908682789
		Inclination	32.96774389688
		AscendingNode	340.022941318929
		ArgOfPericenter	53.399772014522
		MeanAnomaly	83.028051308533
	}
	UniformRotation
	{
		Period	3.021
	}
	LunarLambert	0.5
	Albedo	0.42
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3199"
}

#1_"3200 Phaethon:Phaethon:1983 TB" "Sol" #1=
#2_"*Фаэтон:3200 Phaethon:Phaethon:1983 TB" "Sol" #2=
#3_"1983 TB:*Фаэтон:3200 Phaethon:Phaethon" "Sol" #3=
".:Phaethon:3200 Phaethon:1983 TB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3200 phaethon.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"pallas.jpg"
	Radius	3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	1.43327106798
		SemiMajorAxis	1.271198645218
		Eccentricity	0.889936459308
		Inclination	22.253193283858
		AscendingNode	265.23067167599
		ArgOfPericenter	322.17362561944
		MeanAnomaly	261.424720922393
	}
	UniformRotation
	{
		Period	3.604
	}
	LunarLambert	0.5
	Albedo	0.1066
	InfoURL	"https://en.wikipedia.org/wiki/3200_Phaethon"
}

#New3
#1_"3213 Smolensk:Smolensk:1977 NQ:1980 BJ5:1983 PL" "Sol" #1=
#2_"*Смоленск:3213 Smolensk:Smolensk:1977 NQ" "Sol" #2=
#3_"1977 NQ:*Смоленск:3213 Smolensk:Smolensk" "Sol" #3=
".:Smolensk:3213 Smolensk:1977 NQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.86
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.720338730902
		SemiMajorAxis	3.198470597509
		Eccentricity	0.159345601161
		Inclination	0.955292176046
		AscendingNode	33.730965886476
		ArgOfPericenter	325.992684926542
		MeanAnomaly	311.178468219358
	}
	UniformRotation
	{
		Period	3.564
	}
	LunarLambert	0.5
	Albedo	0.074
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3213"
}

#1_"3222 Liller:Liller:1983 NJ:1935 TJ:1975 BA:1982 HQ" "Sol" #1=
#2_"*Лиллер:3222 Liller:Liller:1983 NJ" "Sol" #2=
#3_"1983 NJ:*Лиллер:3222 Liller:Liller" "Sol" #3=
".:Liller:3222 Liller:1983 NJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.975
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.427317104355
		SemiMajorAxis	3.088289440677
		Eccentricity	0.061978556297
		Inclination	15.979659429424
		AscendingNode	150.845610045498
		ArgOfPericenter	129.470150844018
		MeanAnomaly	300.978002050532
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0543
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3222"
}

#1_"3223 Forsius:Forsius:1942 RN:1932 HN:1934 VP:1940 GS:1951 YB1:1957 JC:1967 RC:1979 OU14:1980 RD5: #1=
#1_1982 DA3:1982 DK6:A915 GD" "Sol" #1=
#2_"*Форсиус:3223 Forsius:Forsius:1942 RN" "Sol" #2=
#3_"1942 RN:*Форсиус:3223 Forsius:Forsius" "Sol" #3=
".:Forsius:3223 Forsius:1942 RN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.207377300488
		SemiMajorAxis	2.606166581017
		Eccentricity	0.143157549358
		Inclination	10.061324598213
		AscendingNode	168.189954626262
		ArgOfPericenter	294.024578053617
		MeanAnomaly	328.77184410574
	}
	UniformRotation
	{
		Period	2.343
	}
	LunarLambert	0.5
	Albedo	0.1365
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3223"
}

#1_"3224 Irkutsk:Irkutsk:1977 RL6:1952 DE2:1953 NF:1953 PH:1957 HN:1966 DP:1971 KR:1978 YX1:1982 TS: #1=
#1_1984 AL" "Sol" #1=
#2_"*Иркутск:3224 Irkutsk:Irkutsk:1977 RL6" "Sol" #2=
#3_"1977 RL6:*Иркутск:3224 Irkutsk:Irkutsk" "Sol" #3=
".:Irkutsk:3224 Irkutsk:1977 RL6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.56
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.639947350264
		SemiMajorAxis	2.781868308034
		Eccentricity	0.167752168056
		Inclination	4.315548997014
		AscendingNode	227.864436825481
		ArgOfPericenter	4.238446777352
		MeanAnomaly	130.965787584929
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0551
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3224"
}

#1_"3230 Vampilov:Vampilov:1972 LE:1979 YA3:1983 JJ" "Sol" #1=
#2_"*Вампилов:3230 Vampilov:Vampilov:1972 LE" "Sol" #2=
#3_"1972 LE:*Вампилов:3230 Vampilov:Vampilov" "Sol" #3=
".:Vampilov:3230 Vampilov:1972 LE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.607774102374
		SemiMajorAxis	3.156372170558
		Eccentricity	0.320248701769
		Inclination	15.294040289691
		AscendingNode	74.081497737434
		ArgOfPericenter	243.744612309585
		MeanAnomaly	189.829001720734
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0423
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3230"
}

#New3
#1_"3232 Brest:Brest:1974 SL:1946 GE:1951 ER:1964 VN:1969 TS5:1974 TO:1979 SB3:1983 HM" "Sol" #1=
#2_"*Брест:3232 Brest:Brest:1974 SL" "Sol" #2=
#3_"1974 SL:*Брест:3232 Brest:Brest" "Sol" #3=
".:Brest:3232 Brest:1974 SL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.306
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.255000195624
		SemiMajorAxis	3.022569921077
		Eccentricity	0.082968963869
		Inclination	9.854564017958
		AscendingNode	192.084990988602
		ArgOfPericenter	120.922576150574
		MeanAnomaly	99.408603303354
	}
	UniformRotation
	{
		Period	5.288
	}
	LunarLambert	0.5
	Albedo	0.161
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3232"
}

#1_"3237 Victorplatt:Victorplatt:1984 SA5:1929 CB1:1934 CO:1935 HF:1935 JB:1951 KC:1951 KL:1952 QD1: #1=
#1_1955 BR:1957 OK:1957 QQ:1965 AO1:1971 DA1:1984 WX4" "Sol" #1=
#2_"*Викторплатт:3237 Victorplatt:Victorplatt:1984 SA5" "Sol" #2=
#3_"1984 SA5:*Викторплатт:3237 Victorplatt:Victorplatt" "Sol" #3=
".:Victorplatt:3237 Victorplatt:1984 SA5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.965
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.234863143102
		SemiMajorAxis	3.014843364022
		Eccentricity	0.065798994769
		Inclination	9.110125568739
		AscendingNode	280.328978233543
		ArgOfPericenter	340.188991267057
		MeanAnomaly	36.464569412261
	}
	UniformRotation
	{
		Period	10.36
	}
	LunarLambert	0.5
	Albedo	0.1513
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3237"
}

#1_"3247 Di Martino:Di Martino:1981 YE:1968 HR:1979 HO1:A909 BL" "Sol" #1=
#2_"*Ди Мартино:3247 Di Martino:Di Martino:1981 YE" "Sol" #2=
#3_"1981 YE:*Ди Мартино:3247 Di Martino:Di Martino" "Sol" #3=
".:Di Martino:3247 Di Martino:1981 YE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3247 di martino.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	6.875
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.664739810745
		SemiMajorAxis	2.376967785317
		Eccentricity	0.128834323587
		Inclination	3.934122845629
		AscendingNode	45.632783721892
		ArgOfPericenter	146.390656832525
		MeanAnomaly	266.837933146515
	}
	UniformRotation
	{
		Period	5.445
	}
	LunarLambert	0.5
	Albedo	0.0647
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3247"
}

#1_"3248 Farinella:Farinella:1982 FK:1933 UN1:1950 TK4:1955 NC:1956 VM:1976 GF1" "Sol" #1=
#2_"*Фаринелла:3248 Farinella:Farinella:1982 FK" "Sol" #2=
#3_"1982 FK:*Фаринелла:3248 Farinella:Farinella" "Sol" #3=
".:Farinella:3248 Farinella:1982 FK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.745
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.740520226304
		SemiMajorAxis	3.205989036127
		Eccentricity	0.153219659071
		Inclination	10.854991923017
		AscendingNode	12.346184173993
		ArgOfPericenter	314.104146754171
		MeanAnomaly	134.950899836992
	}
	UniformRotation
	{
		Period	6.676
	}
	LunarLambert	0.5
	Albedo	0.066
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3248"
}

#1_"3256 Daguerre:Daguerre:1981 SJ1:1976 QW" "Sol" #1=
#2_"*Дагер:3256 Daguerre:Daguerre:1981 SJ1" "Sol" #2=
#3_"1981 SJ1:*Дагер:3256 Daguerre:Daguerre" "Sol" #3=
".:Daguerre:3256 Daguerre:1981 SJ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.18
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.629281836629
		SemiMajorAxis	2.777603685975
		Eccentricity	0.097416621148
		Inclination	7.832236395296
		AscendingNode	174.318930078452
		ArgOfPericenter	268.895015169326
		MeanAnomaly	359.929304531749
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0326
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3256"
}

#1_"3258 Somnium:Somnium:1983 RJ:1979 HF3:1980 YG" "Sol" #1=
#2_"*Сомниум:3258 Somnium:Somnium:1983 RJ" "Sol" #2=
#3_"1983 RJ:Somnium:*Сомниум:3258 Somnium" "Sol" #3=
".:Somnium:3258 Somnium:1983 RJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3258 somnium.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.814
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.276037277519
		SemiMajorAxis	2.20577099562
		Eccentricity	0.196810608086
		Inclination	7.555126009383
		AscendingNode	45.012299725349
		ArgOfPericenter	296.964271546109
		MeanAnomaly	80.916054636256
	}
	UniformRotation
	{
		Period	5.3379
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3258"
}

#1_"3261 Tvardovskij:Tvardovskij:1979 SF9:1949 SN1:1953 KB:1959 RL:1967 EQ:1969 UW1:1975 XU5" "Sol" #1=
#2_"*Твардовский:3261 Tvardovskij:Tvardovskij:1979 SF9" "Sol" #2=
#3_"1979 SF9:Tvardovskij:*Твардовский:3261 Tvardovskij" "Sol" #3=
".:Tvardovskij:3261 Tvardovskij:1979 SF9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3261 tvardovskij.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.866
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.958436353102
		SemiMajorAxis	2.907754214067
		Eccentricity	0.07397564306
		Inclination	2.751230246362
		AscendingNode	142.989156244555
		ArgOfPericenter	181.85742222187
		MeanAnomaly	241.903720897182
	}
	UniformRotation
	{
		Period	5.36852
	}
	LunarLambert	0.5
	Albedo	0.294
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3261"
}

#1_"3264 Bounty:Bounty:1934 AF:1976 SF1:1984 AO" "Sol" #1=
#2_"*Баунти:3264 Bounty:Bounty:1934 AF" "Sol" #2=
#3_"1934 AF:*Баунти:3264 Bounty:Bounty" "Sol" #3=
".:Bounty:3264 Bounty:1934 AF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.62740804989
		SemiMajorAxis	3.163735274919
		Eccentricity	0.128597911468
		Inclination	0.966909024298
		AscendingNode	140.176484437195
		ArgOfPericenter	6.308207076663
		MeanAnomaly	148.221577686759
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0534
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3264"
}

#1_"3266 Bernardus:Bernardus:1978 PA" "Sol" #1=
#2_"*Бернардус:3266 Bernardus:Bernardus:1978 PA" "Sol" #2=
#3_"1978 PA:Bernardus:*Бернардус:3266 Bernardus" "Sol" #3=
".:Bernardus:3266 Bernardus:1978 PA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3266 bernardus.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.796
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.636709059055
		SemiMajorAxis	1.908546179631
		Eccentricity	0.110113074144
		Inclination	26.372730477395
		AscendingNode	110.642497555651
		ArgOfPericenter	255.947336793146
		MeanAnomaly	191.720458231853
	}
	UniformRotation
	{
		Period	10.757
	}
	LunarLambert	0.5
	Albedo	0.255
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3266"
}

#1_"3267 Glo:Glo:1981 AA" "Sol" #1=
#2_"*Гло:3267 Glo:Glo:1981 AA" "Sol" #2=
#3_"1981 AA:*Гло:3267 Glo:Glo" "Sol" #3=
".:Glo:3267 Glo:1981 AA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.556345513823
		SemiMajorAxis	2.329863603886
		Eccentricity	0.294949166783
		Inclination	24.015210046854
		AscendingNode	110.576959562805
		ArgOfPericenter	307.522003847027
		MeanAnomaly	224.328493783334
	}
	UniformRotation
	{
		Period	6.8782
	}
	LunarLambert	0.5
	Albedo	0.0607
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3267"
}

#1_"3273 Drukar:Drukar:1975 TS2:1975 VA6:1979 HV" "Sol" #1=
#2_"*Друкар:3273 Drukar:Drukar:1975 TS2" "Sol" #2=
#3_"1975 TS2:*Друкар:3273 Drukar:Drukar" "Sol" #3=
".:Drukar:3273 Drukar:1975 TS2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.655
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.284932894446
		SemiMajorAxis	3.405610387506
		Eccentricity	0.028917153303
		Inclination	14.048448866047
		AscendingNode	46.071806599197
		ArgOfPericenter	220.864338551551
		MeanAnomaly	198.004607188765
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0439
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3273"
}

#1_"3278 Behounek:Behounek:1984 BT:1939 HE:1953 VV1:1965 WN:1982 XA2" "Sol" #1=
#2_"*Бегоунек:3278 Behounek:Behounek:1984 BT" "Sol" #2=
#3_"1984 BT:*Бегоунек:3278 Behounek:Behounek" "Sol" #3=
".:Behounek:3278 Behounek:1984 BT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.215
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.769764957504
		SemiMajorAxis	3.216868289338
		Eccentricity	0.014739218375
		Inclination	9.719634723009
		AscendingNode	78.25219133409
		ArgOfPericenter	77.624346271749
		MeanAnomaly	101.303818967356
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.061
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3278"
}

#1_"3279 Solon:Solon:9103 P-L:1973 SF2:1983 TS:1983 UE:A924 RE" "Sol" #1=
#2_"*Солон:3279 Solon:Solon:1960-3279*:9103 P-L" "Sol" #2=
#3_"1960-3279*:*Солон:3279 Solon:Solon:9103 P-L" "Sol" #3=
".:Solon:3279 Solon:1960-3279*:9103 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3279 solon.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.041
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.268404701083
		SemiMajorAxis	2.202343631309
		Eccentricity	0.174466660861
		Inclination	3.164652151642
		AscendingNode	191.937502189826
		ArgOfPericenter	166.852706669863
		MeanAnomaly	269.445629655894
	}
	UniformRotation
	{
		Period	8.0969
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3279"
}

#1_"3281 Maupertuis:Maupertuis:1938 DZ:1961 TP:1970 AP:1979 TV" "Sol" #1=
#2_"*Мопертюи:3281 Maupertuis:Maupertuis:1938 DZ" "Sol" #2=
#3_"1938 DZ:Maupertuis:*Мопертюи:3281 Maupertuis" "Sol" #3=
".:Maupertuis:3281 Maupertuis:1938 DZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3281 maupertuis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.741
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.601656938148
		SemiMajorAxis	2.349611689145
		Eccentricity	0.097762605431
		Inclination	5.992888982041
		AscendingNode	348.478096116135
		ArgOfPericenter	240.797151119224
		MeanAnomaly	271.290313547972
	}
	UniformRotation
	{
		Period	6.7295
	}
	LunarLambert	0.5
	Albedo	0.489
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3281"
}

#1_"3283 Skorina:Skorina:1979 QA10:1953 TW1:1957 WK:1959 ED:1973 AM2:1977 AJ1" "Sol" #1=
#2_"*Скорина:3283 Skorina:Skorina:1979 QA10" "Sol" #2=
#3_"1979 QA10:*Скорина:3283 Skorina:Skorina" "Sol" #3=
".:Skorina:3283 Skorina:1979 QA10" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.325
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.710191726686
		SemiMajorAxis	2.396580935645
		Eccentricity	0.100719581102
		Inclination	6.898621721869
		AscendingNode	356.6694861442
		ArgOfPericenter	352.933366762594
		MeanAnomaly	187.44507316605
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0918
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3283"
}

#1_"3285 Ruth Wolfe:Ruth Wolfe:1983 VW1:1952 BR:1979 VP1:1979 YR1" "Sol" #1=
#2_"*Рут Вульф:3285 Ruth Wolfe:Ruth Wolfe:1983 VW1" "Sol" #2=
#3_"1983 VW1:*Рут Вульф:3285 Ruth Wolfe:Ruth Wolfe" "Sol" #3=
".:Ruth Wolfe:3285 Ruth Wolfe:1983 VW1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3285 ruth wolfe.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.31
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.017610059885
		SemiMajorAxis	2.527200625404
		Eccentricity	0.2158112247
		Inclination	20.587435293977
		AscendingNode	246.1624567196
		ArgOfPericenter	169.085088606235
		MeanAnomaly	262.699256339723
	}
	UniformRotation
	{
		Period	3.919
	}
	LunarLambert	0.5
	Albedo	0.2857
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3285"
}

#1_"3286 Anatoliya:Anatoliya:1980 BV:1978 TK7:1978 VP14:1984 AN" "Sol" #1=
#2_"*Анатолия:3286 Anatoliya:Anatoliya:1980 BV" "Sol" #2=
#3_"1980 BV:Anatoliya:*Анатолия:3286 Anatoliya" "Sol" #3=
".:Anatoliya:3286 Anatoliya:1980 BV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3286 anatoliya.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.027
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.283937369038
		SemiMajorAxis	2.637687090008
		Eccentricity	0.10125160075
		Inclination	13.424390263172
		AscendingNode	107.42807383189
		ArgOfPericenter	77.819888397497
		MeanAnomaly	194.533929319832
	}
	UniformRotation
	{
		Period	5.81029
	}
	LunarLambert	0.5
	Albedo	0.207
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3286"
}

#1_"3288 Seleucus:Seleucus:1982 DV" "Sol" #1=
#2_"*Селевк:3288 Seleucus:Seleucus:1982 DV" "Sol" #2=
#3_"1982 DV:*Селевк:3288 Seleucus:Seleucus" "Sol" #3=
".:Seleucus:3288 Seleucus:1982 DV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.899184300091
		SemiMajorAxis	2.033192104829
		Eccentricity	0.455947491075
		Inclination	5.928229691212
		AscendingNode	218.66140166202
		ArgOfPericenter	349.28218876055
		MeanAnomaly	97.139685388139
	}
	UniformRotation
	{
		Period	75
	}
	LunarLambert	0.5
	Albedo	0.22
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3288"
}

#1_"3298 Massandra:Massandra:1979 OB15:1950 NE:1950 NO:1972 RT:1983 VC" "Sol" #1=
#2_"*Массандра:3298 Massandra:Massandra:1979 OB15" "Sol" #2=
#3_"1979 OB15:*Массандра:3298 Massandra:Massandra" "Sol" #3=
".:Massandra:3298 Massandra:1979 OB15" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.608942702651
		SemiMajorAxis	2.352779296233
		Eccentricity	0.193558703522
		Inclination	2.567754382354
		AscendingNode	285.179943480648
		ArgOfPericenter	51.473011127237
		MeanAnomaly	267.218910168347
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0565
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3298"
}

#1_"3301 Jansje:Jansje:1978 CT:1925 KC:1958 DC:1958 DC1:1969 TE:1985 GP" "Sol" #1=
#2_"*Янше:3301 Jansje:Jansje:1978 CT" "Sol" #2=
#3_"1978 CT:Jansje:*Янше:3301 Jansje" "Sol" #3=
".:Jansje:3301 Jansje:1978 CT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3301 jansje.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.278
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.338701885402
		SemiMajorAxis	2.233810322086
		Eccentricity	0.152182705513
		Inclination	5.06677678815
		AscendingNode	136.959962087709
		ArgOfPericenter	117.852507621809
		MeanAnomaly	153.753516935526
	}
	UniformRotation
	{
		Period	9.434
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3301"
}

#1_"3307 Athabasca:Athabasca:1981 DE1:1977 AS:2003 WM33" "Sol" #1=
#2_"*Атабаска:3307 Athabasca:Athabasca:1981 DE1" "Sol" #2=
#3_"1981 DE1:*Атабаска:3307 Athabasca:Athabasca" "Sol" #3=
".:Athabasca:3307 Athabasca:1981 DE1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.396487732295
		SemiMajorAxis	2.259511548428
		Eccentricity	0.095963151325
		Inclination	6.373033410101
		AscendingNode	263.203778539534
		ArgOfPericenter	146.226083954941
		MeanAnomaly	99.639835838622
	}
	UniformRotation
	{
		Period	4.902
	}
	LunarLambert	0.5
	Albedo	0.0441
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3307"
}

#1_"3311 Podobed:Podobed:1976 QM1:1974 EL:1979 HN2:1981 SB5:1983 AW1:1984 SP:1985 PD" "Sol" #1=
#2_"*Подобед:3311 Podobed:Podobed:1976 QM1" "Sol" #2=
#3_"1976 QM1:*Подобед:3311 Podobed:Podobed" "Sol" #3=
".:Podobed:3311 Podobed:1976 QM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.02
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.654840505065
		SemiMajorAxis	2.787817896094
		Eccentricity	0.041380048893
		Inclination	0.929004267292
		AscendingNode	157.320570007853
		ArgOfPericenter	12.028668048158
		MeanAnomaly	260.889955396424
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0442
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3311"
}

#1_"3317 Paris:Paris:1984 KF:1963 QD:1982 BN3:1982 DC" "Sol" #1=
#2_"*Парис:3317 Paris:Paris:1984 KF" "Sol" #2=
#3_"1984 KF:*Парис:3317 Paris:Paris" "Sol" #3=
".:Paris:3317 Paris:1984 KF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58.13
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.938103287566
		SemiMajorAxis	5.223377570796
		Eccentricity	0.126340987772
		Inclination	27.860343415695
		AscendingNode	135.897216710007
		ArgOfPericenter	150.447894058134
		MeanAnomaly	145.791022128226
	}
	UniformRotation
	{
		Period	7.082
	}
	LunarLambert	0.5
	Albedo	0.0626
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3317"
}

#1_"3318 Blixen:Blixen:1985 HB:1943 GP:1950 RT:1953 CJ:1962 YF:1970 KB:1972 XL1:1976 QW1:1979 DH" "Sol" #1=
#2_"*Бликсен:3318 Blixen:Blixen:1985 HB" "Sol" #2=
#3_"1985 HB:*Бликсен:3318 Blixen:Blixen" "Sol" #3=
".:Blixen:3318 Blixen:1985 HB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.216564868119
		SemiMajorAxis	3.007813747374
		Eccentricity	0.049473207978
		Inclination	11.582626550349
		AscendingNode	109.190419177928
		ArgOfPericenter	52.146714398254
		MeanAnomaly	285.081953462434
	}
	UniformRotation
	{
		Period	6.456
	}
	LunarLambert	0.5
	Albedo	0.1275
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3318"
}

#1_"3324 Avsyuk:Avsyuk:1983 CW1:1959 VC:1961 DC:1963 SU:1972 TG6:1974 CE" "Sol" #1=
#2_"*Авсюк:3324 Avsyuk:Avsyuk:1983 CW1" "Sol" #2=
#3_"1983 CW1:*Авсюк:3324 Avsyuk:Avsyuk" "Sol" #3=
".:Avsyuk:3324 Avsyuk:1983 CW1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.433127202413
		SemiMajorAxis	2.698576042566
		Eccentricity	0.025224378932
		Inclination	10.764495748955
		AscendingNode	316.809302008503
		ArgOfPericenter	177.374957178968
		MeanAnomaly	66.273774801631
	}
	UniformRotation
	{
		Period	8.614
	}
	LunarLambert	0.5
	Albedo	0.1109
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3324"
}

#1_"3325 TARDIS:TARDIS:1984 JZ:1958 VB1:1969 TP3:1975 VC8:1975 WF1" "Sol" #1=
#2_"*ТАРДИС:3325 TARDIS:TARDIS:1984 JZ" "Sol" #2=
#3_"1984 JZ:*ТАРДИС:3325 TARDIS:TARDIS" "Sol" #3=
".:TARDIS:3325 TARDIS:1984 JZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.83
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.682246470959
		SemiMajorAxis	3.184255519054
		Eccentricity	0.013573288413
		Inclination	22.215314800704
		AscendingNode	46.257378188118
		ArgOfPericenter	82.166046223371
		MeanAnomaly	236.257304164419
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0553
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3325"
}

#1_"3326 Agafonikov:Agafonikov:1985 FL:1931 OB:1946 TE:1964 RA:1964 RO:1967 GJ:1974 EP:1978 GL3: #1=
#1_1979 UP4:1979 WA8:1983 WC1" "Sol" #1=
#2_"*Агафоников:3326 Agafonikov:Agafonikov:1985 FL" "Sol" #2=
#3_"1985 FL:*Агафоников:3326 Agafonikov:Agafonikov" "Sol" #3=
".:Agafonikov:3326 Agafonikov:1985 FL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.55
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.644475859382
		SemiMajorAxis	2.368197493163
		Eccentricity	0.172383892985
		Inclination	3.382896818284
		AscendingNode	4.404403473331
		ArgOfPericenter	280.717908241402
		MeanAnomaly	320.153323435944
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0404
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3326"
}

#1_"3338 Richter:Richter:1973 UX5:1976 QL1" "Sol" #1=
#2_"*Рихтер:3338 Richter:Richter:1973 UX5" "Sol" #2=
#3_"1973 UX5:*Рихтер:3338 Richter:Richter" "Sol" #3=
".:Richter:3338 Richter:1973 UX5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.04
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.143930143489
		SemiMajorAxis	2.146066244617
		Eccentricity	0.170208636553
		Inclination	0.734531999747
		AscendingNode	126.155281321369
		ArgOfPericenter	177.585244184837
		MeanAnomaly	92.839158421281
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3338"
}

#1_"3339 Treshnikov:Treshnikov:1978 LB:1969 VO2" "Sol" #1=
#2_"*Трёшников:3339 Treshnikov:Treshnikov:1978 LB" "Sol" #2=
#3_"1978 LB:*Трёшников:3339 Treshnikov:Treshnikov" "Sol" #3=
".:Treshnikov:3339 Treshnikov:1978 LB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.663695697002
		SemiMajorAxis	3.177321337596
		Eccentricity	0.134067582067
		Inclination	17.810177195915
		AscendingNode	84.801009302397
		ArgOfPericenter	148.655295222717
		MeanAnomaly	158.19750210912
	}
	UniformRotation
	{
		Period	18.2947
	}
	LunarLambert	0.5
	Albedo	0.0601
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3339"
}

#1_"3345 Tarkovskij:Tarkovskij:1982 YC1:1938 QC:1952 BD2:1969 OB" "Sol" #1=
#2_"*Тарковский:3345 Tarkovskij:Tarkovskij:1982 YC1" "Sol" #2=
#3_"1982 YC1:*Тарковский:3345 Tarkovskij:Tarkovskij" "Sol" #3=
".:Tarkovskij:3345 Tarkovskij:1982 YC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.125
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.886943711841
		SemiMajorAxis	2.472103784699
		Eccentricity	0.190359133446
		Inclination	15.854611844246
		AscendingNode	304.905745152345
		ArgOfPericenter	194.317928888763
		MeanAnomaly	42.630266358896
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0688
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3345"
}

#1_"3346 Gerla:Gerla:1951 SD:1942 GM:1977 EX1:1979 RC:1985 RL2" "Sol" #1=
#2_"*Герла:3346 Gerla:Gerla:1951 SD" "Sol" #2=
#3_"1951 SD:*Герла:3346 Gerla:Gerla" "Sol" #3=
".:Gerla:3346 Gerla:1951 SD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.095
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.681288639215
		SemiMajorAxis	3.183897671534
		Eccentricity	0.044757587489
		Inclination	21.497344409421
		AscendingNode	2.727512122305
		ArgOfPericenter	15.24204838201
		MeanAnomaly	44.872888309583
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0549
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3346"
}

#New3
#1_"3348 Pokryshkin:Pokryshkin:1978 EA3:1951 RO:1951 TM:1972 EP:1978 JM2" "Sol" #1=
#2_"*Покрышкин:3348 Pokryshkin:Pokryshkin:1978 EA3" "Sol" #2=
#3_"1978 EA3:*Покрышкин:3348 Pokryshkin:Pokryshkin" "Sol" #3=
".:Pokryshkin:3348 Pokryshkin:1978 EA3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.794
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.655067065224
		SemiMajorAxis	3.174093421479
		Eccentricity	0.163400544579
		Inclination	10.393499206417
		AscendingNode	185.834558176891
		ArgOfPericenter	62.275725311434
		MeanAnomaly	313.053592576422
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.126
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3348"
}

#1_"3353 Jarvis:Jarvis:1981 YC" "Sol" #1=
#2_"*Джарвис:3353 Jarvis:Jarvis:1981 YC" "Sol" #2=
#3_"1981 YC:*Джарвис:3353 Jarvis:Jarvis" "Sol" #3=
".:Jarvis:3353 Jarvis:1981 YC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.86
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.542460577424
		SemiMajorAxis	1.862790510652
		Eccentricity	0.084893476827
		Inclination	21.808891150242
		AscendingNode	245.625237344981
		ArgOfPericenter	34.637881688349
		MeanAnomaly	131.36969306401
	}
	UniformRotation
	{
		Period	202
	}
	LunarLambert	0.5
	Albedo	0.0744
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3353"
}

#1_"3360 Syrinx:Syrinx:1981 VA" "Sol" #1=
#2_"*Сиринга:3360 Syrinx:Syrinx:1981 VA" "Sol" #2=
#3_"1981 VA:*Сиринга:3360 Syrinx:Syrinx" "Sol" #3=
".:Syrinx:3360 Syrinx:1981 VA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.877560695506
		SemiMajorAxis	2.468123771212
		Eccentricity	0.745598540468
		Inclination	21.182266295284
		AscendingNode	243.019259916085
		ArgOfPericenter	63.002578284626
		MeanAnomaly	213.757708786747
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.17
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3360"
}

#1_"3361 Orpheus:Orpheus:1982 HR" "Sol" #1=
#2_"*Орфей:3361 Orpheus:Orpheus:1982 HR" "Sol" #2=
#3_"1982 HR:*Орфей:3361 Orpheus:Orpheus" "Sol" #3=
".:Orpheus:3361 Orpheus:1982 HR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.330702217629
		SemiMajorAxis	1.209804286437
		Eccentricity	0.322810373436
		Inclination	2.684201672642
		AscendingNode	189.40514006
		ArgOfPericenter	301.757866873617
		MeanAnomaly	239.206334711569
	}
	UniformRotation
	{
		Period	3.532
	}
	LunarLambert	0.5
	Albedo	0.48
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3361"
}

#1_"3362 Khufu:Khufu:1984 QA" "Sol" #1=
#2_"*Хуфу:3362 Khufu:Khufu:1984 QA" "Sol" #2=
#3_"1984 QA:*Хуфу:3362 Khufu:Khufu" "Sol" #3=
".:Khufu:3362 Khufu:1984 QA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.984309201085
		SemiMajorAxis	0.989499460363
		Eccentricity	0.468488860657
		Inclination	9.917198876029
		AscendingNode	152.453234782957
		ArgOfPericenter	55.035581363901
		MeanAnomaly	355.22424804994
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.21
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3362"
}

#1_"3368 Duncombe:Duncombe:1985 QT:1954 RG:1954 RN:1970 GH1:1973 SP5:1976 GJ4" "Sol" #1=
#2_"*Данкомбе:3368 Duncombe:Duncombe:1985 QT" "Sol" #2=
#3_"1985 QT:*Данкомбе:3368 Duncombe:Duncombe" "Sol" #3=
".:Duncombe:3368 Duncombe:1985 QT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.230888180907
		SemiMajorAxis	3.386058862319
		Eccentricity	0.088829852866
		Inclination	19.148028093932
		AscendingNode	4.122565155672
		ArgOfPericenter	352.055051602577
		MeanAnomaly	253.16160742028
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0431
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3368"
}

#1_"3375 Amy:Amy:1981 JY1:1955 EE" "Sol" #1=
#2_"*Эми:3375 Amy:Amy:1981 JY1:1955 EE" "Sol" #2=
#3_"1981 JY1:Amy:*Эми:3375 Amy:1955 EE" "Sol" #3=
".:Amy:3375 Amy:1981 JY1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3375 amy.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.36
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.200324729792
		SemiMajorAxis	2.17165365617
		Eccentricity	0.025700323774
		Inclination	1.079791998514
		AscendingNode	169.256262645571
		ArgOfPericenter	352.442538533484
		MeanAnomaly	121.636782185024
	}
	UniformRotation
	{
		Period	3.2556
	}
	LunarLambert	0.5
	Albedo	0.125
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3375"
}

#1_"3379 Oishi:Oishi:1931 TJ1:1964 YG:1981 NQ:A906 WC" "Sol" #1=
#2_"*Оиси:3379 Oishi:Oishi:1931 TJ1" "Sol" #2=
#3_"1931 TJ1:*Оиси:3379 Oishi:Oishi" "Sol" #3=
".:Oishi:3379 Oishi:1931 TJ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.445
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.613172006522
		SemiMajorAxis	2.354617078451
		Eccentricity	0.130950006283
		Inclination	2.850911925865
		AscendingNode	146.772800835402
		ArgOfPericenter	304.10520489748
		MeanAnomaly	302.114424934111
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0386
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3379"
}

#1_"3389 Sinzot:Sinzot:1984 DU:1964 VB1:1975 EG4:1975 EH1:1977 QN4" "Sol" #1=
#2_"*Синцот:3389 Sinzot:Sinzot:1984 DU" "Sol" #2=
#3_"1984 DU:*Синцот:3389 Sinzot:Sinzot" "Sol" #3=
".:Sinzot:3389 Sinzot:1984 DU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.355
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.618810333644
		SemiMajorAxis	2.773413451905
		Eccentricity	0.136647313595
		Inclination	7.069250763415
		AscendingNode	150.122222768188
		ArgOfPericenter	268.540156320251
		MeanAnomaly	309.578551235393
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0606
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3389"
}

#1_"3396 Muazzez:Muazzez:A915 TE:1940 TL:1957 HO:1971 SL1:1973 AJ" "Sol" #1=
#2_"*Муаззец:3396 Muazzez:Muazzez:1915 TE" "Sol" #2=
#3_"1915 TE:*Муаззец:3396 Muazzez:Muazzez" "Sol" #3=
".:Muazzez:3396 Muazzez:1915 TE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.815
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.234342696916
		SemiMajorAxis	3.38731027449
		Eccentricity	0.185221518431
		Inclination	8.348503760708
		AscendingNode	38.069241275052
		ArgOfPericenter	316.363844154982
		MeanAnomaly	359.05090641469
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0497
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3396"
}

#1_"3397 Leyla:Leyla:1964 XA" "Sol" #1=
#2_"*Лейла:3397 Leyla:Leyla:1964 XA" "Sol" #2=
#3_"1964 XA:*Лейла:3397 Leyla:Leyla" "Sol" #3=
".:Leyla:3397 Leyla:1964 XA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.67
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.601976159964
		SemiMajorAxis	2.349750520845
		Eccentricity	0.297740825971
		Inclination	21.993490635707
		AscendingNode	25.85446409752
		ArgOfPericenter	95.372101987181
		MeanAnomaly	294.138087184527
	}
	UniformRotation
	{
		Period	3.098
	}
	LunarLambert	0.5
	Albedo	0.2251
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3397"
}

#1_"3405 Daiwensai:Daiwensai:1964 UQ:1950 JJ:1951 RC1:1955 OB:1981 UH8:1984 LE" "Sol" #1=
#2_"*Дайвенсай:3405 Daiwensai:Daiwensai:1964 UQ" "Sol" #2=
#3_"1964 UQ:*Дайвенсай:3405 Daiwensai:Daiwensai" "Sol" #3=
".:Daiwensai:3405 Daiwensai:1964 UQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.135
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.216776523764
		SemiMajorAxis	2.610046564244
		Eccentricity	0.115513528428
		Inclination	13.183186962756
		AscendingNode	241.933117591645
		ArgOfPericenter	63.11821854823
		MeanAnomaly	36.485981025924
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.047
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3405"
}

#1_"3406 Omsk:Omsk:1969 DA:1951 KA1:1983 CH3" "Sol" #1=
#2_"*Омск:3406 Omsk:Omsk:1969 DA" "Sol" #2=
#3_"1969 DA:*Омск:3406 Omsk:Omsk" "Sol" #3=
".:Omsk:3406 Omsk:1969 DA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.672816449181
		SemiMajorAxis	2.794990567106
		Eccentricity	0.132862077233
		Inclination	8.365062000193
		AscendingNode	269.939672835529
		ArgOfPericenter	310.410560345381
		MeanAnomaly	231.215862723802
	}
	UniformRotation
	{
		Period	7.275
	}
	LunarLambert	0.5
	Albedo	0.2476
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3406"
}

#1_"3407 Jimmysimms:Jimmysimms:1973 DT:1973 GW:1977 BV:1980 WN" "Sol" #1=
#2_"*Джиммисиммс:3407 Jimmysimms:Jimmysimms:1973 DT" "Sol" #2=
#3_"1973 DT:Jimmysimms:*Джиммисиммс:3407 Jimmysimms" "Sol" #3=
".:Jimmysimms:3407 Jimmysimms:1973 DT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3407 jimmysimms.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	7.838
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.406867843646
		SemiMajorAxis	2.687908927053
		Eccentricity	0.154493889339
		Inclination	13.076812415324
		AscendingNode	102.966502963416
		ArgOfPericenter	344.033813446904
		MeanAnomaly	49.750890149649
	}
	UniformRotation
	{
		Period	6.819
	}
	LunarLambert	0.5
	Albedo	0.071
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3407"
}

#1_"3415 Danby:Danby:1928 SL:1967 RL:1983 RV" "Sol" #1=
#2_"*Дэнби:3415 Danby:Danby:1928 SL" "Sol" #2=
#3_"1928 SL:*Дэнби:3415 Danby:Danby" "Sol" #3=
".:Danby:3415 Danby:1928 SL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.165
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.899267270271
		SemiMajorAxis	3.966301620524
		Eccentricity	0.249715041138
		Inclination	1.366417038716
		AscendingNode	253.985129602969
		ArgOfPericenter	136.714062897889
		MeanAnomaly	320.852709153539
	}
	UniformRotation
	{
		Period	5.666
	}
	LunarLambert	0.5
	Albedo	0.0809
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3415"
}

#1_"3418 Izvekov:Izvekov:1973 QZ1:1934 RB1:1962 TC:1979 WM7:1984 PB:1984 RJ" "Sol" #1=
#2_"*Извеков:3418 Izvekov:Izvekov:1973 QZ1" "Sol" #2=
#3_"1973 QZ1:*Извеков:3418 Izvekov:Izvekov" "Sol" #3=
".:Izvekov:3418 Izvekov:1973 QZ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.565
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.637542206722
		SemiMajorAxis	3.167532425549
		Eccentricity	0.182411793512
		Inclination	1.894209085952
		AscendingNode	84.183939538223
		ArgOfPericenter	284.63935467
		MeanAnomaly	106.586817754748
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0457
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3418"
}
###### Исправление ошибки
#1_"3419 Guth:Guth:1981 JZ:1932 YF:1941 HP" "Sol" #1=
#2_"*Гут:3419 Guth:Guth:1981 JZ" "Sol" #2=
#3_"1981 JZ:3419 Guth:Guth" "Sol" #3=
".:Guth:3419 Guth:1981 JZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.48
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.760550627002
		SemiMajorAxis	3.21344247876
		Eccentricity	0.063853421991
		Inclination	17.48512603528
		AscendingNode	58.545815126538
		ArgOfPericenter	224.165761720982
		MeanAnomaly	247.680932197518
	}
	UniformRotation
	{
		Period	14.43
	}
	LunarLambert	0.5
	Albedo	0.0854
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3419"
}

#1_"3425 Hurukawa:Hurukawa:1929 BD:1951 GB:1971 DJ1:1978 PN:1979 SG1:1981 DW3:A903 CB" "Sol" #1=
#2_"*Хурукава:3425 Hurukawa:Hurukawa:1929 BD" "Sol" #2=
#3_"1929 BD:*Хурукава:3425 Hurukawa:Hurukawa" "Sol" #3=
".:Hurukawa:3425 Hurukawa:1929 BD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.201587787803
		SemiMajorAxis	3.002053909522
		Eccentricity	0.085168307206
		Inclination	9.212341696657
		AscendingNode	291.530248719304
		ArgOfPericenter	134.942231680918
		MeanAnomaly	236.768577511677
	}
	UniformRotation
	{
		Period	24.84
	}
	LunarLambert	0.5
	Albedo	0.1315
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3425"
}

#1_"3428 Roberts:Roberts:1952 JH:1952 KB:1972 YQ1:1978 JH2:1980 TD15:1982 FR1" "Sol" #1=
#2_"*Робертс:3428 Roberts:Roberts:1952 JH" "Sol" #2=
#3_"1952 JH:Roberts:*Робертс:3428 Roberts" "Sol" #3=
".:Roberts:3428 Roberts:1952 JH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3428 roberts.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	8.582
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.347275269224
		SemiMajorAxis	2.663622197937
		Eccentricity	0.166251426277
		Inclination	8.872483860143
		AscendingNode	230.801230718456
		ArgOfPericenter	303.688910822008
		MeanAnomaly	11.991445047319
	}
	UniformRotation
	{
		Period	3.278
	}
	LunarLambert	0.5
	Albedo	0.095
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3428"
}

#1_"3442 Yashin:Yashin:1978 TO7:1929 AG:1955 SL:1980 BL5:1984 WY" "Sol" #1=
#2_"*Яшин:3442 Yashin:Yashin:1978 TO7" "Sol" #2=
#3_"1978 TO7:*Яшин:3442 Yashin:Yashin" "Sol" #3=
".:Yashin:3442 Yashin:1978 TO7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.580750231137
		SemiMajorAxis	3.146223634052
		Eccentricity	0.140782654269
		Inclination	12.238446881474
		AscendingNode	100.191040904434
		ArgOfPericenter	298.641124849913
		MeanAnomaly	156.92743744115
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0674
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3442"
}

#1_"3445 Pinson:Pinson:1983 FC:1952 DF:1974 CK1" "Sol" #1=
#2_"*Пинсон:3445 Pinson:Pinson:1983 FC" "Sol" #2=
#3_"1983 FC:*Пинсон:3445 Pinson:Pinson" "Sol" #3=
".:Pinson:3445 Pinson:1983 FC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.88
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.409800861983
		SemiMajorAxis	2.689101431148
		Eccentricity	0.123260443599
		Inclination	11.27834795285
		AscendingNode	334.155587931936
		ArgOfPericenter	200.11514618634
		MeanAnomaly	74.605615711875
	}
	UniformRotation
	{
		Period	7.801
	}
	LunarLambert	0.5
	Albedo	0.0738
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3445"
}

#1_"3455 Kristensen:Kristensen:1985 QC:1967 EC:1978 NF4:1979 XH1:1982 SJ4:1982 UH5" "Sol" #1=
#2_"*Кристенсен:3455 Kristensen:Kristensen:1985 QC" "Sol" #2=
#3_"1985 QC:Kristensen:*Кристенсен:3455 Kristensen" "Sol" #3=
".:Kristensen:3455 Kristensen:1985 QC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3455 kristensen.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.972
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.35942595983
		SemiMajorAxis	2.243044627731
		Eccentricity	0.064503272639
		Inclination	3.557225371933
		AscendingNode	168.812181301657
		ArgOfPericenter	0.230594592116
		MeanAnomaly	297.327968999699
	}
	UniformRotation
	{
		Period	8.111
	}
	LunarLambert	0.5
	Albedo	0.334
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3455"
}

#1_"3461 Mandelshtam:Mandelshtam:1977 SA1:1968 DQ:1981 YU1" "Sol" #1=
#2_"*Мандельштам:3461 Mandelshtam:Mandelshtam:1977 SA1" "Sol" #2=
#3_"1977 SA1:*Мандельштам:3461 Mandelshtam:Mandelshtam" "Sol" #3=
".:Mandelshtam:3461 Mandelshtam:1977 SA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.72
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.666934212772
		SemiMajorAxis	2.377916557088
		Eccentricity	0.135033247797
		Inclination	3.245126107465
		AscendingNode	57.953325279096
		ArgOfPericenter	343.906960109177
		MeanAnomaly	27.94493311073
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0305
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3461"
}

#1_"3467 Bernheim:Bernheim:1981 SF2:1929 WG1:1949 BU:1968 DP:1970 WR:1977 QJ:1981 SJ6:1981 UB19" "Sol" #1=
#2_"*Бернгейм:3467 Bernheim:Bernheim:1981 SF2" "Sol" #2=
#3_"1981 SF2:*Бернгейм:3467 Bernheim:Bernheim" "Sol" #3=
".:Bernheim:3467 Bernheim:1981 SF2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.741503232596
		SemiMajorAxis	2.410045721119
		Eccentricity	0.14875898588
		Inclination	4.112470152164
		AscendingNode	105.376539947132
		ArgOfPericenter	349.10588711
		MeanAnomaly	238.944198604517
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0448
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3467"
}

#1_"3470 Yaronika:Yaronika:1975 ES:1954 LD:1968 DY:1968 FA1:1972 LH1:1973 UX4:1979 KN1" "Sol" #1=
#2_"*Яроника:3470 Yaronika:Yaronika:1975 ES" "Sol" #2=
#3_"1975 ES:*Яроника:3470 Yaronika:Yaronika" "Sol" #3=
".:Yaronika:3470 Yaronika:1975 ES" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.59278425691
		SemiMajorAxis	2.345751257706
		Eccentricity	0.145036098659
		Inclination	2.55686437259
		AscendingNode	237.165330900115
		ArgOfPericenter	312.428751341905
		MeanAnomaly	354.063950403725
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.062
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3470"
}

#1_"3471 Amelin:Amelin:1977 QK2:1974 DN:1980 DN2:1980 EU" "Sol" #1=
#2_"*Амелин:3471 Amelin:Amelin:1977 QK2" "Sol" #2=
#3_"1977 QK2:*Амелин:3471 Amelin:Amelin" "Sol" #3=
".:Amelin:3471 Amelin:1977 QK2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.698503346591
		SemiMajorAxis	3.190326051642
		Eccentricity	0.053023416214
		Inclination	15.391840071336
		AscendingNode	334.86417406658
		ArgOfPericenter	159.212912807031
		MeanAnomaly	53.451155229005
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0609
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3471"
}

#1_"3475 Fichte:Fichte:1972 TD:1956 XN:1961 UB:1981 KU1:1986 CM1" "Sol" #1=
#2_"*Фихте:3475 Fichte:Fichte:1972 TD" "Sol" #2=
#3_"1972 TD:*Фихте:3475 Fichte:Fichte" "Sol" #3=
".:Fichte:3475 Fichte:1972 TD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.355
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.650245805564
		SemiMajorAxis	3.172289104079
		Eccentricity	0.128151264609
		Inclination	15.002625366104
		AscendingNode	241.976160258295
		ArgOfPericenter	231.063432971899
		MeanAnomaly	70.146172386097
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0897
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3475"
}

#1_"3476 Dongguan:Dongguan:1978 UF2:1984 WH" "Sol" #1=
#2_"*ДунГуань:3476 Dongguan:Dongguan:1978 UF2" "Sol" #2=
#3_"1978 UF2:*ДунГуань:3476 Dongguan:Dongguan" "Sol" #3=
".:Dongguan:3476 Dongguan:1978 UF2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.765
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.614205368648
		SemiMajorAxis	3.158784962922
		Eccentricity	0.195745033607
		Inclination	21.609728936116
		AscendingNode	43.84124491685
		ArgOfPericenter	25.870205223623
		MeanAnomaly	127.543225144033
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0309
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3476"
}

#1_"3478 Fanale:Fanale:1979 XG:1925 TC:1930 DT:1935 SL1:1950 AA:1962 WA1:1962 XB1:1975 RO1:1978 NL3: #1=
#1_1979 YY8:1980 BR5:1982 VS1:1982 XS4" "Sol" #1=
#2_"*Фанале:3478 Fanale:Fanale:1979 XG" "Sol" #2=
#3_"1979 XG:*Фанале:3478 Fanale:Fanale" "Sol" #3=
".:Fanale:3478 Fanale:1979 XG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3478 fanale.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.494
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.34376063598
		SemiMajorAxis	2.236066176386
		Eccentricity	0.162944651989
		Inclination	3.8406925435
		AscendingNode	126.473181150193
		ArgOfPericenter	269.888665585239
		MeanAnomaly	221.930320687714
	}
	UniformRotation
	{
		Period	3.245
	}
	LunarLambert	0.5
	Albedo	0.362
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3478"
}

#1_"3485 Barucci:Barucci:1983 NU:1952 HT3:1982 DB5" "Sol" #1=
#2_"*Баруччи:3485 Barucci:Barucci:1983 NU" "Sol" #2=
#3_"1983 NU:*Баруччи:3485 Barucci:Barucci" "Sol" #3=
".:Barucci:3485 Barucci:1983 NU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.807711854135
		SemiMajorAxis	2.438394195532
		Eccentricity	0.166965803554
		Inclination	1.804386966008
		AscendingNode	315.408277185426
		ArgOfPericenter	339.005184011767
		MeanAnomaly	97.470240338757
	}
	UniformRotation
	{
		Period	14.65
	}
	LunarLambert	0.5
	Albedo	0.0858
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3485"
}

#1_"3492 Petra-Pepi:Petra-Pepi:1985 DQ:1951 CG:1977 JD1:1978 SA1:1978 TK9:1980 CB" "Sol" #1=
#2_"*Петра-Пепи:3492 Petra-Pepi:Petra-Pepi:1985 DQ" "Sol" #2=
#3_"1985 DQ:*Петра-Пепи:3492 Petra-Pepi:Petra-Pepi" "Sol" #3=
".:Petra-Pepi:3492 Petra-Pepi:1985 DQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3492 petra-pepi.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.829
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.232019878724
		SemiMajorAxis	2.616332872268
		Eccentricity	0.143088026571
		Inclination	13.621937701827
		AscendingNode	138.820433507637
		ArgOfPericenter	97.204435898177
		MeanAnomaly	359.122937661739
	}
	UniformRotation
	{
		Period	47.05
	}
	LunarLambert	0.5
	Albedo	0.248
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3492"
}

#1_"3501 Olegiya:Olegiya:1971 QU:1957 WZ:1962 WS:1966 PB:1970 GC2:1970 JK:1970 JQ:1980 JW:1985 HO1" "Sol" #1=
#2_"*Олегия:3501 Olegiya:Olegiya:1971 QU" "Sol" #2=
#3_"1971 QU:*Олегия:3501 Olegiya:Olegiya" "Sol" #3=
".:Olegiya:3501 Olegiya:1971 QU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.99377282108
		SemiMajorAxis	2.92155266445
		Eccentricity	0.088793159072
		Inclination	4.992831881085
		AscendingNode	246.169190368372
		ArgOfPericenter	70.99908333642
		MeanAnomaly	245.092754872455
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0935
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3501"
}

#1_"3522 Becker:Becker:1941 SW:1964 UG:1981 TL2:1981 UA20:1981 WC6" "Sol" #1=
#2_"*Беккер:3522 Becker:Becker:1941 SW" "Sol" #2=
#3_"1941 SW:*Беккер:3522 Becker:Becker" "Sol" #3=
".:Becker:3522 Becker:1941 SW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.661688689595
		SemiMajorAxis	3.17657067531
		Eccentricity	0.289720389511
		Inclination	8.360249585375
		AscendingNode	201.808511432734
		ArgOfPericenter	150.015437380372
		MeanAnomaly	342.234947064049
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0192
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3522"
}

#1_"3526 Jeffbell:Jeffbell:1984 CN:1977 TP3:1977 VJ" "Sol" #1=
#2_"*Джеффбел:3526 Jeffbell:Jeffbell:1984 CN" "Sol" #2=
#3_"1984 CN:*Джеффбел:3526 Jeffbell:Jeffbell" "Sol" #3=
".:Jeffbell:3526 Jeffbell:1984 CN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.661652444453
		SemiMajorAxis	2.790537046581
		Eccentricity	0.094473431598
		Inclination	8.489825189807
		AscendingNode	42.475141275192
		ArgOfPericenter	244.617249775534
		MeanAnomaly	81.516752891865
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0418
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3526"
}

#1_"3532 Tracie:Tracie:1983 AS2:1981 SD7" "Sol" #1=
#2_"*Трейси:3532 Tracie:Tracie:1983 AS2" "Sol" #2=
#3_"1983 AS2:*Трейси:3532 Tracie:Tracie" "Sol" #3=
".:Tracie:3532 Tracie:1983 AS2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.976427587165
		SemiMajorAxis	2.914783648039
		Eccentricity	0.05833943426
		Inclination	10.351330738659
		AscendingNode	56.407171127068
		ArgOfPericenter	342.597815001852
		MeanAnomaly	219.58473038183
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0948
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3532"
}

#1_"3533 Toyota:Toyota:1986 UE:1953 VA2:1971 FJ:1976 SZ4:1978 GQ3:1978 JH3:1979 QX7:1983 YJ" "Sol" #1=
#2_"*Тойота:3533 Toyota:Toyota:1986 UE" "Sol" #2=
#3_"1986 UE:*Тойота:3533 Toyota:Toyota" "Sol" #3=
".:Toyota:3533 Toyota:1986 UE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.788
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.306996004356
		SemiMajorAxis	2.219645635662
		Eccentricity	0.117050185192
		Inclination	4.86933889975
		AscendingNode	197.196057296035
		ArgOfPericenter	237.499783240951
		MeanAnomaly	150.533810913063
	}
	UniformRotation
	{
		Period	2.9807
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3533"
}

#1_"3544 Borodino:Borodino:1977 RD4:1936 QJ1:1943 GM:1947 LO:1951 RW1:1951 SJ:1980 FM11:1981 RN5" "Sol" #1=
#2_"*Бородино:3544 Borodino:Borodino:1977 RD4" "Sol" #2=
#3_"1977 RD4:Borodino:*Бородино:3544 Borodino" "Sol" #3=
".:Borodino:3544 Borodino:1977 RD4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3544 borodino.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.251
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.720365075664
		SemiMajorAxis	2.400959887342
		Eccentricity	0.220992594355
		Inclination	8.905161036039
		AscendingNode	147.639012479321
		ArgOfPericenter	148.854491045902
		MeanAnomaly	238.056599850033
	}
	UniformRotation
	{
		Period	5.442
	}
	LunarLambert	0.5
	Albedo	0.247
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3544"
}

#1_"3548 Eurybates:Eurybates:1973 SO:1954 CB:1957 JX:1978 EE5:1985 TZ" "Sol" #1=
#2_"*Эврибат:3548 Eurybates:Eurybates:1973 SO" "Sol" #2=
#3_"1973 SO:*Эврибат:3548 Eurybates:Eurybates" "Sol" #3=
".:Eurybates:3548 Eurybates:1973 SO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.07
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.80604271069
		SemiMajorAxis	5.184785157375
		Eccentricity	0.089953674295
		Inclination	8.067543696809
		AscendingNode	43.570147966403
		ArgOfPericenter	28.009969515962
		MeanAnomaly	136.977745269635
	}
	UniformRotation
	{
		Period	8.711
	}
	LunarLambert	0.5
	Albedo	0.0538
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3548"
}

#1_"3551 Verenia:Verenia:1983 RD" "Sol" #1=
#2_"*Верения:3551 Verenia:Verenia:1983 RD" "Sol" #2=
#3_"1983 RD:*Верения:3551 Verenia:Verenia" "Sol" #3=
".:Verenia:3551 Verenia:1983 RD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.028793162944
		SemiMajorAxis	2.093345642162
		Eccentricity	0.486856055009
		Inclination	9.507686361696
		AscendingNode	173.837646483223
		ArgOfPericenter	193.251034871794
		MeanAnomaly	110.892647039758
	}
	UniformRotation
	{
		Period	4.93
	}
	LunarLambert	0.5
	Albedo	0.37
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3551"
}

#1_"3552 Don Quixote:Don Quixote:1983 SA" "Sol" #1=
#2_"*Дон Кихот:3552 Don Quixote:Don Quixote:1983 SA" "Sol" #2=
#3_"1983 SA:*Дон Кихот:3552 Don Quixote:Don Quixote" "Sol" #3=
".:Don Quixote:3552 Don Quixote:1983 SA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	8.675265669817
		SemiMajorAxis	4.22198209757
		Eccentricity	0.713424748805
		Inclination	31.029815558974
		AscendingNode	350.199189248118
		ArgOfPericenter	317.047532679832
		MeanAnomaly	218.403863976401
	}
	UniformRotation
	{
		Period	7.7
	}
	LunarLambert	0.5
	Albedo	0.03
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3552"
}

#1_"3554 Amun:Amun:1986 EB" "Sol" #1=
#2_"*Амон:3554 Amun:Amun:1986 EB" "Sol" #2=
#3_"1986 EB:*Амон:3554 Amun:Amun" "Sol" #3=
".:Amun:3554 Amun:1986 EB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.24
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.960766680434
		SemiMajorAxis	0.973658113811
		Eccentricity	0.280444807723
		Inclination	23.36175044296
		AscendingNode	358.628158187162
		ArgOfPericenter	359.382197205968
		MeanAnomaly	134.433069338711
	}
	UniformRotation
	{
		Period	2.53
	}
	LunarLambert	0.5
	Albedo	0.1284
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3554"
}

#1_"3560 Chenqian:Chenqian:1980 RZ2:1933 SY:1951 CT:1970 TG:1978 JE1:1980 RX4" "Sol" #1=
#2_"*ЧэньЦянь:3560 Chenqian:Chenqian:1980 RZ2" "Sol" #2=
#3_"1980 RZ2:*ЧэньЦянь:3560 Chenqian:Chenqian" "Sol" #3=
".:Chenqian:3560 Chenqian:1980 RZ2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.236104495165
		SemiMajorAxis	3.015319955168
		Eccentricity	0.11840289351
		Inclination	9.290251609933
		AscendingNode	325.200267625872
		ArgOfPericenter	59.5930391006
		MeanAnomaly	161.386383828276
	}
	UniformRotation
	{
		Period	18.79
	}
	LunarLambert	0.5
	Albedo	0.1245
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3560"
}

#1_"3561 Devine:Devine:1983 HO:1977 QT" "Sol" #1=
#2_"*Девайн:3561 Devine:Devine:1983 HO" "Sol" #2=
#3_"1983 HO:*Девайн:3561 Devine:Devine" "Sol" #3=
".:Devine:3561 Devine:1983 HO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.37
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.86587527915
		SemiMajorAxis	3.95511609402
		Eccentricity	0.128115062887
		Inclination	9.684257836704
		AscendingNode	117.858577987604
		ArgOfPericenter	176.254475528178
		MeanAnomaly	296.211533871099
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0865
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3561"
}

#1_"3564 Talthybius:Talthybius:1985 TC1:1979 HW2:1979 HY1:1980 JU" "Sol" #1=
#2_"*Талфибий:3564 Talthybius:Talthybius:1985 TC1" "Sol" #2=
#3_"1985 TC1:*Талфибий:3564 Talthybius:Talthybius" "Sol" #3=
".:Talthybius:3564 Talthybius:1985 TC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.46
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.898919489413
		SemiMajorAxis	5.21194170057
		Eccentricity	0.041276692914
		Inclination	15.500932963778
		AscendingNode	23.794819846517
		ArgOfPericenter	201.901235836972
		MeanAnomaly	313.35265144341
	}
	UniformRotation
	{
		Period	40.59
	}
	LunarLambert	0.5
	Albedo	0.0934
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3564"
}

#1_"3570 Wuyeesun:Wuyeesun:1979 XO:1931 UK:1970 AA1:1971 GA:1977 LS:1978 SZ:1982 KF1:1984 WC1" "Sol" #1=
#2_"*Вуеесан:3570 Wuyeesun:Wuyeesun:1979 XO" "Sol" #2=
#3_"1979 XO:*Вуеесан:3570 Wuyeesun:Wuyeesun" "Sol" #3=
".:Wuyeesun:3570 Wuyeesun:1979 XO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.495
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.248949414262
		SemiMajorAxis	3.020249284147
		Eccentricity	0.090381350816
		Inclination	11.320167602202
		AscendingNode	85.030957916671
		ArgOfPericenter	222.242110645344
		MeanAnomaly	5.03354466775
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1687
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3570"
}

#1_"3571 Milanstefanik:Milanstefanik:1982 EJ:1976 NL:1985 TJ3" "Sol" #1=
#2_"*Миланштефаник:3571 Milanstefanik:Milanstefanik:1982 EJ" "Sol" #2=
#3_"1982 EJ:*Миланштефаник:3571 Milanstefanik:Milanstefanik" "Sol" #3=
".:Milanstefanik:3571 Milanstefanik:1982 EJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.819192420237
		SemiMajorAxis	3.939451870608
		Eccentricity	0.111078001176
		Inclination	7.854443297153
		AscendingNode	248.996460259879
		ArgOfPericenter	20.527140591549
		MeanAnomaly	351.347456371487
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0424
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3571"
}

#1_"3573 Holmberg:Holmberg:1982 QO1:1929 WN:1947 BL:1976 YW1:1979 WH5" "Sol" #1=
#2_"*Хольмберг:3573 Holmberg:Holmberg:1982 QO1" "Sol" #2=
#3_"1982 QO1:Holmberg:*Хольмберг:3573 Holmberg" "Sol" #3=
".:Holmberg:3573 Holmberg:1982 QO1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3573 holmberg.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.122
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.350127244936
		SemiMajorAxis	2.23890362931
		Eccentricity	0.066178209017
		Inclination	2.762624124457
		AscendingNode	268.827506002482
		ArgOfPericenter	210.216090700393
		MeanAnomaly	326.091378634583
	}
	UniformRotation
	{
		Period	6.5431
	}
	LunarLambert	0.5
	Albedo	0.343
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3573"
}

#1_"3578 Carestia:Carestia:1977 CC:1939 PL:1950 LG:1985 RY" "Sol" #1=
#2_"*Царестья:3578 Carestia:Carestia:1977 CC" "Sol" #2=
#3_"1977 CC:*Царестья:3578 Carestia:Carestia" "Sol" #3=
".:Carestia:3578 Carestia:1977 CC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.75299316719
		SemiMajorAxis	3.210631315127
		Eccentricity	0.208162475084
		Inclination	21.312062899396
		AscendingNode	284.756406386089
		ArgOfPericenter	47.96896992289
		MeanAnomaly	49.245446725324
	}
	UniformRotation
	{
		Period	9.93
	}
	LunarLambert	0.5
	Albedo	0.0121
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3578"
}

#1_"3584 Aisha:Aisha:1981 TW:1954 RS:1965 UY:1978 EX1" "Sol" #1=
#2_"*Аиша:3584 Aisha:Aisha:1981 TW" "Sol" #2=
#3_"1981 TW:*Аиша:3584 Aisha:Aisha" "Sol" #3=
".:Aisha:3584 Aisha:1981 TW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.685
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.419289290177
		SemiMajorAxis	3.085243327935
		Eccentricity	0.097360873877
		Inclination	2.134807847897
		AscendingNode	305.154318518056
		ArgOfPericenter	106.574867540835
		MeanAnomaly	0.656682404519
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0397
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3584"
}

#1_"3587 Descartes:Descartes:1981 RK5:1975 GE1:1983 AR2" "Sol" #1=
#2_"*Декарт:3587 Descartes:Descartes:1981 RK5" "Sol" #2=
#3_"1981 RK5:*Декарт:3587 Descartes:Descartes" "Sol" #3=
".:Descartes:3587 Descartes:1981 RK5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.445009224928
		SemiMajorAxis	2.703395850828
		Eccentricity	0.039905181652
		Inclination	7.827798171267
		AscendingNode	32.992412207386
		ArgOfPericenter	26.6379945397
		MeanAnomaly	116.827312248257
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.061
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3587"
}

#1_"3591 Vladimirskij:Vladimirskij:1978 QJ2:1932 HB:1973 UH1:1979 VD3:1984 UG1" "Sol" #1=
#2_"*Владимирский:3591 Vladimirskij:Vladimirskij:1978 QJ2" "Sol" #2=
#3_"1978 QJ2:*Владимирский:3591 Vladimirskij:Vladimirskij" "Sol" #3=
".:Vladimirskij:3591 Vladimirskij:1978 QJ2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.875
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.659956238165
		SemiMajorAxis	3.175922631306
		Eccentricity	0.139086753803
		Inclination	1.141999124412
		AscendingNode	27.483471558893
		ArgOfPericenter	259.786531506256
		MeanAnomaly	211.604823761876
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1138
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3591"
}

#1_"3598 Saucier:Saucier:1977 KK1:1959 CK:1978 QU:1979 WL6" "Sol" #1=
#2_"*Саусиер:3598 Saucier:Saucier:1977 KK1" "Sol" #2=
#3_"1977 KK1:*Саусиер:3598 Saucier:Saucier" "Sol" #3=
".:Saucier:3598 Saucier:1977 KK1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.16
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.660506167407
		SemiMajorAxis	3.176128346023
		Eccentricity	0.10183377328
		Inclination	0.78017658154
		AscendingNode	161.659777784021
		ArgOfPericenter	66.593122147885
		MeanAnomaly	244.26755564414
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0584
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3598"
}

#1_"3614 Tumilty:Tumilty:1983 AE1:1952 DO:1959 RE:1974 OL:1983 CW3" "Sol" #1=
#2_"*Тумилти:3614 Tumilty:Tumilty:1983 AE1" "Sol" #2=
#3_"1983 AE1:*Тумилти:3614 Tumilty:Tumilty" "Sol" #3=
".:3614 Tumilty:1983 AE1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.06
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.147005081819
		SemiMajorAxis	2.981015699085
		Eccentricity	0.127738543021
		Inclination	16.717035633088
		AscendingNode	287.19718695031
		ArgOfPericenter	311.069151601238
		MeanAnomaly	340.537323252088
	}
	UniformRotation
	{
		Period	26.8
	}
	LunarLambert	0.5
	Albedo	0.0274
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3614"
}

#1_"3630 Lubomir:Lubomir:1984 QN:1966 TK:1970 PC1:1970 QS1:1980 XT1" "Sol" #1=
#2_"*Любомир:3630 Lubomir:Lubomir:1984 QN" "Sol" #2=
#3_"1984 QN:*Любомир:3630 Lubomir:Lubomir" "Sol" #3=
".:Lubomir:3630 Lubomir:1984 QN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.611887372578
		SemiMajorAxis	2.770641449077
		Eccentricity	0.204647722028
		Inclination	7.419356725758
		AscendingNode	336.655384681405
		ArgOfPericenter	323.955482459267
		MeanAnomaly	232.619822829581
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0535
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3630"
}

#1_"3631 Sigyn:Sigyn:1987 BV1:1952 UD:1957 QD:1968 UC2:1971 BN:1972 LW:1982 FR2:1985 YE" "Sol" #1=
#2_"*Сигюн:3631 Sigyn:Sigyn:1987 BV1" "Sol" #2=
#3_"1987 BV1:*Сигюн:3631 Sigyn:Sigyn" "Sol" #3=
".:Sigyn:3631 Sigyn:1987 BV1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.59
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.447973985048
		SemiMajorAxis	3.096120692063
		Eccentricity	0.076129028602
		Inclination	14.423476967509
		AscendingNode	150.879450883972
		ArgOfPericenter	158.41123135866
		MeanAnomaly	225.280087222955
	}
	UniformRotation
	{
		Period	41
	}
	LunarLambert	0.5
	Albedo	0.0901
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3631"
}

#1_"3637 O'Meara:O'Meara:1984 UQ:1942 GB:1942 GX:1946 GD:1950 HU:1959 OA:1972 TJ2:1983 HF1" "Sol" #1=
#2_"*О'Меара:3637 O'Meara:O'Meara:1984 UQ" "Sol" #2=
#3_"1984 UQ:*О'Меара:3637 O'Meara:O'Meara" "Sol" #3=
".:O'Meara:3637 O'Meara:1984 UQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.55
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.088713150489
		SemiMajorAxis	2.55693071739
		Eccentricity	0.123922730688
		Inclination	14.317891232143
		AscendingNode	207.847677325925
		ArgOfPericenter	69.85664022144
		MeanAnomaly	228.707270009587
	}
	UniformRotation
	{
		Period	5.49
	}
	LunarLambert	0.5
	Albedo	0.1488
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3637"
}

#1_"3641 Williams Bay:Williams Bay:A922 WC:1977 LJ:1978 RQ4:1982 HZ1:1987 FK" "Sol" #1=
#2_"*Уильямс-Бэй:3641 Williams Bay:Williams Bay:1922 WC" "Sol" #2=
#3_"1922 WC:*Уильямс-Бэй:3641 Williams Bay:Williams Bay" "Sol" #3=
".:Williams Bay:3641 Williams Bay:1922 WC" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.775
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.174794332038
		SemiMajorAxis	2.991735956047
		Eccentricity	0.13017221327
		Inclination	16.12515295923
		AscendingNode	30.804468020382
		ArgOfPericenter	293.893503540532
		MeanAnomaly	10.080322512888
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0489
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3641"
}

#1_"3642 Frieden:Frieden:1953 XL1:1936 FU:1945 BD:1950 FK:1959 CB1:1959 EB1:1978 GB3:1982 BK8: #1=
#1_A908 ED" "Sol" #1=
#2_"*Фриден:3642 Frieden:Frieden:1953 XL1:1936 FU" "Sol" #2=
#3_"1953 XL1:*Фриден:3642 Frieden:Frieden:1936 FU" "Sol" #3=
".:Frieden:3642 Frieden:1953 XL1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.555
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.656206196952
		SemiMajorAxis	2.788363151315
		Eccentricity	0.082504238853
		Inclination	13.475086870278
		AscendingNode	131.304648228734
		ArgOfPericenter	15.040884148038
		MeanAnomaly	350.535169331236
	}
	UniformRotation
	{
		Period	14.491
	}
	LunarLambert	0.5
	Albedo	0.0475
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3642"
}

#1_"3647 Dermott:Dermott:1986 AD1:1958 DP:1975 VM5:1977 DO3:1979 QK8" "Sol" #1=
#2_"*Дермотт:3647 Dermott:Dermott:1986 AD1" "Sol" #2=
#3_"1986 AD1:*Дермотт:3647 Dermott:Dermott" "Sol" #3=
".:Dermott:3647 Dermott:1986 AD1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.345
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.686213147377
		SemiMajorAxis	2.800330070136
		Eccentricity	0.101853599883
		Inclination	8.048876336647
		AscendingNode	126.160724893882
		ArgOfPericenter	219.650665018337
		MeanAnomaly	185.073120270809
	}
	UniformRotation
	{
		Period	21.779
	}
	LunarLambert	0.5
	Albedo	0.0517
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3647"
}

#1_"3650 Kunming:Kunming:1978 UO2:1950 PB:1956 TC:1956 UQ:1982 HT" "Sol" #1=
#2_"*Куньмин:3650 Kunming:Kunming:1978 UO2" "Sol" #2=
#3_"1978 UO2:*Куньмин:3650 Kunming:Kunming" "Sol" #3=
".:Kunming:3650 Kunming:1978 UO2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.11
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.51182602479
		SemiMajorAxis	3.120265379931
		Eccentricity	0.240092490285
		Inclination	14.600661267076
		AscendingNode	36.776425144621
		ArgOfPericenter	285.068915194028
		MeanAnomaly	228.843711997563
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0386
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3650"
}

#New3
#1_"3657 Ermolova:Ermolova:1978 ST6:1925 TE:1984 GD1" "Sol" #1=
#2_"*Ермолаева:3657 Ermolova:Ermolova:1978 ST6" "Sol" #2=
#3_"1978 ST6:*Ермолаева:3657 Ermolova:Ermolova" "Sol" #3=
".:Ermolova:3657 Ermolova:1978 ST6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3657 ermolova.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.328
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.517311472813
		SemiMajorAxis	2.312784053537
		Eccentricity	0.132306147418
		Inclination	5.791965156848
		AscendingNode	237.281778949472
		ArgOfPericenter	102.410593080715
		MeanAnomaly	49.542067990011
	}
	UniformRotation
	{
		Period	2.6064
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3657"
}

#1_"3660 Lazarev:Lazarev:1978 QX2:1979 WR2:1982 GF:1985 XM" "Sol" #1=
#2_"*Лазарев:3660 Lazarev:Lazarev:1978 QX2" "Sol" #2=
#3_"1978 QX2:*Лазарев:3660 Lazarev:Lazarev" "Sol" #3=
".:Lazarev:3660 Lazarev:1978 QX2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.375
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.774866490603
		SemiMajorAxis	3.218764212048
		Eccentricity	0.083854253639
		Inclination	7.793299433922
		AscendingNode	354.971036676858
		ArgOfPericenter	217.590494222167
		MeanAnomaly	229.452652789167
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.062
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3660"
}

#1_"3666 Holman:Holman:1979 HP:1938 WQ:1982 VH1:1984 CB1" "Sol" #1=
#2_"*Холман:3666 Holman:Holman:1979 HP" "Sol" #2=
#3_"1979 HP:*Холман:3666 Holman:Holman" "Sol" #3=
".:Holman:3666 Holman:1979 HP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.925
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.504962943616
		SemiMajorAxis	3.117674698121
		Eccentricity	0.126937887221
		Inclination	2.363542031247
		AscendingNode	120.388703829857
		ArgOfPericenter	54.889785047388
		MeanAnomaly	192.840149059108
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0592
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3666"
}

#1_"3671 Dionysus:Dionysus:1984 KD" "Sol" #1=
#2_"*Дионис:3671 Dionysus:Dionysus:1984 KD" "Sol" #2=
#3_"1984 KD:*Дионис:3671 Dionysus:Dionysus" "Sol" #3=
".:Dionysus:3671 Dionysus:1984 KD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.715
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.258180436463
		SemiMajorAxis	2.197748300698
		Eccentricity	0.542231980547
		Inclination	13.547936784767
		AscendingNode	82.163170768107
		ArgOfPericenter	204.202970185255
		MeanAnomaly	123.415351999745
	}
	UniformRotation
	{
		Period	2.7053
	}
	LunarLambert	0.5
	Albedo	0.16
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3671"
}

#1_"1997 3671 I" "Sol/3671 Dionysus" #1=
#2_"1997 3671 I" "Sol/3671 Dionysus" #2=
#3_"1997 3671 I" "Sol/3671 Dionysus" #3=
".:1997 3671 I" "Sol/3671 Dionysus" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.145
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	1.156
		SemiMajorAxis	3.4
		Eccentricity	0.07
	}
	LunarLambert	0.5
	Albedo	0.16
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-03671.html"
}

#1_"3678 Mongmanwai:Mongmanwai:1966 BO:1934 GS:1950 FE" "Sol" #1=
#2_"*Монгманвай:3678 Mongmanwai:Mongmanwai:1966 BO" "Sol" #2=
#3_"1966 BO:*Монгманвай:3678 Mongmanwai:Mongmanwai" "Sol" #3=
".:Mongmanwai:3678 Mongmanwai:1966 BO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3678 mongmanwai.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.986
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.080260259815
		SemiMajorAxis	2.553405417531
		Eccentricity	0.188748677978
		Inclination	8.285029997095
		AscendingNode	142.018057850967
		ArgOfPericenter	51.322341861066
		MeanAnomaly	349.360747862281
	}
	UniformRotation
	{
		Period	4.184
	}
	LunarLambert	0.5
	Albedo	0.253
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3678"
}

#1_"3682 Welther:Welther:A923 NB:1951 YO:1978 NP3:1984 AA" "Sol" #1=
#2_"*Велтнер:3682 Welther:Welther:1923 NB" "Sol" #2=
#3_"1923 NB:*Велтнер:3682 Welther:Welther" "Sol" #3=
".:Welther:3682 Welther:1923 NB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.66
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.573340391407
		SemiMajorAxis	2.755181517542
		Eccentricity	0.321966499031
		Inclination	13.571550186287
		AscendingNode	255.619225401164
		ArgOfPericenter	113.70920468
		MeanAnomaly	311.722670638623
	}
	UniformRotation
	{
		Period	3.5973
	}
	LunarLambert	0.5
	Albedo	0.1189
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3682"
}

#1_"3684 Berry:Berry:1983 AK:1952 DL1:1971 UE4:1973 FO1" "Sol" #1=
#2_"*Берри:3684 Berry:Berry:1983 AK" "Sol" #2=
#3_"1983 AK:*Берри:3684 Berry:Berry" "Sol" #3=
".:3684 Berry:Berry:1983 AK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.459862832643
		SemiMajorAxis	2.287531691058
		Eccentricity	0.15352403572
		Inclination	6.81158918135
		AscendingNode	94.985368849669
		ArgOfPericenter	67.714320777175
		MeanAnomaly	40.897935908085
	}
	UniformRotation
	{
		Period	11.9
	}
	LunarLambert	0.5
	Albedo	0.0504
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3684"
}

#1_"3685 Derdenye:Derdenye:1981 EH14:1957 WK1" "Sol" #1=
#2_"*Дерденье:3685 Derdenye:Derdenye:1981 EH14" "Sol" #2=
#3_"1981 EH14:*Дерденье:3685 Derdenye:Derdenye" "Sol" #3=
".:Derdenye:3685 Derdenye:1981 EH14" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.085
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.354088925885
		SemiMajorAxis	2.666404671765
		Eccentricity	0.174692011123
		Inclination	15.118756333668
		AscendingNode	202.876077713741
		ArgOfPericenter	183.233404474678
		MeanAnomaly	57.492791413256
	}
	UniformRotation
	{
		Period	12
	}
	LunarLambert	0.5
	Albedo	0.0817
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3685"
}

#1_"3686 Antoku:Antoku:1987 EB:1974 KF:1978 EF:1978 ET6:1979 OW14" "Sol" #1=
#2_"*Антоку:3686 Antoku:Antoku:1987 EB" "Sol" #2=
#3_"1987 EB:*Антоку:3686 Antoku:Antoku" "Sol" #3=
".:Antoku:3686 Antoku:1987 EB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.537637015988
		SemiMajorAxis	2.740823271692
		Eccentricity	0.145132587003
		Inclination	5.720944079555
		AscendingNode	134.589345270644
		ArgOfPericenter	79.122093391381
		MeanAnomaly	353.316949870115
	}
	UniformRotation
	{
		Period	6.2
	}
	LunarLambert	0.5
	Albedo	0.068
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3686"
}

#1_"3687 Dzus:Dzus:A908 TC:1952 HM3:1970 GD2:1980 TO8:1980 TX:1984 NC" "Sol" #1=
#2_"*Джус:3687 Dzus:Dzus:1908 TC" "Sol" #2=
#3_"1908 TC:*Джус:3687 Dzus:Dzus" "Sol" #3=
".:Dzus:3687 Dzus:1908 TC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.305
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.503260659934
		SemiMajorAxis	2.72696306445
		Eccentricity	0.199839733404
		Inclination	15.797223934456
		AscendingNode	224.898738351031
		ArgOfPericenter	113.899431658545
		MeanAnomaly	225.363212997405
	}
	UniformRotation
	{
		Period	7.44
	}
	LunarLambert	0.5
	Albedo	0.0542
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3687"
}

#1_"3691 Bede:Bede:1982 FT" "Sol" #1=
#2_"*Беда:3691 Bede:Bede:1982 FT" "Sol" #2=
#3_"1982 FT:*Беда:3691 Bede:Bede" "Sol" #3=
".:Bede:3691 Bede:1982 FT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.363693447676
		SemiMajorAxis	1.774415405456
		Eccentricity	0.284118240972
		Inclination	20.36010841069
		AscendingNode	348.771764056191
		ArgOfPericenter	234.883214193062
		MeanAnomaly	284.048671668728
	}
	UniformRotation
	{
		Period	226.8
	}
	LunarLambert	0.5
	Albedo	0.14
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3691"
}

#1_"3693 Barringer:Barringer:1982 RU" "Sol" #1=
#2_"*Баррингер:3693 Barringer:Barringer:1982 RU" "Sol" #2=
#3_"1982 RU:*Баррингер:3693 Barringer:Barringer" "Sol" #3=
".:Barringer:3693 Barringer:1982 RU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3693 barringer.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	13.747
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.580528237777
		SemiMajorAxis	3.146140198987
		Eccentricity	0.204525192008
		Inclination	14.920783809612
		AscendingNode	178.878029519504
		ArgOfPericenter	184.760936206697
		MeanAnomaly	289.176722605269
	}
	UniformRotation
	{
		Period	6.626
	}
	LunarLambert	0.5
	Albedo	0.049
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3693"
}

#1_"3694 Sharon:Sharon:1984 SH5:1979 FJ1:1986 AX" "Sol" #1=
#2_"*Шерон:3694 Sharon:Sharon:1984 SH5" "Sol" #2=
#3_"1984 SH5:*Шерон:3694 Sharon:Sharon" "Sol" #3=
".:Sharon:3694 Sharon:1984 SH5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.655
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.806715904475
		SemiMajorAxis	3.935260157789
		Eccentricity	0.206223474804
		Inclination	4.976445766301
		AscendingNode	311.093592883023
		ArgOfPericenter	80.780102981985
		MeanAnomaly	302.173037126221
	}
	UniformRotation
	{
		Period	11.478
	}
	LunarLambert	0.5
	Albedo	0.0653
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3694"
}

#1_"3702 Trubetskaya:Trubetskaya:1970 NB:1975 XL:1975 XZ4:1982 JB4" "Sol" #1=
#2_"*Трубецкая:3702 Trubetskaya:Trubetskaya:1970 NB" "Sol" #2=
#3_"1970 NB:*Трубецкая:3702 Trubetskaya:Trubetskaya" "Sol" #3=
".:Trubetskaya:3702 Trubetskaya:1970 NB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.595
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.245007458979
		SemiMajorAxis	2.621682953751
		Eccentricity	0.236843793161
		Inclination	15.649245638237
		AscendingNode	119.951032132703
		ArgOfPericenter	254.776132033964
		MeanAnomaly	115.797925996716
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1369
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3702"
}

#1_"3708 1974 FV1:1974 FV1:1930 XF:1953 SG:1965 TA:1974 HN3:1975 NQ" "Sol" #1=
#2_"1974 FV1:3708 1974 FV1:1930 XF" "Sol" #2=
#3_"1974 FV1:3708 1974 FV1:1930 XF" "Sol" #3=
".:1930 XF:3708 1974 FV1:1953 SG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	39.795
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.910920782049
		SemiMajorAxis	5.215445633714
		Eccentricity	0.159100187152
		Inclination	13.373063751675
		AscendingNode	291.171818100704
		ArgOfPericenter	57.870961924116
		MeanAnomaly	76.899807758154
	}
	UniformRotation
	{
		Period	6.553
	}
	LunarLambert	0.5
	Albedo	0.0531
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3708"
}

#1_"3709 Polypoites:Polypoites:1985 TL3:1971 OK1:1979 HQ2:1985 WK" "Sol" #1=
#2_"*Полипет:3709 Polypoites:Polypoites:1985 TL3" "Sol" #2=
#3_"1985 TL3:*Полипет:3709 Polypoites:Polypoites" "Sol" #3=
".:Polypoites:3709 Polypoites:1985 TL3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	49.545
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.013739394979
		SemiMajorAxis	5.245416802556
		Eccentricity	0.060429282099
		Inclination	19.620818910427
		AscendingNode	187.146094312059
		ArgOfPericenter	247.709169500194
		MeanAnomaly	103.054556136278
	}
	UniformRotation
	{
		Period	5.71
	}
	LunarLambert	0.5
	Albedo	0.0452
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3709"
}

#1_"3714 Kenrussell:Kenrussell:1983 TT1:1973 FK:1979 XT:1981 FH1:1987 ST2" "Sol" #1=
#2_"*Кенрасселл:3714 Kenrussell:Kenrussell:1983 TT1" "Sol" #2=
#3_"1983 TT1:*Кенрасселл:3714 Kenrussell:Kenrussell" "Sol" #3=
".:Kenrussell:3714 Kenrussell:1983 TT1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.575
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.101257258267
		SemiMajorAxis	2.562157795774
		Eccentricity	0.177861057956
		Inclination	14.363544342102
		AscendingNode	29.626911295039
		ArgOfPericenter	22.823357687027
		MeanAnomaly	193.070934464053
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1078
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3714"
}

#1_"3722 Urata:Urata:1927 UE:1937 UL:1937 VP:1967 TA:1984 YV2" "Sol" #1=
#2_"*Урата:3722 Urata:Urata:1927 UE" "Sol" #2=
#3_"1927 UE:*Урата:3722 Urata:Urata" "Sol" #3=
".:Urata:3722 Urata:1927 UE:1937 UL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3722 urata.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.934
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.34474036889
		SemiMajorAxis	2.236502938242
		Eccentricity	0.198962976648
		Inclination	6.457206697575
		AscendingNode	232.428316686681
		ArgOfPericenter	136.394654644116
		MeanAnomaly	98.786120753399
	}
	UniformRotation
	{
		Period	5.567
	}
	LunarLambert	0.5
	Albedo	0.197
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3722"
}

#1_"3724 Annenskij:Annenskij:1979 YN8:1933 XB:1955 QQ:1965 YM:1969 RF2:1974 VM2:1980 AE:1985 DF1" "Sol" #1=
#2_"*Анненский:3724 Annenskij:Annenskij:1979 YN8" "Sol" #2=
#3_"1979 YN8:*Анненский:3724 Annenskij:Annenskij" "Sol" #3=
".:Annenskij:3724 Annenskij:1979 YN8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.075
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.595488217362
		SemiMajorAxis	2.764069570006
		Eccentricity	0.165419848027
		Inclination	7.734705392816
		AscendingNode	269.274642358636
		ArgOfPericenter	117.597054296732
		MeanAnomaly	278.946838099555
	}
	UniformRotation
	{
		Period	3.974
	}
	LunarLambert	0.5
	Albedo	0.2022
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3724"
}

#1_"3725 Valsecchi:Valsecchi:1981 EA11:1974 SZ2" "Sol" #1=
#2_"*Вальсекки:3725 Valsecchi:Valsecchi:1981 EA11" "Sol" #2=
#3_"1981 EA11:Valsecchi:*Вальсекки:3725 Valsecchi" "Sol" #3=
".:Valsecchi:3725 Valsecchi:1981 EA11" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3725 valsecchi.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.63
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.39463529563
		SemiMajorAxis	2.682932572522
		Eccentricity	0.203751434667
		Inclination	11.407335458478
		AscendingNode	345.641374444424
		ArgOfPericenter	17.713231865333
		MeanAnomaly	236.781715486464
	}
	UniformRotation
	{
		Period	3.57
	}
	LunarLambert	0.5
	Albedo	0.111
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3725"
}

#1_"3728 IRAS:IRAS:1983 QF:1948 RN:1963 FA:1972 FH:1976 GL:1985 GT" "Sol" #1=
#2_"IRAS:3728 IRAS:1983 QF" "Sol" #2=
#3_"1983 QF:IRAS:3728 IRAS" "Sol" #3=
".:IRAS:3728 IRAS:1983 QF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.775
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.314707463308
		SemiMajorAxis	2.650302436205
		Eccentricity	0.213130495712
		Inclination	22.593172564296
		AscendingNode	167.373138570822
		ArgOfPericenter	281.23031385076
		MeanAnomaly	47.657209266232
	}
	UniformRotation
	{
		Period	8.323
	}
	LunarLambert	0.5
	Albedo	0.1161
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3728"
}

#1_"3730 Hurban:Hurban:1983 XM1:1955 QB:1962 BE:1973 QV:1975 BL1:1982 OC:A919 QA" "Sol" #1=
#2_"*Гурбан:3730 Hurban:Hurban:1983 XM1" "Sol" #2=
#3_"1983 XM1:*Гурбан:3730 Hurban:Hurban" "Sol" #3=
".:Hurban:3730 Hurban:1983 XM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.19
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.498261257213
		SemiMajorAxis	2.724944421904
		Eccentricity	0.162874487962
		Inclination	6.957415915939
		AscendingNode	305.544221073757
		ArgOfPericenter	41.286511076376
		MeanAnomaly	43.495101027342
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0484
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3730"
}

#1_"3731 Hancock:Hancock:1984 DH1:1969 OA:1969 PR" "Sol" #1=
#2_"*Хэнкок:3731 Hancock:Hancock:1984 DH1" "Sol" #2=
#3_"1984 DH1:*Хэнкок:3731 Hancock:Hancock" "Sol" #3=
".:Hancock:3731 Hancock:1984 DH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.799400224944
		SemiMajorAxis	3.227874090423
		Eccentricity	0.116476451385
		Inclination	21.571141428175
		AscendingNode	264.294388072776
		ArgOfPericenter	253.536962412323
		MeanAnomaly	80.20277102436
	}
	UniformRotation
	{
		Period	6.712
	}
	LunarLambert	0.5
	Albedo	0.0552
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3731"
}

#1_"3735 Trebon:Trebon:1983 XS:1973 YX3:1974 CK:A903 BE" "Sol" #1=
#2_"*Тршебонь:3735 Trebon:Trebon:1983 XS" "Sol" #2=
#3_"1983 XS:Trebon:*Тршебонь:3735 Trebon" "Sol" #3=
".:Trebon:3735 Trebon:1983 XS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3735 trebon.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	10.487
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.454045314725
		SemiMajorAxis	3.098420517016
		Eccentricity	0.150888995915
		Inclination	5.207774763339
		AscendingNode	298.197930434099
		ArgOfPericenter	259.157897623304
		MeanAnomaly	258.811262069834
	}
	UniformRotation
	{
		Period	8.4709
	}
	LunarLambert	0.5
	Albedo	0.092
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3735"
}

#1_"3744 Horn-d'Arturo:Horn-d'Arturo:1983 VE:1966 VQ:1979 YF8" "Sol" #1=
#2_"*Орн-д'Артуро:3744 Horn-d'Arturo:Horn-d'Arturo:1983 VE" "Sol" #2=
#3_"1983 VE:*Орн-д'Артуро:3744 Horn-d'Arturo:Horn-d'Arturo" "Sol" #3=
".:Horn-d'Arturo:3744 Horn-d'Arturo:1983 VE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.875
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.260416164228
		SemiMajorAxis	2.628023317997
		Eccentricity	0.277719115945
		Inclination	3.753708379951
		AscendingNode	228.111606559324
		ArgOfPericenter	185.870328803395
		MeanAnomaly	99.43571421725
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.054
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3744"
}

#1_"3746 Heyuan:Heyuan:1964 TC1:1935 SD2:1976 YM5:1981 RS4" "Sol" #1=
#2_"*ХэЮань:3746 Heyuan:Heyuan:1964 TC1" "Sol" #2=
#3_"1964 TC1:Heyuan:*ХэЮань:3746 Heyuan" "Sol" #3=
".:Heyuan:3746 Heyuan:1964 TC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3746 heyuan.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	7.601
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.661605353329
		SemiMajorAxis	3.176539503905
		Eccentricity	0.249356639867
		Inclination	1.028303041936
		AscendingNode	24.520960461314
		ArgOfPericenter	304.570768142172
		MeanAnomaly	109.641788011858
	}
	UniformRotation
	{
		Period	16.301
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3746"
}

#1_"3747 Belinskij:Belinskij:1975 VY5:1930 XR:1981 SF8:1981 VE" "Sol" #1=
#2_"*Белинский:3747 Belinskij:Belinskij:1975 VY5" "Sol" #2=
#3_"1975 VY5:*Белинский:3747 Belinskij:Belinskij" "Sol" #3=
".:Belinskij:3747 Belinskij:1975 VY5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.697092440109
		SemiMajorAxis	3.189799429451
		Eccentricity	0.119498434059
		Inclination	24.353741753783
		AscendingNode	38.214522430098
		ArgOfPericenter	105.047217102209
		MeanAnomaly	196.17706073474
	}
	UniformRotation
	{
		Period	3.31
	}
	LunarLambert	0.5
	Albedo	0.0898
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3747"
}

#1_"3749 Balam:Balam:1982 BG1:1954 XM:1962 ED:1974 YO" "Sol" #1=
#2_"*Балам:3749 Balam:Balam:1982 BG1" "Sol" #2=
#3_"1982 BG1:*Балам:3749 Balam:Balam" "Sol" #3=
".:Balam:3749 Balam:1982 BG1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.975
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.344821817661
		SemiMajorAxis	2.236539245928
		Eccentricity	0.109319947518
		Inclination	5.382337769953
		AscendingNode	295.739790557125
		ArgOfPericenter	174.035279004933
		MeanAnomaly	319.283468539864
	}
	UniformRotation
	{
		Period	2.80483
	}
	LunarLambert	0.5
	Albedo	0.16
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3749"
}

#1_"2008 3749 I" "Sol/3749 Balam" #1=
#2_"2008 3749 I" "Sol/3749 Balam" #2=
#3_"2008 3749 I" "Sol/3749 Balam" #3=
".:2008 3749 I" "Sol/3749 Balam" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.83
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	1.391
		SemiMajorAxis	20
	}
	LunarLambert	0.5
	Albedo	0.16
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-03749.html"
}

#1_"2002 3749 I" "Sol/3749 Balam" #1=
#2_"2002 3749 I" "Sol/3749 Balam" #2=
#3_"2002 3749 I" "Sol/3749 Balam" #3=
".:2002 3749 I" "Sol/3749 Balam" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.92
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	61
		SemiMajorAxis	289
		Eccentricity	0.9
	}
	LunarLambert	0.5
	Albedo	0.16
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-03749.html"
}

#1_"3751 Kiang:Kiang:1983 NK:1954 GN:1977 LM1:1977 NA" "Sol" #1=
#2_"*Цян:3751 Kiang:Kiang:1983 NK" "Sol" #2=
#3_"1983 NK:*Цян:3751 Kiang:Kiang" "Sol" #3=
".:Kiang:3751 Kiang:1983 NK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.78
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.589117981247
		SemiMajorAxis	3.14936780373
		Eccentricity	0.100998016156
		Inclination	13.224727547984
		AscendingNode	271.33723328
		ArgOfPericenter	21.439835232224
		MeanAnomaly	236.173024661022
	}
	UniformRotation
	{
		Period	8.2421
	}
	LunarLambert	0.5
	Albedo	0.0794
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3751"
}

#1_"3752 Camillo:Camillo:1985 PA" "Sol" #1=
#2_"*Камилло:3752 Camillo:Camillo:1985 PA" "Sol" #2=
#3_"1985 PA:*Камилло:3752 Camillo:Camillo" "Sol" #3=
".:Camillo:3752 Camillo:1985 PA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3752 camillo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.153
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.680358924994
		SemiMajorAxis	1.413391808056
		Eccentricity	0.301805285182
		Inclination	55.559798987142
		AscendingNode	147.978800494158
		ArgOfPericenter	312.219660990398
		MeanAnomaly	57.384195258527
	}
	UniformRotation
	{
		Period	37.846
	}
	LunarLambert	0.5
	Albedo	0.21
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3752"
}

#1_"3753 Cruithne:Cruithne:1986 TO:1983 UH" "Sol" #1=
#2_"*Круитни:3753 Cruithne:Cruithne:1986 TO" "Sol" #2=
#3_"1986 TO:*Круитни:3753 Cruithne:Cruithne" "Sol" #3=
".:Cruithne:3753 Cruithne:1986 TO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	2.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.996543327812
		SemiMajorAxis	0.997681660382
		Eccentricity	0.514873364462
		Inclination	19.807604746548
		AscendingNode	126.244999815522
		ArgOfPericenter	43.812001748101
		MeanAnomaly	348.458971732306
	}
	UniformRotation
	{
		Period	27.3099
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"https://en.wikipedia.org/wiki/3753_Cruithne"
}

#1_"3754 Kathleen:Kathleen:1931 FM:1925 BF:1929 WA1:1955 MR:1957 WH1:1959 CH1:1959 EC1:1963 WD: #1=
#1_1977 KR:1978 NM2:1982 DQ4:1985 UD4:1987 BK:A909 HE" "Sol" #1=
#2_"*Кэтлин:3754 Kathleen:Kathleen:1931 FM" "Sol" #2=
#3_"1931 FM:*Кэтлин:3754 Kathleen:Kathleen" "Sol" #3=
".:Kathleen:3754 Kathleen:1931 FM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.615
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.615116891191
		SemiMajorAxis	3.159126860615
		Eccentricity	0.109039030005
		Inclination	8.460842050812
		AscendingNode	110.561729203294
		ArgOfPericenter	56.467260694785
		MeanAnomaly	306.029096487647
	}
	UniformRotation
	{
		Period	11.17
	}
	LunarLambert	0.5
	Albedo	0.0624
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3754"
}

#1_"3757 Anagolay:Anagolay:1982 XB" "Sol" #1=
#2_"*Анаголай:3757 Anagolay:Anagolay:1982 XB" "Sol" #2=
#3_"1982 XB:*Анаголай:3757 Anagolay:Anagolay" "Sol" #3=
".:Anagolay:3757 Anagolay:1982 XB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.485442018159
		SemiMajorAxis	1.834834746818
		Eccentricity	0.445589859436
		Inclination	3.868007745277
		AscendingNode	74.980922989985
		ArgOfPericenter	17.168301061749
		MeanAnomaly	305.969087418448
	}
	UniformRotation
	{
		Period	9.0046
	}
	LunarLambert	0.5
	Albedo	0.18
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3757"
}

#1_"3758 Karttunen:Karttunen:1983 WP" "Sol" #1=
#2_"*Карттунен:3758 Karttunen:Karttunen:1983 WP" "Sol" #2=
#3_"1983 WP:Karttunen:*Карттунен:3758 Karttunen" "Sol" #3=
".:Karttunen:3758 Karttunen:1983 WP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3758 karttunen.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.906
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.264459448336
		SemiMajorAxis	2.629685779205
		Eccentricity	0.113951111253
		Inclination	14.139901125566
		AscendingNode	80.947890610848
		ArgOfPericenter	56.291770254782
		MeanAnomaly	227.60709912469
	}
	UniformRotation
	{
		Period	12.50101
	}
	LunarLambert	0.5
	Albedo	0.241
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3758"
}

#1_"3759 Piironen:Piironen:1984 AP" "Sol" #1=
#2_"*Пииронен:3759 Piironen:Piironen:1984 AP" "Sol" #2=
#3_"1984 AP:*Пииронен:3759 Piironen:Piironen" "Sol" #3=
".:Piironen:3759 Piironen:1984 AP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.075
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.482714147599
		SemiMajorAxis	2.718662075792
		Eccentricity	0.117085134486
		Inclination	13.059657807279
		AscendingNode	292.955118952204
		ArgOfPericenter	166.642725681125
		MeanAnomaly	325.488433919742
	}
	UniformRotation
	{
		Period	15.02
	}
	LunarLambert	0.5
	Albedo	0.0297
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3759"
}

#1_"3772 Piaf:Piaf:1982 UR7:1943 GN:1950 TR2:1958 DR:1969 FJ:1972 XK2" "Sol" #1=
#2_"*Пиаф:3772 Piaf:Piaf:1982 UR7" "Sol" #2=
#3_"1982 UR7:*Пиаф:3772 Piaf:Piaf" "Sol" #3=
".:Piaf:3772 Piaf:1982 UR7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.965
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.254008596921
		SemiMajorAxis	3.022189677428
		Eccentricity	0.061815887417
		Inclination	11.025199112461
		AscendingNode	101.518766580854
		ArgOfPericenter	195.436610997455
		MeanAnomaly	154.188656560986
	}
	UniformRotation
	{
		Period	5.376
	}
	LunarLambert	0.5
	Albedo	0.087
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3772"
}

#1_"3773 Smithsonian:Smithsonian:1984 YY:1938 DA2:1971 TS:1974 QO:1981 YC2" "Sol" #1=
#2_"*Смитсониан:3773 Smithsonian:Smithsonian:1984 YY" "Sol" #2=
#3_"1984 YY:Smithsonian:*Смитсониан:3773 Smithsonian" "Sol" #3=
".:Smithsonian:3773 Smithsonian:1984 YY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3773 smithsonian.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.597
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.186799728997
		SemiMajorAxis	2.165530872405
		Eccentricity	0.184348773851
		Inclination	1.326267425028
		AscendingNode	63.445856894301
		ArgOfPericenter	286.735768204365
		MeanAnomaly	103.019909354866
	}
	UniformRotation
	{
		Period	6.9804
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3773"
}

#1_"3776 Vartiovuori:Vartiovuori:1938 GG:1952 UO:1952 WD:1975 TC5:1975 VG7" "Sol" #1=
#2_"*Вартиовуори:3776 Vartiovuori:Vartiovuori:1938 GG" "Sol" #2=
#3_"1938 GG:*Вартиовуори:3776 Vartiovuori:Vartiovuori" "Sol" #3=
".:Vartiovuori:3776 Vartiovuori:1938 GG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.71
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.682439082917
		SemiMajorAxis	3.184327476771
		Eccentricity	0.065386318032
		Inclination	27.405978836499
		AscendingNode	39.647969289682
		ArgOfPericenter	162.116822537877
		MeanAnomaly	158.857443547159
	}
	UniformRotation
	{
		Period	7.7
	}
	LunarLambert	0.5
	Albedo	0.2229
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3776"
}

#1_"3781 Dufek:Dufek:1986 RG1:1936 FZ:1948 TK1:1972 TS1:1981 OA:1982 VE1:1984 CO" "Sol" #1=
#2_"*Дуфек:3781 Dufek:Dufek:1986 RG1" "Sol" #2=
#3_"1986 RG1:*Дуфек:3781 Dufek:Dufek" "Sol" #3=
".:Dufek:3781 Dufek:1986 RG1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.796909677489
		SemiMajorAxis	2.844257372909
		Eccentricity	0.075742354433
		Inclination	2.046464818899
		AscendingNode	183.663039645224
		ArgOfPericenter	157.437447222393
		MeanAnomaly	321.2974583782
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0578
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3781"
}

#1_"3784 Chopin:Chopin:1986 UL1:1951 KY:1977 AB2:1978 GG2" "Sol" #1=
#2_"*Шопен:3784 Chopin:Chopin:1986 UL1" "Sol" #2=
#3_"1986 UL1:*Шопен:3784 Chopin:Chopin" "Sol" #3=
".:Chopin:3784 Chopin:1986 UL1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.526827668344
		SemiMajorAxis	3.12592447257
		Eccentricity	0.167759803656
		Inclination	13.547756218086
		AscendingNode	94.732730583733
		ArgOfPericenter	192.579020725602
		MeanAnomaly	138.559826968401
	}
	UniformRotation
	{
		Period	12.72
	}
	LunarLambert	0.5
	Albedo	0.0864
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3784"
}

#1_"3786 Yamada:Yamada:1988 AE:1931 AE1:1954 XJ:1958 WB:1973 MA" "Sol" #1=
#2_"*Ямада:3786 Yamada:Yamada:1988 AE" "Sol" #2=
#3_"1988 AE:Yamada:*Ямада:3786 Yamada" "Sol" #3=
".:Yamada:3786 Yamada:1988 AE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3786 yamada.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.258
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.071278068034
		SemiMajorAxis	2.549656702373
		Eccentricity	0.081209406246
		Inclination	14.317109903442
		AscendingNode	261.765117713582
		ArgOfPericenter	356.72679578246
		MeanAnomaly	263.347138612917
	}
	UniformRotation
	{
		Period	4.034
	}
	LunarLambert	0.5
	Albedo	0.409
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3786"
}

#1_"3787 Aivazovskij:Aivazovskij:1977 RG7:1931 DM:1967 RO:1987 UA3" "Sol" #1=
#2_"*Айвазовский:3787 Aivazovskij:Aivazovskij:1977 RG7" "Sol" #2=
#3_"1977 RG7:Aivazovskij:*Айвазовский:3787 Aivazovskij" "Sol" #3=
".:Aivazovskij:3787 Aivazovskij:1977 RG7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3787 aivazovskij.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.044
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.817155485497
		SemiMajorAxis	2.85225472422
		Eccentricity	0.129835658536
		Inclination	12.055394968551
		AscendingNode	185.880597492993
		ArgOfPericenter	305.618110448479
		MeanAnomaly	325.449811240219
	}
	UniformRotation
	{
		Period	2.97
	}
	LunarLambert	0.5
	Albedo	0.333
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3787"
}

#1_"3793 Leonteus:Leonteus:1985 TE3:1951 WT1:1961 TB:1973 UJ3:1978 GO:1980 KX1:1986 XO" "Sol" #1=
#2_"*Леонтей:3793 Leonteus:Leonteus:1985 TE3" "Sol" #2=
#3_"1985 TE3:*Леонтей:3793 Leonteus:Leonteus" "Sol" #3=
".:Leonteus:3793 Leonteus:1985 TE3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	43.13
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.889702183204
		SemiMajorAxis	5.209249788529
		Eccentricity	0.090394602216
		Inclination	20.91388657483
		AscendingNode	200.548066509702
		ArgOfPericenter	262.911452654792
		MeanAnomaly	95.360806455457
	}
	UniformRotation
	{
		Period	11.22
	}
	LunarLambert	0.5
	Albedo	0.0717
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3793"
}

#1_"3799 Novgorod:Novgorod:1979 SL9:1977 FX2:1978 NH8" "Sol" #1=
#2_"*Новгород:3799 Novgorod:Novgorod:1979 SL9" "Sol" #2=
#3_"1979 SL9:*Новгород:3799 Novgorod:Novgorod" "Sol" #3=
".:Novgorod:3799 Novgorod:1979 SL9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.595589584325
		SemiMajorAxis	3.15179842304
		Eccentricity	0.144015441734
		Inclination	1.351209872406
		AscendingNode	156.94280183
		ArgOfPericenter	94.968566479796
		MeanAnomaly	221.04342397833
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1003
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3799"
}

#1_"3803 Tuchkova:Tuchkova:1981 TP1:1952 HF4:1976 YA1:1980 RU3:1981 WB4:1984 JV" "Sol" #1=
#2_"*Тучкова:3803 Tuchkova:Tuchkova:1981 TP1" "Sol" #2=
#3_"1981 TP1:*Тучкова:3803 Tuchkova:Tuchkova" "Sol" #3=
".:Tuchkova:3803 Tuchkova:1981 TP1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.725
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.32929081682
		SemiMajorAxis	3.050990194728
		Eccentricity	0.05297322946
		Inclination	13.047000395109
		AscendingNode	250.49326953743
		ArgOfPericenter	276.363176007968
		MeanAnomaly	319.823691392746
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0425
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3803"
}

#1_"3805 Goldreich:Goldreich:1981 DK3:1978 NK7" "Sol" #1=
#2_"*Голдрайх:3805 Goldreich:Goldreich:1981 DK3" "Sol" #2=
#3_"1981 DK3:*Голдрайх:3805 Goldreich:Goldreich" "Sol" #3=
".:Goldreich:3805 Goldreich:1981 DK3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.39653720535
		SemiMajorAxis	2.683706596184
		Eccentricity	0.188003746696
		Inclination	11.835206818022
		AscendingNode	312.472415916248
		ArgOfPericenter	64.106043641875
		MeanAnomaly	47.053918856714
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1165
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3805"
}

#1_"3812 Lidaksum:Lidaksum:1965 AK1:1982 BU2" "Sol" #1=
#2_"*Лидаксум:3812 Lidaksum:Lidaksum:1965 AK1" "Sol" #2=
#3_"1965 AK1:*Лидаксум:3812 Lidaksum:Lidaksum" "Sol" #3=
".:Lidaksum:3812 Lidaksum:1965 AK1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.045
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.650593054387
		SemiMajorAxis	3.172419076286
		Eccentricity	0.118006995509
		Inclination	18.420490929309
		AscendingNode	123.01927026174
		ArgOfPericenter	37.116139576449
		MeanAnomaly	260.381853569384
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0318
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3812"
}

#1_"3815 Konig:Konig:1959 GG:1955 HJ:1959 GT:1959 JD:1967 EL:1967 GR:1969 VZ:1977 UZ:1981 RT3: #1=
#1_1985 TC2" "Sol" #1=
#2_"*Кёниг:3815 Konig:Konig:1959 GG" "Sol" #2=
#3_"1959 GG:*Кёниг:3815 Konig:Konig" "Sol" #3=
".:Konig:3815 Konig:1959 GG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.605
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.119224451795
		SemiMajorAxis	2.569635378875
		Eccentricity	0.10617386337
		Inclination	8.641342499634
		AscendingNode	197.243983987517
		ArgOfPericenter	10.441220310845
		MeanAnomaly	178.195026485028
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.036
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3815"
}

#1_"3818 Gorlitsa:Gorlitsa:1979 QL8:1968 QL:1979 SR3" "Sol" #1=
#2_"*Горлица:3818 Gorlitsa:Gorlitsa:1979 QL8" "Sol" #2=
#3_"1979 QL8:*Горлица:3818 Gorlitsa:Gorlitsa" "Sol" #3=
".:Gorlitsa:3818 Gorlitsa:1979 QL8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.09
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.644555803983
		SemiMajorAxis	2.368232125287
		Eccentricity	0.179213764936
		Inclination	2.038590463922
		AscendingNode	244.045393586459
		ArgOfPericenter	64.056831419534
		MeanAnomaly	269.811785234918
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0356
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3818"
}

#1_"3822 Segovia:Segovia:1988 DP1:1962 ST:1976 YE2:1979 UP:1986 WV9" "Sol" #1=
#2_"*Сеговия:3822 Segovia:Segovia:1988 DP1" "Sol" #2=
#3_"1988 DP1:Segovia:*Сеговия:3822 Segovia" "Sol" #3=
".:Segovia:3822 Segovia:1988 DP1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3822 segovia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	3.652
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.419481579628
		SemiMajorAxis	2.269697839271
		Eccentricity	0.117268086983
		Inclination	2.559819099766
		AscendingNode	335.914921674066
		ArgOfPericenter	280.396997853843
		MeanAnomaly	101.798255726389
	}
	UniformRotation
	{
		Period	11.03204
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3822"
}

#1_"3829 Gunma:Gunma:1988 EM:1951 GO1:1958 TD:1979 HX6:1981 SU4:1981 UY10:1984 KG:1986 UE2" "Sol" #1=
#2_"*Гунма:3829 Gunma:Gunma:1988 EM:1951 GO1" "Sol" #2=
#3_"1988 EM:*Гунма:3829 Gunma:Gunma:1951 GO1" "Sol" #3=
".:Gunma:3829 Gunma:1988 EM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.165
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.64711843808
		SemiMajorAxis	2.784733841538
		Eccentricity	0.166660710504
		Inclination	7.54894393385
		AscendingNode	189.553157989762
		ArgOfPericenter	315.000165301513
		MeanAnomaly	275.695411341643
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0393
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3829"
}

#1_"3838 Epona:Epona:1986 WA" "Sol" #1=
#2_"*Эпона:3838 Epona:Epona:1986 WA" "Sol" #2=
#3_"1986 WA:*Эпона:3838 Epona:Epona" "Sol" #3=
".:Epona:3838 Epona:1986 WA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.845941304024
		SemiMajorAxis	1.504780391937
		Eccentricity	0.702444265862
		Inclination	29.216222933373
		AscendingNode	235.545684481433
		ArgOfPericenter	49.660191140651
		MeanAnomaly	103.868793480212
	}
	UniformRotation
	{
		Period	2.3812
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3838"
}

#1_"3839 Bogaevskij:Bogaevskij:1971 OU:1976 YN3:1979 SQ12:1979 SQ6" "Sol" #1=
#2_"*Богаевский:3839 Bogaevskij:Bogaevskij:1971 OU" "Sol" #2=
#3_"1971 OU:*Богаевский:3839 Bogaevskij:Bogaevskij" "Sol" #3=
".:Bogaevskij:3839 Bogaevskij:1971 OU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.832068192906
		SemiMajorAxis	2.448781399329
		Eccentricity	0.184193731889
		Inclination	2.68841093395
		AscendingNode	240.775553042613
		ArgOfPericenter	36.426813110432
		MeanAnomaly	134.557077095999
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1378
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3839"
}

#1_"3846 Hazel:Hazel:1980 TK5:1955 UD1:1978 GH3:1978 JM3:1983 HH" "Sol" #1=
#2_"*Хазел:3846 Hazel:Hazel:1980 TK5" "Sol" #2=
#3_"1980 TK5:*Хазел:3846 Hazel:Hazel" "Sol" #3=
".:Hazel:3846 Hazel:1980 TK5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.038214578247
		SemiMajorAxis	2.938860501538
		Eccentricity	0.084163339684
		Inclination	9.039430086204
		AscendingNode	223.615318119069
		ArgOfPericenter	285.48774477498
		MeanAnomaly	154.029167206043
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0753
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3846"
}

#1_"3855 Pasasymphonia:Pasasymphonia:1986 NF1:1936 RM:1946 QE:1963 UO:1963 WA:1979 HQ5:1985 DR" "Sol" #1=
#2_"*Пасасимфония:3855 Pasasymphonia:Pasasymphonia:1986 NF1" "Sol" #2=
#3_"1986 NF1:*Пасасимфония:3855 Pasasymphonia:Pasasymphonia" "Sol" #3=
".:Pasasymphonia:3855 Pasasymphonia:1986 NF1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.145
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.349293275828
		SemiMajorAxis	2.2385320506
		Eccentricity	0.208689251456
		Inclination	6.841274451189
		AscendingNode	106.011280304948
		ArgOfPericenter	233.707097184747
		MeanAnomaly	141.185715905331
	}
	UniformRotation
	{
		Period	6.5131
	}
	LunarLambert	0.5
	Albedo	0.2569
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3855"
}

#1_"3872 Akirafujii:Akirafujii:1983 AV:1931 AY" "Sol" #1=
#2_"*Акирафудзии:3872 Akirafujii:Akirafujii:1983 AV" "Sol" #2=
#3_"1983 AV:*Акирафудзии:3872 Akirafujii:Akirafujii" "Sol" #3=
".:Akirafujii:3872 Akirafujii:1983 AV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.342650113843
		SemiMajorAxis	2.661732607894
		Eccentricity	0.203469843713
		Inclination	13.042032423674
		AscendingNode	94.785331585012
		ArgOfPericenter	65.931172713535
		MeanAnomaly	97.29590173499
	}
	UniformRotation
	{
		Period	10.635
	}
	LunarLambert	0.5
	Albedo	0.0583
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3872"
}

#1_"3876 Quaide:Quaide:1988 KJ:1978 NF8:1980 XZ2:1984 UP1:1987 DH1" "Sol" #1=
#2_"*Куэйд:3876 Quaide:Quaide:1988 KJ" "Sol" #2=
#3_"1988 KJ:*Куэйд:3876 Quaide:Quaide" "Sol" #3=
".:Quaide:3876 Quaide:1988 KJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.243114011171
		SemiMajorAxis	3.018010405746
		Eccentricity	0.084798196406
		Inclination	11.248670751536
		AscendingNode	101.499569892333
		ArgOfPericenter	193.720387966709
		MeanAnomaly	333.820117021223
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1111
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3876"
}

#1_"3895 Earhart:Earhart:1987 DE:1969 EB:1980 GS:1981 PO" "Sol" #1=
#2_"*Эрхарт:3895 Earhart:Earhart:1987 DE" "Sol" #2=
#3_"1987 DE:*Эрхарт:3895 Earhart:Earhart" "Sol" #3=
".:Earhart:3895 Earhart:1987 DE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.47
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.605817824712
		SemiMajorAxis	2.351420964974
		Eccentricity	0.180877387055
		Inclination	24.3484032467
		AscendingNode	150.822673477967
		ArgOfPericenter	8.778255522943
		MeanAnomaly	246.853910546902
	}
	UniformRotation
	{
		Period	3.564
	}
	LunarLambert	0.5
	Albedo	0.1228
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3895"
}

#1_"3899 Wichterle:Wichterle:1982 SN1:1948 TF2:1949 YG:1949 YW:1951 GL1:1953 RX:1954 YN:1965 SQ: #1=
#1_1976 SZ:1984 CB:1985 FQ:1987 OF1" "Sol" #1=
#2_"*Вихтерле:3899 Wichterle:Wichterle:1982 SN1" "Sol" #2=
#3_"1982 SN1:*Вихтерле:3899 Wichterle:Wichterle" "Sol" #3=
".:Wichterle:3899 Wichterle:1982 SN1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.88
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.690222220215
		SemiMajorAxis	3.187234491795
		Eccentricity	0.178231025334
		Inclination	2.819556598652
		AscendingNode	82.038083463929
		ArgOfPericenter	326.310382194805
		MeanAnomaly	213.327442483391
	}
	UniformRotation
	{
		Period	5.8572
	}
	LunarLambert	0.5
	Albedo	0.1037
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3899"
}

#1_"3901 Nanjingdaxue:Nanjingdaxue:1958 GQ:1954 KE:1958 GH:1976 SC4" "Sol" #1=
#2_"*НаньЦзиньДаСюэ:3901 Nanjingdaxue:Nanjingdaxue:1958 GQ" "Sol" #2=
#3_"1958 GQ:*НаньЦзиньДаСюэ:3901 Nanjingdaxue:Nanjingdaxue" "Sol" #3=
".:Nanjingdaxue:3901 Nanjingdaxue:1958 GQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.244093359216
		SemiMajorAxis	2.621306579731
		Eccentricity	0.281442665835
		Inclination	12.815196225588
		AscendingNode	8.548953191044
		ArgOfPericenter	231.750347816323
		MeanAnomaly	91.237091510537
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0419
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3901"
}

#1_"3902 Yoritomo:Yoritomo:1986 AL:1934 AB:1984 WF1:1984 YG1" "Sol" #1=
#2_"*Ёритомо:3902 Yoritomo:Yoritomo:1986 AL" "Sol" #2=
#3_"1986 AL:*Ёритомо:3902 Yoritomo:Yoritomo" "Sol" #3=
".:Yoritomo:3902 Yoritomo:1986 AL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.89
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.807547226097
		SemiMajorAxis	3.230896396137
		Eccentricity	0.064585897522
		Inclination	15.567955777244
		AscendingNode	293.79326385144
		ArgOfPericenter	351.272110246388
		MeanAnomaly	218.00366763027
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0631
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3902"
}

#1_"3906 Chao:Chao:1987 KE1:1956 GE:1966 EA:1986 GB2:1987 MD" "Sol" #1=
#2_"*Чао:3906 Chao:Chao:1987 KE1" "Sol" #2=
#3_"1987 KE1:*Чао:3906 Chao:Chao" "Sol" #3=
".:Chao:3906 Chao:1987 KE1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23.545
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.02129189451
		SemiMajorAxis	2.932275987787
		Eccentricity	0.068490645652
		Inclination	26.073993534873
		AscendingNode	149.200994124178
		ArgOfPericenter	205.729986183247
		MeanAnomaly	81.499100358474
	}
	UniformRotation
	{
		Period	11.892
	}
	LunarLambert	0.5
	Albedo	0.0381
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3906"
}

#1_"3908 Nyx:Nyx:1980 PA:1988 XB1" "Sol" #1=
#2_"*Нюкта:3908 Nyx:Nyx:1980 PA" "Sol" #2=
#3_"1980 PA:*Нюкта:3908 Nyx:Nyx" "Sol" #3=
".:Nyx:3908 Nyx:1980 PA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3908 nyx.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"vesta.dds"
	Color	[ 1.000 0.951 0.842 ]
	BlendTexture	true
	Radius	0.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.676360021742
		SemiMajorAxis	1.927632416598
		Eccentricity	0.458658453807
		Inclination	2.182234029121
		AscendingNode	261.464804703673
		ArgOfPericenter	126.310427427797
		MeanAnomaly	280.06064908542
	}
	UniformRotation
	{
		Period	4.42601
	}
	LunarLambert	0.5
	Albedo	0.23
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3908"
}

#1_"3910 Liszt:Liszt:1988 SF:1954 GC:1974 RP1:1977 DK4:1977 GF1:1979 WX4:1984 WD2" "Sol" #1=
#2_"*Лист:3910 Liszt:Liszt:1988 SF" "Sol" #2=
#3_"1988 SF:Liszt:*Лист:3910 Liszt" "Sol" #3=
".:Liszt:3910 Liszt:1988 SF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3910 liszt.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.76
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.673939103059
		SemiMajorAxis	2.795438217383
		Eccentricity	0.132380028173
		Inclination	8.688055389118
		AscendingNode	2.604431684847
		ArgOfPericenter	273.515317384088
		MeanAnomaly	90.831530562234
	}
	UniformRotation
	{
		Period	4.73
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3910"
}

#1_"3911 Otomo:Otomo:1940 QB:1951 TU:1954 EU:1962 WB:1976 KA1:1979 FL:1983 VC2:1986 GC2:1987 MS" "Sol" #1=
#2_"*Отомо:3911 Otomo:Otomo:1940 QB" "Sol" #2=
#3_"1940 QB:*Отомо:3911 Otomo:Otomo" "Sol" #3=
".:Otomo:3911 Otomo:1940 QB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.295016255175
		SemiMajorAxis	3.037894798492
		Eccentricity	0.098884575958
		Inclination	10.740193713981
		AscendingNode	210.38036082687
		ArgOfPericenter	133.585456520288
		MeanAnomaly	4.390032218494
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1937
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3911"
}

#1_"3915 Fukushima:Fukushima:1988 PA1:1926 GQ:1935 UL:1935 UX:1950 QT:1975 EX5:1977 TV7:1977 TW3: #1=
#1_1979 FH1:1983 EM" "Sol" #1=
#2_"*Фукусима:3915 Fukushima:Fukushima:1988 PA1" "Sol" #2=
#3_"1988 PA1:*Фукусима:3915 Fukushima:Fukushima" "Sol" #3=
".:Fukushima:3915 Fukushima:1988 PA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.19
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.8087069854
		SemiMajorAxis	2.438819020504
		Eccentricity	0.041465664085
		Inclination	14.431891144838
		AscendingNode	173.507456759803
		ArgOfPericenter	144.331728937434
		MeanAnomaly	338.968586119611
	}
	UniformRotation
	{
		Period	9.418
	}
	LunarLambert	0.5
	Albedo	0.0561
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3915"
}

#1_"3916 Maeva:Maeva:1981 QA3:1972 BC:1972 CA:1978 EE6" "Sol" #1=
#2_"*Маева:3916 Maeva:Maeva:1981 QA3" "Sol" #2=
#3_"1981 QA3:*Маева:3916 Maeva:Maeva" "Sol" #3=
".:Maeva:3916 Maeva:1981 QA3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.97
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.834375266296
		SemiMajorAxis	3.240838863088
		Eccentricity	0.13086780127
		Inclination	1.948359974879
		AscendingNode	28.10027107523
		ArgOfPericenter	81.426176886997
		MeanAnomaly	158.238368255525
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0484
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3916"
}

#1_"3918 Brel:Brel:1988 PE1:1931 VF1:1951 RX1:1968 UN3:1971 OK:1978 TE4:1980 DQ4" "Sol" #1=
#2_"*Брель:3918 Brel:Brel:1988 PE1" "Sol" #2=
#3_"1988 PE1:Brel:*Брель:3918 Brel" "Sol" #3=
".:Brel:3918 Brel:1988 PE1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"3918 brel.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.131
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.36289291216
		SemiMajorAxis	2.244587588132
		Eccentricity	0.208690906131
		Inclination	7.514822617192
		AscendingNode	160.696094317235
		ArgOfPericenter	202.757787177851
		MeanAnomaly	156.320222120335
	}
	UniformRotation
	{
		Period	3.098
	}
	LunarLambert	0.5
	Albedo	0.289
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3918"
}

#1_"3922 Heather:Heather:1971 SP3:1954 SN:1962 CU:1971 UN4:1982 RH1" "Sol" #1=
#2_"*Хизер:3922 Heather:Heather:1971 SP3" "Sol" #2=
#3_"1971 SP3:*Хизер:3922 Heather:Heather" "Sol" #3=
".:Heather:3922 Heather:1971 SP3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.04
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.550250041853
		SemiMajorAxis	3.134749903423
		Eccentricity	0.203280366282
		Inclination	2.013391072329
		AscendingNode	350.958792939118
		ArgOfPericenter	11.403805900161
		MeanAnomaly	284.962544721492
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0438
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3922"
}

#1_"3925 Tret'yakov:Tret'yakov:1977 SS2:1937 RG:1937 SA:1948 OF:1965 PA:1971 ON1:1971 PA:1977 TM6: #1=
#1_1980 DR5:1980 FS10" "Sol" #1=
#2_"*Третьяков:3925 Tret'yakov:Tret'yakov:1977 SS2" "Sol" #2=
#3_"1977 SS2:*Третьяков:3925 Tret'yakov:Tret'yakov" "Sol" #3=
".:Tret'yakov:3925 Tret'yakov:1977 SS2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20.93
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.603525196557
		SemiMajorAxis	3.154777619618
		Eccentricity	0.194306436739
		Inclination	15.609386197481
		AscendingNode	163.68526985
		ArgOfPericenter	207.372511155134
		MeanAnomaly	225.12484045979
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3925"
}

#1_"3932 Edshay:Edshay:1984 SC5:1959 PE:1979 EK:1982 BN11" "Sol" #1=
#2_"*Эдшай:3932 Edshay:Edshay:1984 SC5" "Sol" #2=
#3_"1984 SC5:*Эдшай:3932 Edshay:Edshay" "Sol" #3=
".:Edshay:3932 Edshay:1984 SC5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.135
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.114119307145
		SemiMajorAxis	2.56751182841
		Eccentricity	0.165237939501
		Inclination	14.574606527695
		AscendingNode	324.551059113142
		ArgOfPericenter	328.575480359223
		MeanAnomaly	183.837828974183
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1859
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3932"
}

#1_"3935 Toatenmongakkai:Toatenmongakkai:1987 PB:1939 XK:1951 WM:1967 TO:1971 QU1:1979 SC3:1983 OJ" "Sol" #1=
#2_"*Тоатентонгаккай:3935 Toatenmongakkai:Toatenmongakkai:1987 PB" "Sol" #2=
#3_"1987 PB:*Тоатентонгаккай:3935 Toatenmongakkai:Toatenmongakkai" "Sol" #3=
".:Toatenmongakkai:3935 Toatenmongakkai:1987 PB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.705
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.047890110687
		SemiMajorAxis	2.539882785247
		Eccentricity	0.232961247619
		Inclination	8.745656313501
		AscendingNode	300.483275635397
		ArgOfPericenter	104.356341712417
		MeanAnomaly	208.865155430232
	}
	UniformRotation
	{
		Period	106.3
	}
	LunarLambert	0.5
	Albedo	0.1962
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3935"
}

#1_"3939 Huruhata:Huruhata:1953 GO:1972 VW1:1977 TY4:1982 SW2:1986 GH1:1988 TT1" "Sol" #1=
#2_"*Хоруната:3939 Huruhata:Huruhata:1953 GO" "Sol" #2=
#3_"1953 GO:*Хоруната:3939 Huruhata:Huruhata" "Sol" #3=
".:Huruhata:3939 Huruhata:1953 GO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.23
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.486223168252
		SemiMajorAxis	3.110595301815
		Eccentricity	0.101362605024
		Inclination	24.774953480018
		AscendingNode	32.464703734202
		ArgOfPericenter	252.643710540591
		MeanAnomaly	4.530239552612
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0524
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3939"
}

#1_"3945 Gerasimenko:Gerasimenko:1982 PL:1971 TD2:1980 FM1" "Sol" #1=
#2_"*Герасименко:3945 Gerasimenko:Gerasimenko:1982 PL" "Sol" #2=
#3_"1982 PL:*Герасименко:3945 Gerasimenko:Gerasimenko" "Sol" #3=
".:Gerasimenko:3945 Gerasimenko:1982 PL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.59
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.503455324001
		SemiMajorAxis	3.117105456372
		Eccentricity	0.27043886332
		Inclination	1.834151206808
		AscendingNode	9.483619323283
		ArgOfPericenter	333.316971006481
		MeanAnomaly	302.829258330388
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0395
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3945"
}

#1_"3957 Sugie:Sugie:1933 OD:1955 SZ:1986 EO5" "Sol" #1=
#2_"*Сугиэ:3957 Sugie:Sugie:1933 OD" "Sol" #2=
#3_"1933 OD:*Сугиэ:3957 Sugie:Sugie" "Sol" #3=
".:Sugie:3957 Sugie:1933 OD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.410108958082
		SemiMajorAxis	3.081758054056
		Eccentricity	0.198798897191
		Inclination	5.729047989386
		AscendingNode	181.865761073192
		ArgOfPericenter	131.225488196322
		MeanAnomaly	6.790754572021
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0321
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3957"
}

#1_"3961 Arthurcox:Arthurcox:1962 OB:1962 PQ:1962 QL:1978 GG:1979 OF14:1979 QJ7:1980 WL" "Sol" #1=
#2_"*Артуркокс:3961 Arthurcox:Arthurcox:1962 OB" "Sol" #2=
#3_"1962 OB:*Артуркокс:3961 Arthurcox:Arthurcox" "Sol" #3=
".:Arthurcox:3961 Arthurcox:1962 OB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.14
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.244587429229
		SemiMajorAxis	2.62151001287
		Eccentricity	0.154116871735
		Inclination	12.66522624691
		AscendingNode	316.66503305766
		ArgOfPericenter	327.042303469952
		MeanAnomaly	144.252856115351
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.2012
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3961"
}

#1_"3967 Shekhtelia:Shekhtelia:1976 YW2:1977 AF:1978 EB7:1983 CX5" "Sol" #1=
#2_"*Шехтелия:3967 Shekhtelia:Shekhtelia:1976 YW2" "Sol" #2=
#3_"1976 YW2:*Шехтелия:3967 Shekhtelia:Shekhtelia" "Sol" #3=
".:Shekhtelia:3967 Shekhtelia:1976 YW2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.415
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.849103805321
		SemiMajorAxis	3.24629077626
		Eccentricity	0.05225979539
		Inclination	17.460032520692
		AscendingNode	101.111946540102
		ArgOfPericenter	9.469649145854
		MeanAnomaly	162.489311831259
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0642
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3967"
}

#1_"3970 Herran:Herran:1979 ME9:1963 UT:1971 ST1:1979 RH:1982 FQ3" "Sol" #1=
#2_"*Хэрран:3970 Herran:Herran:1979 ME9" "Sol" #2=
#3_"1979 ME9:*Хэрран:3970 Herran:Herran" "Sol" #3=
".:Herran:3970 Herran:1979 ME9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.585
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.085917918884
		SemiMajorAxis	2.555765227924
		Eccentricity	0.134013708486
		Inclination	15.13899788893
		AscendingNode	21.734378878513
		ArgOfPericenter	304.382334205961
		MeanAnomaly	239.332226686894
	}
	UniformRotation
	{
		Period	8.09
	}
	LunarLambert	0.5
	Albedo	0.1117
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3970"
}

#1_"3971 Voronikhin:Voronikhin:1979 YM8:1940 WQ:1955 YD:1956 AJ1:1971 BF3:1974 XP:1980 AD" "Sol" #1=
#2_"*Воронихин:3971 Voronikhin:Voronikhin:1979 YM8" "Sol" #2=
#3_"1979 YM8:*Воронихин:3971 Voronikhin:Voronikhin" "Sol" #3=
".:Voronikhin:3971 Voronikhin:1979 YM8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.66
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.808241348144
		SemiMajorAxis	2.848734910018
		Eccentricity	0.183953863359
		Inclination	13.009779521295
		AscendingNode	284.834323071136
		ArgOfPericenter	83.648812566134
		MeanAnomaly	169.673459494991
	}
	UniformRotation
	{
		Period	5.552
	}
	LunarLambert	0.5
	Albedo	0.0392
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3971"
}

#1_"3976 Lise:Lise:1983 JM:1943 TF:1951 KS:1974 KL:1978 JD1:1979 OM14:1980 TF15:1983 KA" "Sol" #1=
#2_"*Лисе:3976 Lise:Lise:1983 JM" "Sol" #2=
#3_"1983 JM:*Лисе:3976 Lise:Lise" "Sol" #3=
".:Lise:3976 Lise:1983 JM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.145
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.578691926866
		SemiMajorAxis	2.757330432232
		Eccentricity	0.070635518497
		Inclination	12.717198262354
		AscendingNode	222.447588603833
		ArgOfPericenter	103.935888103007
		MeanAnomaly	232.952940429567
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0585
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3976"
}

#1_"3978 Klepesta:Klepesta:1983 VP1:1965 AN:1976 JF7:1978 TX5:1985 BE2" "Sol" #1=
#2_"*Клепешта:3978 Klepesta:Klepesta:1983 VP1" "Sol" #2=
#3_"1983 VP1:*Клепешта:3978 Klepesta:Klepesta" "Sol" #3=
".:Klepesta:3978 Klepesta:1983 VP1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.89255296439
		SemiMajorAxis	2.881939695901
		Eccentricity	0.005613901909
		Inclination	12.16513415902
		AscendingNode	242.423681643804
		ArgOfPericenter	223.75585755088
		MeanAnomaly	75.247091044565
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0518
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3978"
}

#1_"3979 Brorsen:Brorsen:1983 VV1:1974 CQ:1977 RG5" "Sol" #1=
#2_"*Брорсен:3979 Brorsen:Brorsen:1983 VV1" "Sol" #2=
#3_"1983 VV1:*Брорсен:3979 Brorsen:Brorsen" "Sol" #3=
".:Brorsen:3979 Brorsen:1983 VV1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.595
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.474428139794
		SemiMajorAxis	3.10613531562
		Eccentricity	0.029718842813
		Inclination	3.056626625203
		AscendingNode	344.014610853722
		ArgOfPericenter	102.319430764094
		MeanAnomaly	215.960247119954
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1003
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3979"
}

#1_"3981 Stodola:Stodola:1984 BL:1965 SR:1971 UF2:1976 SS:1977 VB2:1979 FT1" "Sol" #1=
#2_"*Стодола:3981 Stodola:Stodola:1984 BL" "Sol" #2=
#3_"1984 BL:*Стодола:3981 Stodola:Stodola" "Sol" #3=
".:Stodola:3981 Stodola:1984 BL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.28
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.63745748357
		SemiMajorAxis	3.167500690206
		Eccentricity	0.171390207793
		Inclination	2.460550062042
		AscendingNode	79.699591380514
		ArgOfPericenter	347.784204552513
		MeanAnomaly	222.268279503687
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0603
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3981"
}

#1_"3983 Sakiko:Sakiko:1984 SX:1952 FX:1971 BO:1975 EG3" "Sol" #1=
#2_"*Сакико:3983 Sakiko:Sakiko:1984 SX" "Sol" #2=
#3_"1984 SX:*Сакико:3983 Sakiko:Sakiko" "Sol" #3=
".:Sakiko:3983 Sakiko:1984 SX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.195
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.834457300862
		SemiMajorAxis	2.449799090924
		Eccentricity	0.112945067951
		Inclination	2.60912389195
		AscendingNode	329.220031521412
		ArgOfPericenter	226.014412450721
		MeanAnomaly	123.345437042533
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0721
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3983"
}

#1_"3987 Wujek:Wujek:1986 EL1:1969 OS:1979 VX2:1979 YS1" "Sol" #1=
#2_"*Вуек:3987 Wujek:Wujek:1986 EL1" "Sol" #2=
#3_"1986 EL1:*Вуек:3987 Wujek:Wujek" "Sol" #3=
".:Wujek:3987 Wujek:1986 EL1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.519327607902
		SemiMajorAxis	2.733445472732
		Eccentricity	0.118828923488
		Inclination	4.827848503626
		AscendingNode	48.529756942144
		ArgOfPericenter	307.319483718791
		MeanAnomaly	326.359634857189
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0539
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3987"
}

#1_"3988 Huma:Huma:1986 LA" "Sol" #1=
#2_"*Хума:3988 Huma:Huma:1986 LA" "Sol" #2=
#3_"1986 LA:*Хума:3988 Huma:Huma" "Sol" #3=
".:Huma:3988 Huma:1986 LA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.919297155654
		SemiMajorAxis	1.544386553211
		Eccentricity	0.316798648825
		Inclination	10.766227968811
		AscendingNode	229.843699008868
		ArgOfPericenter	86.879067161945
		MeanAnomaly	267.782748919446
	}
	UniformRotation
	{
		Period	10.4
	}
	LunarLambert	0.5
	Albedo	0.27
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3988"
}

#1_"3994 Ayashi:Ayashi:1988 XF:1936 VE:1936 XF:1949 WD:1966 RL:1975 WR:1977 DU3:1977 EV2:1979 SE4: #1=
#1_1986 EM4" "Sol" #1=
#2_"*Аяси:3994 Ayashi:Ayashi:1988 XF" "Sol" #2=
#3_"1988 XF:*Аяси:3994 Ayashi:Ayashi" "Sol" #3=
".:Ayashi:3994 Ayashi:1988 XF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.855
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.321300689618
		SemiMajorAxis	2.653001668482
		Eccentricity	0.243734628002
		Inclination	3.679560923073
		AscendingNode	52.079167769758
		ArgOfPericenter	297.08779084884
		MeanAnomaly	58.745877633528
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0782
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3994"
}

#1_"3999 Aristarchus:Aristarchus:1989 AL:1943 EW:1951 GD1:1970 DA:1972 TJ1:1974 EH:1975 NA1:1976 UQ4: #1=
#1_1979 QC7:1980 XF1:1984 YH3" "Sol" #1=
#2_"*Аристарх:3999 Aristarchus:Aristarchus:1989 AL" "Sol" #2=
#3_"1989 AL:*Аристарх:3999 Aristarchus:Aristarchus" "Sol" #3=
".:Aristarchus:3999 Aristarchus:1989 AL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.07
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.858616484
		SemiMajorAxis	2.460078367118
		Eccentricity	0.120056881906
		Inclination	2.542599042772
		AscendingNode	296.682243885802
		ArgOfPericenter	210.338059309792
		MeanAnomaly	226.532525096796
	}
	UniformRotation
	{
		Period	12.58
	}
	LunarLambert	0.5
	Albedo	0.0589
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=3999"
}

#1_"4002 Shinagawa:Shinagawa:1950 JB:1950 JL:1950 LO:1984 YU5:1985 BW" "Sol" #1=
#2_"*Синагава:4002 Shinagawa:Shinagawa:1950 JB" "Sol" #2=
#3_"1950 JB:*Синагава:4002 Shinagawa:Shinagawa" "Sol" #3=
".:Shinagawa:4002 Shinagawa:1950 JB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.991673680532
		SemiMajorAxis	2.516312367517
		Eccentricity	0.030001793567
		Inclination	14.685411347624
		AscendingNode	116.922725642302
		ArgOfPericenter	186.152686132215
		MeanAnomaly	358.709395886404
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.2021
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4002"
}

#1_"4006 Sandler:Sandler:1972 YR:1965 AW:1969 AS:1971 OO:1973 AA1:1975 NC1:1979 OA14:1979 QH10: #1=
#1_1981 AN1" "Sol" #1=
#2_"*Сандлер:4006 Sandler:Sandler:1972 YR" "Sol" #2=
#3_"1972 YR:*Сандлер:4006 Sandler:Sandler" "Sol" #3=
".:Sandler:4006 Sandler:1972 YR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.13
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.989632527646
		SemiMajorAxis	2.515454479073
		Eccentricity	0.183539140953
		Inclination	2.386716842015
		AscendingNode	293.985406486947
		ArgOfPericenter	123.161785167037
		MeanAnomaly	217.824082986722
	}
	UniformRotation
	{
		Period	3.4
	}
	LunarLambert	0.5
	Albedo	0.0669
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4006"
}

#1_"4009 Drobyshevskij:Drobyshevskij:1977 EN1:1982 BP3:1984 SP5" "Sol" #1=
#2_"*Дробышевский:4009 Drobyshevskij:Drobyshevskij:1977 EN1" "Sol" #2=
#3_"1977 EN1:*Дробышевский:4009 Drobyshevskij:Drobyshevskij" "Sol" #3=
".:Drobyshevskij:4009 Drobyshevskij:1977 EN1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.025
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.570952129321
		SemiMajorAxis	3.142540013779
		Eccentricity	0.134759886273
		Inclination	2.293056495064
		AscendingNode	72.44533619864
		ArgOfPericenter	180.327432468054
		MeanAnomaly	240.287720228322
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0542
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4009"
}

#1_"4014 Heizman:Heizman:1979 SG10:1977 KS1:1979 US3:1979 VL" "Sol" #1=
#2_"*Хейзмен:4014 Heizman:Heizman:1979 SG10" "Sol" #2=
#3_"1979 SG10:*Хейзмен:4014 Heizman:Heizman" "Sol" #3=
".:Heizman:4014 Heizman:1979 SG10" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.415
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.326956908184
		SemiMajorAxis	3.420774526942
		Eccentricity	0.031327373966
		Inclination	1.106981090886
		AscendingNode	270.688910713103
		ArgOfPericenter	109.247872352501
		MeanAnomaly	202.214482211217
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0206
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4014"
}

#1_"4015 Wilson-Harrington:Wilson-Harrington:1979 VA:107P" "Sol" #1=
#2_"*Вильсон-Харрингтон:4015 Wilson-Harrington:Wilson-Harrington:1979 VA:107P" "Sol" #2=
#3_"1979 VA:*Вильсон-Харрингтон:4015 Wilson-Harrington:Wilson-Harrington:107P" "Sol" #3=
".:Wilson-Harrington:4015 Wilson-Harrington:1979 VA:107P" "Sol" #4=
{
	Class	"asteroid" # Классифицируется и как комета

	# Class	"comet"
	Mesh	"asteroid-large.cmod"
	Texture	"comet.dds"
	Radius	2
	OrbitColor	[ 0.611765 0.317647 0.12549 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.294335080673
		SemiMajorAxis	2.641953387562
		Eccentricity	0.623840582927
		Inclination	2.782445401847
		AscendingNode	270.366076810299
		ArgOfPericenter	91.503279056479
		MeanAnomaly	70.374917584727
	}
	UniformRotation
	{
		Period	3.5736
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4015"
}

#1_"4034 Vishnu:Vishnu:1986 PA" "Sol" #1=
#2_"*Вишну:4034 Vishnu:Vishnu:1986 PA" "Sol" #2=
#3_"1986 PA:*Вишну:4034 Vishnu:Vishnu" "Sol" #3=
".:Vishnu:4034 Vishnu:1986 PA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.090696492411
		SemiMajorAxis	1.059572007156
		Eccentricity	0.444001015218
		Inclination	11.168490635177
		AscendingNode	157.963789365707
		ArgOfPericenter	296.60986795154
		MeanAnomaly	247.664364015062
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.52
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4034"
}

#1_"4035 1986 WD:1986 WD:1973 SR4:1973 UF6" "Sol" #1=
#2_"1986 WD:4035 1986 WD" "Sol" #2=
#3_"1986 WD:4035 1986 WD" "Sol" #3=
".:1986 WD:4035 1986 WD:1973 SR4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.23
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.146726459622
		SemiMajorAxis	5.284055446687
		Eccentricity	0.056339998726
		Inclination	12.132652912443
		AscendingNode	233.739000300474
		ArgOfPericenter	198.500941889048
		MeanAnomaly	114.786193930144
	}
	UniformRotation
	{
		Period	13.467
	}
	LunarLambert	0.5
	Albedo	0.0718
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4035"
}

#1_"4037 Ikeya:Ikeya:1987 EC:1976 YF6:1978 JL:1982 BX" "Sol" #1=
#2_"*Икея:4037 Ikeya:Ikeya:1987 EC" "Sol" #2=
#3_"1987 EC:Ikeya:*Икея:4037 Ikeya" "Sol" #3=
".:Ikeya:4037 Ikeya:1987 EC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4037 ikeya.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.542
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.611649844788
		SemiMajorAxis	2.77054631666
		Eccentricity	0.160840986973
		Inclination	8.45410223204
		AscendingNode	13.501677669568
		ArgOfPericenter	74.577820628293
		MeanAnomaly	236.591294428093
	}
	UniformRotation
	{
		Period	4.057537
	}
	LunarLambert	0.5
	Albedo	0.352
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4037"
}

#1_"4049 Noragal':Noragal':1973 QD2:1935 RK:1941 UY:1957 TJ:1977 EM3:1979 VW2:1981 AR2:1984 SE4" "Sol" #1=
#2_"*Норагаль:4049 Noragal':Noragal':1973 QD2" "Sol" #2=
#3_"1973 QD2:*Норагаль:4049 Noragal':Noragal'" "Sol" #3=
".:Noragal':4049 Noragal':1973 QD2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.895
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.380871044794
		SemiMajorAxis	3.070644842411
		Eccentricity	0.272540465777
		Inclination	2.382847154623
		AscendingNode	97.331518200862
		ArgOfPericenter	217.56754926339
		MeanAnomaly	250.376180409882
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0859
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4049"
}

#1_"4055 Magellan:Magellan (asteroid):1985 DO2:1988 OG" "Sol" #1=
#2_"*Магеллан (астероид):4055 Magellan:Magellan (asteroid):1985 DO2" "Sol" #2=
#3_"1985 DO2:*Магеллан (астероид):4055 Magellan:Magellan (asteroid)" "Sol" #3=
".:Magellan (asteroid):4055 Magellan:1985 DO2" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.245
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.455808970336
		SemiMajorAxis	1.820221554087
		Eccentricity	0.326482569878
		Inclination	23.256784026576
		AscendingNode	164.852316996866
		ArgOfPericenter	154.365421116799
		MeanAnomaly	262.557313388849
	}
	UniformRotation
	{
		Period	7.475
	}
	LunarLambert	0.5
	Albedo	0.31
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4055"
}

#1_"4060 Deipylos:Deipylos:1987 YT1:1942 ET:1950 UJ:1951 YP1:1966 FN" "Sol" #1=
#2_"*Дипил:4060 Deipylos:Deipylos:1987 YT1" "Sol" #2=
#3_"1987 YT1:*Дипил:4060 Deipylos:Deipylos" "Sol" #3=
".:Deipylos:4060 Deipylos:1987 YT1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	39.605
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.012528777296
		SemiMajorAxis	5.245064411527
		Eccentricity	0.154734958552
		Inclination	16.150314903299
		AscendingNode	168.260244954588
		ArgOfPericenter	307.367171669194
		MeanAnomaly	68.256469776263
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0776
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4060"
}

#1_"4061 Martelli:Martelli:1988 FF3:1934 PL:1973 SX5:1978 NN2:1978 SD:1979 WW5:1982 DD5:1982 DH6" "Sol" #1=
#2_"*Мартелли:4061 Martelli:Martelli:1988 FF3" "Sol" #2=
#3_"1988 FF3:*Мартелли:4061 Martelli:Martelli" "Sol" #3=
".:Martelli:4061 Martelli:1988 FF3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.515
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.520164932979
		SemiMajorAxis	3.123411711707
		Eccentricity	0.130936009326
		Inclination	1.669570854734
		AscendingNode	23.451360355811
		ArgOfPericenter	249.157022872824
		MeanAnomaly	252.958386442116
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.093
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4061"
}

#1_"4063 Euforbo:Euforbo:1989 CG2:1943 EV:1951 XJ:1970 LC:1974 VO2" "Sol" #1=
#2_"*Эвфорбо:4063 Euforbo:Euforbo:1989 CG2" "Sol" #2=
#3_"1989 CG2:*Эвфорбо:4063 Euforbo:Euforbo" "Sol" #3=
".:Euforbo:4063 Euforbo:1989 CG2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	51.23
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.787981843707
		SemiMajorAxis	5.179496023717
		Eccentricity	0.118934603794
		Inclination	18.939166841898
		AscendingNode	113.51804330995
		ArgOfPericenter	318.634304503318
		MeanAnomaly	124.05399461204
	}
	UniformRotation
	{
		Period	8.846
	}
	LunarLambert	0.5
	Albedo	0.0611
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4063"
}

#1_"4068 Menestheus:Menestheus:1973 SW:1979 HA2:1987 WR3" "Sol" #1=
#2_"*Менесфей:4068 Menestheus:Menestheus:1973 SW" "Sol" #2=
#3_"1973 SW:*Менесфей:4068 Menestheus:Menestheus" "Sol" #3=
".:Menestheus:4068 Menestheus:1973 SW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.697894686145
		SemiMajorAxis	5.153073495455
		Eccentricity	0.074087258181
		Inclination	17.558042535074
		AscendingNode	177.698588788668
		ArgOfPericenter	317.786007523841
		MeanAnomaly	40.203062039724
	}
	UniformRotation
	{
		Period	14.341
	}
	LunarLambert	0.5
	Albedo	0.0789
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4068"
}

#1_"4077 Asuka:Asuka:1982 XV1:1935 YJ:1951 YS1:1954 JH:1971 TD:1977 XC:1982 VK11:2016 FN6" "Sol" #1=
#2_"*Аска:4077 Asuka:Asuka:1982 XV1" "Sol" #2=
#3_"1982 XV1:Asuka:*Аска:4077 Asuka" "Sol" #3=
".:Asuka:4077 Asuka:1982 XV1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4077 asuka.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.738
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.25213142817
		SemiMajorAxis	3.02146978292
		Eccentricity	0.084974586971
		Inclination	11.408801065552
		AscendingNode	70.518420741062
		ArgOfPericenter	242.152782586422
		MeanAnomaly	280.195794296753
	}
	UniformRotation
	{
		Period	7.919
	}
	LunarLambert	0.5
	Albedo	0.185
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4077"
}

#1_"4080 Galinskij:Galinskij:1983 PW:1941 ST1:1964 WO1" "Sol" #1=
#2_"*Галинский:4080 Galinskij:Galinskij:1983 PW" "Sol" #2=
#3_"1983 PW:Galinskij:*Галинский:4080 Galinskij" "Sol" #3=
".:*Галинский:4080 Galinskij:1941 ST1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4080 galinskij.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.597
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.247876802482
		SemiMajorAxis	2.193112431773
		Eccentricity	0.211100659604
		Inclination	3.798989784513
		AscendingNode	222.045534617388
		ArgOfPericenter	96.235718780854
		MeanAnomaly	113.881749028931
	}
	UniformRotation
	{
		Period	7.36
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4080"
}

#1_"4086 Podalirius:Podalirius:1985 VK2:1951 XE1" "Sol" #1=
#2_"*Подалирий:4086 Podalirius:Podalirius:1985 VK2" "Sol" #2=
#3_"1985 VK2:*Подалирий:4086 Podalirius:Podalirius" "Sol" #3=
".:Podalirius:4086 Podalirius:1985 VK2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	43.445
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.038674410834
		SemiMajorAxis	5.252672347984
		Eccentricity	0.121431979034
		Inclination	21.717700614481
		AscendingNode	54.974940512835
		ArgOfPericenter	357.114667905228
		MeanAnomaly	155.973983514284
	}
	UniformRotation
	{
		Period	10.43
	}
	LunarLambert	0.5
	Albedo	0.0536
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4086"
}

#1_"4089 Galbraith:Galbraith:1986 JG:1974 WO:1976 GH4:1977 TR7:1982 AM" "Sol" #1=
#2_"*Гэлбрейт:Galbraith:4089 Galbraith:1986 JG" "Sol" #2=
#3_"1986 JG:Galbraith:*Гэлбрейт:4089 Galbraith" "Sol" #3=
".:Galbraith:4089 Galbraith:1986 JG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4089 galbraith.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.041
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.231203293265
		SemiMajorAxis	2.185600193022
		Eccentricity	0.132065164291
		Inclination	1.143797740192
		AscendingNode	316.659306020944
		ArgOfPericenter	321.412103122951
		MeanAnomaly	152.109625703245
	}
	UniformRotation
	{
		Period	4.9123
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4089"
}

#1_"4093 Bennett:Bennett:1986 VD:1981 UG21:1981 UG9" "Sol" #1=
#2_"*Беннетт:4093 Bennett:Bennett:1986 VD" "Sol" #2=
#3_"1986 VD:*Беннетт:4093 Bennett:Bennett" "Sol" #3=
".:Bennett:4093 Bennett:1986 VD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.241287099674
		SemiMajorAxis	3.017309301003
		Eccentricity	0.033951900548
		Inclination	9.35201214046
		AscendingNode	260.467402029349
		ArgOfPericenter	210.355543581903
		MeanAnomaly	57.141391404052
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0601
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4093"
}

#1_"4103 Chahine:Chahine:1989 EB:1949 GG:1978 EA7:1978 GE2:1985 CB1:A905 GB" "Sol" #1=
#2_"*Шахин:4103 Chahine:Chahine:1989 EB" "Sol" #2=
#3_"1989 EB:*Шахин:4103 Chahine:Chahine" "Sol" #3=
".:Chahine:4103 Chahine:1989 EB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.485
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.672489601446
		SemiMajorAxis	2.380317639592
		Eccentricity	0.191788974902
		Inclination	26.991754143796
		AscendingNode	23.188444704744
		ArgOfPericenter	329.212470912345
		MeanAnomaly	175.441222196799
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.3477
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4103"
}

#1_"4107 Rufino:Rufino:1989 GT:1960 HA:1970 SC:1978 PY3:1978 QN:1986 PK:1988 CM:1988 EP2" "Sol" #1=
#2_"*Руфино:4107 Rufino:Rufino:1989 GT" "Sol" #2=
#3_"1989 GT:*Руфино:4107 Rufino:Rufino" "Sol" #3=
".:Rufino:4107 Rufino:1989 GT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.087560684733
		SemiMajorAxis	2.556450221704
		Eccentricity	0.201065159452
		Inclination	17.531229726347
		AscendingNode	149.089402022433
		ArgOfPericenter	312.322146694737
		MeanAnomaly	208.647830675509
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.3179
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4107"
}

#1_"4110 Keats:Keats:1977 CZ:1950 HN:1967 JF:1968 QO1:1969 VM1:1972 GC1:1979 QM7:1979 SF3:1980 VR2: #1=
#1_1982 BQ9:1984 MV:1985 UZ6:1985 VL1:1989 LB" "Sol" #1=
#2_"*Китс:4110 Keats:Keats:1977 CZ" "Sol" #2=
#3_"1977 CZ:*Китс:4110 Keats:Keats" "Sol" #3=
".:Keats:4110 Keats:1977 CZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.466462959012
		SemiMajorAxis	3.103121675697
		Eccentricity	0.117159625989
		Inclination	2.100010152212
		AscendingNode	194.12197839681
		ArgOfPericenter	68.269681680431
		MeanAnomaly	242.235061494931
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0633
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4110"
}

#1_"4112 Hrabal:Hrabal:1981 ST:1957 JA:1968 HL1:1987 UV" "Sol" #1=
#2_"*Грабал:4112 Hrabal:Hrabal:1981 ST" "Sol" #2=
#3_"1981 ST:*Грабал:4112 Hrabal:Hrabal" "Sol" #3=
".:Hrabal:4112 Hrabal:1981 ST" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.502408117477
		SemiMajorAxis	3.116710025199
		Eccentricity	0.042109404975
		Inclination	16.625009634602
		AscendingNode	175.707616572388
		ArgOfPericenter	173.765927784842
		MeanAnomaly	23.570486424269
	}
	UniformRotation
	{
		Period	8
	}
	LunarLambert	0.5
	Albedo	0.0226
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4112"
}

#1_"4121 Carlin:Carlin:1986 JH:1950 TN3:1982 FF4:1983 VB2:1983 WK1" "Sol" #1=
#2_"*Карлин:4121 Carlin:Carlin:1986 JH" "Sol" #2=
#3_"1986 JH:*Карлин:4121 Carlin:Carlin" "Sol" #3=
".:Carlin:4121 Carlin:1986 JH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.658004826424
		SemiMajorAxis	2.374054663867
		Eccentricity	0.254982268291
		Inclination	23.084334539828
		AscendingNode	46.568337683776
		ArgOfPericenter	280.770573546334
		MeanAnomaly	227.328001643881
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.4164
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4121"
}

#1_"4124 Herriot:Herriot:1986 SE:1956 EX:1963 TH1:1965 AJ1:1981 RA3:1989 GQ2" "Sol" #1=
#2_"*Герриот:4124 Herriot:Herriot:1986 SE" "Sol" #2=
#3_"1986 SE:*Герриот:4124 Herriot:Herriot" "Sol" #3=
".:Herriot:4124 Herriot:1986 SE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.88
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.650359397957
		SemiMajorAxis	2.786028430438
		Eccentricity	0.030417663711
		Inclination	3.600033220836
		AscendingNode	330.980269509833
		ArgOfPericenter	119.68911516067
		MeanAnomaly	298.659965093258
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0452
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4124"
}

#1_"4131 Stasik:Stasik:1988 DR4:1975 XP5:1979 OT12" "Sol" #1=
#2_"*Стасик:4131 Stasik:Stasik:1988 DR4" "Sol" #2=
#3_"1988 DR4:*Стасик:4131 Stasik:Stasik" "Sol" #3=
".:Stasik:4131 Stasik:1988 DR4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.629757794705
		SemiMajorAxis	3.164615899799
		Eccentricity	0.103007143871
		Inclination	12.422826200628
		AscendingNode	282.971256180473
		ArgOfPericenter	96.808164497201
		MeanAnomaly	38.113861819627
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0501
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4131"
}

#1_"4132 Bartok:Bartok:1988 EH" "Sol" #1=
#2_"*Барток:4132 Bartok:Bartok:1988 EH" "Sol" #2=
#3_"1988 EH:*Барток:4132 Bartok:Bartok" "Sol" #3=
".:Bartok:4132 Bartok:1988 EH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.28
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.73394384953
		SemiMajorAxis	2.406798434668
		Eccentricity	0.287486995747
		Inclination	23.328027419397
		AscendingNode	173.006202087156
		ArgOfPericenter	254.6162590857
		MeanAnomaly	130.293257403614
	}
	UniformRotation
	{
		Period	3.297
	}
	LunarLambert	0.5
	Albedo	0.3308
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4132"
}

#1_"4140 Branham:Branham:1976 VA:1929 RW:1952 BZ:1986 PL2:1989 CJ" "Sol" #1=
#2_"*Бренхем:4140 Branham:Branham:1976 VA" "Sol" #2=
#3_"1976 VA:*Бренхем:4140 Branham:Branham" "Sol" #3=
".:Branham:4140 Branham:1976 VA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.228968798547
		SemiMajorAxis	3.01257983944
		Eccentricity	0.116655261605
		Inclination	7.728529165736
		AscendingNode	127.20873893453
		ArgOfPericenter	218.834254322633
		MeanAnomaly	137.622355558947
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0637
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4140"
}

#1_"4141 Nintanlena:Nintanlena:1978 PG3:1974 SK2:1978 RD3:1978 TY:1979 YN9:1980 BK3" "Sol" #1=
#2_"*Нинтанлена:4141 Nintanlena:Nintanlena:1978 PG3" "Sol" #2=
#3_"1978 PG3:*Нинтанлена:4141 Nintanlena:Nintanlena" "Sol" #3=
".:Nintanlena:4141 Nintanlena:1978 PG3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.465
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.114474120901
		SemiMajorAxis	2.567659446139
		Eccentricity	0.011361097747
		Inclination	8.963994094012
		AscendingNode	326.329366458365
		ArgOfPericenter	270.253031434182
		MeanAnomaly	36.796027605869
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0723
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4141"
}

#1_"4144 Vladvasil'ev:Vladvasil'ev:1981 SW6:1979 HW4" "Sol" #1=
#2_"*Владвасильев:4144 Vladvasil'ev:Vladvasil'ev:1981 SW6" "Sol" #2=
#3_"1981 SW6:*Владвасильев:4144 Vladvasil'ev:Vladvasil'ev" "Sol" #3=
".:Vladvasil'ev:4144 Vladvasil'ev:1981 SW6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.610654571283
		SemiMajorAxis	3.157452938503
		Eccentricity	0.036013524412
		Inclination	9.272416499582
		AscendingNode	171.826686209342
		ArgOfPericenter	220.615962037573
		MeanAnomaly	317.045529352841
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0666
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4144"
}

#1_"4146 Rudolfinum:Rudolfinum:1982 DD2:1938 GM:1979 HT4:1984 YL2" "Sol" #1=
#2_"*Рудольфинум:4146 Rudolfinum:Rudolfinum:1982 DD2" "Sol" #2=
#3_"1982 DD2:*Рудольфинум:4146 Rudolfinum:Rudolfinum" "Sol" #3=
".:Rudolfinum:4146 Rudolfinum:1982 DD2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.394991951261
		SemiMajorAxis	2.258848121402
		Eccentricity	0.106295011681
		Inclination	4.703146090423
		AscendingNode	169.797841887811
		ArgOfPericenter	321.18142778706
		MeanAnomaly	254.901076013514
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0469
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4146"
}

#1_"4152 Weber:Weber:1985 JF:1976 UO10" "Sol" #1=
#2_"*Вебер:4152 Weber:Weber:1985 JF" "Sol" #2=
#3_"1985 JF:*Вебер:4152 Weber:Weber" "Sol" #3=
".:Weber:4152 Weber:1985 JF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.662926922042
		SemiMajorAxis	3.177033810338
		Eccentricity	0.084874794866
		Inclination	17.572736849004
		AscendingNode	201.527085021647
		ArgOfPericenter	335.058581045214
		MeanAnomaly	118.950857789289
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0585
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4152"
}

#1_"4157 Izu:Izu:1988 XD2:1934 HB:1975 VX1:1975 WJ1:1979 WK7:1982 HW1" "Sol" #1=
#2_"*Изу:4157 Izu:Izu:1988 XD2" "Sol" #2=
#3_"1988 XD2:*Изу:4157 Izu:Izu" "Sol" #3=
".:Izu:4157 Izu:1988 XD2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.505
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.371203479625
		SemiMajorAxis	2.673387300927
		Eccentricity	0.161413610592
		Inclination	12.797092983699
		AscendingNode	67.015930447148
		ArgOfPericenter	206.31178915692
		MeanAnomaly	122.940108315612
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0695
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4157"
}

#1_"4159 Freeman:Freeman:1989 GK:1937 NT:1938 WH:1940 GM:1957 LO:1977 LN" "Sol" #1=
#2_"*Фриман:4159 Freeman:Freeman:1989 GK" "Sol" #2=
#3_"1989 GK:*Фриман:4159 Freeman:Freeman" "Sol" #3=
".:Freeman:4159 Freeman:1989 GK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.655
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.072587332617
		SemiMajorAxis	2.550203295076
		Eccentricity	0.073434886237
		Inclination	15.188933526191
		AscendingNode	91.316567649795
		ArgOfPericenter	312.133501377089
		MeanAnomaly	270.422838276219
	}
	UniformRotation
	{
		Period	4.4021
	}
	LunarLambert	0.5
	Albedo	0.2822
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4159"
}

#1_"4162 SAF:SAF:1940 WA:1951 AS1:1987 OP" "Sol" #1=
#2_"SAF:4162 SAF:1940 WA" "Sol" #2=
#3_"1940 WA:4162 SAF:SAF" "Sol" #3=
".:SAF:4162 SAF:1940 WA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.655
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.774389749865
		SemiMajorAxis	2.835348485462
		Eccentricity	0.135939853589
		Inclination	14.250484287872
		AscendingNode	254.220723920238
		ArgOfPericenter	157.09297769152
		MeanAnomaly	188.107806070817
	}
	UniformRotation
	{
		Period	7.5
	}
	LunarLambert	0.5
	Albedo	0.062
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4162"
}

#1_"4169 Celsius:Celsius:1980 FO3:1964 TM:1974 FK:1977 TL7:1984 BE:1986 EQ" "Sol" #1=
#2_"*Цельсий:4169 Celsius:Celsius:1980 FO3" "Sol" #2=
#3_"1980 FO3:*Цельсий:4169 Celsius:Celsius" "Sol" #3=
".:Celsius:4169 Celsius:1980 FO3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.55
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.245066917873
		SemiMajorAxis	3.39119369454
		Eccentricity	0.172173320477
		Inclination	10.046895797674
		AscendingNode	356.047232064421
		ArgOfPericenter	29.822545405216
		MeanAnomaly	343.383651146484
	}
	UniformRotation
	{
		Period	10.887
	}
	LunarLambert	0.5
	Albedo	0.0704
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4169"
}

#1_"4176 Sudek:Sudek:1987 DS:1949 FF1:1952 VC:1974 TC1:1979 SX5:1982 FO" "Sol" #1=
#2_"*Судек:4176 Sudek:Sudek:1987 DS" "Sol" #2=
#3_"1987 DS:*Судек:4176 Sudek:Sudek" "Sol" #3=
".:Sudek:4176 Sudek:1987 DS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.456007881565
		SemiMajorAxis	3.099163756499
		Eccentricity	0.143666054472
		Inclination	2.599917206955
		AscendingNode	114.330788841963
		ArgOfPericenter	356.192071204265
		MeanAnomaly	58.774513145501
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0341
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4176"
}

#1_"4179 Toutatis:Toutatis:1989 AC:1934 CT" "Sol" #1=
#2_"*Таутатис:4179 Toutatis:Toutatis:1989 AC" "Sol" #2=
#3_"1989 AC:*Таутатис:4179 Toutatis:Toutatis" "Sol" #3=
".:Toutatis:4179 Toutatis:1989 AC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4179 toutatis.cmod"
	MeshCenter	[ 0.0313 0.2171 0.0064 ]
	Texture	"toutatis.jpg"
	Radius	2.13
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.0335954783319
		SemiMajorAxis	2.533899735306762
		Eccentricity	0.6296101756201973
		Inclination	0.4471200287566686
		AscendingNode	124.3647618253029
		ArgOfPericenter	278.7510751311503
		MeanAnomaly	184.1319033839458
	}
	PrecessingRotation
	{
		Period	176
		Inclination	145
		PrecessionPeriod	-0.0201
	}
	LunarLambert	0.5
	Albedo	0.16
	InfoURL	"https://en.wikipedia.org/wiki/4179_Toutatis"
}

#1_"4183 Cuno:Cuno:1987 MB:1986 VT7:1959 LM" "Sol" #1=
#2_"*Куно:4183 Cuno:Cuno:1987 MB" "Sol" #2=
#3_"1987 MB:*Куно:4183 Cuno:Cuno" "Sol" #3=
".:Cuno:4183 Cuno:1987 MB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.790817488325
		SemiMajorAxis	1.982206164107
		Eccentricity	0.634414430479
		Inclination	6.707521984457
		AscendingNode	294.933481171564
		ArgOfPericenter	236.273514144863
		MeanAnomaly	345.22000965473
	}
	UniformRotation
	{
		Period	3.5595
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4183"
}

#1_"4186 Tamashima:Tamashima:1977 DT1:1979 PM:1982 BB8:1983 GE2:1985 QB:1988 CX5" "Sol" #1=
#2_"*Тамасима:4186 Tamashima:Tamashima:1977 DT1" "Sol" #2=
#3_"1977 DT1:*Тамасима:4186 Tamashima:Tamashima" "Sol" #3=
".:Tamashima:4186 Tamashima:1977 DT1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.595
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.482330471918
		SemiMajorAxis	3.109123732646
		Eccentricity	0.064039396603
		Inclination	24.094781825151
		AscendingNode	144.764126959465
		ArgOfPericenter	276.826757319912
		MeanAnomaly	42.427266885315
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4186"
}

#1_"4192 Breysacher:Breysacher:1981 DH:1949 PD:1949 PX:1954 LB:1972 TK5:1978 SA6:1980 BZ3:1989 QC" "Sol" #1=
#2_"*Брейсахер:4192 Breysacher:Breysacher:1981 DH" "Sol" #2=
#3_"1981 DH:*Брейсахер:4192 Breysacher:Breysacher" "Sol" #3=
".:Breysacher:4192 Breysacher:1981 DH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.335
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.774365464921
		SemiMajorAxis	3.218578036678
		Eccentricity	0.163882435021
		Inclination	0.532675609838
		AscendingNode	209.896970308815
		ArgOfPericenter	124.487355677497
		MeanAnomaly	144.33392251154
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0665
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4192"
}

#1_"4194 Sweitzer:Sweitzer:1982 RE:1931 BH:1967 ES:1971 DV1:1972 HR1:1972 KC:1989 CK8" "Sol" #1=
#2_"*Свейцер:4194 Sweitzer:Sweitzer:1982 RE" "Sol" #2=
#3_"1982 RE:*Свейцер:4194 Sweitzer:Sweitzer" "Sol" #3=
".:Sweitzer:4194 Sweitzer:1982 RE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.225
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.430147594689
		SemiMajorAxis	2.697366723329
		Eccentricity	0.044991708963
		Inclination	7.527948833027
		AscendingNode	156.098762124199
		ArgOfPericenter	355.618304082336
		MeanAnomaly	296.813480925829
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0823
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4194"
}

#1_"4197 Morpheus:Morpheus:1982 TA" "Sol" #1=
#2_"*Морфей:4197 Morpheus:Morpheus:1982 TA" "Sol" #2=
#3_"1982 TA:*Морфей:4197 Morpheus:Morpheus" "Sol" #3=
".:Morpheus:4197 Morpheus:1982 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.479553962486
		SemiMajorAxis	2.296202837257
		Eccentricity	0.771930346699
		Inclination	12.575572587775
		AscendingNode	7.207640646425
		ArgOfPericenter	122.372773398039
		MeanAnomaly	56.761929445927
	}
	UniformRotation
	{
		Period	3.538
	}
	LunarLambert	0.5
	Albedo	0.37
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4197"
}

#1_"4201 Orosz:Orosz:1984 JA1:1950 LR:1967 JH:1969 UB:1974 SR2:1975 WX" "Sol" #1=
#2_"*Орос:4201 Orosz:Orosz:1984 JA1" "Sol" #2=
#3_"1984 JA1:*Орос:4201 Orosz:Orosz" "Sol" #3=
".:Orosz:4201 Orosz:1984 JA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.865
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.6077570557
		SemiMajorAxis	3.156365774001
		Eccentricity	0.22888155256
		Inclination	8.875507611885
		AscendingNode	238.172877033366
		ArgOfPericenter	13.944109582202
		MeanAnomaly	150.587717813822
	}
	UniformRotation
	{
		Period	17.3849
	}
	LunarLambert	0.5
	Albedo	0.0726
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4201"
}

#1_"4209 Briggs:Briggs:1986 TG4:1969 SB:1978 EL8:1986 WD5:1989 CO4" "Sol" #1=
#2_"*Бригс:4209 Briggs:Briggs:1986 TG4" "Sol" #2=
#3_"1986 TG4:*Бригс:4209 Briggs:Briggs" "Sol" #3=
".:Briggs:4209 Briggs:1986 TG4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.815
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.605443310786
		SemiMajorAxis	3.155497509146
		Eccentricity	0.085066268664
		Inclination	21.624469739702
		AscendingNode	330.374902306847
		ArgOfPericenter	12.733692054102
		MeanAnomaly	19.600128258844
	}
	UniformRotation
	{
		Period	12.22
	}
	LunarLambert	0.5
	Albedo	0.1288
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4209"
}

#1_"4211 Rosniblett:Rosniblett:1987 RT:1935 SQ:1970 RG:1975 NL" "Sol" #1=
#2_"*Розниблетт:4211 Rosniblett:Rosniblett:1987 RT" "Sol" #2=
#3_"1987 RT:*Розниблетт:4211 Rosniblett:Rosniblett" "Sol" #3=
".:Rosniblett:4211 Rosniblett:1987 RT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.685
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.69949082131
		SemiMajorAxis	3.190694601669
		Eccentricity	0.203346829038
		Inclination	0.587152560275
		AscendingNode	24.356821558218
		ArgOfPericenter	316.973066367964
		MeanAnomaly	279.59669207427
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0259
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4211"
}

#1_"4217 Engelhardt:Engelhardt:1988 BO2:1944 RL:1951 RY1:1970 AA" "Sol" #1=
#2_"*Энгельхардт:4217 Engelhardt:Engelhardt:1988 BO2" "Sol" #2=
#3_"1988 BO2:*Энгельхардт:4217 Engelhardt:Engelhardt" "Sol" #3=
".:Engelhardt:4217 Engelhardt:1988 BO2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.519789552292
		SemiMajorAxis	2.313870222139
		Eccentricity	0.212770651991
		Inclination	23.142984559849
		AscendingNode	355.448924508802
		ArgOfPericenter	348.533212328741
		MeanAnomaly	352.583986821809
	}
	UniformRotation
	{
		Period	3.0661
	}
	LunarLambert	0.5
	Albedo	0.2108
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4217"
}

#1_"4222 Nancita:Nancita:1988 EK1:1950 TF4:1952 HN:1968 QL1:1972 XQ1:1979 SL6:1983 XC1:1988 KL" "Sol" #1=
#2_"*Нэнсита:4222 Nancita:Nancita:1988 EK1" "Sol" #2=
#3_"1988 EK1:*Нэнсита:4222 Nancita:Nancita" "Sol" #3=
".:Nancita:4222 Nancita:1988 EK1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.642308927899
		SemiMajorAxis	2.367258678625
		Eccentricity	0.295024135899
		Inclination	3.740361204828
		AscendingNode	206.874434336571
		ArgOfPericenter	217.507083672915
		MeanAnomaly	194.311899196516
	}
	UniformRotation
	{
		Period	3.8732
	}
	LunarLambert	0.5
	Albedo	0.2703
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4222"
}

#1_"4224 Susa:Susa:1988 KG:1950 YB:1961 AH:1977 GB1:1978 JX2:1982 FD1" "Sol" #1=
#2_"*Сьюза:4224 Susa:Susa:1988 KG" "Sol" #2=
#3_"1988 KG:*Сьюза:4224 Susa:Susa" "Sol" #3=
".:Susa:4224 Susa:1988 KG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.982511556371
		SemiMajorAxis	2.917158824776
		Eccentricity	0.187248728733
		Inclination	12.117217283529
		AscendingNode	200.925889575086
		ArgOfPericenter	179.952460408541
		MeanAnomaly	353.806826890311
	}
	UniformRotation
	{
		Period	6.178
	}
	LunarLambert	0.5
	Albedo	0.0648
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4224"
}

#1_"4226 Damiaan:Damiaan:1989 RE:1931 TY2:1965 SJ:1970 SD1:1970 WT:1975 WQ:1978 JM:1982 BF12: #1=
#1_1983 ED2" "Sol" #1=
#2_"*Дамиан:4226 Damiaan:Damiaan:1989 RE" "Sol" #2=
#3_"1989 RE:*Дамиан:4226 Damiaan:Damiaan" "Sol" #3=
".:Damiaan:4226 Damiaan:1989 RE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.51
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.843552287027
		SemiMajorAxis	2.862664990465
		Eccentricity	0.258143578964
		Inclination	5.375272762175
		AscendingNode	212.328338297245
		ArgOfPericenter	131.30035441358
		MeanAnomaly	72.281021862614
	}
	UniformRotation
	{
		Period	24
	}
	LunarLambert	0.5
	Albedo	0.0555
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4226"
}

#1_"4230 van den Bergh:van den Bergh:1973 ST1:1978 JB2:1979 OD" "Sol" #1=
#2_"*ван ден Берг:4230 van den Bergh:van den Bergh:1973 ST1" "Sol" #2=
#3_"1973 ST1:*ван ден Берг:4230 van den Bergh:van den Bergh" "Sol" #3=
".:van den Bergh:4230 van den Bergh:1973 ST1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.875
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.842125274836
		SemiMajorAxis	3.947150770832
		Eccentricity	0.132949922948
		Inclination	3.098402471232
		AscendingNode	160.557509072824
		ArgOfPericenter	23.464879840055
		MeanAnomaly	272.707769665465
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0259
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4230"
}

#1_"4231 Fireman:Fireman:1976 WD:1976 YV3:1976 YY7:1977 AT:1979 SP10:1986 XK1" "Sol" #1=
#2_"*Фиремен:4231 Fireman:Fireman:1976 WD" "Sol" #2=
#3_"1976 WD:*Фиремен:4231 Fireman:Fireman" "Sol" #3=
".:Fireman:4231 Fireman:1976 WD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.398570763739
		SemiMajorAxis	2.260435277687
		Eccentricity	0.065696984522
		Inclination	8.589890073414
		AscendingNode	261.086275948711
		ArgOfPericenter	77.077605897726
		MeanAnomaly	169.890604000855
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0437
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4231"
}

#1_"4236 Lidov:Lidov:1979 FV1:1934 GC:1951 XQ:1954 JT:1957 WL:1972 BW:1982 TE:1985 DJ" "Sol" #1=
#2_"*Лидов:4236 Lidov:Lidov:1979 FV1" "Sol" #2=
#3_"1979 FV1:*Лидов:4236 Lidov:Lidov" "Sol" #3=
".:Lidov:4236 Lidov:1979 FV1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.355
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.387936041901
		SemiMajorAxis	3.442718959685
		Eccentricity	0.03147405401
		Inclination	7.293649008124
		AscendingNode	349.061392026631
		ArgOfPericenter	143.883074216635
		MeanAnomaly	257.503965891262
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0455
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4236"
}

#1_"4243 Nankivell:Nankivell:1981 GF1:1983 SV:1988 RQ9" "Sol" #1=
#2_"*Нэнкивелл:4243 Nankivell:Nankivell:1981 GF1" "Sol" #2=
#3_"1981 GF1:*Нэнкивелл:4243 Nankivell:Nankivell" "Sol" #3=
".:Nankivell:4243 Nankivell:1981 GF1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.04
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.268523022952
		SemiMajorAxis	3.027753071018
		Eccentricity	0.119337306135
		Inclination	9.011136239977
		AscendingNode	345.150422168624
		ArgOfPericenter	355.959663349716
		MeanAnomaly	0.392001925416
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0493
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4243"
}

#1_"4250 Perun:Perun:1984 UG:1950 TB2:1977 LQ1:1978 RH5:1978 TW3" "Sol" #1=
#2_"*Перун:4250 Perun:Perun:1984 UG" "Sol" #2=
#3_"1984 UG:*Перун:4250 Perun:Perun" "Sol" #3=
".:Perun:4250 Perun:1984 UG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.645651016941
		SemiMajorAxis	3.170569063968
		Eccentricity	0.115069288839
		Inclination	2.520258997727
		AscendingNode	59.388134089015
		ArgOfPericenter	264.551398470864
		MeanAnomaly	187.917502883151
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0664
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4250"
}

#1_"4257 Ubasti:Ubasti:1987 QA" "Sol" #1=
#2_"*Убасти:4257 Ubasti:Ubasti:1987 QA" "Sol" #2=
#3_"1987 QA:*Убасти:4257 Ubasti:Ubasti" "Sol" #3=
".:Ubasti:4257 Ubasti:1987 QA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.114055525816
		SemiMajorAxis	1.647171395364
		Eccentricity	0.468309624832
		Inclination	40.715340676918
		AscendingNode	169.216047723066
		ArgOfPericenter	278.939511697443
		MeanAnomaly	282.367750629721
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.14
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4257"
}

#1_"4265 Kani:Kani:1989 TX:1940 WM:1955 VJ:1974 VH2:1983 AP1:A917 TB" "Sol" #1=
#2_"*Кани:4265 Kani:Kani:1989 TX" "Sol" #2=
#3_"1989 TX:Kani:*Кани:4265 Kani" "Sol" #3=
".:Kani:4265 Kani:1989 TX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4265 kani.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	7.122
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.782152625552
		SemiMajorAxis	2.427470153286
		Eccentricity	0.200764024474
		Inclination	4.356991548257
		AscendingNode	127.250270182896
		ArgOfPericenter	242.738126031651
		MeanAnomaly	88.483311511177
	}
	UniformRotation
	{
		Period	5.7279
	}
	LunarLambert	0.5
	Albedo	0.056
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4265"
}

#1_"4266 Waltari:Waltari:1940 YE:1957 YA:1978 NR7" "Sol" #1=
#2_"*Валтари:4266 Waltari:Waltari:1940 YE" "Sol" #2=
#3_"1940 YE:*Валтари:4266 Waltari:Waltari" "Sol" #3=
".:Waltari:4266 Waltari:1940 YE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.647519284386
		SemiMajorAxis	3.171268498429
		Eccentricity	0.176424102539
		Inclination	16.501061591003
		AscendingNode	322.534517592896
		ArgOfPericenter	157.146336516222
		MeanAnomaly	340.289169327759
	}
	UniformRotation
	{
		Period	11.2
	}
	LunarLambert	0.5
	Albedo	0.0528
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4266"
}

#1_"4281 Pounds:Pounds:1985 TE1:1981 SW4:1981 UT18" "Sol" #1=
#2_"*Фунт:4281 Pounds:Pounds:1985 TE1" "Sol" #2=
#3_"1985 TE1:*Фунт:4281 Pounds:Pounds" "Sol" #3=
".:Pounds:4281 Pounds:1985 TE1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.864937431748
		SemiMajorAxis	2.462764266663
		Eccentricity	0.111930104132
		Inclination	0.72925788726
		AscendingNode	187.9300877329
		ArgOfPericenter	209.065201478019
		MeanAnomaly	182.054699630273
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0361
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4281"
}

#1_"4284 Kaho:Kaho:1988 FL3:1959 RZ:1970 NF" "Sol" #1=
#2_"*Кахо:4284 Kaho:Kaho:1988 FL3" "Sol" #2=
#3_"1988 FL3:Kaho:*Кахо:4284 Kaho" "Sol" #3=
".:Kaho:4284 Kaho:1988 FL3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4284 kaho.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.469
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.717336894855
		SemiMajorAxis	2.399656874121
		Eccentricity	0.274620784664
		Inclination	11.773765563109
		AscendingNode	137.49159900383
		ArgOfPericenter	167.98514748339
		MeanAnomaly	175.228995785272
	}
	UniformRotation
	{
		Period	4.0584
	}
	LunarLambert	0.5
	Albedo	0.128
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4284"
}

#1_"4292 Aoba:Aoba:1989 VO:1938 QE:1955 KK:1957 WH2:1959 ES:1979 QW2:1986 AB1:1988 PX3" "Sol" #1=
#2_"*Аоба:4292 Aoba:Aoba:1989 VO" "Sol" #2=
#3_"1989 VO:*Аоба:4292 Aoba:Aoba" "Sol" #3=
".:Aoba:4292 Aoba:1989 VO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.295
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.559696236569
		SemiMajorAxis	2.749698896238
		Eccentricity	0.048591654789
		Inclination	3.54540875902
		AscendingNode	321.621637929002
		ArgOfPericenter	142.789596669668
		MeanAnomaly	134.469997122062
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0385
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4292"
}

#1_"4298 Jorgenunez:Jorgenunez:1941 WA:1973 YB3:1980 DN3:1985 BF" "Sol" #1=
#2_"*Джорженунез:4298 Jorgenunez:Jorgenunez:1941 WA" "Sol" #2=
#3_"1941 WA:*Джорженунез:4298 Jorgenunez:Jorgenunez" "Sol" #3=
".:Jorgenunez:4298 Jorgenunez:1941 WA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.455
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.31999309439
		SemiMajorAxis	3.047440564854
		Eccentricity	0.29394224756
		Inclination	3.296384399403
		AscendingNode	88.146883590638
		ArgOfPericenter	311.607471523609
		MeanAnomaly	277.937837378355
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0651
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4298"
}

#1_"4313 Bouchet:Bouchet:1979 HK1:1933 WL:1976 UK14:1978 ER3:1983 HE:1989 UR5" "Sol" #1=
#2_"*Буше:4313 Bouchet:Bouchet:1979 HK1" "Sol" #2=
#3_"1979 HK1:*Буше:4313 Bouchet:Bouchet" "Sol" #3=
".:Bouchet:4313 Bouchet:1979 HK1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.06
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.32279192408
		SemiMajorAxis	2.65361198164
		Eccentricity	0.013145712022
		Inclination	9.273523167488
		AscendingNode	44.195459429671
		ArgOfPericenter	166.517467875981
		MeanAnomaly	110.961894323947
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0758
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4313"
}

#1_"4315 Pronik:Pronik:1979 SL11:1978 BD:1979 TA2:1979 UW1:1979 WP5:1983 HG" "Sol" #1=
#2_"*Проник:4315 Pronik:Pronik:1979 SL11" "Sol" #2=
#3_"1979 SL11:*Проник:4315 Pronik:Pronik" "Sol" #3=
".:Pronik:4315 Pronik:1979 SL11" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.715
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.131296294753
		SemiMajorAxis	2.974947187062
		Eccentricity	0.295150373873
		Inclination	16.68840827787
		AscendingNode	28.526134810292
		ArgOfPericenter	266.104034930635
		MeanAnomaly	359.438832532016
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0513
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4315"
}

#1_"4317 Garibaldi:Garibaldi:1980 DA1:1972 EA:1988 EF1" "Sol" #1=
#2_"*Гарибальди:4317 Garibaldi:Garibaldi:1980 DA1" "Sol" #2=
#3_"1980 DA1:*Гарибальди:4317 Garibaldi:Garibaldi" "Sol" #3=
".:Garibaldi:4317 Garibaldi:1980 DA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.988576896621
		SemiMajorAxis	3.996141076647
		Eccentricity	0.162292320158
		Inclination	9.817271102572
		AscendingNode	38.496832505837
		ArgOfPericenter	94.771221872022
		MeanAnomaly	158.738115645918
	}
	UniformRotation
	{
		Period	28.5
	}
	LunarLambert	0.5
	Albedo	0.0499
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4317"
}

#1_"4327 Ries:Ries:1982 KB1:1951 WA2:1983 WM1:1983 XF1" "Sol" #1=
#2_"*Райс:4327 Ries:Ries:1982 KB1" "Sol" #2=
#3_"1982 KB1:*Райс:4327 Ries:Ries" "Sol" #3=
".:Ries:4327 Ries:1982 KB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.611490298665
		SemiMajorAxis	2.770482415816
		Eccentricity	0.226044947192
		Inclination	16.676280635962
		AscendingNode	55.759897745757
		ArgOfPericenter	277.014094362707
		MeanAnomaly	306.040021145117
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.097
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4327"
}

#1_"4332 Milton:Milton:1983 RC:1933 SH1:1989 ET4" "Sol" #1=
#2_"*Милтон:4332 Milton:Milton:1983 RC" "Sol" #2=
#3_"1983 RC:*Милтон:4332 Milton:Milton" "Sol" #3=
".:Milton:4332 Milton:1983 RC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.77
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.155832047759
		SemiMajorAxis	2.584837170942
		Eccentricity	0.314839431065
		Inclination	19.168364253775
		AscendingNode	166.001662842922
		ArgOfPericenter	198.471758775524
		MeanAnomaly	183.180587866513
	}
	UniformRotation
	{
		Period	3.2978
	}
	LunarLambert	0.5
	Albedo	0.2306
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4332"
}

#1_"4335 Verona:Verona:1983 VC7:1927 SG:1973 SB5:1978 ES1:1988 BZ2" "Sol" #1=
#2_"*Верона:4335 Verona:Verona:1983 VC7" "Sol" #2=
#3_"1983 VC7:*Верона:4335 Verona:Verona" "Sol" #3=
".:Verona:4335 Verona:1983 VC7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.575
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.288284622506
		SemiMajorAxis	2.2112650385
		Eccentricity	0.22035410607
		Inclination	3.103220747518
		AscendingNode	37.648250116201
		ArgOfPericenter	324.73638741
		MeanAnomaly	185.563646193118
	}
	UniformRotation
	{
		Period	3.5943
	}
	LunarLambert	0.5
	Albedo	0.2418
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4335"
}

#1_"4341 Poseidon:Poseidon:1987 KF" "Sol" #1=
#2_"*Посейдон:4341 Poseidon:Poseidon:1987 KF" "Sol" #2=
#3_"1987 KF:*Посейдон:4341 Poseidon:Poseidon" "Sol" #3=
".:Poseidon:4341 Poseidon:1987 KF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.485707805855
		SemiMajorAxis	1.834965553278
		Eccentricity	0.679690227457
		Inclination	11.854950307237
		AscendingNode	108.122404399948
		ArgOfPericenter	15.637106333916
		MeanAnomaly	56.764943153585
	}
	UniformRotation
	{
		Period	6.262
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4341"
}

#1_"4342 Freud:Freud:1987 QO9:1950 NT1:1954 JM:1962 EG:1978 RA1:1979 YL7" "Sol" #1=
#2_"*Фрейд:4342 Freud:Freud:1987 QO9" "Sol" #2=
#3_"1987 QO9:*Фрейд:4342 Freud:Freud" "Sol" #3=
".:Freud:4342 Freud:1987 QO9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.59866865288
		SemiMajorAxis	2.765344723799
		Eccentricity	0.092483078322
		Inclination	6.079284995473
		AscendingNode	133.469517849807
		ArgOfPericenter	181.831507224042
		MeanAnomaly	354.282892435504
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.092
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4342"
}

#1_"4343 Tetsuya:Tetsuya:1988 AC:1979 DS:1984 JQ1" "Sol" #1=
#2_"*Тэцуя:4343 Tetsuya:Tetsuya:1988 AC" "Sol" #2=
#3_"1988 AC:*Тэцуя:4343 Tetsuya:Tetsuya" "Sol" #3=
".:Tetsuya:4343 Tetsuya:1988 AC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.47
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.647360292959
		SemiMajorAxis	2.784830459924
		Eccentricity	0.172526843216
		Inclination	6.935910562374
		AscendingNode	221.240662004694
		ArgOfPericenter	280.820381711304
		MeanAnomaly	259.645561195537
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0856
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4343"
}

#1_"4349 Tiburcio:Tiburcio:1989 LX:1931 AE:1951 YV1:1959 SS:1968 WD:1982 BJ4:1984 MJ:1986 AZ2" "Sol" #1=
#2_"*Тибурсио:4349 Tiburcio:Tiburcio:1989 LX" "Sol" #2=
#3_"1989 LX:*Тибурсио:4349 Tiburcio:Tiburcio" "Sol" #3=
".:Tiburcio:4349 Tiburcio:1989 LX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.07
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.2380753041
		SemiMajorAxis	2.618828013774
		Eccentricity	0.241918635695
		Inclination	10.73744387543
		AscendingNode	90.528019961197
		ArgOfPericenter	280.218447965767
		MeanAnomaly	358.915759872398
	}
	UniformRotation
	{
		Period	16.284
	}
	LunarLambert	0.5
	Albedo	0.054
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4349"
}

#1_"4350 Shibecha:Shibecha:1989 UG1:1951 YC1:1972 TS4:1972 VO:1978 EX6:1980 TR1:1987 KJ" "Sol" #1=
#2_"*Шибеча:4350 Shibecha:Shibecha:1989 UG1" "Sol" #2=
#3_"1989 UG1:*Шибеча:4350 Shibecha:Shibecha" "Sol" #3=
".:Shibecha:4350 Shibecha:1989 UG1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.257455043772
		SemiMajorAxis	2.62680547213
		Eccentricity	0.192881863074
		Inclination	13.691981492749
		AscendingNode	32.386398001113
		ArgOfPericenter	109.895429113664
		MeanAnomaly	241.352971564444
	}
	UniformRotation
	{
		Period	2.89
	}
	LunarLambert	0.5
	Albedo	0.0487
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4350"
}

#1_"4356 Marathon:Marathon:9522 P-L:1974 RB1:1987 FB" "Sol" #1=
#2_"*Марафон:4356 Marathon:Marathon:1960-4356*:9522 P-L" "Sol" #2=
#3_"1960-4356*:*Марафон:4356 Marathon:Marathon:9522 P-L" "Sol" #3=
".:Marathon:4356 Marathon:1960-4356*:9522 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.18
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.693831665478
		SemiMajorAxis	2.803364302421
		Eccentricity	0.190366830173
		Inclination	7.457136153504
		AscendingNode	1.926610242462
		ArgOfPericenter	264.827017150705
		MeanAnomaly	274.65542807807
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0665
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4356"
}

#1_"4366 Venikagan:Venikagan:1979 YV8:1952 BH:1969 BC:1975 ES5:1978 SQ5:1980 BJ3:1981 JJ:1981 JW2: #1=
#1_1986 EU" "Sol" #1=
#2_"*Веникаган:4366 Venikagan:Venikagan:1979 YV8" "Sol" #2=
#3_"1979 YV8:*Веникаган:4366 Venikagan:Venikagan" "Sol" #3=
".:Venikagan:4366 Venikagan:1979 YV8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.305
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.608309630424
		SemiMajorAxis	3.15657311766
		Eccentricity	0.139589739695
		Inclination	1.730176981972
		AscendingNode	38.584734321122
		ArgOfPericenter	87.769867044961
		MeanAnomaly	79.791854285819
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0273
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4366"
}

#1_"4368 Pillmore:Pillmore:1981 JC2:1972 TV4:1977 UC:1983 TA2:1988 PG4" "Sol" #1=
#2_"*Пиллморе:4368 Pillmore:Pillmore:1981 JC2" "Sol" #2=
#3_"1981 JC2:*Пиллморе:4368 Pillmore:Pillmore" "Sol" #3=
".:Pillmore:4368 Pillmore:1981 JC2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.465
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.683984523269
		SemiMajorAxis	3.184904806924
		Eccentricity	0.021175877914
		Inclination	20.917987048469
		AscendingNode	225.505967819256
		ArgOfPericenter	117.526234330545
		MeanAnomaly	208.808938091652
	}
	UniformRotation
	{
		Period	3.6054
	}
	LunarLambert	0.5
	Albedo	0.1219
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4368"
}

#1_"4378 Voigt:Voigt:1988 JF:1944 ME:1952 BY1:1987 DK:A913 HB" "Sol" #1=
#2_"*Войгт:4378 Voigt:Voigt:1988 JF" "Sol" #2=
#3_"1988 JF:*Войгт:4378 Voigt:Voigt" "Sol" #3=
".:Voigt:4378 Voigt:1988 JF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.381293456486
		SemiMajorAxis	2.677499677046
		Eccentricity	0.244664747923
		Inclination	10.985220643437
		AscendingNode	98.259409778822
		ArgOfPericenter	128.484384986668
		MeanAnomaly	54.730879734784
	}
	UniformRotation
	{
		Period	10.796
	}
	LunarLambert	0.5
	Albedo	0.2734
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4378"
}

#1_"4379 Snelling:Snelling:1988 PT1:1975 GX:1983 UM1" "Sol" #1=
#2_"*Снеллинг:4379 Snelling:Snelling:1988 PT1" "Sol" #2=
#3_"1988 PT1:*Снеллинг:4379 Snelling:Snelling" "Sol" #3=
".:Snelling:4379 Snelling:1988 PT1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.19
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.62026677507
		SemiMajorAxis	3.161058153226
		Eccentricity	0.123346412902
		Inclination	21.659035492085
		AscendingNode	211.240976256484
		ArgOfPericenter	171.96548707404
		MeanAnomaly	201.064030599603
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.043
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4379"
}

#1_"4381 Uenohara:Uenohara:1989 WD1:1952 UF:1954 CD:1955 HS:1960 HB:1976 HN:1978 TO4:1979 YQ8: #1=
#1_1983 TD1" "Sol" #1=
#2_"*Уэнохара:4381 Uenohara:Uenohara:1989 WD1" "Sol" #2=
#3_"1989 WD1:*Уэнохара:4381 Uenohara:Uenohara" "Sol" #3=
".:Uenohara:4381 Uenohara:1989 WD1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.245
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.266369577866
		SemiMajorAxis	3.026927976497
		Eccentricity	0.079650996397
		Inclination	11.224034259027
		AscendingNode	108.122435279473
		ArgOfPericenter	228.864307524942
		MeanAnomaly	351.934389539984
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1394
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4381"
}

#1_"4399 Ashizuri:Ashizuri:1984 UA:1970 EV2" "Sol" #1=
#2_"*Ачизури:4399 Ashizuri:Ashizuri:1984 UA" "Sol" #2=
#3_"1984 UA:*Ачизури:4399 Ashizuri:Ashizuri" "Sol" #3=
".:Ashizuri:4399 Ashizuri:1984 UA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4399 ashizuri.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.392
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.139723238975
		SemiMajorAxis	2.578153295752
		Eccentricity	0.171063340192
		Inclination	12.075617135803
		AscendingNode	244.118521872741
		ArgOfPericenter	53.648421503425
		MeanAnomaly	228.912961802631
	}
	UniformRotation
	{
		Period	2.829
	}
	LunarLambert	0.5
	Albedo	0.275
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4399"
}

#1_"4414 Sesostris:Sesostris:4153 P-L:1971 VA1:1983 AE:1987 ES" "Sol" #1=
#2_"*Сесострис:4414 Sesostris:Sesostris:1960-4414*:4153 P-L" "Sol" #2=
#3_"1960-4414*:*Сесострис:4414 Sesostris:Sesostris:4153 P-L" "Sol" #3=
".:Sesostris:4414 Sesostris:1960-4414*:4153 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.045
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.566393965836
		SemiMajorAxis	2.334250225204
		Eccentricity	0.117413998746
		Inclination	7.747423207366
		AscendingNode	350.608101638337
		ArgOfPericenter	120.167054512364
		MeanAnomaly	337.816030253007
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0304
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4414"
}

#1_"4424 Arkhipova:Arkhipova:1967 DB:1935 EE:1949 FG:1972 BP" "Sol" #1=
#2_"*Архипова:4424 Arkhipova:Arkhipova:1967 DB" "Sol" #2=
#3_"1967 DB:*Архипова:4424 Arkhipova:Arkhipova" "Sol" #3=
".:Arkhipova:4424 Arkhipova:1967 DB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.505
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.581513343972
		SemiMajorAxis	2.758463038169
		Eccentricity	0.077146785132
		Inclination	14.719353284569
		AscendingNode	138.489830200971
		ArgOfPericenter	15.745973027962
		MeanAnomaly	159.183883309111
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0709
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4424"
}

#1_"4431 Holeungholee:Holeungholee:1978 WU14:1962 XO1:1962 YC:1972 RM1:1988 RM" "Sol" #1=
#2_"*Холеонгхолее:4431 Holeungholee:Holeungholee:1978 WU14" "Sol" #2=
#3_"1978 WU14:*Холеонгхолее:4431 Holeungholee:Holeungholee" "Sol" #3=
".:Holeungholee:4431 Holeungholee:1978 WU14" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.362844913392
		SemiMajorAxis	3.063783153017
		Eccentricity	0.09894516374
		Inclination	10.901184269115
		AscendingNode	223.123896064218
		ArgOfPericenter	218.650799630542
		MeanAnomaly	248.610907425091
	}
	UniformRotation
	{
		Period	9.81
	}
	LunarLambert	0.5
	Albedo	0.0925
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4431"
}

#1_"4436 Ortizmoreno:Ortizmoreno:1983 EX:1959 CY:1972 JL1:1975 XB2:1981 YK1" "Sol" #1=
#2_"*Ортизморено:4436 Ortizmoreno:Ortizmoreno:1983 EX:1959 CY" "Sol" #2=
#3_"1983 EX:*Ортизморено:4436 Ortizmoreno:Ortizmoreno:1959 CY" "Sol" #3=
".:Ortizmoreno:4436 Ortizmoreno:1983 EX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.37
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.859604142774
		SemiMajorAxis	3.250174785274
		Eccentricity	0.055191199544
		Inclination	17.327649441527
		AscendingNode	90.525352487402
		ArgOfPericenter	27.374408455059
		MeanAnomaly	206.522806629256
	}
	UniformRotation
	{
		Period	8.24
	}
	LunarLambert	0.5
	Albedo	0.0744
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4436"
}

#1_"4438 Sykes:Sykes:1983 WR:1971 TA:1977 TN5:1987 KB5" "Sol" #1=
#2_"*Сайкс:4438 Sykes:Sykes:1983 WR" "Sol" #2=
#3_"1983 WR:*Сайкс:4438 Sykes:Sykes" "Sol" #3=
".:Sykes:4438 Sykes:1983 WR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.43
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.628505862575
		SemiMajorAxis	3.164146722578
		Eccentricity	0.251965533403
		Inclination	13.305810722084
		AscendingNode	56.887389629005
		ArgOfPericenter	292.162567061307
		MeanAnomaly	226.698015077152
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0718
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4438"
}

#1_"4442 Garcia:Garcia:1985 RB1:1988 BC5" "Sol" #1=
#2_"*Гарсия:4442 Garcia:Garcia:1985 RB1" "Sol" #2=
#3_"1985 RB1:*Гарсия:4442 Garcia:Garcia" "Sol" #3=
".:Garcia:4442 Garcia:1985 RB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.335
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.215108316856
		SemiMajorAxis	3.007253833724
		Eccentricity	0.240505821885
		Inclination	15.129756817948
		AscendingNode	286.385357387368
		ArgOfPericenter	265.220521808737
		MeanAnomaly	39.296160858604
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0683
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4442"
}

#1_"4449 Sobinov:Sobinov:1987 RX3:1953 PT:1973 EJ:1981 SP3" "Sol" #1=
#2_"*Собинов:4449 Sobinov:Sobinov:1987 RX3" "Sol" #2=
#3_"1987 RX3:*Собинов:4449 Sobinov:Sobinov" "Sol" #3=
".:Sobinov:4449 Sobinov:1987 RX3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.01
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.568530312909
		SemiMajorAxis	3.141629193231
		Eccentricity	0.094861830959
		Inclination	4.898818511871
		AscendingNode	299.15952048051
		ArgOfPericenter	311.681289281822
		MeanAnomaly	67.768438933038
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0649
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4449"
}

#1_"4450 Pan:Pan (asteroid):1987 SY:1937 CA" "Sol" #1=
#2_"*Пан (астероид):4450 Pan:Pan (asteroid):1987 SY" "Sol" #2=
#3_"1987 SY:*Пан (астероид):4450 Pan:Pan (asteroid)" "Sol" #3=
".:Pan (asteroid):4450 Pan:1987 SY" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.7808
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.73234580388
		SemiMajorAxis	1.442395163411
		Eccentricity	0.58649331864
		Inclination	5.519890534938
		AscendingNode	311.856787451936
		ArgOfPericenter	291.773868163818
		MeanAnomaly	303.695308091017
	}
	UniformRotation
	{
		Period	56.48
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4450"
}

#1_"4460 Bihoro:Bihoro:1990 DS:1937 PF:1937 RV:1942 PF:1947 PB:1970 ES2:1980 BF3:1980 FH9:1987 QG" "Sol" #1=
#2_"*Бихоро:4460 Bihoro:Bihoro:1990 DS" "Sol" #2=
#3_"1990 DS:*Бихоро:4460 Bihoro:Bihoro" "Sol" #3=
".:Bihoro:4460 Bihoro:1990 DS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.91
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.008396911367
		SemiMajorAxis	2.927253661196
		Eccentricity	0.180519293274
		Inclination	27.048833021651
		AscendingNode	326.368737945716
		ArgOfPericenter	30.825354564822
		MeanAnomaly	137.508381539626
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0444
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4460"
}

#1_"4470 Sergeev-Censkij:Sergeev-Censkij:1978 QP1:1973 UF2:1979 XU1:1984 UJ4" "Sol" #1=
#2_"*Сергеев-Ценский:4470 Sergeev-Censkij:Sergeev-Censkij:1978 QP1" "Sol" #2=
#3_"1978 QP1:*Сергеев-Ценский:4470 Sergeev-Censkij:Sergeev-Censkij" "Sol" #3=
".:Sergeev-Censkij:4470 Sergeev-Censkij:1978 QP1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.17
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.552116768807
		SemiMajorAxis	3.135452741928
		Eccentricity	0.171183995229
		Inclination	2.460279272205
		AscendingNode	120.004193128337
		ArgOfPericenter	202.255528447876
		MeanAnomaly	204.475608734645
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0912
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4470"
}

#1_"4483 Petofi:Petofi:1986 RC2" "Sol" #1=
#2_"*Петёфи:4483 Petofi:Petofi:1986 RC2" "Sol" #2=
#3_"1986 RC2:*Петёфи:4483 Petofi:Petofi" "Sol" #3=
".:Petofi:4483 Petofi:1986 RC2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4483 petofi.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.925
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	2.665673086967
		SemiMajorAxis	1.922497527908
		Eccentricity	0.083812482386
		Inclination	26.728127256117
		AscendingNode	184.194715047912
		ArgOfPericenter	186.191854957634
		MeanAnomaly	264.313026354226
	}
	UniformRotation
	{
		Period	4.3331
	}
	LunarLambert	0.5
	Albedo	0.193
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4483"
}

#1_"4484 Sif:Sif:1987 DD:1964 VN2" "Sol" #1=
#2_"*Сиф:4484 Sif:Sif:1987 DD" "Sol" #2=
#3_"1987 DD:*Сиф:4484 Sif:Sif" "Sol" #3=
".:Sif:4484 Sif:1987 DD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.66
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.276662917876
		SemiMajorAxis	2.634700248895
		Eccentricity	0.10055561587
		Inclination	29.785474913295
		AscendingNode	85.029975116378
		ArgOfPericenter	359.662663218326
		MeanAnomaly	241.126134893628
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0562
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4484"
}

#1_"4486 Mithra:Mithra:1987 SB:1974 DN1" "Sol" #1=
#2_"*Митра:4486 Mithra:Mithra:1987 SB" "Sol" #2=
#3_"1987 SB:*Митра:4486 Mithra:Mithra" "Sol" #3=
".:Mithra:4486 Mithra:1987 SB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4486 mithra.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.175
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.261420078859
		SemiMajorAxis	2.199204888575
		Eccentricity	0.662844698682
		Inclination	3.03966515982
		AscendingNode	82.248994113218
		ArgOfPericenter	168.891482203226
		MeanAnomaly	149.73301226447
	}
	UniformRotation
	{
		Period	67.5
	}
	LunarLambert	0.5
	Albedo	0.297
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4486"
}

#1_"4489 1988 AK:1988 AK:1980 KA1:1989 AQ1" "Sol" #1=
#2_"1988 AK:4489 1988 AK" "Sol" #2=
#3_"1988 AK:4489 1988 AK" "Sol" #3=
".:1988 AK:4489 1988 AK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	46.465
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.952546108389
		SemiMajorAxis	5.227589580098
		Eccentricity	0.05816071294
		Inclination	22.204522056926
		AscendingNode	86.587068304251
		ArgOfPericenter	8.631599227919
		MeanAnomaly	73.399102258236
	}
	UniformRotation
	{
		Period	12.58
	}
	LunarLambert	0.5
	Albedo	0.0514
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4489"
}

#1_"4490 Bambery:Bambery:1988 ND" "Sol" #1=
#2_"*Бамбери:4490 Bambery:Bambery:1988 ND" "Sol" #2=
#3_"1988 ND:*Бамбери:4490 Bambery:Bambery" "Sol" #3=
".:Bambery:4490 Bambery:1988 ND" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4490 bambery.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.658
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.68307840157
		SemiMajorAxis	1.930856983907
		Eccentricity	0.092328345304
		Inclination	26.122280648833
		AscendingNode	134.83463246173
		ArgOfPericenter	267.869810516073
		MeanAnomaly	211.715718537476
	}
	UniformRotation
	{
		Period	5.815
	}
	LunarLambert	0.5
	Albedo	0.141
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4490"
}

#1_"4493 Naitomitsu:Naitomitsu:1988 TG1:1941 WP:1962 VH:1962 WF1:1985 DH1" "Sol" #1=
#2_"*Наитомицу:4493 Naitomitsu:Naitomitsu:1988 TG1" "Sol" #2=
#3_"1988 TG1:*Наитомицу:4493 Naitomitsu:Naitomitsu" "Sol" #3=
".:Naitomitsu:4493 Naitomitsu:1988 TG1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	10.37
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.259096383374
		SemiMajorAxis	3.024140413372
		Eccentricity	0.070885860576
		Inclination	9.006500413703
		AscendingNode	264.65459890568
		ArgOfPericenter	157.731922339813
		MeanAnomaly	318.868462696787
	}
	UniformRotation
	{
		Period	5.04
	}
	LunarLambert	0.5
	Albedo	0.1636
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4493"
}

#1_"4500 Pascal:Pascal:1989 CL:1931 TE1:1954 XG:1965 WT:1981 QK1:1981 QY1:1987 TF" "Sol" #1=
#2_"*Паскаль:4500 Pascal:Pascal:1989 CL" "Sol" #2=
#3_"1989 CL:*Паскаль:4500 Pascal:Pascal" "Sol" #3=
".:Pascal:4500 Pascal:1989 CL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.28
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.647128081779
		SemiMajorAxis	3.171122047953
		Eccentricity	0.162942744048
		Inclination	2.93950884828
		AscendingNode	136.996993603104
		ArgOfPericenter	306.074794589342
		MeanAnomaly	250.117633299042
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0813
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4500"
}

#1_"4505 Okamura:Okamura:1990 DV1:1943 ET:1973 YC4:1976 NO:1978 YG:1982 SS" "Sol" #1=
#2_"*Окамура:4505 Okamura:Okamura:1990 DV1" "Sol" #2=
#3_"1990 DV1:*Окамура:4505 Okamura:Okamura" "Sol" #3=
".:Okamura:4505 Okamura:1990 DV1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.675
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.219035788386
		SemiMajorAxis	3.008763475984
		Eccentricity	0.051306362238
		Inclination	11.842953155769
		AscendingNode	119.192181826958
		ArgOfPericenter	21.378823480523
		MeanAnomaly	283.222860165774
	}
	UniformRotation
	{
		Period	6.6687
	}
	LunarLambert	0.5
	Albedo	0.1714
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4505"
}

#1_"4507 Petercollins:Petercollins:1990 FV:1932 HG:1970 EQ3:1975 EX:1976 KG1:1977 QM:1985 FV:1987 RL5: #1=
#1_1987 SW" "Sol" #1=
#2_"*Питерколлинз:4507 Petercollins:Petercollins:1990 FV" "Sol" #2=
#3_"1990 FV:*Питерколлинз:4507 Petercollins:Petercollins" "Sol" #3=
".:Petercollins:4507 Petercollins:1990 FV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4507 petercollins.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.512
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.858784095334
		SemiMajorAxis	2.868663445028
		Eccentricity	0.009604984786
		Inclination	2.663756510404
		AscendingNode	47.532361698506
		ArgOfPericenter	77.648033784195
		MeanAnomaly	129.213810114355
	}
	UniformRotation
	{
		Period	6.58
	}
	LunarLambert	0.5
	Albedo	0.277
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4507"
}

#1_"4511 Rembrandt:Rembrandt:1935 SP1:1935 UK:1975 ER3:1987 SA1" "Sol" #1=
#2_"*Рембрандт:4511 Rembrandt:Rembrandt:1935 SP1" "Sol" #2=
#3_"1935 SP1:*Рембрандт:4511 Rembrandt:Rembrandt" "Sol" #3=
".:Rembrandt:4511 Rembrandt:1935 SP1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.51
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.718615205585
		SemiMajorAxis	2.400206968886
		Eccentricity	0.251298913417
		Inclination	22.741576172839
		AscendingNode	0.394644386039
		ArgOfPericenter	302.68384928746
		MeanAnomaly	148.526638026508
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.2861
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4511"
}

#1_"4522 Britastra:Britastra:1980 BM:1952 US1:1952 VH:1960 MD:1978 TR1:1980 BK4:1980 CC:1982 OQ" "Sol" #1=
#2_"*Бритастра:4522 Britastra:Britastra:1980 BM" "Sol" #2=
#3_"1980 BM:*Бритастра:4522 Britastra:Britastra" "Sol" #3=
".:Britastra:4522 Britastra:1980 BM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.368832269356
		SemiMajorAxis	2.672420406765
		Eccentricity	0.203761944355
		Inclination	12.521722193509
		AscendingNode	131.969239795529
		ArgOfPericenter	228.424985611399
		MeanAnomaly	101.801164554032
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0527
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4522"
}

#1_"4529 Webern:Webern:1984 ED:1942 CK:1986 PW2" "Sol" #1=
#2_"*Веберн:4529 Webern:Webern:1984 ED" "Sol" #2=
#3_"1984 ED:Webern:*Веберн:4529 Webern" "Sol" #3=
".:Webern:4529 Webern:1984 ED" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4529 webern.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.214
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.229586062093
		SemiMajorAxis	3.012816918579
		Eccentricity	0.06013249573
		Inclination	10.997395146866
		AscendingNode	131.780768708573
		ArgOfPericenter	5.834318257631
		MeanAnomaly	123.544458386456
	}
	UniformRotation
	{
		Period	3.469
	}
	LunarLambert	0.5
	Albedo	0.214
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4529"
}

#1_"4540 Oriani:Oriani:1988 VY1:1962 XE1:1968 DF:1975 WL:1977 FH3" "Sol" #1=
#2_"*Ориани:4540 Oriani:Oriani:1988 VY1" "Sol" #2=
#3_"1988 VY1:*Ориани:4540 Oriani:Oriani" "Sol" #3=
".:Oriani:4540 Oriani:1988 VY1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.353867474755
		SemiMajorAxis	2.66631426122
		Eccentricity	0.176307670317
		Inclination	6.351905770289
		AscendingNode	246.616777452155
		ArgOfPericenter	261.048121346667
		MeanAnomaly	273.688931869298
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1129
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4540"
}

#1_"4543 Phoinix:Phoinix:1989 CQ1:1930 DN:1977 AP1" "Sol" #1=
#2_"*Феникс:4543 Phoinix:Phoinix:1989 CQ1" "Sol" #2=
#3_"1989 CQ1:*Феникс:4543 Phoinix:Phoinix" "Sol" #3=
".:Phoinix:4543 Phoinix:1989 CQ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	31.395
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.57528516159
		SemiMajorAxis	5.117002915037
		Eccentricity	0.096382364563
		Inclination	14.711765513482
		AscendingNode	325.408228420301
		ArgOfPericenter	85.50086290429
		MeanAnomaly	157.769261535255
	}
	UniformRotation
	{
		Period	38.866
	}
	LunarLambert	0.5
	Albedo	0.0591
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4543"
}

#1_"4544 Xanthus:Xanthus:1989 FB" "Sol" #1=
#2_"*Ксанф:4544 Xanthus:Xanthus:1989 FB" "Sol" #2=
#3_"1989 FB:*Ксанф:4544 Xanthus:Xanthus" "Sol" #3=
".:Xanthus:4544 Xanthus:1989 FB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.063345128099
		SemiMajorAxis	1.041783230225
		Eccentricity	0.250101103833
		Inclination	14.144939960379
		AscendingNode	24.014510827658
		ArgOfPericenter	333.732765957896
		MeanAnomaly	258.521581098151
	}
	UniformRotation
	{
		Period	37.65
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4544"
}

#1_"4547 Massachusetts:Massachusetts:1990 KP:1958 TW:1960 ED:1962 UF:1974 TD:1977 FB2:1979 UJ2: #1=
#1_1985 DC2:1987 SP13:A909 BG" "Sol" #1=
#2_"*Массачусетс:4547 Massachusetts:Massachusetts:1990 KP" "Sol" #2=
#3_"1990 KP:*Массачусетс:4547 Massachusetts:Massachusetts" "Sol" #3=
".:Massachusetts:4547 Massachusetts:1990 KP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.226656725809
		SemiMajorAxis	2.614121988097
		Eccentricity	0.069490670185
		Inclination	18.012758380946
		AscendingNode	358.31116946407
		ArgOfPericenter	38.543143422328
		MeanAnomaly	112.637503916311
	}
	UniformRotation
	{
		Period	7.703
	}
	LunarLambert	0.5
	Albedo	0.1184
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4547"
}

#1_"4554 Fanynka:Fanynka:1986 UT:1974 SQ3:1976 YE:1978 JF1:1984 JU:1985 KG" "Sol" #1=
#2_"*Фанынка:4554 Fanynka:Fanynka:1986 UT" "Sol" #2=
#3_"1986 UT:*Фанынка:4554 Fanynka:Fanynka" "Sol" #3=
".:Fanynka:4554 Fanynka:1986 UT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4554 fanynka.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	13.158
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.686646239536
		SemiMajorAxis	3.185899021623
		Eccentricity	0.119715410911
		Inclination	9.214045878604
		AscendingNode	255.684929973461
		ArgOfPericenter	5.771287752305
		MeanAnomaly	106.254543158203
	}
	UniformRotation
	{
		Period	4.779
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4554"
}

#1_"4562 Poleungkuk:Poleungkuk:1979 UD2:1955 MH1:1955 MN:1967 RU:1973 AW1:1983 YU:1987 WY4" "Sol" #1=
#2_"*Полеунгкук:4562 Poleungkuk:Poleungkuk:1979 UD2" "Sol" #2=
#3_"1979 UD2:*Полеунгкук:4562 Poleungkuk:Poleungkuk" "Sol" #3=
".:Poleungkuk:4562 Poleungkuk:1979 UD2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.68
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.885134025519
		SemiMajorAxis	2.471336415792
		Eccentricity	0.142013298721
		Inclination	3.421649305871
		AscendingNode	264.128685268134
		ArgOfPericenter	35.679188611228
		MeanAnomaly	93.844822200012
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0473
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4562"
}

#1_"4570 Runcorn:Runcorn:1985 PR:1969 TO:1971 BU1:1982 SB11:1984 DY1:1985 RF4:1986 XC3" "Sol" #1=
#2_"*Ранкорна:4570 Runcorn:Runcorn:1985 PR" "Sol" #2=
#3_"1985 PR:Runcorn:*Ранкорна:4570 Runcorn" "Sol" #3=
".:Runcorn:4570 Runcorn:1985 PR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4570 runcorn.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.972
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.260598446708
		SemiMajorAxis	2.1988355171
		Eccentricity	0.108882825676
		Inclination	5.01484018294
		AscendingNode	349.214484486025
		ArgOfPericenter	208.904755212434
		MeanAnomaly	2.526789658941
	}
	UniformRotation
	{
		Period	20
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4570"
}

#1_"4573 Piestany:Piestany:1986 TP6:1951 AD:1951 CN" "Sol" #1=
#2_"*Пиестани:4573 Piestany:Piestany:1986 TP6" "Sol" #2=
#3_"1986 TP6:*Пиестани:4573 Piestany:Piestany" "Sol" #3=
".:Piestany:4573 Piestany:1986 TP6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.302298828889
		SemiMajorAxis	3.040679634078
		Eccentricity	0.067725017194
		Inclination	9.416079224331
		AscendingNode	299.370960591766
		ArgOfPericenter	246.392424851422
		MeanAnomaly	337.200126018141
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0616
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4573"
}

#1_"4581 Asclepius:Asclepius:1989 FC" "Sol" #1=
#2_"*Асклепий:4581 Asclepius:Asclepius:1989 FC" "Sol" #2=
#3_"1989 FC:*Асклепий:4581 Asclepius:Asclepius" "Sol" #3=
".:Asclepius:4581 Asclepius:1989 FC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.033895005016
		SemiMajorAxis	1.022458029678
		Eccentricity	0.35700766793
		Inclination	4.919255454531
		AscendingNode	180.286624005656
		ArgOfPericenter	255.298592684214
		MeanAnomaly	20.466243533572
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4581"
}

#1_"4597 Consolmagno:Consolmagno:1983 UA1:1952 HQ2:1952 HR1:1975 XG7:1981 EO48:1987 TE:1990 KP1" "Sol" #1=
#2_"*Консолмагно:4597 Consolmagno:Consolmagno:1983 UA1" "Sol" #2=
#3_"1983 UA1:*Консолмагно:4597 Consolmagno:Consolmagno" "Sol" #3=
".:Consolmagno:4597 Consolmagno:1983 UA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.21506853949
		SemiMajorAxis	2.609341725772
		Eccentricity	0.119346460386
		Inclination	4.867870618367
		AscendingNode	70.244815414883
		ArgOfPericenter	163.664519797545
		MeanAnomaly	296.867641842825
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0824
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4597"
}

#1_"4606 Saheki:Saheki:1987 UM1:1972 GA1:1977 TJ7:1977 VF2:1982 FH4" "Sol" #1=
#2_"*Хасеки:4606 Saheki:Saheki:1987 UM1" "Sol" #2=
#3_"1987 UM1:*Хасеки:4606 Saheki:Saheki" "Sol" #3=
".:Saheki:4606 Saheki:1987 UM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4606 saheki.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	3.328
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.378833978774
		SemiMajorAxis	2.251675317222
		Eccentricity	0.101487603029
		Inclination	2.633185656408
		AscendingNode	241.306563066563
		ArgOfPericenter	252.187398416947
		MeanAnomaly	329.094624350685
	}
	UniformRotation
	{
		Period	4.969
	}
	LunarLambert	0.5
	Albedo	0.332
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4606"
}

#1_"4609 Pizarro:Pizarro:1988 CT3:1969 VZ1:1978 JQ1:1984 NB:1990 OE3" "Sol" #1=
#2_"*Пизарро:4609 Pizarro:Pizarro:1988 CT3" "Sol" #2=
#3_"1988 CT3:*Пизарро:4609 Pizarro:Pizarro" "Sol" #3=
".:Pizarro:4609 Pizarro:1988 CT3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.496552544895
		SemiMajorAxis	3.114498464996
		Eccentricity	0.105652098801
		Inclination	13.342883075217
		AscendingNode	188.807870398151
		ArgOfPericenter	117.15039516365
		MeanAnomaly	172.343053345985
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0582
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4609"
}

#1_"4611 Vulkaneifel:Vulkaneifel:1989 GR6:1965 SL:1975 AC1:1975 BD:1980 DN1:1980 FW11" "Sol" #1=
#2_"*Вульканайфель:4611 Vulkaneifel:Vulkaneifel:1989 GR6" "Sol" #2=
#3_"1989 GR6:*Вульканайфель:4611 Vulkaneifel:Vulkaneifel" "Sol" #3=
".:Vulkaneifel:4611 Vulkaneifel:1989 GR6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4611 vulkaneifel.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.633
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.226454925953
		SemiMajorAxis	2.614038780703
		Eccentricity	0.19451823278
		Inclination	13.781657466204
		AscendingNode	116.335337303693
		ArgOfPericenter	273.845358725962
		MeanAnomaly	262.669191880473
	}
	UniformRotation
	{
		Period	3.756
	}
	LunarLambert	0.5
	Albedo	0.278
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4611"
}

#1_"4617 Zadunaisky:Zadunaisky:1976 DK:1951 WM2:1978 NG3:1980 XA1" "Sol" #1=
#2_"*Задунайский:4617 Zadunaisky:Zadunaisky:1976 DK" "Sol" #2=
#3_"1976 DK:*Задунайский:4617 Zadunaisky:Zadunaisky" "Sol" #3=
".:Zadunaisky:4617 Zadunaisky:1976 DK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.752550008281
		SemiMajorAxis	3.210466434215
		Eccentricity	0.06788484594
		Inclination	18.66969961359
		AscendingNode	234.596861301038
		ArgOfPericenter	273.304111777454
		MeanAnomaly	257.911819576691
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0696
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4617"
}

#1_"4641 Ayako:Ayako:1990 QT3:1935 SH1:1961 UK:1976 GZ1:1977 RX1:1984 YO5:1984 YR6:1987 UU9" "Sol" #1=
#2_"*Аяко:4641 Ayako:Ayako:1990 QT3" "Sol" #2=
#3_"1990 QT3:Ayako:*Аяко:4641 Ayako" "Sol" #3=
".:Ayako:4641 Ayako:1990 QT3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4641 ayako.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.774
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.23808339676
		SemiMajorAxis	2.188701581338
		Eccentricity	0.171698741867
		Inclination	1.652278065406
		AscendingNode	101.967028368705
		ArgOfPericenter	283.843175262878
		MeanAnomaly	30.958680597995
	}
	UniformRotation
	{
		Period	5.3126
	}
	LunarLambert	0.5
	Albedo	0.424
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4641"
}

#1_"4642 Murchie:Murchie:1990 QG4:1977 DJ10:1979 RS:1979 SV8:1980 XL2:A916 PB" "Sol" #1=
#2_"*Мурчие:4642 Murchie:Murchie:1990 QG4" "Sol" #2=
#3_"1990 QG4:*Мурчие:4642 Murchie:Murchie" "Sol" #3=
".:Murchie:4642 Murchie:1990 QG4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.656217912163
		SemiMajorAxis	3.174524040812
		Eccentricity	0.151506408991
		Inclination	1.008849260691
		AscendingNode	149.809430559245
		ArgOfPericenter	129.569672414703
		MeanAnomaly	152.997286171195
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0628
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4642"
}

#1_"4645 Tentaikojo:Tentaikojo:1990 SP4:1931 DU:1962 JB:1977 RT5:1979 FD1:1988 FF2:1990 SJ29" "Sol" #1=
#2_"*Тентаикоджо:4645 Tentaikojo:Tentaikojo:1990 SP4" "Sol" #2=
#3_"1990 SP4:*Тентаикоджо:4645 Tentaikojo:Tentaikojo" "Sol" #3=
".:Tentaikojo:4645 Tentaikojo:1990 SP4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.57
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.366376095971
		SemiMajorAxis	2.671418683243
		Eccentricity	0.134444146668
		Inclination	9.459122472769
		AscendingNode	179.77368428045
		ArgOfPericenter	292.713481618767
		MeanAnomaly	98.817846174649
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1622
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4645"
}

#1_"4648 Tirion:Tirion:1931 UE:1977 CA1" "Sol" #1=
#2_"*Тирион:4648 Tirion:Tirion:1931 UE" "Sol" #2=
#3_"1931 UE:*Тирион:4648 Tirion:Tirion" "Sol" #3=
".:Tirion:4648 Tirion:1931 UE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.145
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.704332421173
		SemiMajorAxis	2.39405707712
		Eccentricity	0.185826404822
		Inclination	9.794909126605
		AscendingNode	319.713692289951
		ArgOfPericenter	122.995584652369
		MeanAnomaly	119.346113930851
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0614
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4648"
}

#1_"4660 Nereus:Nereus:1982 DB" "Sol" #1=
#2_"*Нерей:4660 Nereus:Nereus:1982 DB" "Sol" #2=
#3_"1982 DB:*Нерей:4660 Nereus:Nereus" "Sol" #3=
".:Nereus:4660 Nereus:1982 DB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4660 nereus.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.255
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.816330018802
		SemiMajorAxis	1.488644643047
		Eccentricity	0.36009561566
		Inclination	1.431990714893
		AscendingNode	314.45838557572
		ArgOfPericenter	158.011918122992
		MeanAnomaly	36.747330477302
	}
	UniformRotation
	{
		Period	15.1
	}
	LunarLambert	0.5
	Albedo	0.55
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4660"
}

#1_"4663 Falta:Falta:1984 SM1:1955 QF1:1978 RX3:1978 SK4:1987 DK5" "Sol" #1=
#2_"*Фалта:4663 Falta:Falta:1984 SM1" "Sol" #2=
#3_"1984 SM1:*Фалта:4663 Falta:Falta" "Sol" #3=
".:Falta:4663 Falta:1984 SM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.385
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.75395579771
		SemiMajorAxis	3.210989455132
		Eccentricity	0.059246106347
		Inclination	14.898020404397
		AscendingNode	353.184745995682
		ArgOfPericenter	7.092911061102
		MeanAnomaly	91.777767800603
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0338
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4663"
}

#1_"4672 Takuboku:Takuboku:1988 HB:1971 HT:1979 WS7:1981 AN3" "Sol" #1=
#2_"*Табубоку:4672 Takuboku:Takuboku:1988 HB" "Sol" #2=
#3_"1988 HB:*Табубоку:4672 Takuboku:Takuboku" "Sol" #3=
".:Takuboku:4672 Takuboku:1988 HB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.795
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.690641504712
		SemiMajorAxis	3.187391057631
		Eccentricity	0.051369818663
		Inclination	15.551700073972
		AscendingNode	91.877101523149
		ArgOfPericenter	174.322846569812
		MeanAnomaly	199.187292144893
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0609
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4672"
}

#1_"4688 1980 WF:1980 WF" "Sol" #1=
#2_"1980 WF:4688 1980 WF" "Sol" #2=
#3_"1980 WF:4688 1980 WF" "Sol" #3=
".:1980 WF:4688 1980 WF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.339828055655
		SemiMajorAxis	2.234312614977
		Eccentricity	0.515453238847
		Inclination	6.378483616978
		AscendingNode	241.343223958172
		ArgOfPericenter	213.54895427488
		MeanAnomaly	62.891313457765
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.18
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4688"
}

#1_"4695 Mediolanum:Mediolanum:1985 RU3:1952 BU1:1972 RY1:1981 UP15:1983 EO1:A911 UF" "Sol" #1=
#2_"*Медиоланум:4695 Mediolanum:Mediolanum:1985 RU3" "Sol" #2=
#3_"1985 RU3:*Медиоланум:4695 Mediolanum:Mediolanum" "Sol" #3=
".:Mediolanum:4695 Mediolanum:1985 RU3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.360458801844
		SemiMajorAxis	2.669004607698
		Eccentricity	0.137940295401
		Inclination	12.544853129265
		AscendingNode	177.26210920345
		ArgOfPericenter	273.539790543509
		MeanAnomaly	180.939910235565
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.056
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4695"
}

#1_"4709 Ennomos:Ennomos:1988 TU2:1954 UM1:1977 UT2" "Sol" #1=
#2_"*Энномус:4709 Ennomos:Ennomos:1988 TU2" "Sol" #2=
#3_"1988 TU2:*Энномус:4709 Ennomos:Ennomos" "Sol" #3=
".:Ennomos:4709 Ennomos:1988 TU2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.425
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.984520145955
		SemiMajorAxis	5.236908248021
		Eccentricity	0.022834318144
		Inclination	25.463803999376
		AscendingNode	253.171284920788
		ArgOfPericenter	88.874358055013
		MeanAnomaly	103.081402281282
	}
	UniformRotation
	{
		Period	12.275
	}
	LunarLambert	0.5
	Albedo	0.0744
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4709"
}

#1_"4712 Iwaizumi:Iwaizumi:1989 QE:1931 EN:1950 RB1:1964 CB:1979 YN2:1987 FO1" "Sol" #1=
#2_"*Иваизуми:4712 Iwaizumi:Iwaizumi:1989 QE" "Sol" #2=
#3_"1989 QE:*Иваизуми:4712 Iwaizumi:Iwaizumi" "Sol" #3=
".:Iwaizumi:4712 Iwaizumi:1989 QE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.375
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.595913675288
		SemiMajorAxis	3.151920121211
		Eccentricity	0.13458413818
		Inclination	12.224654419152
		AscendingNode	334.101141195928
		ArgOfPericenter	349.647112304158
		MeanAnomaly	197.812356247363
	}
	UniformRotation
	{
		Period	6.2486
	}
	LunarLambert	0.5
	Albedo	0.0933
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4712"
}

#1_"4717 Kaneko:Kaneko:1989 WX:1931 VB1:1978 TG4:1984 YR1" "Sol" #1=
#2_"*Канэко:4717 Kaneko:Kaneko:1989 WX" "Sol" #2=
#3_"1989 WX:*Канэко:4717 Kaneko:Kaneko" "Sol" #3=
".:Kaneko:4717 Kaneko:1989 WX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.995
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.239000573893
		SemiMajorAxis	3.016431697582
		Eccentricity	0.097979356446
		Inclination	10.785098210956
		AscendingNode	73.309105264625
		ArgOfPericenter	243.237647936716
		MeanAnomaly	15.609220095445
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1808
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4717"
}

#1_"4730 Xingmingzhou:Xingmingzhou:1980 XZ:1932 BE:1983 GR2:1983 JJ1" "Sol" #1=
#2_"*СинМинЧжоу:4730 Xingmingzhou:Xingmingzhou:1980 XZ" "Sol" #2=
#3_"1980 XZ:*СинМинЧжоу:4730 Xingmingzhou:Xingmingzhou" "Sol" #3=
".:Xingmingzhou:4730 Xingmingzhou:1980 XZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.53
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.532485562289
		SemiMajorAxis	3.128057478336
		Eccentricity	0.044522889816
		Inclination	11.994841511929
		AscendingNode	80.784020220749
		ArgOfPericenter	201.60922534557
		MeanAnomaly	203.644764012129
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1022
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4730"
}

#1_"4732 Froeschle:Froeschle:1981 JG:1955 UO1:1972 TF4:1989 VE" "Sol" #1=
#2_"*Фроешле:4732 Froeschle:Froeschle:1981 JG" "Sol" #2=
#3_"1981 JG:*Фроешле:4732 Froeschle:Froeschle" "Sol" #3=
".:Froeschle:4732 Froeschle:1981 JG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.92
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.611610007339
		SemiMajorAxis	3.15781138257
		Eccentricity	0.071516405874
		Inclination	16.856768449042
		AscendingNode	226.439820556671
		ArgOfPericenter	145.391073698524
		MeanAnomaly	202.643192673479
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0599
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4732"
}

#1_"4754 Panthoos:Panthoos:5010 T-3:1988 RH1" "Sol" #1=
#2_"*Пантхус:4754 Panthoos:Panthoos:1977-4754*:5010 T-3" "Sol" #2=
#3_"1977-4754*:*Пантхус:4754 Panthoos:Panthoos:5010 T-3" "Sol" #3=
".:Panthoos:4754 Panthoos:1977-4754*:5010 T-3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	26.575
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.973426763936
		SemiMajorAxis	5.233676079117
		Eccentricity	0.011225752682
		Inclination	12.32641256516
		AscendingNode	155.065238143218
		ArgOfPericenter	200.05172875509
		MeanAnomaly	88.686874281979
	}
	UniformRotation
	{
		Period	27.68
	}
	LunarLambert	0.5
	Albedo	0.0571
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4754"
}

#1_"4758 Hermitage:Hermitage:1978 SN4:1949 OR:1972 RF3:1977 LE1:1984 UU3" "Sol" #1=
#2_"*Эрмитаж:4758 Hermitage:Hermitage:1978 SN4" "Sol" #2=
#3_"1978 SN4:*Эрмитаж:4758 Hermitage:Hermitage" "Sol" #3=
".:Hermitage:4758 Hermitage:1978 SN4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.775986764123
		SemiMajorAxis	3.219180473301
		Eccentricity	0.169035860769
		Inclination	1.623302701894
		AscendingNode	60.807633278636
		ArgOfPericenter	285.613721031737
		MeanAnomaly	123.565266308313
	}
	UniformRotation
	{
		Period	10.1505
	}
	LunarLambert	0.5
	Albedo	0.1106
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4758"
}

#1_"4759 Aretta:Aretta:1978 VG10:1977 RO1:1989 UU4" "Sol" #1=
#2_"*Аретта:4759 Aretta:Aretta:1978 VG10" "Sol" #2=
#3_"1978 VG10:*Аретта:4759 Aretta:Aretta" "Sol" #3=
".:Aretta:4759 Aretta:1978 VG10:1977 RO1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.82
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.664426238313
		SemiMajorAxis	3.177594553146
		Eccentricity	0.179385900444
		Inclination	0.805333229293
		AscendingNode	142.588435282776
		ArgOfPericenter	204.890974600311
		MeanAnomaly	180.402805038123
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1255
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4759"
}

#1_"4764 Joneberhart:Joneberhart:1983 CC:1989 MA" "Sol" #1=
#2_"*Джонберхарт:4764 Joneberhart:Joneberhart:1983 CC" "Sol" #2=
#3_"1983 CC:Joneberhart:*Джонберхарт:4764 Joneberhart" "Sol" #3=
".:Joneberhart:4764 Joneberhart:1983 CC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4764 joneberhart.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.413
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.685043173999
		SemiMajorAxis	1.931799491265
		Eccentricity	0.047115198328
		Inclination	24.834623062548
		AscendingNode	134.273220734974
		ArgOfPericenter	176.753435524115
		MeanAnomaly	71.467917818339
	}
	UniformRotation
	{
		Period	5.483
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4764"
}

#1_"4768 Hartley:Hartley:1988 PH1" "Sol" #1=
#2_"*Хартли:4768 Hartley:Hartley:1988 PH1" "Sol" #2=
#3_"1988 PH1:*Хартли:4768 Hartley:Hartley" "Sol" #3=
".:Hartley:4768 Hartley:1988 PH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.315
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.654191880934
		SemiMajorAxis	3.173765928946
		Eccentricity	0.236527401111
		Inclination	20.083444886574
		AscendingNode	320.501819419296
		ArgOfPericenter	26.654960295579
		MeanAnomaly	214.680005661599
	}
	UniformRotation
	{
		Period	22.08
	}
	LunarLambert	0.5
	Albedo	0.0398
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4768"
}

#1_"4769 Castalia:Castalia:1989 PB" "Sol" #1=
#2_"*Касталия:4769 Castalia:Castalia:1989 PB" "Sol" #2=
#3_"1989 PB:*Касталия:4769 Castalia:Castalia" "Sol" #3=
".:Castalia:4769 Castalia:1989 PB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4769 castalia.cmod"
	MeshCenter	[ -0.0456 -0.0347 -0.0178 ]
	Texture	"castalia.jpg"
	Radius	0.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.0964554311904
		SemiMajorAxis	1.06329846579985
		Eccentricity	0.4831758779219762
		Inclination	8.886375314583967
		AscendingNode	325.5963169809532
		ArgOfPericenter	121.3573923850026
		MeanAnomaly	327.6374077005201
	}
	UniformRotation
	{
		Period	4.095
		Inclination	146
		AscendingNode	325
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4769"
}

#1_"4772 Frankdrake:Frankdrake:1989 VM:1971 QD1:1980 DH:1986 GL2" "Sol" #1=
#2_"*Фрэнкдрейк:4772 Frankdrake:Frankdrake:1989 VM" "Sol" #2=
#3_"1989 VM:*Фрэнкдрейк:4772 Frankdrake:Frankdrake" "Sol" #3=
".:Frankdrake:4772 Frankdrake:1989 VM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.619601189599
		SemiMajorAxis	3.160808580742
		Eccentricity	0.069161950799
		Inclination	11.514657230975
		AscendingNode	209.905101448645
		ArgOfPericenter	186.684695977595
		MeanAnomaly	172.452078484835
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0409
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4772"
}

#1_"4783 Wasson:Wasson:1983 AH1:1987 AA" "Sol" #1=
#2_"*Вассон:4783 Wasson:Wasson:1983 AH1" "Sol" #2=
#3_"1983 AH1:*Вассон:4783 Wasson:Wasson" "Sol" #3=
".:Wasson:4783 Wasson:1983 AH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.67
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.082027064245
		SemiMajorAxis	2.55414246896
		Eccentricity	0.205005285514
		Inclination	16.570471999215
		AscendingNode	109.293045857722
		ArgOfPericenter	357.943167444864
		MeanAnomaly	301.987288915367
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0455
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4783"
}

#1_"4790 Petrpravec:Petrpravec:1988 PP:1978 EA1" "Sol" #1=
#2_"*Пётрправец:4790 Petrpravec:Petrpravec:1988 PP" "Sol" #2=
#3_"1988 PP:*Пётрправец:4790 Petrpravec:Petrpravec" "Sol" #3=
".:Petrpravec:4790 Petrpravec:1988 PP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.254110636926
		SemiMajorAxis	2.625429649141
		Eccentricity	0.085903645958
		Inclination	12.725112690167
		AscendingNode	131.521470081404
		ArgOfPericenter	85.462203770798
		MeanAnomaly	161.560457280866
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1084
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4790"
}

#1_"4791 Iphidamas:Iphidamas:1988 PB1" "Sol" #1=
#2_"*Ипхидамас:4791 Iphidamas:Iphidamas:1988 PB1" "Sol" #2=
#3_"1988 PB1:*Ипхидамас:4791 Iphidamas:Iphidamas" "Sol" #3=
".:Iphidamas:4791 Iphidamas:1988 PB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.925
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.735677220432
		SemiMajorAxis	5.164163326836
		Eccentricity	0.047147073001
		Inclination	25.962823252531
		AscendingNode	261.456556216644
		ArgOfPericenter	165.421091003055
		MeanAnomaly	351.319035436315
	}
	UniformRotation
	{
		Period	9.727
	}
	LunarLambert	0.5
	Albedo	0.0579
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4791"
}

#1_"4800 Veveri:Veveri:1989 TG17:1979 YG6:1984 UO4" "Sol" #1=
#2_"*Вевери:4800 Veveri:Veveri:1989 TG17" "Sol" #2=
#3_"1989 TG17:Veveri:*Вевери:4800 Veveri" "Sol" #3=
".:Veveri:4800 Veveri:1989 TG17" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4800 veveri.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.044
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.212656982002
		SemiMajorAxis	3.00631139708
		Eccentricity	0.10588079291
		Inclination	10.298080125091
		AscendingNode	179.629187627611
		ArgOfPericenter	180.159294023494
		MeanAnomaly	98.77970858249
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.133
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4800"
}

#1_"4801 Ohre:Ohre:1989 UR4:1939 BE:1952 DA1:1985 YQ1" "Sol" #1=
#2_"*Огрже:4801 Ohre:Ohre:1989 UR4" "Sol" #2=
#3_"1989 UR4:Ohre:*Огрже:4801 Ohre" "Sol" #3=
".:Ohre:4801 Ohre:1989 UR4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4801 ohre.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	6.98
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.300207222206
		SemiMajorAxis	2.6443612715
		Eccentricity	0.16178088403
		Inclination	2.254187400316
		AscendingNode	66.59570544238
		ArgOfPericenter	45.238060957073
		MeanAnomaly	67.660408038413
	}
	UniformRotation
	{
		Period	32
	}
	LunarLambert	0.5
	Albedo	0.091
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4801"
}

#1_"4812 Hakuhou:Hakuhou:1977 DL3:1972 XZ:1979 SO8:1988 FP" "Sol" #1=
#2_"*Хакухоу:4812 Hakuhou:Hakuhou:1977 DL3" "Sol" #2=
#3_"1977 DL3:*Хакухоу:4812 Hakuhou:Hakuhou" "Sol" #3=
".:Hakuhou:4812 Hakuhou:1977 DL3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	3.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.643759091478
		SemiMajorAxis	2.367886976888
		Eccentricity	0.207581887674
		Inclination	4.674752336707
		AscendingNode	3.71211263033
		ArgOfPericenter	73.404259278079
		MeanAnomaly	185.618610271307
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.058
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4812"
}

#1_"4813 Terebizh:Terebizh:1977 RR7:1981 JN1:1981 KV" "Sol" #1=
#2_"*Теребиж:4813 Terebizh:Terebizh:1977 RR7" "Sol" #2=
#3_"1977 RR7:*Теребиж:4813 Terebizh:Terebizh" "Sol" #3=
".:Terebizh:4813 Terebizh:1977 RR7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.995
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.518699208847
		SemiMajorAxis	3.122858797969
		Eccentricity	0.102319515915
		Inclination	11.856781014982
		AscendingNode	20.964148249142
		ArgOfPericenter	296.130465344881
		MeanAnomaly	311.889884550752
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0226
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4813"
}

#1_"4831 Baldwin:Baldwin:1988 RX11:1970 GK1:1975 ET" "Sol" #1=
#2_"*Балдвин:4831 Baldwin:Baldwin:1988 RX11" "Sol" #2=
#3_"1988 RX11:*Балдвин:4831 Baldwin:Baldwin" "Sol" #3=
".:Baldwin:4831 Baldwin:1988 RX11" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.59
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.436707693231
		SemiMajorAxis	3.091850745982
		Eccentricity	0.114427516946
		Inclination	0.264518601529
		AscendingNode	65.78955762162
		ArgOfPericenter	145.826502645954
		MeanAnomaly	59.858464754964
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0157
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4831"
}

#1_"4833 Meges:Meges:1989 AL2:1975 XN5" "Sol" #1=
#2_"*Мегес:4833 Meges:Meges:1989 AL2" "Sol" #2=
#3_"1989 AL2:*Мегес:4833 Meges:Meges" "Sol" #3=
".:Meges:4833 Meges:1989 AL2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	43.665
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.01468386347
		SemiMajorAxis	5.245691713685
		Eccentricity	0.091739270193
		Inclination	34.691518394523
		AscendingNode	101.76674502891
		ArgOfPericenter	279.848348642941
		MeanAnomaly	156.259272339074
	}
	UniformRotation
	{
		Period	14.25
	}
	LunarLambert	0.5
	Albedo	0.0531
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4833"
}

#1_":4834 Thoas:Thoas:1989 AM2:1975 XX3:1986 XN:1987 WP2" "Sol" #1=
#2_"*Фоант:4834 Thoas:Thoas:1989 AM2" "Sol" #2=
#3_"1989 AM2:*Фоант:4834 Thoas:Thoas" "Sol" #3=
".:Thoas:4834 Thoas:1989 AM2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	43.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.925197586042
		SemiMajorAxis	5.219612399622
		Eccentricity	0.135456574452
		Inclination	28.465230810122
		AscendingNode	76.031214258138
		ArgOfPericenter	352.050645971529
		MeanAnomaly	110.513070377156
	}
	UniformRotation
	{
		Period	18.192
	}
	LunarLambert	0.5
	Albedo	0.049
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4834"
}

#1_"4836 Medon:Medon:1989 CK1:1986 XM" "Sol" #1=
#2_"*Медон:4836 Medon:Medon:1989 CK1" "Sol" #2=
#3_"1989 CK1:*Медон:4836 Medon:Medon" "Sol" #3=
".:Medon:4836 Medon:1989 CK1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.865
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.855486247108
		SemiMajorAxis	5.199250942268
		Eccentricity	0.109125185899
		Inclination	19.412087731631
		AscendingNode	82.050526668856
		ArgOfPericenter	34.421785640016
		MeanAnomaly	85.772278563288
	}
	UniformRotation
	{
		Period	9.838
	}
	LunarLambert	0.5
	Albedo	0.061
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4836"
}

#1_"4837 Bickerton:Bickerton:1989 ME:1978 QM" "Sol" #1=
#2_"*Биккертон:4837 Bickerton:Bickerton:1989 ME" "Sol" #2=
#3_"1989 ME:*Биккертон:4837 Bickerton:Bickerton" "Sol" #3=
".:Bickerton:4837 Bickerton:1989 ME" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.08
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.727062556221
		SemiMajorAxis	3.200976480196
		Eccentricity	0.132713232
		Inclination	28.233463963497
		AscendingNode	327.206519596293
		ArgOfPericenter	44.310818177627
		MeanAnomaly	92.406587615644
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0693
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4837"
}

#1_"4840 Otaynang:Otaynang:1989 UY:1955 XF:1978 YW1" "Sol" #1=
#2_"*Отайнанг:4840 Otaynang:Otaynang:1989 UY" "Sol" #2=
#3_"1989 UY:*Отайнанг:4840 Otaynang:Otaynang" "Sol" #3=
".:Otaynang:4840 Otaynang:1989 UY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.89
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.67625414452
		SemiMajorAxis	3.18201644525
		Eccentricity	0.10053990023
		Inclination	15.170381019461
		AscendingNode	247.475987417282
		ArgOfPericenter	194.326691493499
		MeanAnomaly	124.104594309305
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0398
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4840"
}

#1_"4843 Megantic:Megantic:1990 DR4:1982 RT1:1990 EO10:A908 BH" "Sol" #1=
#2_"*Межантик:4843 Megantic:Megantic:1990 DR4" "Sol" #2=
#3_"1990 DR4:*Межантик:4843 Megantic:Megantic" "Sol" #3=
".:Megantic:4843 Megantic:1990 DR4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.01
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.430460934955
		SemiMajorAxis	3.089481941693
		Eccentricity	0.121948145413
		Inclination	11.009273652255
		AscendingNode	162.632803140796
		ArgOfPericenter	220.776564747635
		MeanAnomaly	319.057214889579
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4843"
}

#1_"4870 Shcherban':Shcherban':1989 UK8:1931 UL:1933 BL:1956 AB:1980 EF1" "Sol" #1=
#2_"*Щербань:4870 Shcherban':Shcherban':1989 UK8" "Sol" #2=
#3_"1989 UK8:*Щербань:4870 Shcherban':Shcherban'" "Sol" #3=
".:Shcherban':4870 Shcherban':1989 UK8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.754055880444
		SemiMajorAxis	3.211026689073
		Eccentricity	0.080592798657
		Inclination	9.736832645425
		AscendingNode	83.526102985458
		ArgOfPericenter	345.75859743143
		MeanAnomaly	105.95401309369
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0834
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4870"
}

#1_"4874 Burke:Burke:1991 AW:1928 BB:1970 EC:1987 EM" "Sol" #1=
#2_"*Бурке:4874 Burke:Burke:1991 AW" "Sol" #2=
#3_"1991 AW:*Бурке:4874 Burke:Burke" "Sol" #3=
".:Burke:4874 Burke:1991 AW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.199413516993
		SemiMajorAxis	2.602876883266
		Eccentricity	0.122454254706
		Inclination	14.655327656739
		AscendingNode	127.595633368621
		ArgOfPericenter	325.528715498971
		MeanAnomaly	275.19281788056
	}
	UniformRotation
	{
		Period	3.657
	}
	LunarLambert	0.5
	Albedo	0.0818
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4874"
}

#1_"4877 Humboldt:Humboldt:5066 T-2:1982 YF2:1986 TU15:1986 UF1" "Sol" #1=
#2_"*Гумбольдт:4877 Humboldt:Humboldt:1973-4877*:5066 T-2" "Sol" #2=
#3_"1973-4877*:Humboldt:*Гумбольдт:4877 Humboldt:5066 T-2" "Sol" #3=
".:Humboldt:4877 Humboldt:1973-4877*:5066 T-2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4877 humboldt.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.414
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.270578178746
		SemiMajorAxis	2.632200594694
		Eccentricity	0.134439644362
		Inclination	12.40195542307
		AscendingNode	228.893657705356
		ArgOfPericenter	201.412339005664
		MeanAnomaly	5.864716591172
	}
	UniformRotation
	{
		Period	3.491213
	}
	LunarLambert	0.5
	Albedo	0.29
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4877"
}

#1_"4889 Praetorius:Praetorius:1982 UW3:1979 CB:1979 ED:1990 FC3" "Sol" #1=
#2_"*Праэториус:4889 Praetorius:Praetorius:1982 UW3" "Sol" #2=
#3_"1982 UW3:*Праэториус:4889 Praetorius:Praetorius" "Sol" #3=
".:Praetorius:4889 Praetorius:1982 UW3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.195
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.445655344471
		SemiMajorAxis	3.095242163592
		Eccentricity	0.192503646137
		Inclination	13.946399591746
		AscendingNode	185.876891979446
		ArgOfPericenter	275.312311669586
		MeanAnomaly	254.255411767742
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0908
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4889"
}

#1_"4896 Tomoegozen:Tomoegozen:1986 YA:1975 XJ2:1985 OU:1986 RE4" "Sol" #1=
#2_"*Томоегозен:4896 Tomoegozen:Tomoegozen:1986 YA" "Sol" #2=
#3_"1986 YA:*Томоегозен:4896 Tomoegozen:Tomoegozen" "Sol" #3=
".:Tomoegozen:4896 Tomoegozen:1986 YA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4896 tomoegozen.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	13.402
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.480429135956
		SemiMajorAxis	3.108404837577
		Eccentricity	0.168098306653
		Inclination	16.564408111494
		AscendingNode	261.407125314183
		ArgOfPericenter	96.585352049551
		MeanAnomaly	90.923024580924
	}
	UniformRotation
	{
		Period	8.869
	}
	LunarLambert	0.5
	Albedo	0.157
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4896"
}

#1_"4903 Ichikawa:Ichikawa:1989 UD:1953 FU:1972 TM1:1977 OG:1980 BU4:1983 TG" "Sol" #1=
#2_"*Итикава:4903 Ichikawa:Ichikawa:1989 UD" "Sol" #2=
#3_"1989 UD:*Итикава:4903 Ichikawa:Ichikawa" "Sol" #3=
".:Ichikawa:4903 Ichikawa:1989 UD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.57885928198
		SemiMajorAxis	3.145512895088
		Eccentricity	0.182673074857
		Inclination	2.543026347211
		AscendingNode	90.77898303954
		ArgOfPericenter	251.098927821189
		MeanAnomaly	209.745686706416
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4903"
}

#1_"4907 Zoser:Zoser:7618 P-L:1972 XR1:1977 RE3:1980 FD11" "Sol" #1=
#2_"*Зосер:4907 Zoser:Zoser:1960-4907*:7618 P-L" "Sol" #2=
#3_"1960-4907*:*Зосер:4907 Zoser:Zoser:7618 P-L" "Sol" #3=
".:Zoser:4907 Zoser:1960-4907*:7618 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.99
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.662799219643
		SemiMajorAxis	3.176986047479
		Eccentricity	0.093658830773
		Inclination	5.994537301883
		AscendingNode	136.51628284982
		ArgOfPericenter	302.142654866727
		MeanAnomaly	138.228857355619
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0529
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4907"
}

#1_"4911 Rosenzweig:Rosenzweig:1953 UD:1987 SM" "Sol" #1=
#2_"*Росензвеиг:4911 Rosenzweig:Rosenzweig:1953 UD" "Sol" #2=
#3_"1953 UD:*Росензвеиг:4911 Rosenzweig:Rosenzweig" "Sol" #3=
".:Rosenzweig:4911 Rosenzweig:1953 UD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.289509924905
		SemiMajorAxis	2.639974000789
		Eccentricity	0.178886028089
		Inclination	13.020130507989
		AscendingNode	209.860994101571
		ArgOfPericenter	157.66081067272
		MeanAnomaly	117.238622638664
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0908
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4911"
}

#1_"4917 Yurilvovia:Yurilvovia:1973 SC6:1955 SM2:1955 UH:1964 TO1:1982 RD" "Sol" #1=
#2_"*Юрильвовия:4917 Yurilvovia:Yurilvovia:1973 SC6" "Sol" #2=
#3_"1973 SC6:Yurilvovia:*Юрильвовия:4917 Yurilvovia" "Sol" #3=
".:Yurilvovia:4917 Yurilvovia:1973 SC6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4917 yurilvovia.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.205
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.546655102197
		SemiMajorAxis	2.744453472552
		Eccentricity	0.107617521458
		Inclination	3.712476354744
		AscendingNode	180.694121154763
		ArgOfPericenter	197.467719377346
		MeanAnomaly	186.548426310952
	}
	UniformRotation
	{
		Period	1.1
	}
	LunarLambert	0.5
	Albedo	0.208
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4917"
}

#1_"4918 Rostropovich:Rostropovich:1974 QU1:1983 YC" "Sol" #1=
#2_"*Ростропович:4918 Rostropovich:Rostropovich:1974 QU1" "Sol" #2=
#3_"1974 QU1:*Ростропович:4918 Rostropovich:Rostropovich" "Sol" #3=
".:Rostropovich:4918 Rostropovich:1974 QU1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.965
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.288092596667
		SemiMajorAxis	2.639392440059
		Eccentricity	0.233498940754
		Inclination	1.768768946613
		AscendingNode	205.338670432566
		ArgOfPericenter	195.666289193525
		MeanAnomaly	104.546964386351
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0651
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4918"
}

#1_"4930 Rephiltim:Rephiltim:1983 AO2:1950 CD:1965 WU:1990 HE1" "Sol" #1=
#2_"*Рефилтим:4930 Rephiltim:Rephiltim:1983 AO2" "Sol" #2=
#3_"1983 AO2:*Рефилтим:4930 Rephiltim:Rephiltim" "Sol" #3=
".:Rephiltim:4930 Rephiltim:1983 AO2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.635
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.517972937678
		SemiMajorAxis	3.122584809241
		Eccentricity	0.047911445218
		Inclination	15.528436691188
		AscendingNode	122.301685444477
		ArgOfPericenter	358.862738734089
		MeanAnomaly	263.140289057925
	}
	UniformRotation
	{
		Period	5.243
	}
	LunarLambert	0.5
	Albedo	0.072
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4930"
}

#1_"4954 Eric:Eric:1990 SQ" "Sol" #1=
#2_"*Эрик:4954 Eric:Eric:1990 SQ" "Sol" #2=
#3_"1990 SQ:*Эрик:4954 Eric:Eric" "Sol" #3=
".:Eric:4954 Eric:1990 SQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4954 eric.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.831214924612
		SemiMajorAxis	2.001288767405
		Eccentricity	0.448652414164
		Inclination	17.446660827576
		AscendingNode	358.527830275082
		ArgOfPericenter	52.438570075598
		MeanAnomaly	174.930470328478
	}
	UniformRotation
	{
		Period	12.056
	}
	LunarLambert	0.5
	Albedo	0.176
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4954"
}

#1_"4955 Gold:Gold:1990 SF2:1987 BQ2:1990 WB" "Sol" #1=
#2_"*Голд:4955 Gold:Gold:1990 SF2" "Sol" #2=
#3_"1990 SF2:*Голд:4955 Gold:Gold" "Sol" #3=
".:Gold:4955 Gold:1990 SF2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.92
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.620467261916
		SemiMajorAxis	3.161133327215
		Eccentricity	0.129499087593
		Inclination	7.420212367113
		AscendingNode	89.845860855663
		ArgOfPericenter	247.912569950347
		MeanAnomaly	141.453278615281
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0599
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4955"
}

#1_"4958 Wellnitz:Wellnitz:1991 NT1:1931 AF1:1950 TC3:1953 JP:1961 WA:1980 NG:1982 YA3:1984 FG2: #1=
#1_1989 EE8" "Sol" #1=
#2_"*Веллниц:4958 Wellnitz:Wellnitz:1991 NT1" "Sol" #2=
#3_"1991 NT1:*Веллниц:4958 Wellnitz:Wellnitz" "Sol" #3=
".:Wellnitz:4958 Wellnitz:1991 NT1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.228996120913
		SemiMajorAxis	3.012590333636
		Eccentricity	0.078865521342
		Inclination	9.087696796861
		AscendingNode	253.096306959221
		ArgOfPericenter	217.798086802067
		MeanAnomaly	15.243270752884
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0582
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4958"
}

#1_"4959 Niinoama:Niinoama:1991 PA1:1958 TZ:1966 CB:1968 MC:1972 EB:1979 OU13:1980 TG1:1980 TS8: #1=
#1_1984 OO:1985 OD:1986 VS1:1989 FE1" "Sol" #1=
#2_"*Нииноама:4959 Niinoama:Niinoama:1991 PA1" "Sol" #2=
#3_"1991 PA1:*Нииноама:4959 Niinoama:Niinoama" "Sol" #3=
".:Niinoama:4959 Niinoama:1991 PA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.98
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.582485238036
		SemiMajorAxis	3.146875689382
		Eccentricity	0.006113877745
		Inclination	9.004664254398
		AscendingNode	128.926774116406
		ArgOfPericenter	303.930498404463
		MeanAnomaly	329.661213419141
	}
	UniformRotation
	{
		Period	4.73
	}
	LunarLambert	0.5
	Albedo	0.1082
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4959"
}

#1_"4966 Edolsen:Edolsen:1981 EO34:1987 SO1" "Sol" #1=
#2_"*Едольсен:4966 Edolsen:Edolsen:1981 EO34" "Sol" #2=
#3_"1981 EO34:*Едольсен:4966 Edolsen:Edolsen" "Sol" #3=
".:Edolsen:4966 Edolsen:1981 EO34" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.83
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.27923584238
		SemiMajorAxis	2.635756867949
		Eccentricity	0.210298107262
		Inclination	9.934499667226
		AscendingNode	175.950345284424
		ArgOfPericenter	183.701608713688
		MeanAnomaly	132.633042240563
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0687
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4966"
}

#1_"4967 Glia:Glia:1983 CF1:1958 UQ:1975 VD6:1979 ML9:1990 KA1" "Sol" #1=
#2_"*Глия:4967 Glia:Glia:1983 CF1" "Sol" #2=
#3_"1983 CF1:*Глия:4967 Glia:Glia" "Sol" #3=
".:Glia:4967 Glia:1983 CF1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.835
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.587269732063
		SemiMajorAxis	3.148673461933
		Eccentricity	0.040477859788
		Inclination	16.982572781968
		AscendingNode	125.011756107168
		ArgOfPericenter	224.135458411012
		MeanAnomaly	41.890352266479
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1054
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4967"
}

#1_"4973 Showa:Showa:1990 FT:1978 CF:1981 WK7:1987 SH14" "Sol" #1=
#2_"*Шова:4973 Showa:Showa:1990 FT" "Sol" #2=
#3_"1990 FT:*Шова:4973 Showa:Showa" "Sol" #3=
".:Showa:4973 Showa:1990 FT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.42
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.361524558959
		SemiMajorAxis	3.433222925731
		Eccentricity	0.078097950543
		Inclination	18.907658586573
		AscendingNode	352.852954417926
		ArgOfPericenter	132.793540115683
		MeanAnomaly	13.362856179153
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0865
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4973"
}

#1_"4995 Griffin:Griffin:1984 QR:1971 BV:1989 CY" "Sol" #1=
#2_"*Гриффин:4995 Griffin:Griffin:1984 QR" "Sol" #2=
#3_"1984 QR:Griffin:*Гриффин:4995 Griffin" "Sol" #3=
".:Griffin:4995 Griffin:1984 QR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"4995 griffin.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.193
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.581451142342
		SemiMajorAxis	2.340815686485
		Eccentricity	0.312661222394
		Inclination	20.594219390408
		AscendingNode	322.151253584204
		ArgOfPericenter	88.608710130956
		MeanAnomaly	353.368716721177
	}
	UniformRotation
	{
		Period	26.37
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=4995"
}

#1_"5006 Teller:Teller:1989 GL5:1932 EY:1982 BN8:1986 TS2" "Sol" #1=
#2_"*Теллер:5006 Teller:Teller:1989 GL5" "Sol" #2=
#3_"1989 GL5:Teller:*Теллер:5006 Teller" "Sol" #3=
".:Teller:5006 Teller:1989 GL5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5006 teller.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.438
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.677725814597
		SemiMajorAxis	3.182566417813
		Eccentricity	0.071783893581
		Inclination	7.636660463556
		AscendingNode	102.82886850532
		ArgOfPericenter	31.075809548368
		MeanAnomaly	20.415431755121
	}
	UniformRotation
	{
		Period	10.898
	}
	LunarLambert	0.5
	Albedo	0.268
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5006"
}

#1_"5008 Miyazawakenji:Miyazawakenji:1991 DV:1926 RT:1949 OS:1968 HF:1969 RO1:1971 BA2:1986 XL" "Sol" #1=
#2_"*Миядзавакэндзи:5008 Miyazawakenji:Miyazawakenji:1991 DV" "Sol" #2=
#3_"1991 DV:Miyazawakenji:*Миядзавакэндзи:5008 Miyazawakenji" "Sol" #3=
".:Miyazawakenji:5008 Miyazawakenji:1991 DV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5008 miyazawakenji.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.603
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.295798475592
		SemiMajorAxis	2.214632305686
		Eccentricity	0.060793843125
		Inclination	5.270270279344
		AscendingNode	142.4376328587
		ArgOfPericenter	42.399813708883
		MeanAnomaly	298.948734362796
	}
	UniformRotation
	{
		Period	13.52
	}
	LunarLambert	0.5
	Albedo	0.298
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5008"
}

#1_"5011 Ptah:Ptah:1983 TF2:6743 P-L" "Sol" #1=
#2_"*Птах:5011 Ptah:Ptah:1983 TF2" "Sol" #2=
#3_"1983 TF2:*Птах:5011 Ptah:Ptah" "Sol" #3=
".:Ptah:5011 Ptah:1983 TF2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.9028
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.0920010246
		SemiMajorAxis	1.6356955058
		Eccentricity	0.500038286816
		Inclination	7.407365029659
		AscendingNode	10.784374761652
		ArgOfPericenter	105.744293638667
		MeanAnomaly	277.868867352099
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.16
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5011"
}

#1_"5012 Eurymedon:Eurymedon:9507 P-L:1984 SV6:1988 AW2:1991 GD3" "Sol" #1=
#2_"*Эвримедон:5012 Eurymedon:Eurymedon:1960-5012*:9507 P-L" "Sol" #2=
#3_"1960-5012*:*Эвримедон:5012 Eurymedon:Eurymedon:9507 P-L" "Sol" #3=
".:Eurymedon:5012 Eurymedon:1960-5012*:9507 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.105600701632
		SemiMajorAxis	5.27212171855
		Eccentricity	0.08485484691
		Inclination	4.996675317099
		AscendingNode	34.833705676898
		ArgOfPericenter	333.947188170059
		MeanAnomaly	177.98198231626
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.063
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5012"
}

#1_"5022 Roccapalumba:Roccapalumba:1984 HE1:1969 RZ:1986 TO4" "Sol" #1=
#2_"*Роккапалумба:5022 Roccapalumba:Roccapalumba:1984 HE1" "Sol" #2=
#3_"1984 HE1:*Роккапалумба:5022 Roccapalumba:Roccapalumba" "Sol" #3=
".:Roccapalumba:5022 Roccapalumba:1984 HE1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.885
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.581853368792
		SemiMajorAxis	3.14663822627
		Eccentricity	0.088866503096
		Inclination	11.052866921202
		AscendingNode	223.063307298535
		ArgOfPericenter	68.956344324605
		MeanAnomaly	94.818717496018
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0324
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5022"
}

#1_"5024 Bechmann:Bechmann:1985 VP:1973 SL3" "Sol" #1=
#2_"*Бекман:5024 Bechmann:Bechmann:1985 VP" "Sol" #2=
#3_"1985 VP:*Бекман:5024 Bechmann:Bechmann" "Sol" #3=
".:Bechmann:5024 Bechmann:1985 VP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.26
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.792506436885
		SemiMajorAxis	3.225315585532
		Eccentricity	0.050182265193
		Inclination	14.63916236255
		AscendingNode	352.600268284638
		ArgOfPericenter	120.29173992273
		MeanAnomaly	277.383728316875
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0545
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5024"
}

#1_"5025 1986 TS6:1986 TS6:1989 BX" "Sol" #1=
#2_"1986 TS6:5025 1986 TS6" "Sol" #2=
#3_"1986 TS6:5025 1986 TS6" "Sol" #3=
".:1986 TS6:5025 1986 TS6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.915
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.860994353387
		SemiMajorAxis	5.200861212769
		Eccentricity	0.074664075634
		Inclination	11.023100864423
		AscendingNode	347.843704223828
		ArgOfPericenter	73.900366636887
		MeanAnomaly	120.831541939631
	}
	UniformRotation
	{
		Period	250
	}
	LunarLambert	0.5
	Albedo	0.0635
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5025"
}

#1_"5027 Androgeos:Androgeos:1988 BX1" "Sol" #1=
#2_"*Андрогей:5027 Androgeos:Androgeos:1988 BX1" "Sol" #2=
#3_"1988 BX1:*Андрогей:5027 Androgeos:Androgeos" "Sol" #3=
".:Androgeos:5027 Androgeos:1988 BX1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.93
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.215387143125
		SemiMajorAxis	5.30394919693
		Eccentricity	0.065129819593
		Inclination	31.448105432707
		AscendingNode	78.222513053179
		ArgOfPericenter	345.130764463258
		MeanAnomaly	122.344057138487
	}
	UniformRotation
	{
		Period	11.355
	}
	LunarLambert	0.5
	Albedo	0.0917
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5027"
}

#1_"5070 Arai:Arai:1991 XT:1951 TY:1954 EN:1970 AS:1979 WQ5:1982 HA:1990 UJ6:1990 VE7" "Sol" #1=
#2_"*Арай:5070 Arai:Arai:1991 XT" "Sol" #2=
#3_"1991 XT:*Арай:5070 Arai:Arai" "Sol" #3=
".:Arai:5070 Arai:1991 XT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.474910944304
		SemiMajorAxis	3.106317938543
		Eccentricity	0.066620349126
		Inclination	6.036054585789
		AscendingNode	339.921469301578
		ArgOfPericenter	187.630859577858
		MeanAnomaly	18.501171662788
	}
	UniformRotation
	{
		Period	53
	}
	LunarLambert	0.5
	Albedo	0.0792
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5070"
}

#1_"5079 Brubeck:Brubeck:1975 DB:1979 BN:1989 OK" "Sol" #1=
#2_"*Брубек:5079 Brubeck:Brubeck:1975 DB" "Sol" #2=
#3_"1975 DB:*Брубек:5079 Brubeck:Brubeck" "Sol" #3=
".:Brubeck:5079 Brubeck:1975 DB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.25
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.297801130854
		SemiMajorAxis	2.643374781323
		Eccentricity	0.203279731408
		Inclination	10.768395143579
		AscendingNode	269.032851727572
		ArgOfPericenter	246.044451571036
		MeanAnomaly	103.153184486561
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0592
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5079"
}

#1_"5081 Sanguin:Sanguin:1976 WC1:1968 HD1:1989 JN" "Sol" #1=
#2_"*Сангуин:5081 Sanguin:Sanguin:1976 WC1" "Sol" #2=
#3_"1976 WC1:*Сангуин:5081 Sanguin:Sanguin" "Sol" #3=
".:Sanguin:5081 Sanguin:1976 WC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.72
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.531518811328
		SemiMajorAxis	2.319007827036
		Eccentricity	0.113803053119
		Inclination	13.194993323716
		AscendingNode	83.300945311775
		ArgOfPericenter	163.630311969576
		MeanAnomaly	59.399635317512
	}
	UniformRotation
	{
		Period	10.262
	}
	LunarLambert	0.5
	Albedo	0.1072
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5081"
}

#1_"5084 Gnedin:Gnedin:1977 FN1:1982 DB1:1988 GU" "Sol" #1=
#2_"*Гнедин:5084 Gnedin:Gnedin:1977 FN1" "Sol" #2=
#3_"1977 FN1:*Гнедин:5084 Gnedin:Gnedin" "Sol" #3=
".:Gnedin:5084 Gnedin:1977 FN1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.55
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.586724293651
		SemiMajorAxis	3.148468539496
		Eccentricity	0.102791674057
		Inclination	7.430327774187
		AscendingNode	42.030281431521
		ArgOfPericenter	116.276082397638
		MeanAnomaly	303.838949516552
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0656
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5084"
}

#1_"5092 Manara:Manara:1982 FJ:1950 TA3:1979 VY:1990 QR3" "Sol" #1=
#2_"*Манара:5092 Manara:Manara:1982 FJ" "Sol" #2=
#3_"1982 FJ:*Манара:5092 Manara:Manara" "Sol" #3=
".:Manara:5092 Manara:1982 FJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.17
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.717015331108
		SemiMajorAxis	3.19723164686
		Eccentricity	0.060449713426
		Inclination	16.099085722069
		AscendingNode	359.186305635083
		ArgOfPericenter	198.358326123525
		MeanAnomaly	250.656970758291
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1014
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5092"
}

#1_"5095 Escalante:Escalante:1983 NL:1967 GD1:1990 HA1" "Sol" #1=
#2_"*Эскаланте:5095 Escalante:Escalante:1983 NL" "Sol" #2=
#3_"1983 NL:*Эскаланте:5095 Escalante:Escalante" "Sol" #3=
".:Escalante:5095 Escalante:1983 NL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.39
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.79009959046
		SemiMajorAxis	2.430869323494
		Eccentricity	0.217128803539
		Inclination	14.60060999006
		AscendingNode	146.865858185364
		ArgOfPericenter	187.56448518179
		MeanAnomaly	83.245448953304
	}
	UniformRotation
	{
		Period	8.542
	}
	LunarLambert	0.5
	Albedo	0.1203
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5095"
}

#1_"5097 Axford:Axford:1983 TW1:1966 RG:1978 JG2:1987 SZ1" "Sol" #1=
#2_"*Асфорд:5097 Axford:Axford:1983 TW1" "Sol" #2=
#3_"1983 TW1:*Асфорд:5097 Axford:Axford" "Sol" #3=
".:Axford:5097 Axford:1983 TW1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.51
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.193378315161
		SemiMajorAxis	2.600382463136
		Eccentricity	0.226752004077
		Inclination	3.896641718758
		AscendingNode	123.956334857427
		ArgOfPericenter	182.241384990553
		MeanAnomaly	211.136933435623
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0547
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5097"
}

#1_"5102 Benfranklin:Benfranklin:1986 RD1:1930 UA1:1939 PB:1988 AJ1" "Sol" #1=
#2_"*Бенфранклин:5102 Benfranklin:Benfranklin:1986 RD1" "Sol" #2=
#3_"1986 RD1:*Бенфранклин:5102 Benfranklin:Benfranklin" "Sol" #3=
".:Benfranklin:5102 Benfranklin:1986 RD1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.685755809113
		SemiMajorAxis	2.800147873426
		Eccentricity	0.196017023876
		Inclination	8.124005412407
		AscendingNode	317.641232758884
		ArgOfPericenter	51.707950884561
		MeanAnomaly	351.562873985039
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0443
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5102"
}

#1_"5105 Westerhout:Westerhout:1986 TM1:1982 UL10:1990 SQ10" "Sol" #1=
#2_"*Вестерхут:5105 Westerhout:Westerhout:1986 TM1" "Sol" #2=
#3_"1986 TM1:*Вестерхут:5105 Westerhout:Westerhout" "Sol" #3=
".:Westerhout:5105 Westerhout:1986 TM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.79
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.182501758136
		SemiMajorAxis	2.595884029858
		Eccentricity	0.158085355814
		Inclination	11.657719772285
		AscendingNode	226.758243205411
		ArgOfPericenter	189.445494327686
		MeanAnomaly	242.419195406742
	}
	UniformRotation
	{
		Period	13.0881
	}
	LunarLambert	0.5
	Albedo	0.0874
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5105"
}

#1_"5111 Jacliff:Jacliff:1987 SE4:1962 XO:1980 TV14" "Sol" #1=
#2_"*Джеклифф:5111 Jacliff:Jacliff:1987 SE4" "Sol" #2=
#3_"1987 SE4:Jacliff:*Джеклифф:5111 Jacliff" "Sol" #3=
".:Jacliff:5111 Jacliff:1987 SE4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5111 jacliff.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.224
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.612271239797
		SemiMajorAxis	2.354225723551
		Eccentricity	0.127070054123
		Inclination	5.803405281385
		AscendingNode	247.242541748202
		ArgOfPericenter	99.830124611633
		MeanAnomaly	61.448507531086
	}
	UniformRotation
	{
		Period	2.839
	}
	LunarLambert	0.5
	Albedo	0.425
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5111"
}

#1_"5130 Ilioneus:Ilioneus:1989 SC7:1990 VE8" "Sol" #1=
#2_"*Илионеус:5130 Ilioneus:Ilioneus:1989 SC7" "Sol" #2=
#3_"1989 SC7:*Илионеус:5130 Ilioneus:Ilioneus" "Sol" #3=
".:Ilioneus:5130 Ilioneus:1989 SC7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	29.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.922440251728
		SemiMajorAxis	5.218807785641
		Eccentricity	0.010279209781
		Inclination	15.729285797459
		AscendingNode	242.513729729149
		ArgOfPericenter	114.048401620049
		MeanAnomaly	45.997985994779
	}
	UniformRotation
	{
		Period	14.768
	}
	LunarLambert	0.5
	Albedo	0.0602
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5130"
}

#1_"5133 Phillipadams:Phillipadams:1990 PA:1983 EB3" "Sol" #1=
#2_"*Филлипадамс:5133 Phillipadams:Phillipadams:1990 PA" "Sol" #2=
#3_"1990 PA:*Филлипадамс:5133 Phillipadams:Phillipadams" "Sol" #3=
".:Phillipadams:5133 Phillipadams:1990 PA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.615
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.466552981457
		SemiMajorAxis	2.712123895172
		Eccentricity	0.224669561518
		Inclination	12.01728939627
		AscendingNode	87.635798582622
		ArgOfPericenter	279.96596096581
		MeanAnomaly	161.394680022935
	}
	UniformRotation
	{
		Period	6.6645
	}
	LunarLambert	0.5
	Albedo	0.0697
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5133"
}

#1_"5140 Kida:Kida:1990 XH:1950 TP3:1953 FC1:1967 TF:1976 GH6:1978 RG" "Sol" #1=
#2_"*Кида:5140 Kida:Kida:1990 XH" "Sol" #2=
#3_"1990 XH:*Кида:5140 Kida:Kida" "Sol" #3=
".:Kida:5140 Kida:1990 XH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.670751004881
		SemiMajorAxis	3.179959465287
		Eccentricity	0.118564720565
		Inclination	11.453908884248
		AscendingNode	163.76317703112
		ArgOfPericenter	216.630656560652
		MeanAnomaly	116.529478802286
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0683
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5140"
}

#1_"5143 Heracles:Heracles:1991 VL:1962 PG" "Sol" #1=
#2_"*Геракл:5143 Heracles:Heracles:1991 VL" "Sol" #2=
#3_"1991 VL:*Геракл:5143 Heracles:Heracles" "Sol" #3=
".:Heracles:5143 Heracles:1991 VL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.483058787894
		SemiMajorAxis	1.83366164017
		Eccentricity	0.772260002922
		Inclination	9.03546855282
		AscendingNode	309.566689859418
		ArgOfPericenter	227.706283855472
		MeanAnomaly	56.823478677701
	}
	UniformRotation
	{
		Period	2.7063
	}
	LunarLambert	0.5
	Albedo	0.13
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5143"
}

#1_"2011 5143 I" "Sol/5143 Heracles" #1=
#2_"2011 5143 I" "Sol/5143 Heracles" #2=
#3_"2011 5143 I" "Sol/5143 Heracles" #3=
".:2011 5143 I" "Sol/5143 Heracles" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.6458
		SemiMajorAxis	4
	}
	LunarLambert	0.5
	Albedo	0.13
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-05143.html"
}

#1_"5144 Achates:Achates:1991 XX:1939 PC:1951 PK:1975 QA:1987 QV11:1988 SS4" "Sol" #1=
#2_"*Ахат:5144 Achates:Achates:1991 XX" "Sol" #2=
#3_"1991 XX:*Ахат:5144 Achates:Achates" "Sol" #3=
".:Achates:5144 Achates:1991 XX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	45.955
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.881799993199
		SemiMajorAxis	5.206941401986
		Eccentricity	0.271039432398
		Inclination	8.900874451113
		AscendingNode	322.829158525917
		ArgOfPericenter	331.52282502438
		MeanAnomaly	115.580327606752
	}
	UniformRotation
	{
		Period	5.958
	}
	LunarLambert	0.5
	Albedo	0.0576
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5144"
}

#1_"5145 Pholus:Pholus:1992 AD" "Sol" #1=
#2_"*Фол:5145 Pholus:Pholus:1992 AD" "Sol" #2=
#3_"1992 AD:*Фол:5145 Pholus:Pholus" "Sol" #3=
".:Pholus:5145 Pholus:1992 AD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.609 0.507 ]
	BlendTexture	true
	Radius	95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	91.724261177566
		SemiMajorAxis	20.338426329493
		Eccentricity	0.57363806153
		Inclination	24.732032681325
		AscendingNode	119.253985829735
		ArgOfPericenter	354.943442359774
		MeanAnomaly	90.969418274109
	}
	UniformRotation
	{
		Period	9.98
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5145"
}

#1_"5153 Gierasch:Gierasch:1940 GO:1957 GC:1990 VL3" "Sol" #1=
#2_"*Герасч:5153 Gierasch:Gierasch:1940 GO" "Sol" #2=
#3_"1940 GO:*Герасч:5153 Gierasch:Gierasch" "Sol" #3=
".:Gierasch:5153 Gierasch:1940 GO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.105
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.333783543444
		SemiMajorAxis	2.658108326678
		Eccentricity	0.17159827304
		Inclination	12.799658665312
		AscendingNode	90.896178769843
		ArgOfPericenter	39.713967304065
		MeanAnomaly	150.493607520786
	}
	UniformRotation
	{
		Period	9
	}
	LunarLambert	0.5
	Albedo	0.0735
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5153"
}

#1_"5176 Yoichi:Yoichi:1989 AU:1935 YH:1948 VS:1948 WS:1952 OH1:1961 TK1" "Sol" #1=
#2_"*Йоичи:5176 Yoichi:Yoichi:1989 AU" "Sol" #2=
#3_"1989 AU:*Йоичи:5176 Yoichi:Yoichi" "Sol" #3=
".:Yoichi:5176 Yoichi:1989 AU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.28
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.402372439171
		SemiMajorAxis	2.686080675709
		Eccentricity	0.310412969114
		Inclination	7.704652578724
		AscendingNode	94.150821543379
		ArgOfPericenter	268.399322068653
		MeanAnomaly	28.850550653225
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0849
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5176"
}

#1_"5185 Alerossi:Alerossi:1990 RV2:1933 SE:1955 SM:1981 RA1:1984 HG:1986 UR4:1988 FQ3" "Sol" #1=
#2_"*Алеросси:5185 Alerossi:Alerossi:1990 RV2" "Sol" #2=
#3_"1990 RV2:*Алеросси:5185 Alerossi:Alerossi" "Sol" #3=
".:Alerossi:5185 Alerossi:1990 RV2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.43
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.376834719991
		SemiMajorAxis	2.675682817643
		Eccentricity	0.084003361042
		Inclination	8.378947554248
		AscendingNode	216.438216218063
		ArgOfPericenter	216.70180764293
		MeanAnomaly	124.454554241919
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1408
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5185"
}

#1_"5192 Yabuki:Yabuki:1991 CC:1951 EX1:1963 FL:1972 WB:1979 BD:1986 HO:1989 VA2" "Sol" #1=
#2_"*Ябуки:5192 Yabuki:Yabuki:1991 CC" "Sol" #2=
#3_"1991 CC:*Ябуки:5192 Yabuki:Yabuki" "Sol" #3=
".:Yabuki:5192 Yabuki:1991 CC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.696880814169
		SemiMajorAxis	3.189720436118
		Eccentricity	0.087016317851
		Inclination	14.920986938285
		AscendingNode	91.140126532097
		ArgOfPericenter	301.851837532312
		MeanAnomaly	164.114179496928
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0966
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5192"
}

#1_"5195 Kaendler:Kaendler:3289 T-1:1978 NA2:1988 VB2" "Sol" #1=
#2_"*Кендлер:5195 Kaendler:Kaendler:1971-5195*:3289 T-1" "Sol" #2=
#3_"1971-5195*:Kaendler:*Кендлер:5195 Kaendler:3289 T-1" "Sol" #3=
".:Kaendler:5195 Kaendler:1971-5195*:3289 T-1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5195 kaendler.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.17
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.179580643344
		SemiMajorAxis	2.162259238907
		Eccentricity	0.131375591287
		Inclination	3.895944065781
		AscendingNode	210.796277999806
		ArgOfPericenter	131.140862469293
		MeanAnomaly	11.01424663385
	}
	UniformRotation
	{
		Period	5.33756
	}
	LunarLambert	0.5
	Albedo	0.283
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5195"
}

#1_"5202 1983 XX:1983 XX:1979 SF12:1990 QX" "Sol" #1=
#2_"1983 XX:5202 1983 XX" "Sol" #2=
#3_"1983 XX:5202 1983 XX" "Sol" #3=
".:1983 XX:5202 1983 XX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.095
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.717421995047
		SemiMajorAxis	2.399693497199
		Eccentricity	0.166052493085
		Inclination	12.616911968413
		AscendingNode	262.645639703872
		ArgOfPericenter	160.63504957251
		MeanAnomaly	131.591143610794
	}
	UniformRotation
	{
		Period	183
	}
	LunarLambert	0.5
	Albedo	0.0893
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5202"
}

#1_"5208 Royer:Royer:1989 CH1" "Sol" #1=
#2_"*Руайе:5208 Royer:Royer:1989 CH1" "Sol" #2=
#3_"1989 CH1:Royer:*Руайе:5208 Royer" "Sol" #3=
".:Royer:5208 Royer:1989 CH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5208 royer.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.04
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.204399547708
		SemiMajorAxis	2.604936767299
		Eccentricity	0.046200030731
		Inclination	15.90207945294
		AscendingNode	124.56654619982
		ArgOfPericenter	21.122921612452
		MeanAnomaly	252.215084060271
	}
	UniformRotation
	{
		Period	3.866
	}
	LunarLambert	0.5
	Albedo	0.27
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5208"
}

#1_"5209 1989 CW1:1989 CW1" "Sol" #1=
#2_"1989 CW1:5209 1989 CW1" "Sol" #2=
#3_"1989 CW1:5209 1989 CW1" "Sol" #3=
".:1989 CW1:5209 1989 CW1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.205
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.796159279959
		SemiMajorAxis	5.181891124287
		Eccentricity	0.05076767534
		Inclination	9.050574992471
		AscendingNode	322.730039836128
		ArgOfPericenter	106.509550301662
		MeanAnomaly	147.005884560175
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0506
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5209"
}

#1_"5222 Ioffe:Ioffe:1980 TL13:1978 LP:1989 TG1" "Sol" #1=
#2_"*Иоффе:5222 Ioffe:Ioffe:1980 TL13" "Sol" #2=
#3_"1980 TL13:*Иоффе:5222 Ioffe:Ioffe" "Sol" #3=
".:Ioffe:5222 Ioffe:1980 TL13" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"pallas.jpg"
	Radius	10.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.622180849947
		SemiMajorAxis	2.77476252927
		Eccentricity	0.14310610515
		Inclination	34.539213296856
		AscendingNode	220.672427493736
		ArgOfPericenter	330.82234671047
		MeanAnomaly	1.887308206508
	}
	UniformRotation
	{
		Period	19.4
	}
	LunarLambert	0.5
	Albedo	0.1463
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5222"
}

#1_"5225 Loral:Loral:1983 TS1:1929 VE:1972 TQ:1978 YC1:1988 RW5" "Sol" #1=
#2_"*Лорал:5225 Loral:Loral:1983 TS1" "Sol" #2=
#3_"1983 TS1:*Лорал:5225 Loral:Loral" "Sol" #3=
".:Loral:5225 Loral:1983 TS1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.407250363925
		SemiMajorAxis	3.08067239859
		Eccentricity	0.188379905725
		Inclination	2.346344208474
		AscendingNode	100.193764884835
		ArgOfPericenter	283.384261258429
		MeanAnomaly	277.034695553772
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0459
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5225"
}

#1_"5228 Maca:Maca:1986 VT:1975 VY2:1989 EE2" "Sol" #1=
#2_"*Маца:5228 Maca:Maca:1986 VT" "Sol" #2=
#3_"1986 VT:*Маца:5228 Maca:Maca" "Sol" #3=
".:Maca:5228 Maca:1986 VT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.165
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.472678376908
		SemiMajorAxis	3.105473415147
		Eccentricity	0.159466370713
		Inclination	1.260547843895
		AscendingNode	195.856481163086
		ArgOfPericenter	128.61067014
		MeanAnomaly	112.49108142867
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0413
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5228"
}

#1_"5229 1987 DE6:1987 DE6:1979 ST12:1990 QE1" "Sol" #1=
#2_"1987 DE6:5229 1987 DE6" "Sol" #2=
#3_"1987 DE6:5229 1987 DE6" "Sol" #3=
".:1987 DE6:5229 1987 DE6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.505190435001
		SemiMajorAxis	3.117760589011
		Eccentricity	0.15890433521
		Inclination	5.723832177962
		AscendingNode	312.56205319451
		ArgOfPericenter	74.496361217224
		MeanAnomaly	118.132293961606
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0503
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5229"
}

#1_"5231 Verne:Verne:1988 JV:1960 WT" "Sol" #1=
#2_"*Верн:5231 Verne:Verne:1988 JV" "Sol" #2=
#3_"1988 JV:Verne:*Верн:5231 Verne" "Sol" #3=
".:Verne:5231 Verne:1988 JV:1960 WT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5231 verne.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.622
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.2430847918
		SemiMajorAxis	2.620891277977
		Eccentricity	0.150797480522
		Inclination	14.897876865226
		AscendingNode	91.202903869739
		ArgOfPericenter	319.574110630501
		MeanAnomaly	108.543462922715
	}
	UniformRotation
	{
		Period	4.32
	}
	LunarLambert	0.5
	Albedo	0.243
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5231"
}

#1_"5236 Yoko:Yoko:1990 TG3:1931 BK:1978 GN3:1983 VQ7:1988 BA1" "Sol" #1=
#2_"*Ёко:5236 Yoko:Yoko:1990 TG3" "Sol" #2=
#3_"1990 TG3:*Ёко:5236 Yoko:Yoko" "Sol" #3=
".:Yoko:5236 Yoko:1990 TG3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.49
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.55889743818
		SemiMajorAxis	2.330978029695
		Eccentricity	0.110026167312
		Inclination	7.400548473473
		AscendingNode	206.256378428357
		ArgOfPericenter	198.084193334089
		MeanAnomaly	265.467613278505
	}
	UniformRotation
	{
		Period	2.768
	}
	LunarLambert	0.5
	Albedo	0.1383
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5236"
}

#1_"5237 Yoshikawa:Yoshikawa:1990 UF3:1931 AL:1985 FY1:1988 CV7" "Sol" #1=
#2_"*Ёсикава:5237 Yoshikawa:Yoshikawa:1990 UF3" "Sol" #2=
#3_"1990 UF3:*Ёсикава:5237 Yoshikawa:Yoshikawa" "Sol" #3=
".:Yoshikawa:5237 Yoshikawa:1990 UF3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.354420815815
		SemiMajorAxis	2.240816161492
		Eccentricity	0.095500993176
		Inclination	5.139218405664
		AscendingNode	38.186753604858
		ArgOfPericenter	145.292757411181
		MeanAnomaly	307.5622286282
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0587
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5237"
}

#1_"5249 Giza:Giza:1983 HJ:1965 AZ:1988 CF1" "Sol" #1=
#2_"*Гиза:5249 Giza:Giza:1983 HJ" "Sol" #2=
#3_"1983 HJ:*Гиза:5249 Giza:Giza" "Sol" #3=
".:Giza:5249 Giza:1983 HJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.115
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.637523351944
		SemiMajorAxis	3.167525362997
		Eccentricity	0.144902842169
		Inclination	2.167798782308
		AscendingNode	122.94746314628
		ArgOfPericenter	56.713485357624
		MeanAnomaly	238.422861774626
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0517
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5249"
}

#1_"5254 Ulysses:Ulysses (asteroid):1986 VG1:1990 FN" "Sol" #1=
#2_"*Улисс:5254 Ulysses:Ulysses (asteroid):1986 VG1" "Sol" #2=
#3_"1986 VG1:*Улисс:5254 Ulysses:Ulysses (asteroid)" "Sol" #3=
".:Ulysses (asteroid):5254 Ulysses:1986 VG1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	39.17
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.981347880923
		SemiMajorAxis	5.235984078415
		Eccentricity	0.120882228489
		Inclination	24.193895781785
		AscendingNode	76.035159156833
		ArgOfPericenter	343.48905550377
		MeanAnomaly	122.4347724458
	}
	UniformRotation
	{
		Period	28.72
	}
	LunarLambert	0.5
	Albedo	0.0869
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5254"
}

#1_"5255 Johnsophie:Johnsophie:1988 KF:1979 HF6:1991 AA2" "Sol" #1=
#2_"*Джонсофи:5255 Johnsophie:Johnsophie:1988 KF" "Sol" #2=
#3_"1988 KF:*Джонсофи:5255 Johnsophie:Johnsophie" "Sol" #3=
".:Johnsophie:5255 Johnsophie:1988 KF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.366193645405
		SemiMajorAxis	2.671344265276
		Eccentricity	0.017066073116
		Inclination	11.614541087244
		AscendingNode	99.630316740544
		ArgOfPericenter	125.491004149713
		MeanAnomaly	41.569048779647
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0723
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5255"
}

#1_"5259 Epeigeus:Epeigeus:1989 BB1" "Sol" #1=
#2_"*Эпеигеус:5259 Epeigeus:Epeigeus:1989 BB1" "Sol" #2=
#3_"1989 BB1:*Эпеигеус:5259 Epeigeus:Epeigeus" "Sol" #3=
".:Epeigeus:5259 Epeigeus:1989 BB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	21.295
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.857060735435
		SemiMajorAxis	5.199711262414
		Eccentricity	0.07275408422
		Inclination	15.921681607745
		AscendingNode	67.468893408744
		ArgOfPericenter	199.388326656576
		MeanAnomaly	287.887551521006
	}
	UniformRotation
	{
		Period	18.42
	}
	LunarLambert	0.5
	Albedo	0.0739
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5259"
}

#1_"5261 Eureka:Eureka:1990 MB" "Sol" #1=
#2_"*Эврика:5261 Eureka:Eureka:1990 MB" "Sol" #2=
#3_"1990 MB:*Эврика:5261 Eureka:Eureka" "Sol" #3=
".:Eureka:5261 Eureka:1990 MB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.595
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.880555238438
		SemiMajorAxis	1.523533220033
		Eccentricity	0.06485967901
		Inclination	20.280350684053
		AscendingNode	245.062271504151
		ArgOfPericenter	95.470351542616
		MeanAnomaly	295.624269390609
	}
	UniformRotation
	{
		Period	2.6902
	}
	LunarLambert	0.5
	Albedo	0.39
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5261"
}

#1_"2011 5261 I" "Sol/5261 Eureka" #1=
#2_"2011 5261 I" "Sol/5261 Eureka" #2=
#3_"2011 5261 I" "Sol/5261 Eureka" #3=
".:2011 5261 I" "Sol/5261 Eureka" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.23
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.7054
		SemiMajorAxis	2.1
	}
	LunarLambert	0.5
	Albedo	0.39
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-05261.html"
}

#1_"5262 Brucegoldberg:Brucegoldberg:1990 XB1:1926 BA:1941 YA:1943 GO:1964 BC:1973 YD:1976 MF: #1=
#1_1978 TJ8:1978 VK14:1980 BR3:1986 CH1" "Sol" #1=
#2_"*Брюсголдберг:5262 Brucegoldberg:Brucegoldberg:1990 XB1" "Sol" #2=
#3_"1990 XB1:*Брюсголдберг:5262 Brucegoldberg:Brucegoldberg" "Sol" #3=
".:Brucegoldberg:5262 Brucegoldberg:1990 XB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.625
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.42506477248
		SemiMajorAxis	3.087434956615
		Eccentricity	0.164862686774
		Inclination	15.974765333881
		AscendingNode	91.107276164602
		ArgOfPericenter	93.308485908053
		MeanAnomaly	96.404358179982
	}
	UniformRotation
	{
		Period	16.43
	}
	LunarLambert	0.5
	Albedo	0.0698
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5262"
}

#1_"5264 Telephus:Telephus:1991 KC:1965 AO" "Sol" #1=
#2_"*Телеф:5264 Telephus:Telephus:1991 KC" "Sol" #2=
#3_"1991 KC:*Телеф:5264 Telephus:Telephus" "Sol" #3=
".:Telephus:5264 Telephus:1991 KC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.63
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.871049207371
		SemiMajorAxis	5.20380006218
		Eccentricity	0.11180421346
		Inclination	33.577299618
		AscendingNode	121.898751726307
		ArgOfPericenter	359.424669412593
		MeanAnomaly	67.757942521272
	}
	UniformRotation
	{
		Period	9.518
	}
	LunarLambert	0.5
	Albedo	0.0522
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5264"
}

#1_"5281 Lindstrom:Lindstrom:1988 SO1:1968 YE:1990 AB1:1991 EP" "Sol" #1=
#2_"*Линдстром:5281 Lindstrom:Lindstrom:1988 SO1" "Sol" #2=
#3_"1988 SO1:*Линдстром:5281 Lindstrom:Lindstrom" "Sol" #3=
".:Lindstrom:5281 Lindstrom:1988 SO1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5281 lindstrom.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	8.492
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	5.231454302214
		SemiMajorAxis	3.013534417096
		Eccentricity	0.117055389388
		Inclination	11.090352252064
		AscendingNode	121.528843969311
		ArgOfPericenter	258.477154258272
		MeanAnomaly	20.211662205763
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.154
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5281"
}

#1_"5283 Pyrrhus:Pyrrhus:1989 BW:1978 GF2" "Sol" #1=
#2_"*Пирр:5283 Pyrrhus:Pyrrhus:1989 BW" "Sol" #2=
#3_"1989 BW:*Пирр:5283 Pyrrhus:Pyrrhus" "Sol" #3=
".:Pyrrhus:5283 Pyrrhus:1989 BW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32.29
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.855979249972
		SemiMajorAxis	5.199395079634
		Eccentricity	0.149379107151
		Inclination	17.487499468213
		AscendingNode	71.154493459411
		ArgOfPericenter	356.39245785
		MeanAnomaly	119.66236112101
	}
	UniformRotation
	{
		Period	7.323
	}
	LunarLambert	0.5
	Albedo	0.0807
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5283"
}

#1_"5299 Bittesini:Bittesini:1969 LB:1976 SP2:1984 DW1:1987 RW3" "Sol" #1=
#2_"*Боттези́ни:5299 Bittesini:Bittesini:1969 LB" "Sol" #2=
#3_"1969 LB:Bittesini:*Боттези́ни:5299 Bittesini" "Sol" #3=
".:Bittesini:5299 Bittesini:1969 LB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5299 bittesini.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	8.866
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.49459047425
		SemiMajorAxis	3.113757245285
		Eccentricity	0.062821327101
		Inclination	4.880777440033
		AscendingNode	326.037576277308
		ArgOfPericenter	76.595115712843
		MeanAnomaly	98.249643518433
	}
	UniformRotation
	{
		Period	4.67966
	}
	LunarLambert	0.5
	Albedo	0.089
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5299"
}

#1_"5304 Bazhenov:Bazhenov:1978 TA7:1976 JR2:1989 YW5" "Sol" #1=
#2_"*Баженов:5304 Bazhenov:Bazhenov:1978 TA7" "Sol" #2=
#3_"1978 TA7:*Баженов:5304 Bazhenov:Bazhenov" "Sol" #3=
".:Bazhenov:5304 Bazhenov:1978 TA7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.144488299024
		SemiMajorAxis	2.980043848405
		Eccentricity	0.070239111781
		Inclination	8.979801058715
		AscendingNode	114.573243398998
		ArgOfPericenter	321.109449057845
		MeanAnomaly	328.021856779551
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0925
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5304"
}

#1_"5316 Filatov:Filatov:1982 UB7:1982 XU3:1987 SF9:1991 LV3" "Sol" #1=
#2_"*Филатов:5316 Filatov:Filatov:1982 UB7" "Sol" #2=
#3_"1982 UB7:*Филатов:5316 Filatov:Filatov" "Sol" #3=
".:Filatov:5316 Filatov:1982 UB7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.31
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.619547322527
		SemiMajorAxis	3.160788381945
		Eccentricity	0.021609035079
		Inclination	14.737999100231
		AscendingNode	230.230819347878
		ArgOfPericenter	239.298348293072
		MeanAnomaly	205.016506932794
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0417
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5316"
}

#1_"5317 Verolacqua:Verolacqua:1983 CE:1970 EH:1983 CB1:1987 BF3" "Sol" #1=
#2_"*Веролаккуа:5317 Verolacqua:Verolacqua:1983 CE" "Sol" #2=
#3_"1983 CE:Verolacqua:*Веролаккуа:5317 Verolacqua" "Sol" #3=
".:Verolacqua:5317 Verolacqua:1983 CE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5317 verolacqua.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.761
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.308012308919
		SemiMajorAxis	2.647560067803
		Eccentricity	0.108794166263
		Inclination	13.978631413858
		AscendingNode	122.024249188686
		ArgOfPericenter	61.870262943315
		MeanAnomaly	288.728388242282
	}
	UniformRotation
	{
		Period	3.022
	}
	LunarLambert	0.5
	Albedo	0.309
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5317"
}

#New3
#1_"5325 Silver:Silver:1988 JQ:1981 OJ" "Sol" #1=
#2_"*Силвер:5325 Silver:Silver:1988 JQ" "Sol" #2=
#3_"1988 JQ:*Силвер:5325 Silver:Silver" "Sol" #3=
".:Silver:5325 Silver:1988 JQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5325 silver.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.687
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.633203016548
		SemiMajorAxis	2.363311541444
		Eccentricity	0.218793739986
		Inclination	23.489737037704
		AscendingNode	134.900311809429
		ArgOfPericenter	120.456061763525
		MeanAnomaly	16.470638581906
	}
	UniformRotation
	{
		Period	4.02361
	}
	LunarLambert	0.5
	Albedo	0.192
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5325"
}

#1_"5330 Senrikyu:Senrikyu:1990 BQ1:1951 RD2" "Sol" #1=
#2_"*Сенрикю:5330 Senrikyu:Senrikyu:1990 BQ1" "Sol" #2=
#3_"1990 BQ1:*Сенрикю:5330 Senrikyu:Senrikyu" "Sol" #3=
".:Senrikyu:5330 Senrikyu:1990 BQ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.145
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.595269684188
		SemiMajorAxis	2.763981941205
		Eccentricity	0.157388466067
		Inclination	33.737435849407
		AscendingNode	307.700094184872
		ArgOfPericenter	21.106424334662
		MeanAnomaly	306.781088171375
	}
	UniformRotation
	{
		Period	14.44
	}
	LunarLambert	0.5
	Albedo	0.2227
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5330"
}

#1_"5332 Davidaguilar:Davidaguilar:1990 DA" "Sol" #1=
#2_"*Дэвидагилар:5332 Davidaguilar:Davidaguilar:1990 DA" "Sol" #2=
#3_"1990 DA:*Дэвидагилар:5332 Davidaguilar:Davidaguilar" "Sol" #3=
".:Davidaguilar:5332 Davidaguilar:1990 DA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5332 davidaguilar.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.182248393137
		SemiMajorAxis	2.163468530519
		Eccentricity	0.456606737878
		Inclination	25.474910705031
		AscendingNode	142.92936964415
		ArgOfPericenter	305.827686589454
		MeanAnomaly	304.869856408772
	}
	UniformRotation
	{
		Period	5.803
	}
	LunarLambert	0.5
	Albedo	0.18
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5332"
}

#1_"5335 Damocles:Damocles:1991 DA" "Sol" #1=
#2_"*Дамокл:5335 Damocles:Damocles:1991 DA" "Sol" #2=
#3_"1991 DA:*Дамокл:5335 Damocles:Damocles" "Sol" #3=
".:Damocles:5335 Damocles:1991 DA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	40.696883771161
		SemiMajorAxis	11.83137725228553
		Eccentricity	0.8670535497386891
		Inclination	62.08449441605067
		AscendingNode	314.2145718723246
		ArgOfPericenter	191.187741310303
		MeanAnomaly	212.4088217447935
	}
	UniformRotation
	{
		Period	10.2
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5335"
}

#1_"5337 Aoki:Aoki:1991 LD:1972 AL:1978 CN:1978 ED4:1980 OL:1981 UP13:1982 YX2:1985 JZ1:1987 SR25: #1=
#1_1990 FP3" "Sol" #1=
#2_"*Аоки:5337 Aoki:Aoki:1991 LD" "Sol" #2=
#3_"1991 LD:*Аоки:5337 Aoki:Aoki" "Sol" #3=
".:Aoki:5337 Aoki:1991 LD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.26
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.732930285201
		SemiMajorAxis	3.20316250563
		Eccentricity	0.092503779249
		Inclination	6.430827135885
		AscendingNode	237.81254857671
		ArgOfPericenter	3.990533051388
		MeanAnomaly	39.955921906502
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.042
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5337"
}

#1_"5358 1992 QH:1992 QH:1951 EQ:1951 GN1:1968 QD1:1970 DB:1975 EP2:1980 FZ5:1980 GL1:1985 FZ: #1=
#1_1987 QA3" "Sol" #1=
#2_"1992 QH:5358 1992 QH" "Sol" #2=
#3_"1992 QH:5358 1992 QH" "Sol" #3=
".:1992 QH:5358 1992 QH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.823649532044
		SemiMajorAxis	2.854817580485
		Eccentricity	0.191403228754
		Inclination	11.088415333555
		AscendingNode	335.552116677398
		ArgOfPericenter	84.589586347544
		MeanAnomaly	162.364504966219
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.2141
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5358"
}

#1_"5361 Goncharov:Goncharov:1976 YC2:1975 WC2:1978 EU5:1981 UK23:1982 YD5:1987 XE:1991 RE30" "Sol" #1=
#2_"*Гончаров:5361 Goncharov:Goncharov:1976 YC2" "Sol" #2=
#3_"1976 YC2:*Гончаров:5361 Goncharov:Goncharov" "Sol" #3=
".:Goncharov:5361 Goncharov:1976 YC2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.7295
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.533692121726
		SemiMajorAxis	3.128512252844
		Eccentricity	0.089609282651
		Inclination	7.233438883182
		AscendingNode	82.411058094796
		ArgOfPericenter	130.097528489878
		MeanAnomaly	185.284673007498
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.081
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5361"
}

#1_"5370 Taranis:Taranis:1986 RA" "Sol" #1=
#2_"*Таранис:5370 Taranis:Taranis:1986 RA" "Sol" #2=
#3_"1986 RA:*Таранис:5370 Taranis:Taranis" "Sol" #3=
".:Taranis:5370 Taranis:1986 RA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.08132784429
		SemiMajorAxis	3.33165592148
		Eccentricity	0.634497748818
		Inclination	19.10276872131
		AscendingNode	177.835516805976
		ArgOfPericenter	161.171673320626
		MeanAnomaly	225.659317566023
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.11
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5370"
}

#1_"5374 Hokutosei:Hokutosei:1989 AM1:1980 PF4:1981 UY12" "Sol" #1=
#2_"*Хокутосей:5374 Hokutosei:Hokutosei:1989 AM1" "Sol" #2=
#3_"1989 AM1:*Хокутосей:5374 Hokutosei:Hokutosei" "Sol" #3=
".:Hokutosei:5374 Hokutosei:1989 AM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.53
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.657176344585
		SemiMajorAxis	3.174882640957
		Eccentricity	0.096914856172
		Inclination	12.283235200801
		AscendingNode	300.024392257575
		ArgOfPericenter	250.861014750593
		MeanAnomaly	136.394838963799
	}
	UniformRotation
	{
		Period	6.7592
	}
	LunarLambert	0.5
	Albedo	0.0606
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5374"
}

#1_"5381 Sekhmet:Sekhmet:1991 JY" "Sol" #1=
#2_"*Сехмет:5381 Sekhmet:Sekhmet:1991 JY" "Sol" #2=
#3_"1991 JY:*Сехмет:5381 Sekhmet:Sekhmet" "Sol" #3=
".:Sekhmet:5381 Sekhmet:1991 JY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.922272417499
		SemiMajorAxis	0.947474096479
		Eccentricity	0.296223157422
		Inclination	48.96785865415
		AscendingNode	58.547832085458
		ArgOfPericenter	37.440470311418
		MeanAnomaly	311.684390466881
	}
	UniformRotation
	{
		Period	2.7
	}
	LunarLambert	0.5
	Albedo	0.44
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5381"
}

#1_"2003 5381 I" "Sol/5381 Sekhmet" #1=
#2_"2003 5381 I" "Sol/5381 Sekhmet" #2=
#3_"2003 5381 I" "Sol/5381 Sekhmet" #3=
".:2003 5381 I" "Sol/5381 Sekhmet" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.5208
		SemiMajorAxis	1.54
	}
	UniformRotation
	{
		Period	10
	}
	LunarLambert	0.5
	Albedo	0.44
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-05381.html"
}

#1_"5384 Changjiangcun:Changjiangcun:1957 VA:1991 GT1" "Sol" #1=
#2_"*ЧанЦзянЦунь:5384 Changjiangcun:Changjiangcun:1957 VA" "Sol" #2=
#3_"1957 VA:*ЧанЦзянЦунь:5384 Changjiangcun:Changjiangcun" "Sol" #3=
".:Changjiangcun:5384 Changjiangcun:1957 VA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.305
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.693076920512
		SemiMajorAxis	1.935650914998
		Eccentricity	0.103751965192
		Inclination	27.088501502037
		AscendingNode	48.869633774901
		ArgOfPericenter	89.054993446561
		MeanAnomaly	350.980402198724
	}
	UniformRotation
	{
		Period	12.5109
	}
	LunarLambert	0.5
	Albedo	0.072
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5384"
}

#1_"5399 Awa:Awa:1989 BT:1978 TP5:1987 SG18" "Sol" #1=
#2_"*Ава:5399 Awa:Awa:1989 BT" "Sol" #2=
#3_"1989 BT:*Ава:5399 Awa:Awa" "Sol" #3=
".:Awa:5399 Awa:1989 BT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.09
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.702565718033
		SemiMajorAxis	2.80684080035
		Eccentricity	0.185151003126
		Inclination	3.735519845468
		AscendingNode	270.920361552167
		ArgOfPericenter	176.496731990421
		MeanAnomaly	212.925407808293
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0754
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5399"
}

#1_"5416 Estremadoyro:Estremadoyro:1978 VE5:1970 AG:1987 SJ27" "Sol" #1=
#2_"*Эстремадойро:5416 Estremadoyro:Estremadoyro:1978 VE5" "Sol" #2=
#3_"1978 VE5:*Эстремадойро:5416 Estremadoyro:Estremadoyro" "Sol" #3=
".:Estremadoyro:5416 Estremadoyro:1978 VE5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.14
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.63871734452
		SemiMajorAxis	2.781376655157
		Eccentricity	0.237111765333
		Inclination	8.393518497371
		AscendingNode	66.729956615925
		ArgOfPericenter	285.55368049502
		MeanAnomaly	325.737730692366
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0697
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5416"
}

#1_"5420 Jancis:Jancis:1982 JR1:1983 VG1" "Sol" #1=
#2_"*Джансис:5420 Jancis:Jancis:1982 JR1" "Sol" #2=
#3_"1982 JR1:*Джансис:5420 Jancis:Jancis" "Sol" #3=
".:Jancis:5420 Jancis:1982 JR1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.175
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.385179076105
		SemiMajorAxis	2.679082498527
		Eccentricity	0.23539703854
		Inclination	8.680807816656
		AscendingNode	85.457657109375
		ArgOfPericenter	258.129658771484
		MeanAnomaly	67.349428071433
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0731
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5420"
}

#1_"5435 Kameoka:Kameoka:1990 BS1:1951 CS1:1972 YG:1983 XX1:1991 LF" "Sol" #1=
#2_"*Камеока:5435 Kameoka:Kameoka:1990 BS1" "Sol" #2=
#3_"1990 BS1:*Камеока:5435 Kameoka:Kameoka" "Sol" #3=
".:Kameoka:5435 Kameoka:1990 BS1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.608607913115
		SemiMajorAxis	3.156685040009
		Eccentricity	0.127671897209
		Inclination	18.139954256997
		AscendingNode	109.175049439132
		ArgOfPericenter	358.949956317747
		MeanAnomaly	184.691177644039
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0737
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5435"
}

#1_"5439 Couturier:Couturier:1990 RW:1982 PW:1982 QJ" "Sol" #1=
#2_"*Кутюрье:5439 Couturier:Couturier:1990 RW" "Sol" #2=
#3_"1990 RW:*Кутюрье:5439 Couturier:Couturier" "Sol" #3=
".:Couturier:5439 Couturier:1990 RW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.055
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.849877243012
		SemiMajorAxis	3.949751524006
		Eccentricity	0.157635459161
		Inclination	1.233227977351
		AscendingNode	351.585164455083
		ArgOfPericenter	330.45247799331
		MeanAnomaly	44.024454309777
	}
	UniformRotation
	{
		Period	50
	}
	LunarLambert	0.5
	Albedo	0.0358
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5439"
}

#1_"5443 Encrenaz:Encrenaz:1991 NX1:1980 RZ5:1986 AJ2:1990 DL6:1990 DQ5" "Sol" #1=
#2_"*Энкреназ:5443 Encrenaz:Encrenaz:1991 NX1" "Sol" #2=
#3_"1991 NX1:*Энкреназ:5443 Encrenaz:Encrenaz" "Sol" #3=
".:Encrenaz:5443 Encrenaz:1991 NX1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.18
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.887221306461
		SemiMajorAxis	2.472221483778
		Eccentricity	0.108086190114
		Inclination	10.734122739
		AscendingNode	320.326948134938
		ArgOfPericenter	232.491502698893
		MeanAnomaly	93.170699132644
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0801
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5443"
}

#1_"5458 Aizman:Aizman:1980 TB12:1972 HM1:1980 VM:1989 GY2" "Sol" #1=
#2_"*Айзман:5458 Aizman:Aizman:1980 TB12" "Sol" #2=
#3_"1980 TB12:*Айзман:5458 Aizman:Aizman" "Sol" #3=
".:Aizman:5458 Aizman:1980 TB12" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.245
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.644064043798
		SemiMajorAxis	3.169974878734
		Eccentricity	0.026026539393
		Inclination	9.176255515849
		AscendingNode	222.398372699662
		ArgOfPericenter	120.846766301185
		MeanAnomaly	63.325628496345
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0526
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5458"
}

#1_"5461 Autumn:Autumn:1983 HB1:1934 PK:1989 GS6" "Sol" #1=
#2_"*Аутумн:5461 Autumn:Autumn:1983 HB1" "Sol" #2=
#3_"1983 HB1:*Аутумн:5461 Autumn:Autumn" "Sol" #3=
".:Autumn:5461 Autumn:1983 HB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.592338200172
		SemiMajorAxis	3.150577378028
		Eccentricity	0.146199699181
		Inclination	12.88892552819
		AscendingNode	112.13159164549
		ArgOfPericenter	191.183511450893
		MeanAnomaly	147.97301976707
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0986
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5461"
}

#1_"5468 Hamatonbetsu:Hamatonbetsu:1988 BK:1962 XH:1969 FL:1985 QQ6" "Sol" #1=
#2_"*Хаматомбецу:5468 Hamatonbetsu:Hamatonbetsu:1988 BK" "Sol" #2=
#3_"1988 BK:*Хаматомбецу:5468 Hamatonbetsu:Hamatonbetsu" "Sol" #3=
".:Hamatonbetsu:5468 Hamatonbetsu:1988 BK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.105
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.875355931738
		SemiMajorAxis	2.875182502434
		Eccentricity	0.223223266071
		Inclination	11.961601744308
		AscendingNode	135.074790751212
		ArgOfPericenter	69.531871444534
		MeanAnomaly	119.714284394644
	}
	UniformRotation
	{
		Period	42.02
	}
	LunarLambert	0.5
	Albedo	0.0748
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5468"
}

#1_"5469 1988 BK4:1988 BK4:1977 DK" "Sol" #1=
#2_"1988 BK4:5469 1988 BK4" "Sol" #2=
#3_"1988 BK4:5469 1988 BK4" "Sol" #3=
".:1988 BK4:5469 1988 BK4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.514409335924
		SemiMajorAxis	3.12124025187
		Eccentricity	0.145173407649
		Inclination	19.204762377785
		AscendingNode	143.81988040603
		ArgOfPericenter	291.716098115869
		MeanAnomaly	357.887166990548
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0268
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5469"
}

#1_"5484 Inoda:Inoda:1990 VH1:1968 YD:1979 VP2:1981 JU" "Sol" #1=
#2_"*Инода:5484 Inoda:Inoda:1990 VH1" "Sol" #2=
#3_"1990 VH1:*Инода:5484 Inoda:Inoda" "Sol" #3=
".:Inoda:5484 Inoda:1990 VH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.16
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.745083430848
		SemiMajorAxis	2.411582904697
		Eccentricity	0.146252344255
		Inclination	12.587537567199
		AscendingNode	48.419407073808
		ArgOfPericenter	110.133527929699
		MeanAnomaly	46.180037619586
	}
	UniformRotation
	{
		Period	14.1479
	}
	LunarLambert	0.5
	Albedo	0.1062
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5484"
}

#1_"5488 Kiyosato:Kiyosato:1991 VK5:1951 ED1:1977 AB3:1978 GC3" "Sol" #1=
#2_"*Киёсато:5488 Kiyosato:Kiyosato:1991 VK5" "Sol" #2=
#3_"1991 VK5:Kiyosato:*Киёсато:5488 Kiyosato" "Sol" #3=
".:Kiyosato:5488 Kiyosato:1991 VK5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5488 kiyosato.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.290537503122
		SemiMajorAxis	3.036181502351
		Eccentricity	0.072860927173
		Inclination	11.280274128224
		AscendingNode	96.624481053663
		ArgOfPericenter	223.561458620274
		MeanAnomaly	356.991691222249
	}
	UniformRotation
	{
		Period	8.7872
	}
	LunarLambert	0.5
	Albedo	0.151
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5488"
}

#1_"5489 Oberkochen:Oberkochen:1993 BF2:1951 EW2:1952 KC1:1952 MF:1959 CD:1966 VO:1980 BS3: #1=
#1_1985 DN1:1986 LH1" "Sol" #1=
#2_"*Оберкохен:5489 Oberkochen:Oberkochen:1993 BF2" "Sol" #2=
#3_"1993 BF2:*Оберкохен:5489 Oberkochen:Oberkochen" "Sol" #3=
".:Oberkochen:5489 Oberkochen:1993 BF2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5489 oberkochen.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.552
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.261244519825
		SemiMajorAxis	2.628363952527
		Eccentricity	0.181966299229
		Inclination	13.99860633648
		AscendingNode	102.195093490212
		ArgOfPericenter	265.703907108215
		MeanAnomaly	143.035903378578
	}
	UniformRotation
	{
		Period	5.625
	}
	LunarLambert	0.5
	Albedo	0.258
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5489"
}

#1_"5494 Johanmohr:Johanmohr:1933 UM1:1971 QD:1986 TV10:1990 HK2" "Sol" #1=
#2_"*Йоханмор:5494 Johanmohr:Johanmohr:1933 UM1" "Sol" #2=
#3_"1933 UM1:Johanmohr:*Йоханмор:5494 Johanmohr" "Sol" #3=
".:Johanmohr:5494 Johanmohr:1933 UM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5494 johanmohr.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.810080827653
		SemiMajorAxis	2.849461420336
		Eccentricity	0.078970280045
		Inclination	1.144264663089
		AscendingNode	322.98640632001
		ArgOfPericenter	59.281458936642
		MeanAnomaly	112.427965511328
	}
	UniformRotation
	{
		Period	5.7272
	}
	LunarLambert	0.5
	Albedo	0.245
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5494"
}

#1_"5495 Rumyantsev:Rumyantsev:1972 RY3:1976 GP2" "Sol" #1=
#2_"*Румянцев:5495 Rumyantsev:Rumyantsev:1972 RY3" "Sol" #2=
#3_"1972 RY3:*Румянцев:5495 Rumyantsev:Rumyantsev" "Sol" #3=
".:Rumyantsev:5495 Rumyantsev:1972 RY3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.88
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.310226292159
		SemiMajorAxis	3.414741408761
		Eccentricity	0.045838548804
		Inclination	9.225574652461
		AscendingNode	32.992446145038
		ArgOfPericenter	278.232774406611
		MeanAnomaly	294.205271096651
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0833
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5495"
}

#1_"5521 Morpurgo:Morpurgo:1991 PM1:1958 TV:1974 OC:1979 YE6:1991 TA" "Sol" #1=
#2_"*Морпурго:5521 Morpurgo:Morpurgo:1991 PM1" "Sol" #2=
#3_"1991 PM1:*Морпурго:5521 Morpurgo:Morpurgo" "Sol" #3=
".:Morpurgo:5521 Morpurgo:1991 PM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.131473483142
		SemiMajorAxis	2.574726946611
		Eccentricity	0.194523379199
		Inclination	11.16227001331
		AscendingNode	90.850636053427
		ArgOfPericenter	266.698112617413
		MeanAnomaly	214.688594489544
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.2393
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5521"
}

#1_"5528 1992 AJ:1992 AJ:1957 BC:1977 QB4:1983 OE:1990 SC18" "Sol" #1=
#2_"1992 AJ:5528 1992 AJ" "Sol" #2=
#3_"1992 AJ:5528 1992 AJ" "Sol" #3=
".:1992 AJ:5528 1992 AJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	11.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.851704884614
		SemiMajorAxis	3.247253115597
		Eccentricity	0.043198243107
		Inclination	16.400630818006
		AscendingNode	140.568436312982
		ArgOfPericenter	336.326077230883
		MeanAnomaly	334.845263758781
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1348
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5528"
}

#1_"5535 Annefrank:Annefrank:1942 EM:1978 EK6:1986 TV14:1991 BO2" "Sol" #1=
#2_"*Аннафранк:5535 Annefrank:Annefrank:1942 EM" "Sol" #2=
#3_"1942 EM:*Аннафранк:5535 Annefrank:Annefrank" "Sol" #3=
".:Annefrank:5535 Annefrank:1942 EM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5535 annefrank.cmod"
	Texture	"asteroid.dds"
	Radius	3.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2452580.5  # 2002 Nov 02
		Period	3.29181007635077
		SemiMajorAxis	2.212845258664521
		Eccentricity	0.06321374038565786
		Inclination	4.246900558835089
		AscendingNode	120.704947556716
		ArgOfPericenter	8.711682814224293
		MeanAnomaly	200.3910238849259
	}
	UniformRotation
	{
		Period	15.12
	}
	LunarLambert	0.5
	Albedo	0.311
	InfoURL	"https://en.wikipedia.org/wiki/5535_Annefrank"
}

#1_"5567 Durisen:Durisen:1953 FK1:1958 FH:1968 DV" "Sol" #1=
#2_"*Дурисен:5567 Durisen:Durisen:1953 FK1" "Sol" #2=
#3_"1953 FK1:*Дурисен:5567 Durisen:Durisen" "Sol" #3=
".:Durisen:5567 Durisen:1953 FK1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.82
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.041169889026
		SemiMajorAxis	2.940009638414
		Eccentricity	0.22017464837
		Inclination	16.165105224276
		AscendingNode	9.064314791504
		ArgOfPericenter	308.452262046569
		MeanAnomaly	331.107986326602
	}
	UniformRotation
	{
		Period	7.001
	}
	LunarLambert	0.5
	Albedo	0.0845
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5567"
}

#1_"5572 Bliskunov:Bliskunov:1978 SS2:1982 HA1:1988 KH" "Sol" #1=
#2_"*Блискунов:5572 Bliskunov:Bliskunov:1978 SS2" "Sol" #2=
#3_"1978 SS2:*Блискунов:5572 Bliskunov:Bliskunov" "Sol" #3=
".:Bliskunov:5572 Bliskunov:1978 SS2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.541451872381
		SemiMajorAxis	3.1314362566
		Eccentricity	0.156380582972
		Inclination	8.929589984542
		AscendingNode	197.728143671999
		ArgOfPericenter	74.877410558359
		MeanAnomaly	266.566571760339
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0686
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5572"
}

#1_"5576 Albanese:Albanese:1986 UM1:1954 UC2:1970 EN:1977 TM8:1982 VT11:1987 YT5" "Sol" #1=
#2_"*Албанесе:5576 Albanese:Albanese:1986 UM1" "Sol" #2=
#3_"1986 UM1:*Албанесе:5576 Albanese:Albanese" "Sol" #3=
".:Albanese:5576 Albanese:1986 UM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.245
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.581337536346
		SemiMajorAxis	2.758392470229
		Eccentricity	0.071583853238
		Inclination	5.613337322488
		AscendingNode	30.895800906476
		ArgOfPericenter	70.845719570102
		MeanAnomaly	327.272855972125
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0681
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5576"
}

#1_"5587 1990 SB:1990 SB:1990 UV12" "Sol" #1=
#2_"1990 SB:5587 1990 SB" "Sol" #2=
#3_"1990 SB:5587 1990 SB" "Sol" #3=
".:1990 SB:5587 1990 SB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5587 1990 SB.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.71275426459
		SemiMajorAxis	2.397684314879
		Eccentricity	0.54494325326
		Inclination	18.076820669692
		AscendingNode	190.080107126135
		ArgOfPericenter	86.644822884109
		MeanAnomaly	228.277436031014
	}
	UniformRotation
	{
		Period	5.0522
	}
	LunarLambert	0.5
	Albedo	0.32
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5587"
}

#1_"5592 Oshima:Oshima:1990 VB4:1955 RA" "Sol" #1=
#2_"*Осима:5592 Oshima:Oshima:1990 VB4" "Sol" #2=
#3_"1990 VB4:*Осима:5592 Oshima:Oshima" "Sol" #3=
".:Oshima:5592 Oshima:1990 VB4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.715
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.661132965485
		SemiMajorAxis	3.176362807318
		Eccentricity	0.064483754329
		Inclination	8.484114708474
		AscendingNode	231.74574102126
		ArgOfPericenter	98.78719661181
		MeanAnomaly	177.959656339192
	}
	UniformRotation
	{
		Period	12.54
	}
	LunarLambert	0.5
	Albedo	0.0686
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5592"
}

#1_"5596 Morbidelli:Morbidelli:1991 PQ10:1938 AB:1981 NF:1982 YP4:1985 UO1:1988 VV7" "Sol" #1=
#2_"*Морбиделли:5596 Morbidelli:Morbidelli:1991 PQ10" "Sol" #2=
#3_"1991 PQ10:Morbidelli:*Морбиделли:5596 Morbidelli" "Sol" #3=
".:Morbidelli:5596 Morbidelli:1991 PQ10" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5596 morbidelli.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.844
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.208018043968
		SemiMajorAxis	2.175132579637
		Eccentricity	0.083787813149
		Inclination	4.234459360357
		AscendingNode	261.771160459687
		ArgOfPericenter	220.24951123311
		MeanAnomaly	207.91749396484
	}
	UniformRotation
	{
		Period	5.4
	}
	LunarLambert	0.5
	Albedo	0.181
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5596"
}

#1_"5603 Rausudake:Rausudake:1992 CE:1973 US1:1977 EW1:1979 OO15:1981 WF3:1987 QF11" "Sol" #1=
#2_"*Раусудаке:5603 Rausudake:Rausudake:1992 CE" "Sol" #2=
#3_"1992 CE:*Раусудаке:5603 Rausudake:Rausudake" "Sol" #3=
".:Rausudake:5603 Rausudake:1992 CE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	21.17
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.958301040586
		SemiMajorAxis	3.9860380555
		Eccentricity	0.061036722695
		Inclination	4.322299031277
		AscendingNode	196.574908876985
		ArgOfPericenter	17.111188455945
		MeanAnomaly	265.408552380334
	}
	UniformRotation
	{
		Period	6.79
	}
	LunarLambert	0.5
	Albedo	0.0622
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5603"
}

#1_"5604 1992 FE:1992 FE" "Sol" #1=
#2_"1992 FE:5604 1992 FE" "Sol" #2=
#3_"1992 FE:5604 1992 FE" "Sol" #3=
".:1992 FE:5604 1992 FE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.275
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.892463072054
		SemiMajorAxis	0.926946570298
		Eccentricity	0.405207475408
		Inclination	4.794009546453
		AscendingNode	311.92577683976
		ArgOfPericenter	82.48351355053
		MeanAnomaly	264.976641751069
	}
	UniformRotation
	{
		Period	5.3375
	}
	LunarLambert	0.5
	Albedo	0.48
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5604"
}

#1_"5616 Vogtland:Vogtland:1987 ST10:1977 LC:1979 YF3:1993 AO" "Sol" #1=
#2_"*Вогтланд:5616 Vogtland:Vogtland:1987 ST10" "Sol" #2=
#3_"1987 ST10:*Вогтланд:5616 Vogtland:Vogtland" "Sol" #3=
".:Vogtland:5616 Vogtland:1987 ST10" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.215
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.267086343427
		SemiMajorAxis	2.630765587754
		Eccentricity	0.197228990115
		Inclination	3.212815053868
		AscendingNode	83.666938305952
		ArgOfPericenter	28.534986365067
		MeanAnomaly	49.50132993118
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0261
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5616"
}

#1_"5625 Jamesferguson:Jamesferguson:1991 AO2:1955 XS:1971 KD:1972 TM:1985 QC2" "Sol" #1=
#2_"*Джеймсфергюсон:5625 Jamesferguson:Jamesferguson:1991 AO2" "Sol" #2=
#3_"1991 AO2:*Джеймсфергюсон:5625 Jamesferguson:Jamesferguson" "Sol" #3=
".:Jamesferguson:5625 Jamesferguson:1991 AO2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5625 jamesferguson.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	7.395
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.369964958782
		SemiMajorAxis	2.672882298542
		Eccentricity	0.195275968845
		Inclination	11.974194249885
		AscendingNode	175.020441518045
		ArgOfPericenter	217.032979013073
		MeanAnomaly	249.997571794729
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.061
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5625"
}

#1_"5641 McCleese:McCleese:1990 DJ:1973 GA" "Sol" #1=
#2_"*МакКлисе:5641 McCleese:McCleese:1990 DJ" "Sol" #2=
#3_"1990 DJ:*МакКлисе:5641 McCleese:McCleese" "Sol" #3=
".:McCleese:5641 McCleese:1990 DJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.84
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.454251062936
		SemiMajorAxis	1.81945166887
		Eccentricity	0.126259342106
		Inclination	22.203394021069
		AscendingNode	151.32346029515
		ArgOfPericenter	57.003570464115
		MeanAnomaly	343.456155469439
	}
	UniformRotation
	{
		Period	418
	}
	LunarLambert	0.5
	Albedo	0.4552
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5641"
}

#1_"5646 1990 TR:1990 TR" "Sol" #1=
#2_"1990 TR:5646 1990 TR" "Sol" #2=
#3_"1990 TR:5646 1990 TR" "Sol" #3=
".:1990 TR:5646 1990 TR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.135373645349
		SemiMajorAxis	2.142170663728
		Eccentricity	0.437113124349
		Inclination	7.914586421383
		AscendingNode	14.140159275481
		ArgOfPericenter	335.666773119896
		MeanAnomaly	264.344000870583
	}
	UniformRotation
	{
		Period	3.1999
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5646"
}

#1_"2012 5646 I" "Sol/5646 1990 TR" #1=
#2_"2012 5646 I" "Sol/5646 1990 TR" #2=
#3_"2012 5646 I" "Sol/5646 1990 TR" #3=
".:2012 5646 I" "Sol/5646 1990 TR" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid.dds"
	Radius	0.24
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.8113
		SemiMajorAxis	5.1
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-05646.html"
}

#1_"5647 1990 TZ:1990 TZ" "Sol" #1=
#2_"1990 TZ:5647 1990 TZ" "Sol" #2=
#3_"1990 TZ:5647 1990 TZ" "Sol" #3=
".:1990 TZ:5647 1990 TZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5647 1990 TZ.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.305
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.775621168814
		SemiMajorAxis	2.424674658284
		Eccentricity	0.268348480275
		Inclination	21.934247611501
		AscendingNode	240.222740390026
		ArgOfPericenter	227.636195915441
		MeanAnomaly	83.024265108905
	}
	UniformRotation
	{
		Period	6.144
	}
	LunarLambert	0.5
	Albedo	0.297
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5647"
}

#1_"5651 Traversa:Traversa:1991 CA2:1977 QL:1980 DY2:1989 WJ7" "Sol" #1=
#2_"*Траверса:5651 Traversa:Traversa:1991 CA2" "Sol" #2=
#3_"1991 CA2:*Траверса:5651 Traversa:Traversa" "Sol" #3=
".:Traversa:5651 Traversa:1991 CA2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.564152841391
		SemiMajorAxis	3.139982535557
		Eccentricity	0.157440404327
		Inclination	14.648191600832
		AscendingNode	139.114489504765
		ArgOfPericenter	229.704457099495
		MeanAnomaly	212.467682094955
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0511
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5651"
}

#1_"5654 Terni:Terni:1993 KG:1951 CU1:1954 US1:1956 GM:1970 FF:1979 EC:1991 VJ16" "Sol" #1=
#2_"*Терни:5654 Terni:Terni:1993 KG" "Sol" #2=
#3_"1993 KG:*Терни:5654 Terni:Terni" "Sol" #3=
".:Terni:5654 Terni:1993 KG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.66
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.625275638744
		SemiMajorAxis	2.776000955644
		Eccentricity	0.200707264245
		Inclination	8.818800105121
		AscendingNode	13.416661901105
		ArgOfPericenter	131.240071149646
		MeanAnomaly	270.544158145808
	}
	UniformRotation
	{
		Period	9.255
	}
	LunarLambert	0.5
	Albedo	0.0684
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5654"
}

#1_"5661 Hildebrand:Hildebrand:1977 PO1:1986 XN3:1990 EW" "Sol" #1=
#2_"*Хильдебранд:5661 Hildebrand:Hildebrand:1977 PO1" "Sol" #2=
#3_"1977 PO1:*Хильдебранд:5661 Hildebrand:Hildebrand" "Sol" #3=
".:Hildebrand:5661 Hildebrand:1977 PO1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	17.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.888118321802
		SemiMajorAxis	3.962568742578
		Eccentricity	0.233598902068
		Inclination	13.312000226998
		AscendingNode	317.122083891664
		ArgOfPericenter	1.723334319705
		MeanAnomaly	280.864505821168
	}
	UniformRotation
	{
		Period	13.61
	}
	LunarLambert	0.5
	Albedo	0.1364
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5661"
}

#1_"5678 DuBridge:DuBridge:1989 TS:1971 VJ" "Sol" #1=
#2_"*ДюБридже:5678 DuBridge:DuBridge:1989 TS" "Sol" #2=
#3_"1989 TS:*ДюБридже:5678 DuBridge:DuBridge" "Sol" #3=
".:DuBridge:5678 DuBridge:1989 TS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.508101581942
		SemiMajorAxis	2.728917004421
		Eccentricity	0.274360431647
		Inclination	34.099680219222
		AscendingNode	48.038609013518
		ArgOfPericenter	297.455502136644
		MeanAnomaly	232.416188952412
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.013
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5678"
}

#1_"5685 Sanenobufukui:Sanenobufukui:1990 XA:1935 CA:1938 YM:1952 UB1:1977 BM" "Sol" #1=
#2_"*Саненобуфукуй:5685 Sanenobufukui:Sanenobufukui:1990 XA" "Sol" #2=
#3_"1990 XA:Sanenobufukui:*Саненобуфукуй:5685 Sanenobufukui" "Sol" #3=
".:Sanenobufukui:5685 Sanenobufukui:1990 XA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5685 sanenobufukui.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.496
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.686390451625
		SemiMajorAxis	2.800400703896
		Eccentricity	0.092084382305
		Inclination	7.709864824899
		AscendingNode	277.01312309733
		ArgOfPericenter	266.717380264956
		MeanAnomaly	127.257191654609
	}
	UniformRotation
	{
		Period	3.388
	}
	LunarLambert	0.5
	Albedo	0.24
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5685"
}

#1_"5697 Arrhenius:Arrhenius:6766 P-L:4243 T-3" "Sol" #1=
#2_"*Аррениус:5697 Arrhenius:Arrhenius:1977-5697*:6766 P-L" "Sol" #2=
#3_"1977-5697*:*Аррениус:5697 Arrhenius:Arrhenius:6766 P-L" "Sol" #3=
".:Arrhenius:5697 Arrhenius:1977-5697*:6766 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.572485636086
		SemiMajorAxis	3.143116681848
		Eccentricity	0.070702102346
		Inclination	13.67641337943
		AscendingNode	170.544447911692
		ArgOfPericenter	116.335573539846
		MeanAnomaly	322.41543011355
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0774
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5697"
}

#1_"5704 Schumacher:Schumacher:1950 DE:1950 BL1:1990 DB1:1990 EX5" "Sol" #1=
#2_"*Шумахер:5704 Schumacher:Schumacher:1950 DE" "Sol" #2=
#3_"1950 DE:*Шумахер:5704 Schumacher:Schumacher" "Sol" #3=
".:Schumacher:5704 Schumacher:1950 DE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.775647490691
		SemiMajorAxis	3.219054411943
		Eccentricity	0.112544869835
		Inclination	11.591112798168
		AscendingNode	151.621393049674
		ArgOfPericenter	39.596226443553
		MeanAnomaly	67.593399116748
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0515
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5704"
}

#1_"5709 Tamyeunleung:Tamyeunleung:1977 TS3:1977 VN1:1977 VQ1:1988 VE2" "Sol" #1=
#2_"*Тамеонлинг:5709 Tamyeunleung:Tamyeunleung:1977 TS3" "Sol" #2=
#3_"1977 TS3:*Тамеонлинг:5709 Tamyeunleung:Tamyeunleung" "Sol" #3=
".:Tamyeunleung:5709 Tamyeunleung:1977 TS3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.18
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.408635307028
		SemiMajorAxis	3.081198405167
		Eccentricity	0.25036534876
		Inclination	4.198306724668
		AscendingNode	113.877415990475
		ArgOfPericenter	260.553196802636
		MeanAnomaly	323.383737473853
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0831
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5709"
}

#1_"5711 Eneev:Eneev:1978 SO4:1981 AS3:1986 TS12:1991 GR3" "Sol" #1=
#2_"*Энеев:5711 Eneev:Eneev:1978 SO4" "Sol" #2=
#3_"1978 SO4:*Энеев:5711 Eneev:Eneev" "Sol" #3=
".:Eneev:5711 Eneev:1978 SO4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.81858444136
		SemiMajorAxis	3.939247660724
		Eccentricity	0.162995737355
		Inclination	6.37148905136
		AscendingNode	14.219539781879
		ArgOfPericenter	295.710345961385
		MeanAnomaly	275.811926069576
	}
	UniformRotation
	{
		Period	30
	}
	LunarLambert	0.5
	Albedo	0.0426
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5711"
}

#1_"5723 Hudson:Hudson:1986 RR2:1969 TR6:1979 QX6" "Sol" #1=
#2_"*Хадсон:5723 Hudson:Hudson:1986 RR2" "Sol" #2=
#3_"1986 RR2:Hudson:*Хадсон:5723 Hudson" "Sol" #3=
".:Hudson:5723 Hudson:1986 RR2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5723 hudson.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.441
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.425554851149
		SemiMajorAxis	2.272384487087
		Eccentricity	0.244768143462
		Inclination	5.583535380683
		AscendingNode	163.168355405292
		ArgOfPericenter	194.432376361983
		MeanAnomaly	314.253658305477
	}
	UniformRotation
	{
		Period	4.475115
	}
	LunarLambert	0.5
	Albedo	0.444
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5723"
}

#1_"5731 Zeus:Zeus:1988 VP4" "Sol" #1=
#2_"*Зевс:5731 Zeus:Zeus:1988 VP4" "Sol" #2=
#3_"1988 VP4:*Зевс:5731 Zeus:Zeus" "Sol" #3=
".:Zeus:5731 Zeus:1988 VP4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.405349545427
		SemiMajorAxis	2.26344005214
		Eccentricity	0.653724456399
		Inclination	11.429723031511
		AscendingNode	281.708251061965
		ArgOfPericenter	216.985309694294
		MeanAnomaly	206.39369701756
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5731"
}

#1_"5738 Billpickering:Billpickering:1989 UY3:1980 WV4" "Sol" #1=
#2_"*Биллпикеринг:5738 Billpickering:Billpickering:1989 UY3" "Sol" #2=
#3_"1989 UY3:Billpickering:*Биллпикеринг:5738 Billpickering" "Sol" #3=
".:Billpickering:5738 Billpickering:1989 UY3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5738 billpickering.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.101
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.530949937657
		SemiMajorAxis	2.738129857409
		Eccentricity	0.477726567422
		Inclination	21.772709745534
		AscendingNode	239.366811179023
		ArgOfPericenter	246.379532221028
		MeanAnomaly	338.42117465235
	}
	UniformRotation
	{
		Period	10.4
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5738"
}

#1_"5747 1991 CO3:1991 CO3:1972 BF" "Sol" #1=
#2_"1991 CO3:5747 1991 CO3" "Sol" #2=
#3_"1991 CO3:5747 1991 CO3" "Sol" #3=
".:1991 CO3:5747 1991 CO3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.065
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.712992995434
		SemiMajorAxis	2.397787094833
		Eccentricity	0.240718373241
		Inclination	24.619669250806
		AscendingNode	282.16909986264
		ArgOfPericenter	170.948783258429
		MeanAnomaly	202.893448706562
	}
	UniformRotation
	{
		Period	38.6
	}
	LunarLambert	0.5
	Albedo	0.267
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5747"
}

#1_"5751 Zao:Zao:1992 AC:1989 EN1" "Sol" #1=
#2_"*Цзао:5751 Zao:Zao:1992 AC" "Sol" #2=
#3_"1992 AC:*Цзао:5751 Zao:Zao" "Sol" #3=
".:Zao:5751 Zao:1992 AC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	1.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.050386050844
		SemiMajorAxis	2.103283118139
		Eccentricity	0.42370157712
		Inclination	16.074964530319
		AscendingNode	121.69642397196
		ArgOfPericenter	25.225406054946
		MeanAnomaly	170.905570076526
	}
	UniformRotation
	{
		Period	76
	}
	LunarLambert	0.5
	Albedo	0.36
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5751"
}

#1_"5757 Ticha:Ticha:1967 JN:1973 UV3:1992 JC" "Sol" #1=
#2_"*Тиха:5757 Ticha:Ticha:1967 JN" "Sol" #2=
#3_"1967 JN:*Тиха:5757 Ticha:Ticha" "Sol" #3=
".:Ticha:5757 Ticha:1967 JN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.525
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.033180620319
		SemiMajorAxis	2.936902590379
		Eccentricity	0.184938853379
		Inclination	13.684589522546
		AscendingNode	38.265427597693
		ArgOfPericenter	242.934843185106
		MeanAnomaly	134.696007633899
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0632
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5757"
}

#1_"5771 Somerville:Somerville:1987 ST1:1982 YY1:1989 BG1" "Sol" #1=
#2_"*Сомервилль:5771 Somerville:Somerville:1987 ST1" "Sol" #2=
#3_"1987 ST1:*Сомервилль:5771 Somerville:Somerville" "Sol" #3=
".:Somerville:5771 Somerville:1987 ST1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.415
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.550077983844
		SemiMajorAxis	3.134685118159
		Eccentricity	0.223735394098
		Inclination	8.225068799408
		AscendingNode	288.510742017031
		ArgOfPericenter	101.286099810636
		MeanAnomaly	317.859473942282
	}
	UniformRotation
	{
		Period	9.2
	}
	LunarLambert	0.5
	Albedo	0.0372
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5771"
}
#New4 ???
#1_"5776 1989 UT2:1989 UT2:1984 LH:1988 JE2" "Sol" #1=
#2_"1989 UT2:5776 1989 UT2" "Sol" #2=
#3_"1989 UT2:5776 1989 UT2" "Sol" #3=
".:1989 UT2:5776 1989 UT2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5776 1989 UT2.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.278
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.136183816613
		SemiMajorAxis	2.576683555914
		Eccentricity	0.167052578006
		Inclination	12.190329667231
		AscendingNode	224.286528813575
		ArgOfPericenter	57.73106266032
		MeanAnomaly	309.938468949
	}
	UniformRotation
	{
		Period	4.34079
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5776"
}

#1_"5786 Talos:Talos:1991 RC" "Sol" #1=
#2_"*Талос:5786 Talos:Talos:1991 RC" "Sol" #2=
#3_"1991 RC:*Талос:5786 Talos:Talos" "Sol" #3=
".:Talos:5786 Talos:1991 RC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.124654477605
		SemiMajorAxis	1.081452070019
		Eccentricity	0.826835928737
		Inclination	23.232384446703
		AscendingNode	161.31296020336
		ArgOfPericenter	8.343140928107
		MeanAnomaly	2.764550393523
	}
	UniformRotation
	{
		Period	38.52
	}
	LunarLambert	0.5
	Albedo	0.11
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5786"
}

#1_"5797 Bivoj:Bivoj:1980 AA:1993 BC2" "Sol" #1=
#2_"*Бивой:5797 Bivoj:Bivoj:1980 AA" "Sol" #2=
#3_"1980 AA:*Бивой:5797 Bivoj:Bivoj" "Sol" #3=
".:Bivoj:5797 Bivoj:1980 AA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.605815386388
		SemiMajorAxis	1.893608936806
		Eccentricity	0.444128900539
		Inclination	4.188339075136
		AscendingNode	299.006319260497
		ArgOfPericenter	168.427370368446
		MeanAnomaly	148.042635714664
	}
	UniformRotation
	{
		Period	2.706
	}
	LunarLambert	0.5
	Albedo	0.33
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5797"
}

#1_"5832 Martaprincipe:Martaprincipe:1991 LE1:1984 YJ5" "Sol" #1=
#2_"*Мартапринцип:5832 Martaprincipe:Martaprincipe:1991 LE1" "Sol" #2=
#3_"1991 LE1:*Мартапринцип:5832 Martaprincipe:Martaprincipe" "Sol" #3=
".:Martaprincipe:5832 Martaprincipe:1991 LE1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.254686172339
		SemiMajorAxis	2.62566643873
		Eccentricity	0.11732229308
		Inclination	28.204863415992
		AscendingNode	110.699304285616
		ArgOfPericenter	262.846856405046
		MeanAnomaly	91.497300586483
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1146
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5832"
}

#1_"5833 Peterson:Peterson:1991 PQ:1972 TN2:1978 PO1" "Sol" #1=
#2_"*Петерсон:5833 Peterson:Peterson:1991 PQ" "Sol" #2=
#3_"1991 PQ:*Петерсон:5833 Peterson:Peterson" "Sol" #3=
".:Peterson:5833 Peterson:1991 PQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.04
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.528469975603
		SemiMajorAxis	3.493028581555
		Eccentricity	0.031544317871
		Inclination	19.382508341662
		AscendingNode	306.67976609733
		ArgOfPericenter	114.99501090115
		MeanAnomaly	105.437940024605
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0901
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5833"
}

#1_"5849 1990 HF1:1990 HF1:1983 ET2:1984 HV" "Sol" #1=
#2_"1990 HF1:5849 1990 HF1" "Sol" #2=
#3_"1990 HF1:5849 1990 HF1" "Sol" #3=
".:1990 HF1:5849 1990 HF1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	14.195
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.672738754354
		SemiMajorAxis	3.180702528951
		Eccentricity	0.008206765628
		Inclination	22.539734663276
		AscendingNode	129.769952779614
		ArgOfPericenter	136.003745556491
		MeanAnomaly	82.782772140502
	}
	UniformRotation
	{
		Period	8.733
	}
	LunarLambert	0.5
	Albedo	0.1823
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5849"
}

#1_"5852 Nanette:Nanette:1991 HO:1955 MB" "Sol" #1=
#2_"*Нанетт:5852 Nanette:Nanette:1991 HO" "Sol" #2=
#3_"1991 HO:*Нанетт:5852 Nanette:Nanette" "Sol" #3=
".:Nanette:5852 Nanette:1991 HO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.534632882669
		SemiMajorAxis	2.739613433873
		Eccentricity	0.213222286277
		Inclination	18.640678518346
		AscendingNode	78.566420646106
		ArgOfPericenter	178.15694646969
		MeanAnomaly	31.69490973591
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0353
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5852"
}

#1_"5870 Baltimore:Baltimore:1989 CC1:1992 PD" "Sol" #1=
#2_"*Балтимор:5870 Baltimore:Baltimore:1989 CC1" "Sol" #2=
#3_"1989 CC1:*Балтимор:5870 Baltimore:Baltimore" "Sol" #3=
".:Baltimore:5870 Baltimore:1989 CC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.77
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.66677583152
		SemiMajorAxis	2.792581297915
		Eccentricity	0.419517144036
		Inclination	28.951226822946
		AscendingNode	154.132624977911
		ArgOfPericenter	271.525084216718
		MeanAnomaly	235.89949606374
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.215
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5870"
}

#1_"5889 Mickiewicz:Mickiewicz:1979 FA3:1990 HJ1" "Sol" #1=
#2_"*Мицкевич:5889 Mickiewicz:Mickiewicz:1979 FA3" "Sol" #2=
#3_"1979 FA3:*Мицкевич:5889 Mickiewicz:Mickiewicz" "Sol" #3=
".:Mickiewicz:5889 Mickiewicz:1979 FA3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.275
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.310902288339
		SemiMajorAxis	3.043967930379
		Eccentricity	0.159282560741
		Inclination	19.181816107524
		AscendingNode	182.120543702757
		ArgOfPericenter	40.159594239408
		MeanAnomaly	229.736749116785
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0726
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5889"
}

#1_"5900 Jensen:Jensen:1986 TL:1930 UT:1969 PD" "Sol" #1=
#2_"*Йенсен:5900 Jensen:Jensen:1986 TL" "Sol" #2=
#3_"1986 TL:*Йенсен:5900 Jensen:Jensen" "Sol" #3=
".:Jensen:5900 Jensen:1986 TL:" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.905
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.582065719449
		SemiMajorAxis	3.146718030881
		Eccentricity	0.215276690424
		Inclination	9.070948576206
		AscendingNode	302.190484622142
		ArgOfPericenter	34.957318097555
		MeanAnomaly	46.37011027386
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0287
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5900"
}

#1_"5914 Kathywhaler:Kathywhaler:1990 WK:1964 VV2:1984 YV1" "Sol" #1=
#2_"*Кэтиуолер:5914 Kathywhaler:Kathywhaler:1990 WK" "Sol" #2=
#3_"1990 WK:*Кэтиуолер:5914 Kathywhaler:Kathywhaler" "Sol" #3=
".:Kathywhaler:5914 Kathywhaler:1990 WK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.665524862848
		SemiMajorAxis	3.541746175665
		Eccentricity	0.08781491411
		Inclination	10.377357037028
		AscendingNode	73.258903070196
		ArgOfPericenter	247.23629612822
		MeanAnomaly	281.227612553856
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.057
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5914"
}

#1_"5919 Patrickmartin:Patrickmartin:1991 PW12:1931 CK:1979 OU5:1983 CC5:1984 KQ:1986 TK3:1989 DD: #1=
#1_A923 VB" "Sol" #1=
#2_"*Патрикмартин:5919 Patrickmartin:Patrickmartin:1991 PW12" "Sol" #2=
#3_"1991 PW12:*Патрикмартин:5919 Patrickmartin:Patrickmartin" "Sol" #3=
".:Patrickmartin:5919 Patrickmartin:1991 PW12" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.225
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.718234343699
		SemiMajorAxis	3.197686117934
		Eccentricity	0.122337892365
		Inclination	0.66512625
		AscendingNode	5.812585685415
		ArgOfPericenter	188.607274692735
		MeanAnomaly	152.920880134458
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0968
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5919"
}

#1_"5922 Shouichi:Shouichi:1992 UV:1950 QF:1950 SN:1979 FO:1982 VN12:1982 YU2:1987 UP8:1987 WL4" "Sol" #1=
#2_"*Шуичи:5922 Shouichi:Shouichi:1992 UV" "Sol" #2=
#3_"1992 UV:*Шуичи:5922 Shouichi:Shouichi" "Sol" #3=
".:Shouichi:5922 Shouichi:1992 UV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.465
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.214614170983
		SemiMajorAxis	3.007063867003
		Eccentricity	0.109132511985
		Inclination	7.852074245855
		AscendingNode	232.309006637602
		ArgOfPericenter	148.796368780929
		MeanAnomaly	98.866605589824
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0542
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5922"
}

#1_"5924 Teruo:Teruo:1994 CH1:1940 CH:1944 HC:1958 DH:1965 AB1:1969 ED1:1980 GN1:1980 KU1:1985 UH4: #1=
#1_1987 FJ:1989 YQ9" "Sol" #1=
#2_"*Теруо:5924 Teruo:Teruo:1994 CH1" "Sol" #2=
#3_"1994 CH1:*Теруо:5924 Teruo:Teruo" "Sol" #3=
".:Teruo:5924 Teruo:1994 CH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.59224819343
		SemiMajorAxis	2.34551791911
		Eccentricity	0.109498292348
		Inclination	4.089573558527
		AscendingNode	109.477580497179
		ArgOfPericenter	69.732017611854
		MeanAnomaly	265.155894283911
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0693
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5924"
}

#1_"5929 Manzano:Manzano:1974 XT:1988 PB" "Sol" #1=
#2_"*Мансано:5929 Manzano:Manzano:1974 XT" "Sol" #2=
#3_"1974 XT:Manzano:*Мансано:5929 Manzano" "Sol" #3=
".:Manzano:5929 Manzano:1974 XT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5929 manzano.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.108
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.618703636019
		SemiMajorAxis	2.357019685373
		Eccentricity	0.30467817101
		Inclination	23.016367922441
		AscendingNode	126.339220235556
		ArgOfPericenter	277.991313595967
		MeanAnomaly	256.407281091999
	}
	UniformRotation
	{
		Period	3.7596
	}
	LunarLambert	0.5
	Albedo	0.411
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5929"
}

#1_"5957 Irina:Irina:1988 JN" "Sol" #1=
#2_"*Ирина:5957 Irina:Irina:1988 JN" "Sol" #2=
#3_"1988 JN:*Ирина:5957 Irina:Irina" "Sol" #3=
".:Irina:5957 Irina:1988 JN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.905
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.802189057623
		SemiMajorAxis	3.228908827243
		Eccentricity	0.111735754109
		Inclination	22.886719480221
		AscendingNode	150.263115204834
		ArgOfPericenter	101.618791641676
		MeanAnomaly	191.740159240608
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1121
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5957"
}

#1_"5959 Shaklan:Shaklan:1989 NB1:1949 MG" "Sol" #1=
#2_"*Шаклан:5959 Shaklan:Shaklan:1989 NB1" "Sol" #2=
#3_"1989 NB1:*Шаклан:5959 Shaklan:Shaklan" "Sol" #3=
".:Shaklan:5959 Shaklan:1989 NB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.97
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.695400484847
		SemiMajorAxis	3.189167848206
		Eccentricity	0.099048620782
		Inclination	17.863706233945
		AscendingNode	135.502654288913
		ArgOfPericenter	147.839520708136
		MeanAnomaly	182.179271656713
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.177
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5959"
}

#1_"5960 Wakkanai:Wakkanai:1989 US:1934 VK:1973 YU1:1976 UD1" "Sol" #1=
#2_"*Вакканай:5960 Wakkanai:Wakkanai:1989 US" "Sol" #2=
#3_"1989 US:*Вакканай:5960 Wakkanai:Wakkanai" "Sol" #3=
".:Wakkanai:5960 Wakkanai:1989 US" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5960 wakkanai.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.332
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.238468620633
		SemiMajorAxis	2.188875166199
		Eccentricity	0.153967185152
		Inclination	4.317676484089
		AscendingNode	43.517397466467
		ArgOfPericenter	330.60210550226
		MeanAnomaly	345.838803227992
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.295
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5960"
}

#1_"5993 Tammydickinson:Tammydickinson:1981 EU22:1989 YN8" "Sol" #1=
#2_"*Тэммидикинсон:5993 Tammydickinson:Tammydickinson:1981 EU22" "Sol" #2=
#3_"1981 EU22:Tammydickinson:*Тэммидикинсон:5993 Tammydickinson" "Sol" #3=
".:Tammydickinson:5993 Tammydickinson:1981 EU22" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"5993 tammydickinson.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.210163687019
		SemiMajorAxis	2.176102345174
		Eccentricity	0.068175367234
		Inclination	1.925216151775
		AscendingNode	339.60539852997
		ArgOfPericenter	197.362263093997
		MeanAnomaly	67.895764367249
	}
	UniformRotation
	{
		Period	9.4471
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=5993"
}

#1_"6000 United Nations:United Nations:1987 UN:1991 TC1" "Sol" #1=
#2_"*Юнайтед Нэйшэнс:6000 United Nations:United Nations:1987 UN" "Sol" #2=
#3_"1987 UN:United Nations:*Юнайтед Нэйшэнс:6000 United Nations" "Sol" #3=
".:United Nations:6000 United Nations:1987 UN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6000 united nations.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.195361039146
		SemiMajorAxis	2.601202078265
		Eccentricity	0.186340100965
		Inclination	14.413215099434
		AscendingNode	52.162509712869
		ArgOfPericenter	315.990073281466
		MeanAnomaly	11.041467126978
	}
	UniformRotation
	{
		Period	3.262
	}
	LunarLambert	0.5
	Albedo	0.211
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6000"
}

#1_"6026 Xenophanes:Xenophanes:1993 BA8:1976 ST1:1984 GC:1986 TT12:1990 SJ18" "Sol" #1=
#2_"*Ксенофан:6026 Xenophanes:Xenophanes:1993 BA8" "Sol" #2=
#3_"1993 BA8:Xenophanes:*Ксенофан:6026 Xenophanes" "Sol" #3=
".:Xenophanes:6026 Xenophanes:1993 BA8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6026 xenophanes.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.779870831968
		SemiMajorAxis	2.837518089908
		Eccentricity	0.067956925129
		Inclination	3.219473581782
		AscendingNode	202.989254539502
		ArgOfPericenter	1.069333872085
		MeanAnomaly	307.798050143191
	}
	UniformRotation
	{
		Period	4.4898
	}
	LunarLambert	0.5
	Albedo	0.118
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6026"
}

#1_"6038 1989 EQ:1989 EQ:1981 QX3" "Sol" #1=
#2_"1989 EQ:6038 1989 EQ" "Sol" #2=
#3_"1989 EQ:6038 1989 EQ" "Sol" #3=
".:1989 EQ:6038 1989 EQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.465
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.328224604753
		SemiMajorAxis	3.050583247393
		Eccentricity	0.18871408505
		Inclination	8.280208263811
		AscendingNode	313.557987729417
		ArgOfPericenter	124.37056571876
		MeanAnomaly	0.206942343382
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0443
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6038"
}

#1_"6053 1993 BW3:1993 BW3" "Sol" #1=
#2_"1993 BW3:6053 1993 BW3" "Sol" #2=
#3_"1993 BW3:6053 1993 BW3" "Sol" #3=
".:1993 BW3:6053 1993 BW3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6053 1993 BW3.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.86
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.147561395856
		SemiMajorAxis	2.147718403624
		Eccentricity	0.528520790758
		Inclination	21.585900292305
		AscendingNode	318.367529781098
		ArgOfPericenter	74.857433486824
		MeanAnomaly	96.792075225852
	}
	UniformRotation
	{
		Period	2.573
	}
	LunarLambert	0.5
	Albedo	0.14
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6053"
}

#1_"6057 Robbia:Robbia:5182 T-3:1980 FY9:1993 KE" "Sol" #1=
#2_"*Роббиа:6057 Robbia:Robbia:1977-6057*:5182 T-3" "Sol" #2=
#3_"1977-6057*:*Роббиа:6057 Robbia:Robbia:5182 T-3" "Sol" #3=
".:6057 Robbia:Robbia:1977-6057*:5182 T-3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.715
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.043774492552
		SemiMajorAxis	3.31792602865
		Eccentricity	0.102227086738
		Inclination	17.862346136587
		AscendingNode	170.930626818436
		ArgOfPericenter	187.924406894054
		MeanAnomaly	66.909864628857
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0852
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6057"
}

#1_"6059 1979 TA:1979 TA:1979 QK9:1983 VD" "Sol" #1=
#2_"1979 TA:6059 1979 TA" "Sol" #2=
#3_"1979 TA:6059 1979 TA" "Sol" #3=
".:1979 TA:6059 1979 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.115
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.804102376773
		SemiMajorAxis	2.436852986517
		Eccentricity	0.217128955308
		Inclination	2.347793976359
		AscendingNode	302.276575302211
		ArgOfPericenter	52.685544701569
		MeanAnomaly	96.00286540172
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0413
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6059"
}

#1_"6063 Jason:Jason:1984 KB" "Sol" #1=
#2_"*Ясон:6063 Jason:Jason:1984 KB" "Sol" #2=
#3_"1984 KB:*Ясон:6063 Jason:Jason" "Sol" #3=
".:Jason:6063 Jason:1984 KB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.291138785556
		SemiMajorAxis	2.21254440835
		Eccentricity	0.766461292038
		Inclination	4.919441079008
		AscendingNode	169.453695730247
		ArgOfPericenter	337.081929428059
		MeanAnomaly	104.110017662762
	}
	UniformRotation
	{
		Period	51.7
	}
	LunarLambert	0.5
	Albedo	0.21
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6063"
}

#1_"6087 Lupo:Lupo:1988 FK:1986 RG5" "Sol" #1=
#2_"*Лупо:6087 Lupo:Lupo:1988 FK" "Sol" #2=
#3_"1988 FK:Lupo:*Лупо:6087 Lupo" "Sol" #3=
".:Lupo:6087 Lupo:1988 FK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6087 lupo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.772
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.681082048798
		SemiMajorAxis	1.929899091693
		Eccentricity	0.076165553869
		Inclination	22.615062988586
		AscendingNode	152.550657737818
		ArgOfPericenter	54.024977995895
		MeanAnomaly	256.618358061485
	}
	UniformRotation
	{
		Period	4.712
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6087"
}

#1_"6090 1989 DJ:1989 DJ:1977 EH2:1983 OH:1990 FO1" "Sol" #1=
#2_"1989 DJ:6090 1989 DJ" "Sol" #2=
#3_"1989 DJ:6090 1989 DJ" "Sol" #3=
".:1989 DJ:6090 1989 DJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	37.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.248908532652
		SemiMajorAxis	5.313648140639
		Eccentricity	0.056630520217
		Inclination	20.180303890588
		AscendingNode	328.534375277886
		ArgOfPericenter	73.617140439055
		MeanAnomaly	139.67779142658
	}
	UniformRotation
	{
		Period	18.476
	}
	LunarLambert	0.5
	Albedo	0.0553
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6090"
}

#1_"6106 Stoss:Stoss:6564 P-L:1971 QH:1988 PR4" "Sol" #1=
#2_"*Стосс:6106 Stoss:Stoss:1960-6106*:6564 P-L" "Sol" #2=
#3_"1960-6106*:*Стосс:6106 Stoss:Stoss:6564 P-L" "Sol" #3=
".:Stoss:6106 Stoss:1960-6106*:6564 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.628298722399
		SemiMajorAxis	3.164069090853
		Eccentricity	0.168281128079
		Inclination	2.563599750891
		AscendingNode	124.920635350845
		ArgOfPericenter	204.253948913499
		MeanAnomaly	226.000354126767
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0649
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6106"
}

#1_"6111 Davemckay:Davemckay:1979 SP13:1969 AP:1973 AO4:1973 CN:1979 SW3:1983 UX" "Sol" #1=
#2_"*Дэйвмаккей:6111 Davemckay:Davemckay:1979 SP13" "Sol" #2=
#3_"1979 SP13:*Дэйвмаккей:6111 Davemckay:Davemckay" "Sol" #3=
".:Davemckay:6111 Davemckay:1979 SP13" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.115
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.839287479437
		SemiMajorAxis	2.451855963341
		Eccentricity	0.199107238511
		Inclination	4.013903037924
		AscendingNode	95.916011962248
		ArgOfPericenter	310.609140976874
		MeanAnomaly	29.270965893304
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0817
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6111"
}

#1_"6129 Demokritos:Demokritos:1989 RB2:1950 DC:1973 AZ" "Sol" #1=
#2_"*Демокрит:6129 Demokritos:Demokritos:1989 RB2" "Sol" #2=
#3_"1989 RB2:*Демокрит:6129 Demokritos:Demokritos" "Sol" #3=
".:Demokritos:6129 Demokritos:1989 RB2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.845
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.672906409573
		SemiMajorAxis	2.795026439496
		Eccentricity	0.168020221685
		Inclination	6.527007479598
		AscendingNode	294.130713972251
		ArgOfPericenter	294.771816936397
		MeanAnomaly	248.840959480909
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0863
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6129"
}

#1_"6136 Gryphon:Gryphon:1990 YH:1986 CE1" "Sol" #1=
#2_"*Грифон:6136 Gryphon:Gryphon:1990 YH" "Sol" #2=
#3_"1990 YH:Gryphon:*Грифон:6136 Gryphon" "Sol" #3=
".:Gryphon:6136 Gryphon:1990 YH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6136 gryphon.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.792
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.258648288695
		SemiMajorAxis	3.023968632218
		Eccentricity	0.057786538301
		Inclination	11.176260247033
		AscendingNode	136.076572927407
		ArgOfPericenter	321.020164899716
		MeanAnomaly	1.609220739829
	}
	UniformRotation
	{
		Period	16.476
	}
	LunarLambert	0.5
	Albedo	0.185
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6136"
}

#1_"6137 Johnfletcher:Johnfletcher:1991 BY:1956 CD:1971 TQ2:1974 FU:1985 DP4" "Sol" #1=
#2_"*Джонфлетчер:6137 Johnfletcher:Johnfletcher:1991 BY" "Sol" #2=
#3_"1991 BY:*Джонфлетчер:6137 Johnfletcher:Johnfletcher" "Sol" #3=
".:Johnfletcher:6137 Johnfletcher:1991 BY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.761464930498
		SemiMajorAxis	3.213782490698
		Eccentricity	0.063428453015
		Inclination	15.440608286338
		AscendingNode	337.001666455786
		ArgOfPericenter	87.789020060506
		MeanAnomaly	126.417685931126
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.086
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6137"
}

#1_"6150 Neukum:Neukum:1980 FR1:1983 VC1" "Sol" #1=
#2_"*Нойкум:6150 Neukum:Neukum:1980 FR1" "Sol" #2=
#3_"1980 FR1:*Нойкум:6150 Neukum:Neukum" "Sol" #3=
".:Neukum:6150 Neukum:1980 FR1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.68
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.594536498304
		SemiMajorAxis	3.151402966472
		Eccentricity	0.141041547524
		Inclination	3.682584168102
		AscendingNode	326.272187230067
		ArgOfPericenter	67.483762466692
		MeanAnomaly	201.145759475062
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0987
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6150"
}

#1_"6157 Prey:Prey:1991 RX2:1984 WM4" "Sol" #1=
#2_"*Прэй:6157 Prey:Prey:1991 RX2" "Sol" #2=
#3_"1991 RX2:*Прэй:6157 Prey:Prey" "Sol" #3=
".:Prey:6157 Prey:1991 RX2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.43
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.776442782947
		SemiMajorAxis	2.425026401681
		Eccentricity	0.084671314392
		Inclination	3.969134028862
		AscendingNode	280.029411336208
		ArgOfPericenter	225.476814646292
		MeanAnomaly	278.373502760107
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0171
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6157"
}

#New4-Name
#1_"6159 Andreseloy:Andreseloy:1991 YH:1987 UY4:1990 OZ1:1990 SB17" "Sol" #1=
#2_"*Андресэлой:6159 Andreseloy:Andreseloy:1991 YH" "Sol" #2=
#3_"Andreseloy:*Андресэлой:6159 Andreseloy:1991 YH" "Sol" #3=
".:Andreseloy:6159 Andreseloy:1991 YH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6159 andreseloy.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.632
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.468498259811
		SemiMajorAxis	2.291336390099
		Eccentricity	0.061596383059
		Inclination	6.856870667263
		AscendingNode	30.299568941658
		ArgOfPericenter	56.590101452895
		MeanAnomaly	306.73916266436
	}
	UniformRotation
	{
		Period	10.639
	}
	LunarLambert	0.5
	Albedo	0.484
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6159"
}

#1_"6161 Vojno-Yasenetsky:Vojno-Yasenetsky:1971 TY2:1990 XA1" "Sol" #1=
#2_"*Войно-Ясенецкий:6161 Vojno-Yasenetsky:Vojno-Yasenetsky:1971 TY2" "Sol" #2=
#3_"1971 TY2:Vojno-Yasenetsky:*Войно-Ясенецкий:6161 Vojno-Yasenetsky" "Sol" #3=
".:Vojno-Yasenetsky:6161 Vojno-Yasenetsky:1971 TY2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6161 vojno-yasenetsky.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	8.59
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.650589234003
		SemiMajorAxis	2.786120226137
		Eccentricity	0.2311806821
		Inclination	8.977317845531
		AscendingNode	280.272411088311
		ArgOfPericenter	181.402011029622
		MeanAnomaly	225.513513081672
	}
	UniformRotation
	{
		Period	7.981
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6161"
}

#1_"6166 Univsima:Univsima:1978 SP4:1970 EP:1986 GQ:1991 EF1" "Sol" #1=
#2_"*Унивсима:6166 Univsima:Univsima:1978 SP4" "Sol" #2=
#3_"1978 SP4:Univsima:*Унивсима:6166 Univsima" "Sol" #3=
".:Univsima:6166 Univsima:1978 SP4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6166 univsima.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.024
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.191666790529
		SemiMajorAxis	2.998235480028
		Eccentricity	0.081375915665
		Inclination	10.849829746736
		AscendingNode	18.037999076858
		ArgOfPericenter	83.342468555366
		MeanAnomaly	70.275292038594
	}
	UniformRotation
	{
		Period	9.6
	}
	LunarLambert	0.5
	Albedo	0.176
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6166"
}

#1_"6174 Polybius:Polybius:1983 TR2:1976 GA6:1978 RQ16" "Sol" #1=
#2_"*Полибий:6174 Polybius:Polybius:1983 TR2" "Sol" #2=
#3_"1983 TR2:*Полибий:6174 Polybius:Polybius" "Sol" #3=
".:Polybius:6174 Polybius:1983 TR2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.305
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.332578909154
		SemiMajorAxis	3.052245009112
		Eccentricity	0.22141123643
		Inclination	14.693077257798
		AscendingNode	21.692269569879
		ArgOfPericenter	301.091166456331
		MeanAnomaly	332.838666489366
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0723
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6174"
}

#1_"6175 Cori:Cori:1983 XW:1954 WF:1988 PY1:1988 UX" "Sol" #1=
#2_"*Цори:6175 Cori:Cori:1983 XW" "Sol" #2=
#3_"1983 XW:*Цори:6175 Cori:Cori" "Sol" #3=
".:Cori:6175 Cori:1983 XW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.69631739664
		SemiMajorAxis	3.189510125238
		Eccentricity	0.207863838945
		Inclination	0.402804310038
		AscendingNode	35.085379401763
		ArgOfPericenter	8.076329317014
		MeanAnomaly	181.92579386546
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1573
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6175"
}

#1_"6178 1986 DA:1986 DA" "Sol" #1=
#2_"1986 DA:6178 1986 DA" "Sol" #2=
#3_"1986 DA:6178 1986 DA" "Sol" #3=
".:1986 DA:6178 1986 DA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.740190630008
		SemiMajorAxis	2.821792469556
		Eccentricity	0.581675562874
		Inclination	4.30478853541
		AscendingNode	64.679208787228
		ArgOfPericenter	127.284168476006
		MeanAnomaly	25.471934472109
	}
	UniformRotation
	{
		Period	3.5
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6178"
}

#1_"6187 1988 RD5:1988 RD5:1977 RH20:1977 RU2:1989 YD5" "Sol" #1=
#2_"1988 RD5:6187 1988 RD5" "Sol" #2=
#3_"1988 RD5:6187 1988 RD5" "Sol" #3=
".:1988 RD5:6187 1988 RD5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.47
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.547178888985
		SemiMajorAxis	3.133593416879
		Eccentricity	0.179604541518
		Inclination	1.934867847127
		AscendingNode	53.128722536853
		ArgOfPericenter	327.537835170535
		MeanAnomaly	230.909565802739
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0616
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6187"
}

#New4-Name
#1_"6192 Javiergorosabel:Javiergorosabel:1990 KB1:1952 PA:1976 GT6:1984 YS2" "Sol" #1=
#2_"*Явиргоросабель:6192 Javiergorosabel:Javiergorosabel:1990 KB1" "Sol" #2=
#3_"1990 KB1:*Явиргоросабель:6192 Javiergorosabel:Javiergorosabel" "Sol" #3=
".:Javiergorosabel:6192 Javiergorosabel:1990 KB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6192 javiergorosabel.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.228
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.470821056088
		SemiMajorAxis	2.292359256168
		Eccentricity	0.266390208387
		Inclination	10.331735153595
		AscendingNode	122.265386860156
		ArgOfPericenter	169.095338169236
		MeanAnomaly	357.187443202178
	}
	UniformRotation
	{
		Period	78.85
	}
	LunarLambert	0.5
	Albedo	0.353
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6192"
}

#1_"6196 Bernardbowen:Bernardbowen:1991 UO4:1981 RP4:1981 SY3" "Sol" #1=
#2_"*Бернардбоуэн:6196 Bernardbowen:Bernardbowen:1991 UO4" "Sol" #2=
#3_"1991 UO4:Bernardbowen:*Бернардбоуэн:6196 Bernardbowen" "Sol" #3=
".:Bernardbowen:6196 Bernardbowen:1991 UO4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.652
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.260787712371
		SemiMajorAxis	2.198920605782
		Eccentricity	0.093967066178
		Inclination	6.196775382883
		AscendingNode	336.77564513
		ArgOfPericenter	322.780537590311
		MeanAnomaly	352.275542934729
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6196"
}

#1_"6205 Menottigalli:Menottigalli:1983 OD" "Sol" #1=
#2_"*Меноттигалли:6205 Menottigalli:Menottigalli:1983 OD" "Sol" #2=
#3_"1983 OD:*Меноттигалли:6205 Menottigalli:Menottigalli" "Sol" #3=
".:Menottigalli:6205 Menottigalli:1983 OD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	3.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.633780785694
		SemiMajorAxis	2.363562084798
		Eccentricity	0.233209441205
		Inclination	13.809410164296
		AscendingNode	131.892590686905
		ArgOfPericenter	215.793681398471
		MeanAnomaly	206.335575068186
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0847
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6205"
}

#1_"6222 1980 PB3:1980 PB3:1990 FO" "Sol" #1=
#2_"1980 PB3:6222 1980 PB3" "Sol" #2=
#3_"1980 PB3:6222 1980 PB3" "Sol" #3=
".:1980 PB3:6222 1980 PB3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.425
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.848553682676
		SemiMajorAxis	3.246087225298
		Eccentricity	0.1237790078
		Inclination	21.238968701427
		AscendingNode	54.421134332819
		ArgOfPericenter	130.064515222789
		MeanAnomaly	66.512410810629
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0641
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6222"
}

#1_"6237 Chikushi:Chikushi:1989 CV:1985 QZ5" "Sol" #1=
#2_"*Чекуши:6237 Chikushi:Chikushi:1989 CV" "Sol" #2=
#3_"1989 CV:*Чекуши:6237 Chikushi:Chikushi" "Sol" #3=
".:Chikushi:6237 Chikushi:1989 CV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.796907203823
		SemiMajorAxis	3.931963178031
		Eccentricity	0.072480053955
		Inclination	5.362588426009
		AscendingNode	25.551137250038
		ArgOfPericenter	205.571224996266
		MeanAnomaly	8.768755971199
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0348
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6237"
}

#1_"6239 Minos:Minos:1989 QF" "Sol" #1=
#2_"*Минос:6239 Minos:Minos:1989 QF" "Sol" #2=
#3_"1989 QF:*Минос:6239 Minos:Minos" "Sol" #3=
".:Minos:6239 Minos:1989 QF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.237
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.235755999534
		SemiMajorAxis	1.151550576019
		Eccentricity	0.412758144614
		Inclination	3.94495630956
		AscendingNode	344.623099639448
		ArgOfPericenter	239.677164453702
		MeanAnomaly	232.321586194171
	}
	UniformRotation
	{
		Period	3.5558
	}
	LunarLambert	0.5
	Albedo	0.34
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6239"
}

#1_"6255 Kuma:Kuma:1994 XT:1975 VJ8:1981 DV3:1986 EB2:1988 SU4:1989 WP3:1992 OL1" "Sol" #1=
#2_"*Кума:6255 Kuma:Kuma:1994 XT:1975 VJ8" "Sol" #2=
#3_"1994 XT:*Кума:6255 Kuma:Kuma:1975 VJ8" "Sol" #3=
".:Kuma:6255 Kuma:1994 XT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.36
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.541544243903
		SemiMajorAxis	2.742396408382
		Eccentricity	0.032766270796
		Inclination	5.120340663512
		AscendingNode	275.403323766703
		ArgOfPericenter	192.242637386442
		MeanAnomaly	181.200093243651
	}
	UniformRotation
	{
		Period	9.7
	}
	LunarLambert	0.5
	Albedo	0.0342
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6255"
}

#1_"6262 Javid:Javid:1978 RZ:1977 LH1:1988 UG1" "Sol" #1=
#2_"*Джавид:6262 Javid:Javid:1978 RZ" "Sol" #2=
#3_"1978 RZ:*Джавид:6262 Javid:Javid" "Sol" #3=
".:Javid:6262 Javid:1978 RZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6262 javid.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.896
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.963119408623
		SemiMajorAxis	2.90958476855
		Eccentricity	0.076167952431
		Inclination	3.011887672086
		AscendingNode	122.016582172362
		ArgOfPericenter	251.227195259958
		MeanAnomaly	141.119374702451
	}
	UniformRotation
	{
		Period	8.02
	}
	LunarLambert	0.5
	Albedo	0.291
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6262"
}

#1_"6276 Kurohone:Kurohone:1994 AB:1978 VG15:1983 VV3:1990 DW3:1992 RW4" "Sol" #1=
#2_"*Курохоне:6276 Kurohone:Kurohone:1994 AB" "Sol" #2=
#3_"1994 AB:Kurohone:*Курохоне:6276 Kurohone" "Sol" #3=
".:Kurohone:6276 Kurohone:1994 AB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6276 kurohone.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.476
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.877222461896
		SemiMajorAxis	2.875916298086
		Eccentricity	0.048885741291
		Inclination	1.435207339755
		AscendingNode	298.514638936627
		ArgOfPericenter	30.132697322049
		MeanAnomaly	18.680326493467
	}
	UniformRotation
	{
		Period	6.3453
	}
	LunarLambert	0.5
	Albedo	0.18
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6276"
}

#1_"6279 1977 UO5:1977 UO5:1977 VW1:1979 DT:1982 RD3:1990 EJ7:1990 FF3" "Sol" #1=
#2_"1977 UO5:6279 1977 UO5" "Sol" #2=
#3_"1977 UO5:6279 1977 UO5" "Sol" #3=
".:1977 UO5:6279 1977 UO5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.415
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.532574540796
		SemiMajorAxis	3.128091017105
		Eccentricity	0.192297434184
		Inclination	2.395039448289
		AscendingNode	68.317514227999
		ArgOfPericenter	355.662879035647
		MeanAnomaly	247.747551266618
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0684
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6279"
}

#1_"6295 Schmoll:Schmoll:1988 CF3:1979 QK7:1983 VG5:1990 TR9" "Sol" #1=
#2_"*Шмолл:6295 Schmoll:Schmoll:1988 CF3" "Sol" #2=
#3_"1988 CF3:*Шмолл:6295 Schmoll:Schmoll" "Sol" #3=
".:Schmoll:6295 Schmoll:1988 CF3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.795
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.587132083231
		SemiMajorAxis	2.343290385876
		Eccentricity	0.196290035723
		Inclination	3.236426193429
		AscendingNode	333.672956909066
		ArgOfPericenter	28.118368340864
		MeanAnomaly	276.439062662467
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1114
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6295"
}

#1_"6336 Dodo:Dodo:1992 UU:1953 TN1:1975 GQ:1982 BA6" "Sol" #1=
#2_"*Додо:6336 Dodo:Dodo:1992 UU" "Sol" #2=
#3_"1992 UU:*Додо:6336 Dodo:Dodo" "Sol" #3=
".:Dodo:6336 Dodo:1992 UU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.49
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.888189963623
		SemiMajorAxis	2.472632168843
		Eccentricity	0.09821784945
		Inclination	9.502063834706
		AscendingNode	24.331293158666
		ArgOfPericenter	358.745700003892
		MeanAnomaly	256.608185380845
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0195
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6336"
}

#1_"6340 Kathmandu:Kathmandu:1993 TF2:1978 EA5:1986 PS3:1989 AA1:1990 HS4:1990 HX4" "Sol" #1=
#2_"*Катманду:6340 Kathmandu:Kathmandu:1993 TF2" "Sol" #2=
#3_"1993 TF2:*Катманду:6340 Kathmandu:Kathmandu" "Sol" #3=
".:Kathmandu:6340 Kathmandu:1993 TF2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.985
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.799489109667
		SemiMajorAxis	3.227907071761
		Eccentricity	0.142016341714
		Inclination	2.294656206916
		AscendingNode	77.907768348656
		ArgOfPericenter	70.231215281146
		MeanAnomaly	134.752951518628
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0702
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6340"
}

#1_"6348 1995 CH1:1995 CH1:1978 UH3:1991 CD5:1993 QA2" "Sol" #1=
#2_"1995 CH1:6348 1995 CH1" "Sol" #2=
#3_"1995 CH1:6348 1995 CH1" "Sol" #3=
".:1995 CH1:6348 1995 CH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.92
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.835537156848
		SemiMajorAxis	2.4502590093
		Eccentricity	0.136628705334
		Inclination	4.931427856648
		AscendingNode	313.141928206082
		ArgOfPericenter	96.427000531281
		MeanAnomaly	142.256025440569
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0726
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6348"
}

#1_"6349 Acapulco:Acapulco:1995 CN1:1947 EC:1973 AH4:1973 CL:1988 SA1" "Sol" #1=
#2_"*Акапулько:6349 Acapulco:Acapulco:1995 CN1" "Sol" #2=
#3_"1995 CN1:*Акапулько:6349 Acapulco:Acapulco" "Sol" #3=
".:Acapulco:6349 Acapulco:1995 CN1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.62
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.353829833503
		SemiMajorAxis	2.666298893495
		Eccentricity	0.139251244556
		Inclination	10.79206565375
		AscendingNode	328.125334334874
		ArgOfPericenter	236.715956518144
		MeanAnomaly	156.963540995075
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0757
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6349"
}

#1_"6350 Schluter:Schluter:3526 P-L:1985 FG2:1990 EQ10:1993 RT2" "Sol" #1=
#2_"*Шлютер:6350 Schluter:Schluter:1960-6350*:3526 P-L" "Sol" #2=
#3_"1960-6350*:*Шлютер:6350 Schluter:Schluter:3526 P-L" "Sol" #3=
".:Schluter:6350 Schluter:1960-6350*:3526 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.28
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.499907777287
		SemiMajorAxis	3.115765780972
		Eccentricity	0.105176521335
		Inclination	11.459143901233
		AscendingNode	336.279945910001
		ArgOfPericenter	48.169586965294
		MeanAnomaly	302.650158692304
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0671
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6350"
}

#1_"6353 Semper:Semper:3107 T-3:1972 VZ:1985 FN2:1988 VU" "Sol" #1=
#2_"*Сэмпер:6353 Semper:Semper:1977-6353*:3107 T-3" "Sol" #2=
#3_"1977-6353*:*Сэмпер:6353 Semper:Semper:3107 T-3" "Sol" #3=
".:Semper:6353 Semper:1977-6353*:3107 T-3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.462860771028
		SemiMajorAxis	3.101758301037
		Eccentricity	0.154805104083
		Inclination	2.527903846415
		AscendingNode	31.81506964505
		ArgOfPericenter	58.681412782241
		MeanAnomaly	246.840649466737
	}
	UniformRotation
	{
		Period	24
	}
	LunarLambert	0.5
	Albedo	0.0962
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6353"
}

#1_"6355 Univermoscow:Univermoscow:1969 TX5:1981 UE21:1981 WP7:1986 TT1" "Sol" #1=
#2_"*Универмоскоу:6355 Univermoscow:Univermoscow:1969 TX5" "Sol" #2=
#3_"1969 TX5:*Универмоскоу:6355 Univermoscow:Univermoscow" "Sol" #3=
".:Univermoscow:6355 Univermoscow:1969 TX5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.19
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.730591004066
		SemiMajorAxis	3.202291094685
		Eccentricity	0.078518575604
		Inclination	22.397506376935
		AscendingNode	24.073642656692
		ArgOfPericenter	234.781009832534
		MeanAnomaly	65.795655462716
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0663
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6355"
}

#1_"6359 Dubinin:Dubinin:1977 AZ1:1966 DK:1979 MN:1981 UX19" "Sol" #1=
#2_"*Дубинин:6359 Dubinin:Dubinin:1977 AZ1" "Sol" #2=
#3_"1977 AZ1:*Дубинин:6359 Dubinin:Dubinin" "Sol" #3=
".:Dubinin:6359 Dubinin:1977 AZ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.735
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.759579204343
		SemiMajorAxis	3.21308120559
		Eccentricity	0.100615935521
		Inclination	10.735112855247
		AscendingNode	89.350948850883
		ArgOfPericenter	35.890777301898
		MeanAnomaly	194.825102915325
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0448
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6359"
}

#1_"6362 Tunis:Tunis:1979 KO:1971 BC1:1981 YA2" "Sol" #1=
#2_"*Тунис:6362 Tunis:Tunis:1979 KO" "Sol" #2=
#3_"1979 KO:*Тунис:6362 Tunis:Tunis" "Sol" #3=
".:Tunis:6362 Tunis:1979 KO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.79
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.707099716171
		SemiMajorAxis	3.193533716236
		Eccentricity	0.171579050833
		Inclination	19.112741732326
		AscendingNode	105.319154981751
		ArgOfPericenter	298.5095201458
		MeanAnomaly	325.307516701718
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0373
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6362"
}

#1_"6372 Walker:Walker:1985 JW1:1939 KD:1979 HV5:1992 QJ2:1993 VL" "Sol" #1=
#2_"*Валкер:6372 Walker:Walker:1985 JW1" "Sol" #2=
#3_"1985 JW1:*Валкер:6372 Walker:Walker" "Sol" #3=
".:Walker:6372 Walker:1985 JW1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.02
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.685372252449
		SemiMajorAxis	3.185423176328
		Eccentricity	0.159063534574
		Inclination	15.796908215574
		AscendingNode	64.086025396307
		ArgOfPericenter	188.305145997833
		MeanAnomaly	45.02322310439
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0443
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6372"
}

#1_"6392 Takashimizuno:Takashimizuno:1990 HR:1986 VZ5" "Sol" #1=
#2_"*Такашимицуно:6392 Takashimizuno:Takashimizuno:1990 HR" "Sol" #2=
#3_"1990 HR:*Такашимицуно:6392 Takashimizuno:Takashimizuno" "Sol" #3=
".:Takashimizuno:6392 Takashimizuno:1990 HR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.275
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.766598400914
		SemiMajorAxis	3.215691196044
		Eccentricity	0.134779741333
		Inclination	17.611781650422
		AscendingNode	53.205059357624
		ArgOfPericenter	248.16281791562
		MeanAnomaly	37.214105746989
	}
	UniformRotation
	{
		Period	21.81
	}
	LunarLambert	0.5
	Albedo	0.0754
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6392"
}

#1_"6403 Steverin:Steverin:1991 NU:1992 US6" "Sol" #1=
#2_"*Стеверин:6403 Steverin:Steverin:1991 NU" "Sol" #2=
#3_"1991 NU:*Стеверин:6403 Steverin:Steverin" "Sol" #3=
".:Steverin:6403 Steverin:1991 NU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6403 steverin.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.438
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.181523519453
		SemiMajorAxis	2.595479249287
		Eccentricity	0.122751090025
		Inclination	14.304042496449
		AscendingNode	228.700352244309
		ArgOfPericenter	64.631320109576
		MeanAnomaly	256.515206588788
	}
	UniformRotation
	{
		Period	3.4905
	}
	LunarLambert	0.5
	Albedo	0.492
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6403"
}

#1_"6404 Vanavara:Vanavara:1991 PS6:1978 EQ1:1989 EY" "Sol" #1=
#2_"*Ванавара:6404 Vanavara:Vanavara:1991 PS6" "Sol" #2=
#3_"1991 PS6:*Ванавара:6404 Vanavara:Vanavara" "Sol" #3=
".:Vanavara:6404 Vanavara:1991 PS6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.465
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.359986432178
		SemiMajorAxis	3.062694359672
		Eccentricity	0.093832617945
		Inclination	4.275591051024
		AscendingNode	109.716891332273
		ArgOfPericenter	44.205594042447
		MeanAnomaly	290.977167652821
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0279
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6404"
}

#1_"6406 Mikejura:Mikejura:1992 MJ:1977 BB:1978 GY4:1979 YN6:1991 CT2:1991 DQ2:1991 ET5:1993 XV2" "Sol" #1=
#2_"*Майклджура:6406 Mikejura:Mikejura:1992 MJ" "Sol" #2=
#3_"1992 MJ:Mikejura:*Майклджура:6406 Mikejura" "Sol" #3=
".:Mikejura:6406 Mikejura:1992 MJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6406 mikejura.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.031
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.432356452826
		SemiMajorAxis	2.275391444032
		Eccentricity	0.178506910615
		Inclination	8.177060663459
		AscendingNode	146.220420242538
		ArgOfPericenter	205.73744563506
		MeanAnomaly	355.69820007049
	}
	UniformRotation
	{
		Period	6.819
	}
	LunarLambert	0.5
	Albedo	0.512
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6406"
}

#1_"6410 Fujiwara:Fujiwara:1992 WO4:1977 LP:1978 XK1:1986 JW:1987 SL27:1987 UE8" "Sol" #1=
#2_"*Фудзивара:6410 Fujiwara:Fujiwara:1992 WO4" "Sol" #2=
#3_"1992 WO4:Fujiwara:*Фудзивара:6410 Fujiwara" "Sol" #3=
".:Fujiwara:6410 Fujiwara:1992 WO4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6410 fujiwara.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	7.411
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.61076445618
		SemiMajorAxis	2.770191694673
		Eccentricity	0.226637578841
		Inclination	8.679657499918
		AscendingNode	76.536941122973
		ArgOfPericenter	250.130073164762
		MeanAnomaly	168.549141457723
	}
	UniformRotation
	{
		Period	7.0073
	}
	LunarLambert	0.5
	Albedo	0.082
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6410"
}

#1_"6422 Akagi:Akagi:1994 CD1:1986 HH1:1991 NQ4" "Sol" #1=
#2_"*Акаги:6422 Akagi:Akagi:1994 CD1" "Sol" #2=
#3_"1994 CD1:Akagi:*Акаги:6422 Akagi" "Sol" #3=
".:Akagi:6422 Akagi:1994 CD1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6422 akagi.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.542
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.25373268879
		SemiMajorAxis	2.625274146065
		Eccentricity	0.150486350736
		Inclination	14.621299969642
		AscendingNode	126.524105299211
		ArgOfPericenter	167.42473180637
		MeanAnomaly	11.960620528029
	}
	UniformRotation
	{
		Period	7.7476
	}
	LunarLambert	0.5
	Albedo	0.257
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6422"
}

#1_"6453 1991 NY:1991 NY:1950 QF1:1979 WT1:1987 SF30:1987 SG23" "Sol" #1=
#2_"1991 NY:6453 1991 NY" "Sol" #2=
#3_"1991 NY:6453 1991 NY" "Sol" #3=
".:1991 NY:6453 1991 NY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.089092819856
		SemiMajorAxis	2.557089002439
		Eccentricity	0.329236663315
		Inclination	5.041869799928
		AscendingNode	196.373731470152
		ArgOfPericenter	111.645330024363
		MeanAnomaly	253.325497881871
	}
	UniformRotation
	{
		Period	15
	}
	LunarLambert	0.5
	Albedo	0.1032
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6453"
}

#1_"6475 Refugium:Refugium:1987 SZ6:1965 TB" "Sol" #1=
#2_"*Рефугиум:6475 Refugium:Refugium:1987 SZ6" "Sol" #2=
#3_"1987 SZ6:*Рефугиум:6475 Refugium:Refugium" "Sol" #3=
".:Refugium:6475 Refugium:1987 SZ6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	16.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.566156169749
		SemiMajorAxis	3.140736173931
		Eccentricity	0.164867375558
		Inclination	8.926915602549
		AscendingNode	277.220459809953
		ArgOfPericenter	75.879061347037
		MeanAnomaly	326.043302264521
	}
	UniformRotation
	{
		Period	8.07
	}
	LunarLambert	0.5
	Albedo	0.1136
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6475"
}

#1_"6479 Leoconnolly:Leoconnolly:1988 LC:1958 GO:1992 JG4:1993 SO5" "Sol" #1=
#2_"*Леоконнолли:6479 Leoconnolly:Leoconnolly:1988 LC" "Sol" #2=
#3_"1988 LC:*Леоконнолли:6479 Leoconnolly:Leoconnolly" "Sol" #3=
".:Leoconnolly:6479 Leoconnolly:1988 LC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.51
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.219301308507
		SemiMajorAxis	2.611088299682
		Eccentricity	0.186223193459
		Inclination	13.288747984047
		AscendingNode	161.865204851797
		ArgOfPericenter	51.854898057407
		MeanAnomaly	129.917739395711
	}
	UniformRotation
	{
		Period	5.11
	}
	LunarLambert	0.5
	Albedo	0.0507
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6479"
}

#1_"6487 Tonyspear:Tonyspear:1991 GA1:1973 JB:1988 RF8" "Sol" #1=
#2_"*Тониспир:6487 Tonyspear:Tonyspear:1991 GA1" "Sol" #2=
#3_"1991 GA1:Tonyspear:*Тониспир:6487 Tonyspear" "Sol" #3=
".:Tonyspear:6487 Tonyspear:1991 GA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6487 tonyspear.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.004
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.618718096994
		SemiMajorAxis	2.357025964745
		Eccentricity	0.304729801537
		Inclination	21.26828727845
		AscendingNode	187.496382588198
		ArgOfPericenter	92.849371092407
		MeanAnomaly	2.306038016199
	}
	UniformRotation
	{
		Period	74.91
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6487"
}

#1_"6489 Golevka:Golevka:1991 JX" "Sol" #1=
#2_"*Голевка:6489 Golevka:Golevka:1991 JX" "Sol" #2=
#3_"1991 JX:*Голевка:6489 Golevka:Golevka" "Sol" #3=
".:Golevka:6489 Golevka:1991 JX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6489 golevka.cmod"
	MeshCenter	[ -0.0289 -0.0111 -0.0331 ]
	Texture	"golevka.jpg"
	Radius	0.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2451986.5  # 2001 Mar 18
		Period	3.9821799646425
		SemiMajorAxis	2.512320953350836
		Eccentricity	0.6009767835157114
		Inclination	2.287528857325901
		AscendingNode	212.1865625269534
		ArgOfPericenter	65.22830030999425
		MeanAnomaly	156.4488038691053
	}
	UniformRotation
	{
		Period	6.0289
		Inclination	135
		AscendingNode	292
	}
	LunarLambert	0.5
	Albedo	0.151
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6489"
}

#1_"6510 Tarry:Tarry:1987 DF" "Sol" #1=
#2_"*Тарри:6510 Tarry:Tarry:1987 DF" "Sol" #2=
#3_"1987 DF:Tarry:*Тарри:6510 Tarry" "Sol" #3=
".:Tarry:6510 Tarry:1987 DF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6510 tarry.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.331
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.620719089208
		SemiMajorAxis	2.357894772599
		Eccentricity	0.225145156934
		Inclination	23.004630682531
		AscendingNode	159.850512878297
		ArgOfPericenter	88.778171457646
		MeanAnomaly	33.012152454504
	}
	UniformRotation
	{
		Period	6.37
	}
	LunarLambert	0.5
	Albedo	0.331
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6510"
}

#1_"6517 Buzzi:Buzzi:1990 BW" "Sol" #1=
#2_"*Буцци:6517 Buzzi:Buzzi:1990 BW" "Sol" #2=
#3_"1990 BW:Buzzi:*Буцци:6517 Buzzi:1990 BW" "Sol" #3=
".:Buzzi:6517 Buzzi:1990 BW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6517 buzzi.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.673360093184
		SemiMajorAxis	1.926191693541
		Eccentricity	0.047811468942
		Inclination	23.417168076748
		AscendingNode	125.982591532089
		ArgOfPericenter	150.754181076235
		MeanAnomaly	251.919707331878
	}
	UniformRotation
	{
		Period	8.648
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6517"
}

#1_"6570 Tomohiro:Tomohiro:1994 JO:1983 JE1:1985 SO5:1985 UQ5:1986 XS4:1991 UH2" "Sol" #1=
#2_"*Томохиро:6570 Tomohiro:Tomohiro:1994 JO" "Sol" #2=
#3_"1994 JO:*Томохиро:6570 Tomohiro:Tomohiro" "Sol" #3=
".:Tomohiro:6570 Tomohiro:1994 JO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.546399406769
		SemiMajorAxis	3.133299857745
		Eccentricity	0.170993436724
		Inclination	14.426487097419
		AscendingNode	215.443667059438
		ArgOfPericenter	323.628529586314
		MeanAnomaly	292.821322283364
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0546
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6570"
}

#1_"6574 Gvishiani:Gvishiani:1976 QE1:1968 DA1:1982 QW1" "Sol" #1=
#2_"*Гвишиани:6574 Gvishiani:Gvishiani:1976 QE1" "Sol" #2=
#3_"1976 QE1:*Гвишиани:6574 Gvishiani:Gvishiani" "Sol" #3=
".:Gvishiani:6574 Gvishiani:1976 QE1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	12.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.272934252099
		SemiMajorAxis	3.401274545511
		Eccentricity	0.191189397782
		Inclination	17.710512711623
		AscendingNode	349.397339058443
		ArgOfPericenter	241.11540105353
		MeanAnomaly	139.63009105585
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1257
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6574"
}

#1_"6590 Barolo:Barolo:1985 TA2:1969 RT:1975 XU3:1987 DZ4:1990 SO15" "Sol" #1=
#2_"*Бароло:6590 Barolo:Barolo:1985 TA2:1969 RT" "Sol" #2=
#3_"1985 TA2:Barolo:*Бароло:6590 Barolo:1969 RT" "Sol" #3=
".:Barolo:6590 Barolo:1985 TA2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6590 barolo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.2572293352
		SemiMajorAxis	3.023424631349
		Eccentricity	0.10354555543
		Inclination	8.99082710748
		AscendingNode	304.442916806965
		ArgOfPericenter	100.952379350691
		MeanAnomaly	321.996555063814
	}
	UniformRotation
	{
		Period	8.35928
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6590"
}

#1_"6606 Makino:Makino:1990 UF:1977 EQ6:1979 SS7:1979 TG1" "Sol" #1=
#2_"*Макино:6606 Makino:Makino:1990 UF:1977 EQ6:1979 SS7" "Sol" #2=
#3_"1990 UF:*Макино:6606 Makino:Makino:1977 EQ6:1979 SS7" "Sol" #3=
".:Makino:6606 Makino:1990 UF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.465507446034
		SemiMajorAxis	3.102760057415
		Eccentricity	0.171232000529
		Inclination	5.021912692257
		AscendingNode	207.709925581905
		ArgOfPericenter	114.532440658013
		MeanAnomaly	197.517508977566
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0287
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6606"
}

#1_"6613 Williamcarl:Williamcarl:1994 LK:1989 TA1" "Sol" #1=
#2_"*Уильямкарл:6613 Williamcarl:Williamcarl:1994 LK" "Sol" #2=
#3_"1994 LK:*Уильямкарл:6613 Williamcarl:Williamcarl" "Sol" #3=
".:Williamcarl:6613 Williamcarl:1994 LK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.622478095804
		SemiMajorAxis	3.161887254454
		Eccentricity	0.173437729695
		Inclination	25.453231246193
		AscendingNode	199.394530985612
		ArgOfPericenter	90.624632287929
		MeanAnomaly	218.673413524001
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.043
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6613"
}

#1_"6619 Kolya:Kolya:1973 SS4:1962 WJ1:1973 UB3:1990 TM15:1990 UH6" "Sol" #1=
#2_"*Коля:6619 Kolya:Kolya:1973 SS4" "Sol" #2=
#3_"1973 SS4:*Коля:6619 Kolya:Kolya" "Sol" #3=
".:Kolya:6619 Kolya:1973 SS4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	13.535
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.644077642526
		SemiMajorAxis	3.169979970526
		Eccentricity	0.187582032246
		Inclination	19.093834334468
		AscendingNode	17.998162944328
		ArgOfPericenter	112.651173521326
		MeanAnomaly	22.52118445382
	}
	UniformRotation
	{
		Period	10.5011
	}
	LunarLambert	0.5
	Albedo	0.1266
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6619"
}

#1_"6621 Timchuk:Timchuk:1975 VN5:1975 XB4:1991 RF26" "Sol" #1=
#2_"*Тимчук:6621 Timchuk:Timchuk:1975 VN5" "Sol" #2=
#3_"1975 VN5:*Тимчук:6621 Timchuk:Timchuk" "Sol" #3=
".:Timchuk:6621 Timchuk:1975 VN5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.86
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.051688520412
		SemiMajorAxis	2.541471432998
		Eccentricity	0.244882330112
		Inclination	7.116343113413
		AscendingNode	124.550331509942
		ArgOfPericenter	254.02199944989
		MeanAnomaly	255.199540006836
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0512
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6621"
}

#1_"6631 Pyatnitskij:Pyatnitskij:1983 RQ4:1987 SR" "Sol" #1=
#2_"*Пятницкий:6631 Pyatnitskij:Pyatnitskij:1983 RQ4" "Sol" #2=
#3_"1983 RQ4:*Пятницкий:6631 Pyatnitskij:Pyatnitskij" "Sol" #3=
".:Pyatnitskij:6631 Pyatnitskij:1983 RQ4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.175
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.879932860083
		SemiMajorAxis	2.469130280105
		Eccentricity	0.148512301816
		Inclination	7.134176979916
		AscendingNode	192.147282253346
		ArgOfPericenter	205.382508711328
		MeanAnomaly	334.037172151385
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0494
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6631"
}

#1_"6648 1991 PM11:1991 PM11:1926 SB:1978 LD:1987 RR6:1987 SA27" "Sol" #1=
#2_"1991 PM11:6648 1991 PM11" "Sol" #2=
#3_"1991 PM11:6648 1991 PM11" "Sol" #3=
".:1991 PM11:6648 1991 PM11" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.795
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.064787161226
		SemiMajorAxis	2.546946008182
		Eccentricity	0.241128994869
		Inclination	4.785271390977
		AscendingNode	327.525380583866
		ArgOfPericenter	33.945344234777
		MeanAnomaly	253.886536834888
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1937
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6648"
}

#1_"6671 Concari:Concari:1994 NC1:1949 HH:1954 JF:1983 EG1:9517 P-L" "Sol" #1=
#2_"*Конкари:6671 Concari:Concari:1994 NC1" "Sol" #2=
#3_"1994 NC1:Concari:*Конкари:6671 Concari" "Sol" #3=
".:Concari:6671 Concari:1994 NC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6671 concari.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	5.478
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.919392040774
		SemiMajorAxis	2.892469720277
		Eccentricity	0.155115115329
		Inclination	14.709939351334
		AscendingNode	180.34882886
		ArgOfPericenter	97.950569293162
		MeanAnomaly	224.03300127482
	}
	UniformRotation
	{
		Period	5.2204
	}
	LunarLambert	0.5
	Albedo	0.071
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6671"
}

#1_"6687 Lahulla:Lahulla:1980 FN1:1978 SO6:1988 RW1" "Sol" #1=
#2_"*Лахулла:6687 Lahulla:Lahulla:1980 FN1" "Sol" #2=
#3_"1980 FN1:*Лахулла:6687 Lahulla:Lahulla" "Sol" #3=
".:Lahulla:6687 Lahulla:1980 FN1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.625
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.395864007003
		SemiMajorAxis	2.259234918029
		Eccentricity	0.020704983479
		Inclination	0.535734072416
		AscendingNode	80.490256766896
		ArgOfPericenter	310.230525110382
		MeanAnomaly	223.482869676192
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0192
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6687"
}

#1_"6719 Gallaj:Gallaj:1990 UL11:1985 SO4:1990 WM9:1992 CE5:1992 EP18" "Sol" #1=
#2_"*Галлай:6719 Gallaj:Gallaj:1990 UL11" "Sol" #2=
#3_"1990 UL11:Gallaj:*Галлай:6719 Gallaj" "Sol" #3=
".:Gallaj:6719 Gallaj:1990 UL11" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6719 gallaj.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.066
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.578786782165
		SemiMajorAxis	2.757368513923
		Eccentricity	0.081467892435
		Inclination	3.224145455287
		AscendingNode	76.537877259488
		ArgOfPericenter	315.232169055749
		MeanAnomaly	275.597124287386
	}
	UniformRotation
	{
		Period	4.4305
	}
	LunarLambert	0.5
	Albedo	0.203
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6719"
}

#1_"6755 Solov'yanenko:Solov'yanenko:1976 YE1:1972 VU:1987 ST24:1990 ME2:1990 MR1:1991 TU4" "Sol" #1=
#2_"*Соловяненко:6755 Solov'yanenko:Solov'yanenko:1976 YE1" "Sol" #2=
#3_"1976 YE1:Solov'yanenko:*Соловяненко:6755 Solov'yanenko" "Sol" #3=
".:Solov'yanenko:6755 Solov'yanenko:1976 YE1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6755 solovyanenko.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.815536573956
		SemiMajorAxis	2.441733597843
		Eccentricity	0.043209104157
		Inclination	4.735027952001
		AscendingNode	279.655723037192
		ArgOfPericenter	145.023618976996
		MeanAnomaly	200.411541540777
	}
	UniformRotation
	{
		Period	8.1681
	}
	LunarLambert	0.5
	Albedo	0.222
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6755"
}

#1_"6779 Perrine:Perrine:1990 DM1:1973 EH" "Sol" #1=
#2_"*Перрине:6779 Perrine:Perrine:1990 DM1" "Sol" #2=
#3_"1990 DM1:*Перрине:6779 Perrine:Perrine" "Sol" #3=
".:Perrine:6779 Perrine:1990 DM1:1973 EH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.388597522829
		SemiMajorAxis	2.256010887253
		Eccentricity	0.107697385783
		Inclination	1.847704254865
		AscendingNode	314.200317612307
		ArgOfPericenter	200.127229785952
		MeanAnomaly	109.806876073138
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.033
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6779"
}

#1_"6785 1990 VA7:1990 VA7:1967 UK:1973 YM:1978 TH4:1979 YL2:1984 UU4" "Sol" #1=
#2_"1990 VA7:6785 1990 VA7" "Sol" #2=
#3_"1990 VA7:6785 1990 VA7" "Sol" #3=
".:1990 VA7:6785 1990 VA74" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.69267864765
		SemiMajorAxis	3.188151696402
		Eccentricity	0.098423304485
		Inclination	20.059227854268
		AscendingNode	46.279905552991
		ArgOfPericenter	119.656839147135
		MeanAnomaly	348.614414854569
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0849
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6785"
}

#1_"6794 Masuisakura:Masuisakura:1992 DK:1946 UJ:1957 YY:1968 YA:1973 UW3:1979 YK2" "Sol" #1=
#2_"*Масуисакура:6794 Masuisakura:Masuisakura:1992 DK" "Sol" #2=
#3_"1992 DK:*Масуисакура:6794 Masuisakura:Masuisakura" "Sol" #3=
".:Masuisakura:6794 Masuisakura:1992 DK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.410606832176
		SemiMajorAxis	3.081947120362
		Eccentricity	0.213237709752
		Inclination	16.33526366542
		AscendingNode	41.086207362699
		ArgOfPericenter	349.121254477807
		MeanAnomaly	195.324022001426
	}
	UniformRotation
	{
		Period	4.58
	}
	LunarLambert	0.5
	Albedo	0.0978
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6794"
}

#1_"6862 Virgiliomarcon:Virgiliomarcon:1991 GL:1954 UP:1988 UJ1" "Sol" #1=
#2_"*Виргилиомаркон:6862 Virgiliomarcon:Virgiliomarcon:1991 GL" "Sol" #2=
#3_"1991 GL:*Виргилиомаркон:6862 Virgiliomarcon:Virgiliomarcon" "Sol" #3=
".:Virgiliomarcon:6862 Virgiliomarcon:1991 GL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.657018437234
		SemiMajorAxis	3.174823560878
		Eccentricity	0.017844629108
		Inclination	12.096386900051
		AscendingNode	17.678481885864
		ArgOfPericenter	39.639810672911
		MeanAnomaly	200.260644801071
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0624
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6862"
}

#1_"6868 Seiyauyeda:Seiyauyeda:1992 HD:1973 YU3:1976 SN9:1979 HR4:A905 FA" "Sol" #1=
#2_"*Сейяуеда:6868 Seiyauyeda:Seiyauyeda:1992 HD" "Sol" #2=
#3_"1992 HD:*Сейяуеда:6868 Seiyauyeda:Seiyauyeda" "Sol" #3=
".:Seiyauyeda:6868 Seiyauyeda:1992 HD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.52
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.340551863996
		SemiMajorAxis	2.660875154535
		Eccentricity	0.149793522814
		Inclination	3.377535026025
		AscendingNode	120.07920515
		ArgOfPericenter	84.848880535988
		MeanAnomaly	85.765470818
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0493
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6868"
}

#1_"6879 Hyogo:Hyogo:1994 TC15:1977 RJ1:1985 DV:1988 SM1:1992 LZ" "Sol" #1=
#2_"*Хиого:6879 Hyogo:Hyogo:1994 TC15" "Sol" #2=
#3_"1994 TC15:*Хиого:6879 Hyogo:Hyogo" "Sol" #3=
".:Hyogo:6879 Hyogo:1994 TC15" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.510058993854
		SemiMajorAxis	3.119598462401
		Eccentricity	0.176220315355
		Inclination	8.571518726029
		AscendingNode	103.06563823756
		ArgOfPericenter	307.275611584148
		MeanAnomaly	233.542381999218
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0535
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6879"
}

#1_"6882 Sormano:Sormano:1995 CC1:1986 XM2:1989 OW:1993 OQ" "Sol" #1=
#2_"*Сормано:6882 Sormano:Sormano:1995 CC1" "Sol" #2=
#3_"1995 CC1:Sormano:*Сормано:6882 Sormano" "Sol" #3=
".:Sormano:6882 Sormano:1995 CC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6882 sormano.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.048
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.079115443344
		SemiMajorAxis	2.552927781775
		Eccentricity	0.099076188197
		Inclination	14.387229900666
		AscendingNode	284.206155027197
		ArgOfPericenter	15.840453695722
		MeanAnomaly	279.148146288572
	}
	UniformRotation
	{
		Period	3.6901
	}
	LunarLambert	0.5
	Albedo	0.269
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6882"
}

#1_"6895 1987 DG6:1987 DG6:1957 HX:1983 EX1:1984 QA1" "Sol" #1=
#2_"1987 DG6:6895 1987 DG6" "Sol" #2=
#3_"1987 DG6:6895 1987 DG6" "Sol" #3=
".:1987 DG6:6895 1987 DG6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.03
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.360898464129
		SemiMajorAxis	2.66918401404
		Eccentricity	0.164747454307
		Inclination	1.130249612077
		AscendingNode	296.159641713723
		ArgOfPericenter	328.619505155642
		MeanAnomaly	42.744872040264
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0273
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6895"
}

#1_"6905 Miyazaki:Miyazaki:1990 TW:1951 KB:1952 WG:1967 EO1:1973 SO5:1977 OY:1990 UY12:1994 SF" "Sol" #1=
#2_"*Мидзаки:6905 Miyazaki:Miyazaki:1990 TW" "Sol" #2=
#3_"1990 TW:Miyazaki:*Мидзаки:6905 Miyazaki" "Sol" #3=
".:Miyazaki:6905 Miyazaki:1990 TW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"6905 miyazaki.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.638
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.22870987051
		SemiMajorAxis	2.614968478459
		Eccentricity	0.194883179318
		Inclination	13.456648076133
		AscendingNode	48.456569047255
		ArgOfPericenter	306.82536390398
		MeanAnomaly	107.334479515041
	}
	UniformRotation
	{
		Period	2.7418
	}
	LunarLambert	0.5
	Albedo	0.221
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6905"
}

#1_"6925 Susumu:Susumu:1993 UW2:1964 TF2:1972 HP1:1976 DL:1987 MV" "Sol" #1=
#2_"*Сусуму:6925 Susumu:Susumu:1993 UW2" "Sol" #2=
#3_"1993 UW2:*Сусуму:6925 Susumu:Susumu" "Sol" #3=
".:Susumu:6925 Susumu:1993 UW2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.51
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.771798105375
		SemiMajorAxis	2.834322332645
		Eccentricity	0.099762923117
		Inclination	14.205894297154
		AscendingNode	207.517195773584
		ArgOfPericenter	85.425791853735
		MeanAnomaly	259.970198897706
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0481
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6925"
}

#1_"6939 Lestone:Lestone:1952 SW1:4849 T-1" "Sol" #1=
#2_"*Лестоне:6939 Lestone:Lestone:1952 SW1" "Sol" #2=
#3_"1952 SW1:*Лестоне:6939 Lestone:Lestone" "Sol" #3=
".:Lestone:6939 Lestone:1952 SW1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.31
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.164613595882
		SemiMajorAxis	2.588477177758
		Eccentricity	0.103054852173
		Inclination	14.101043728053
		AscendingNode	36.511483127176
		ArgOfPericenter	185.225806931532
		MeanAnomaly	146.256778880323
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0212
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6939"
}

#1_"6974 Solti:Solti:1992 MC:1941 HE:1959 RF:1980 RZ4:1995 DO" "Sol" #1=
#2_"*Солти:6974 Solti:Solti:1992 MC" "Sol" #2=
#3_"1992 MC:*Солти:6974 Solti:Solti" "Sol" #3=
".:Solti:6974 Solti:1992 MC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	7.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.191559707026
		SemiMajorAxis	2.599630576354
		Eccentricity	0.140264431027
		Inclination	15.793404175652
		AscendingNode	166.041396593666
		ArgOfPericenter	201.759381644782
		MeanAnomaly	47.619018188394
	}
	UniformRotation
	{
		Period	2.423
	}
	LunarLambert	0.5
	Albedo	0.1381
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6974"
}

#1_"6984 Lewiscarroll:Lewiscarroll:1994 AO:1953 UQ:1969 VZ2:1972 HK1" "Sol" #1=
#2_"*Льюискэрролл:6984 Lewiscarroll:Lewiscarroll:1994 AO" "Sol" #2=
#3_"1994 AO:*Льюискэрролл:6984 Lewiscarroll:Lewiscarroll" "Sol" #3=
".:Lewiscarroll:6984 Lewiscarroll:1994 AO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.935760142673
		SemiMajorAxis	3.978507859946
		Eccentricity	0.189099604799
		Inclination	16.791346983263
		AscendingNode	206.224473769303
		ArgOfPericenter	248.085885988016
		MeanAnomaly	229.373259942414
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0425
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6984"
}

#1_"6989 Hoshinosato:Hoshinosato:1994 XH1:1981 JP1:1981 KC:1988 RP13" "Sol" #1=
#2_"*Хошиносато:6989 Hoshinosato:Hoshinosato:1994 XH1" "Sol" #2=
#3_"1994 XH1:*Хошиносато:6989 Hoshinosato:Hoshinosato" "Sol" #3=
".:Hoshinosato:6989 Hoshinosato:1994 XH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.219642802918
		SemiMajorAxis	3.008996766554
		Eccentricity	0.094193490218
		Inclination	9.395726078542
		AscendingNode	292.821161964921
		ArgOfPericenter	133.567604777237
		MeanAnomaly	323.090538684791
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1725
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=6989"
}

#1_"7001 Noether:Noether:1955 EH:1977 CB1:1988 CD1" "Sol" #1=
#2_"*Нётер:7001 Noether:Noether:1955 EH" "Sol" #2=
#3_"1955 EH:Noether:*Нётер:7001 Noether" "Sol" #3=
".:Noether:7001 Noether:1955 EH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7001 noether.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.061
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.670996575248
		SemiMajorAxis	2.379672461012
		Eccentricity	0.150404470453
		Inclination	7.026078162285
		AscendingNode	151.765478612045
		ArgOfPericenter	278.41727433383
		MeanAnomaly	22.00222212087
	}
	UniformRotation
	{
		Period	9.581
	}
	LunarLambert	0.5
	Albedo	0.216
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7001"
}

#1_"7019 Tagayuichan:Tagayuichan:1992 EM1:1970 EF1:1994 WY3" "Sol" #1=
#2_"*Tagayuichan:7019 Tagayuichan:Tagayuichan:1992 EM1" "Sol" #2=
#3_"1992 EM1:*Tagayuichan:7019 Tagayuichan:Tagayuichan" "Sol" #3=
".:Tagayuichan:7019 Tagayuichan:1992 EM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.11
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.636767453931
		SemiMajorAxis	2.364857009573
		Eccentricity	0.156731955418
		Inclination	11.416686355878
		AscendingNode	100.591914763689
		ArgOfPericenter	26.608109486591
		MeanAnomaly	135.141669252235
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0889
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7019"
}

#1_"7043 Godart:Godart:1934 RB:1974 KJ:1978 US:1987 FZ1:1992 YA" "Sol" #1=
#2_"*Годар:7043 Godart:Godart:1934 RB" "Sol" #2=
#3_"1934 RB:*Годар:7043 Godart:Godart" "Sol" #3=
".:Godart:7043 Godart:1934 RB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7043 godart.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.86
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.362901738237
		SemiMajorAxis	2.244591515483
		Eccentricity	0.186546939232
		Inclination	5.997616793642
		AscendingNode	163.438594440106
		ArgOfPericenter	130.040746597778
		MeanAnomaly	42.99124204282
	}
	UniformRotation
	{
		Period	8.4531
	}
	LunarLambert	0.5
	Albedo	0.225
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7043"
}

#1_"7050 1982 FE3:1982 FE3:1983 RT8:1987 KE:1996 KU" "Sol" #1=
#2_"1982 FE3:7050 1982 FE3" "Sol" #2=
#3_"1982 FE3:7050 1982 FE3" "Sol" #3=
".:1982 FE3:7050 1982 FE3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.677892867103
		SemiMajorAxis	2.79701446748
		Eccentricity	0.185463083056
		Inclination	7.759720811163
		AscendingNode	20.724158912125
		ArgOfPericenter	246.208980259759
		MeanAnomaly	302.913136773878
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7050"
}

#1_"7052 1988 VQ2:1988 VQ2:1992 NK" "Sol" #1=
#2_"1988 VQ2:7052 1988 VQ2" "Sol" #2=
#3_"1988 VQ2:7052 1988 VQ2" "Sol" #3=
".:1988 VQ2:7052 1988 VQ2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.474006933871
		SemiMajorAxis	2.715140453104
		Eccentricity	0.284785502856
		Inclination	17.558330809557
		AscendingNode	57.037432032074
		ArgOfPericenter	288.255025643842
		MeanAnomaly	338.730291566573
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1682
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7052"
}

#1_"7066 Nessus:Nessus:1993 HA2" "Sol" #1=
#2_"*Несс:7066 Nessus:Nessus:1993 HA2" "Sol" #2=
#3_"1993 HA2:*Несс:7066 Nessus:Nessus" "Sol" #3=
".:Nessus:7066 Nessus:1993 HA2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	30
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	121.081363033801
		SemiMajorAxis	24.474438262035
		Eccentricity	0.519512354761
		Inclination	15.656435819463
		AscendingNode	31.236311584036
		ArgOfPericenter	170.25142471994
		MeanAnomaly	67.964504646214
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7066"
}

#1_"7072 Beijingdaxue:Beijingdaxue:1996 CB8:1977 EF9:1977 EW2:1988 CY1:1992 CU1:1994 XU5" "Sol" #1=
#2_"*БэйЦзинДаСюэ:7072 Beijingdaxue:Beijingdaxue:1996 CB8" "Sol" #2=
#3_"1996 CB8:Beijingdaxue:*БэйЦзинДаСюэ:7072 Beijingdaxue" "Sol" #3=
".:Beijingdaxue:7072 Beijingdaxue:1996 CB8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7072 beijingdaxue.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.086
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.756481367562
		SemiMajorAxis	2.416473431369
		Eccentricity	0.149564722028
		Inclination	0.100430300371
		AscendingNode	145.707148671124
		ArgOfPericenter	92.114897875552
		MeanAnomaly	166.043616252744
	}
	UniformRotation
	{
		Period	5.3041
	}
	LunarLambert	0.5
	Albedo	0.212
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7072"
}

#1_"7083 Kant:Kant:1989 CL3:1973 TT:1978 WF2" "Sol" #1=
#2_"*Кант:7083 Kant:Kant:1989 CL3" "Sol" #2=
#3_"1989 CL3:*Кант:7083 Kant:Kant" "Sol" #3=
".:Kant:7083 Kant:1989 CL3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.17
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.699053418139
		SemiMajorAxis	2.8054430252
		Eccentricity	0.227311011131
		Inclination	6.825256049837
		AscendingNode	241.772022126125
		ArgOfPericenter	147.706382368399
		MeanAnomaly	262.369267070901
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1161
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7083"
}

#1_"7088 Ishtar:Ishtar:1992 AA" "Sol" #1=
#2_"*Иштар:7088 Ishtar:Ishtar:1992 AA" "Sol" #2=
#3_"1992 AA:*Иштар:7088 Ishtar:Ishtar" "Sol" #3=
".:Ishtar:7088 Ishtar:1992 AA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.695
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.787339278023
		SemiMajorAxis	1.980558865938
		Eccentricity	0.39068059631
		Inclination	8.300825174122
		AscendingNode	102.685534731762
		ArgOfPericenter	354.698098633188
		MeanAnomaly	79.201485686046
	}
	UniformRotation
	{
		Period	2.679
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7088"
}

#1_"2006 7088 I" "Sol/7088 Ishtar" #1=
#2_"2006 7088 I" "Sol/7088 Ishtar" #2=
#3_"2006 7088 I" "Sol/7088 Ishtar" #3=
".:2006 7088 I" "Sol/7088 Ishtar" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.29
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.8604
		SemiMajorAxis	2.8
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-07088.html"
}

#1_"7092 Cadmus:Cadmus:1992 LC" "Sol" #1=
#2_"*Кадм:7092 Cadmus:Cadmus:1992 LC" "Sol" #2=
#3_"1992 LC:*Кадм:7092 Cadmus:Cadmus" "Sol" #3=
".:Cadmus:7092 Cadmus:1992 LC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.036835041744
		SemiMajorAxis	2.535256280273
		Eccentricity	0.698085812524
		Inclination	17.80786531549
		AscendingNode	57.728543131289
		ArgOfPericenter	93.777630665147
		MeanAnomaly	233.07118062468
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.14
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7092"
}

#1_"7096 Napier:Napier:1992 VM" "Sol" #1=
#2_"*Непер:7096 Napier:Napier:1992 VM" "Sol" #2=
#3_"1992 VM:*Непер:7096 Napier:Napier" "Sol" #3=
".:Napier:7096 Napier:1992 VM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	2.795
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.622314982669
		SemiMajorAxis	2.774816210229
		Eccentricity	0.50433661027
		Inclination	11.225429609093
		AscendingNode	148.705387737183
		ArgOfPericenter	254.970974181002
		MeanAnomaly	279.539053407739
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0428
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7096"
}

#1_"7106 Kondakov:Kondakov:1978 PM3:1993 XA2" "Sol" #1=
#2_"*Кондаков:7106 Kondakov:Kondakov:1978 PM3" "Sol" #2=
#3_"1978 PM3:Kondakov:*Кондаков:7106 Kondakov" "Sol" #3=
".:Kondakov:7106 Kondakov:1978 PM3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7106 kondakov.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.804
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.678251523478
		SemiMajorAxis	2.797157431314
		Eccentricity	0.181133820817
		Inclination	9.920826664608
		AscendingNode	148.022094379795
		ArgOfPericenter	204.651407231793
		MeanAnomaly	68.715430219656
	}
	UniformRotation
	{
		Period	7.5969
	}
	LunarLambert	0.5
	Albedo	0.367
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7106"
}

#1_"7110 Johnpearse:Johnpearse:1983 XH1:1975 BM1:1978 RV2:1978 TN3:1987 QE3" "Sol" #1=
#2_"*Джонпирс:7110 Johnpearse:Johnpearse:1983 XH1" "Sol" #2=
#3_"1983 XH1:*Джонпирс:7110 Johnpearse:Johnpearse" "Sol" #3=
".:Johnpearse:7110 Johnpearse:1983 XH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.681555716245
		SemiMajorAxis	2.798474342086
		Eccentricity	0.205399687761
		Inclination	7.660092719756
		AscendingNode	173.657153745964
		ArgOfPericenter	267.151612353143
		MeanAnomaly	213.361476466197
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0625
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7110"
}

#1_"7119 Hiera:Hiera:1989 AV2" "Sol" #1=
#2_"*Хира:7119 Hiera:Hiera:1989 AV2" "Sol" #2=
#3_"1989 AV2:*Хира:7119 Hiera:Hiera" "Sol" #3=
".:Hiera:7119 Hiera:1989 AV2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.715131216553
		SemiMajorAxis	5.158134195811
		Eccentricity	0.101260758039
		Inclination	19.303831616816
		AscendingNode	285.575676868924
		ArgOfPericenter	121.857609552188
		MeanAnomaly	124.057593773626
	}
	UniformRotation
	{
		Period	400
	}
	LunarLambert	0.5
	Albedo	0.0364
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7119"
}

#1_"7170 Livesey:Livesey:1987 MK:1978 PU4" "Sol" #1=
#2_"*Ливси:7170 Livesey:Livesey:1987 MK" "Sol" #2=
#3_"1987 MK:*Ливси:7170 Livesey:Livesey" "Sol" #3=
".:Livesey:7170 Livesey:1987 MK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.605
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.431584776775
		SemiMajorAxis	2.697950059434
		Eccentricity	0.182470952056
		Inclination	12.507451784032
		AscendingNode	330.723336509726
		ArgOfPericenter	28.244344676023
		MeanAnomaly	34.317505235026
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0998
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7170"
}

#1_"7200 1994 NO:1994 NO" "Sol" #1=
#2_"1994 NO:7200 1994 NO" "Sol" #2=
#3_"1994 NO:7200 1994 NO" "Sol" #3=
".:1994 NO:7200 1994 NO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.66
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.599482326553
		SemiMajorAxis	3.153260016616
		Eccentricity	0.343520183212
		Inclination	20.596673672451
		AscendingNode	236.312305313281
		ArgOfPericenter	88.808488503602
		MeanAnomaly	209.93749890663
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0346
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7200"
}

#1_"7201 Kuritariku:Kuritariku:1994 UF1:1965 UF2:1976 UU4:1983 RH2:1987 WE:1990 RB11" "Sol" #1=
#2_"*Куритарику:7201 Kuritariku:Kuritariku:1994 UF1" "Sol" #2=
#3_"1994 UF1:*Куритарику:7201 Kuritariku:Kuritariku" "Sol" #3=
".:Kuritariku:7201 Kuritariku:1994 UF1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7201 kuritariku.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.738
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.610983534114
		SemiMajorAxis	2.35366619931
		Eccentricity	0.112271508492
		Inclination	7.685095593866
		AscendingNode	47.857468613341
		ArgOfPericenter	352.991039084223
		MeanAnomaly	254.359048014624
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.309
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7201"
}

#1_"7210 Darius:Darius:6555 P-L:1977 GB:1987 FU1:1989 UE6" "Sol" #1=
#2_"*Дарий:7210 Darius:Darius:1960-7210*:6555 P-L" "Sol" #2=
#3_"1960-7210*:*Дарий:7210 Darius:Darius:6555 P-L" "Sol" #3=
".:Darius:7210 Darius:1960-7210*:6555 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.125
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	4.771384262756
		SemiMajorAxis	2.834158455869
		Eccentricity	0.006103485425
		Inclination	3.012050452474
		AscendingNode	124.551049756802
		ArgOfPericenter	35.534641433511
		MeanAnomaly	89.336094224133
	}
	UniformRotation
	{
		Period	6.2372
	}
	LunarLambert	0.5
	Albedo	0.237
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7210"
}

#1_"7217 Dacke:Dacke:1979 QX3:1991 TG1" "Sol" #1=
#2_"*Даск:7217 Dacke:Dacke:1979 QX3" "Sol" #2=
#3_"1979 QX3:*Даск:7217 Dacke:Dacke" "Sol" #3=
".:Dacke:7217 Dacke:1979 QX3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.735
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.748712432623
		SemiMajorAxis	3.209038455542
		Eccentricity	0.170128613846
		Inclination	10.168709430222
		AscendingNode	325.769674505235
		ArgOfPericenter	354.779727872003
		MeanAnomaly	63.998520924806
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0511
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7217"
}

#1_"7233 Majella:Majella:1986 EQ5:1951 GU:1992 UR1" "Sol" #1=
#2_"*Маелла:7233 Majella:Majella:1986 EQ5" "Sol" #2=
#3_"1986 EQ5:Majella:*Маелла:7233 Majella" "Sol" #3=
".:Majella:7233 Majella:1986 EQ5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7233 majella.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.286
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.355351408883
		SemiMajorAxis	2.666920068972
		Eccentricity	0.130102526467
		Inclination	12.25946693733
		AscendingNode	18.574971238615
		ArgOfPericenter	212.661114671344
		MeanAnomaly	10.544537769775
	}
	UniformRotation
	{
		Period	3.812
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7233"
}

#1_"7289 Kamegamori:Kamegamori:1991 JU:1978 WJ1:1984 KN" "Sol" #1=
#2_"*Камэгамори:7289 Kamegamori:Kamegamori:1991 JU" "Sol" #2=
#3_"1991 JU:Kamegamori:*Камэгамори:7289 Kamegamori" "Sol" #3=
".:Kamegamori:7289 Kamegamori:1991 JU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7289 kamegamori.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.004
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.531260763766
		SemiMajorAxis	2.318894859286
		Eccentricity	0.134762452176
		Inclination	8.401709024152
		AscendingNode	54.241197030355
		ArgOfPericenter	239.971306167539
		MeanAnomaly	55.480112362815
	}
	UniformRotation
	{
		Period	3.8311
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7289"
}

#1_"7318 Dyukov:Dyukov:1969 OX:1969 PZ:1987 YF2:1994 NM" "Sol" #1=
#2_"*Дюков:7318 Dyukov:Dyukov:1969 OX" "Sol" #2=
#3_"1969 OX:Dyukov:*Дюков:7318 Dyukov" "Sol" #3=
".:Dyukov:7318 Dyukov:1969 OX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7318 dyukov.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.849
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.219499809596
		SemiMajorAxis	2.611170193148
		Eccentricity	0.180575950561
		Inclination	13.81948167894
		AscendingNode	133.949184236953
		ArgOfPericenter	211.207308447432
		MeanAnomaly	68.432315805995
	}
	UniformRotation
	{
		Period	4.856
	}
	LunarLambert	0.5
	Albedo	0.327
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7318"
}

#1_"7331 Balindblad:Balindblad:1985 TV:1980 WK:1991 VF13" "Sol" #1=
#2_"*Балиндблад:7331 Balindblad:Balindblad:1985 TV" "Sol" #2=
#3_"1985 TV:*Балиндблад:7331 Balindblad:Balindblad" "Sol" #3=
".:Balindblad:7331 Balindblad:1985 TV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.245
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.681606679311
		SemiMajorAxis	3.184016494069
		Eccentricity	0.03566716127
		Inclination	22.35050856224
		AscendingNode	24.326377288329
		ArgOfPericenter	347.100420319816
		MeanAnomaly	54.340054040103
	}
	UniformRotation
	{
		Period	16.3
	}
	LunarLambert	0.5
	Albedo	0.074
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7331"
}

#1_"7335 1989 JA:1989 JA" "Sol" #1=
#2_"1989 JA:7335 1989 JA" "Sol" #2=
#3_"1989 JA:7335 1989 JA" "Sol" #3=
".:1989 JA:7335 1989 JA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.356485864467
		SemiMajorAxis	1.770806433459
		Eccentricity	0.484233608523
		Inclination	15.194202224072
		AscendingNode	61.341889233759
		ArgOfPericenter	232.258910043579
		MeanAnomaly	283.483964677018
	}
	UniformRotation
	{
		Period	12
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7335"
}

#1_"7366 Agata:Agata:1996 UY:1973 QF2:1979 UX4:1979 WN6:1987 DL5:1990 SC29:1990 SS26:1990 SX2" "Sol" #1=
#2_"*Агата:7366 Agata:Agata:1996 UY" "Sol" #2=
#3_"1996 UY:*Агата:7366 Agata:Agata" "Sol" #3=
".:Agata:7366 Agata:1996 UY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.035
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.610492278517
		SemiMajorAxis	3.157392050273
		Eccentricity	0.140379677848
		Inclination	6.334785410361
		AscendingNode	50.131606908021
		ArgOfPericenter	337.576994603737
		MeanAnomaly	97.691260052122
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0311
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7366"
}

#1_"7394 Xanthomalitia:Xanthomalitia:1985 QX4:1931 VH:1993 RG2" "Sol" #1=
#2_"*Ксанфомалития:7394 Xanthomalitia:Xanthomalitia:1985 QX4" "Sol" #2=
#3_"1985 QX4:*Ксанфомалития:7394 Xanthomalitia:Xanthomalitia" "Sol" #3=
".:Xanthomalitia:7394 Xanthomalitia:1985 QX4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.165
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.792265100569
		SemiMajorAxis	3.930402354809
		Eccentricity	0.033514305583
		Inclination	8.609485217618
		AscendingNode	174.704320305788
		ArgOfPericenter	192.844409969369
		MeanAnomaly	255.588865321272
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0326
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7394"
}

#1_"7466 1989 VC2:1989 VC2:1983 VJ1:1989 TG2" "Sol" #1=
#2_"1989 VC2:7466 1989 VC2" "Sol" #2=
#3_"1989 VC2:7466 1989 VC2" "Sol" #3=
".:1989 VC2:7466 1989 VC2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.121496874982
		SemiMajorAxis	3.346310888572
		Eccentricity	0.139894412557
		Inclination	6.409421741525
		AscendingNode	18.098427237166
		ArgOfPericenter	356.114091796677
		MeanAnomaly	44.378095736517
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0552
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7466"
}

#1_"7505 Furusho:Furusho:1997 AM2:1940 WC:1944 OG:1950 BA1:1970 WG:1991 NS" "Sol" #1=
#2_"*Фурусо:7505 Furusho:Furusho:1997 AM2" "Sol" #2=
#3_"1997 AM2:*Фурусо:7505 Furusho:Furusho" "Sol" #3=
".:Furusho:7505 Furusho:1997 AM2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.535
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.28621554282
		SemiMajorAxis	2.638622145243
		Eccentricity	0.379963021943
		Inclination	6.374757426732
		AscendingNode	86.552791510075
		ArgOfPericenter	288.069203167769
		MeanAnomaly	123.950604493397
	}
	UniformRotation
	{
		Period	4.14
	}
	LunarLambert	0.5
	Albedo	0.3732
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7505"
}

#New4-Name
#1_"7517 Alisondoane:Alisondoane:1989 AD:1938 UV:1961 VJ:1980 TF7:1982 FU3" "Sol" #1=
#2_"*Элисондоан:7517 Alisondoane:Alisondoane:1989 AD" "Sol" #2=
#3_"Alisondoane:*Элисондоан:7517 Alisondoane:1989 AD" "Sol" #3=
".:Alisondoane:7517 Alisondoane:1989 AD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7517 alisondoane.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.573
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.826705885486
		SemiMajorAxis	2.446496439466
		Eccentricity	0.260942695768
		Inclination	6.057735645036
		AscendingNode	0.636309970549
		ArgOfPericenter	55.519718738847
		MeanAnomaly	351.522669646135
	}
	UniformRotation
	{
		Period	9.701
	}
	LunarLambert	0.5
	Albedo	0.122
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7517"
}

#1_"7536 Fahrenheit:Fahrenheit:1995 WB7:1978 EX7:1991 AZ3:1992 AG3" "Sol" #1=
#2_"*Фаренгейт:7536 Fahrenheit:Fahrenheit:1995 WB7" "Sol" #2=
#3_"1995 WB7:*Фаренгейт:7536 Fahrenheit:Fahrenheit" "Sol" #3=
".:Fahrenheit:7536 Fahrenheit:1995 WB7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.385
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.806624859086
		SemiMajorAxis	2.84809639425
		Eccentricity	0.153997940472
		Inclination	12.619813436731
		AscendingNode	303.856540663005
		ArgOfPericenter	353.112061714835
		MeanAnomaly	107.573501921414
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0549
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7536"
}

#1_"7588 1992 FJ1:1992 FJ1:1963 DP:1980 DQ:1982 PJ1" "Sol" #1=
#2_"1992 FJ1:7588 1992 FJ1" "Sol" #2=
#3_"1992 FJ1:7588 1992 FJ1" "Sol" #3=
".:1992 FJ1:7588 1992 FJ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.455
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.756632421806
		SemiMajorAxis	3.211985169599
		Eccentricity	0.146812439076
		Inclination	20.727428410904
		AscendingNode	320.14342095273
		ArgOfPericenter	260.005677951594
		MeanAnomaly	319.967984092696
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0429
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7588"
}

#1_"7605 1995 SR1:1995 SR1:1933 OF" "Sol" #1=
#2_"1995 SR1:7605 1995 SR1" "Sol" #2=
#3_"1995 SR1:7605 1995 SR1" "Sol" #3=
".:1995 SR1:7605 1995 SR1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.42
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.607305300379
		SemiMajorAxis	3.156196255937
		Eccentricity	0.075828797052
		Inclination	25.875864794727
		AscendingNode	311.722737630084
		ArgOfPericenter	269.776244787738
		MeanAnomaly	289.683764174357
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0426
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7605"
}

#1_"7611 Hashitatsu:Hashitatsu:1996 BW1:1977 NE:1992 KL" "Sol" #1=
#2_"*Нашитацу:7611 Hashitatsu:Hashitatsu:1996 BW1" "Sol" #2=
#3_"1996 BW1:*Нашитацу:7611 Hashitatsu:Hashitatsu" "Sol" #3=
".:Hashitatsu:7611 Hashitatsu:1996 BW1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.355
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.148701185129
		SemiMajorAxis	2.981670556666
		Eccentricity	0.155818487329
		Inclination	8.495474682419
		AscendingNode	109.359247903778
		ArgOfPericenter	170.417571576067
		MeanAnomaly	110.453594593288
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0653
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7611"
}

#1_"7612 1996 CN2:1996 CN2:1966 XC:1971 SQ2:1982 SE12:1982 SK12:1983 XH:1985 FS" "Sol" #1=
#2_"1996 CN2:7612 1996 CN2" "Sol" #2=
#3_"1996 CN2:7612 1996 CN2" "Sol" #3=
".:1996 CN2:7612 1996 CN2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.125
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.636352592464
		SemiMajorAxis	3.167086808868
		Eccentricity	0.080587585429
		Inclination	9.802911235277
		AscendingNode	154.030646683432
		ArgOfPericenter	263.639541090736
		MeanAnomaly	202.343580241063
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0896
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7612"
}

#1_"7632 Stanislav:Stanislav:1982 UT5:1972 TC1:1984 FP" "Sol" #1=
#2_"*Станислав:7632 Stanislav:Stanislav:1982 UT5" "Sol" #2=
#3_"1982 UT5:*Станислав:7632 Stanislav:Stanislav" "Sol" #3=
".:Stanislav:7632 Stanislav:1982 UT5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7632 stanislav.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.283
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.320347650176
		SemiMajorAxis	2.22561601201
		Eccentricity	0.090043763779
		Inclination	3.385066561965
		AscendingNode	224.042549109505
		ArgOfPericenter	202.794591762072
		MeanAnomaly	273.181016010005
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.195
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7632"
}

#1_"7635 1983 VH1:1983 VH1:1994 VA3" "Sol" #1=
#2_"1983 VH1:7635 1983 VH1" "Sol" #2=
#3_"1983 VH1:7635 1983 VH1" "Sol" #3=
".:1983 VH1:7635 1983 VH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.47
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.414544851283
		SemiMajorAxis	3.083442367905
		Eccentricity	0.105661706427
		Inclination	11.101621837993
		AscendingNode	78.895057423231
		ArgOfPericenter	316.651512889721
		MeanAnomaly	273.669871794493
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0924
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7635"
}

#1_"7641 1986 TT6:1986 TT6:1975 VT5:1975 XS4:1986 VP5:1991 HY:1996 RN26" "Sol" #1=
#2_"1986 TT6:7641 1986 TT6" "Sol" #2=
#3_"1986 TT6:7641 1986 TT6" "Sol" #3=
".:1986 TT6:7641 1986 TT6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	34.485
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.907859010793
		SemiMajorAxis	5.214551821722
		Eccentricity	0.053544953588
		Inclination	34.698163516039
		AscendingNode	242.061809401761
		ArgOfPericenter	229.263242007783
		MeanAnomaly	71.805160559896
	}
	UniformRotation
	{
		Period	27.77
	}
	LunarLambert	0.5
	Albedo	0.0708
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7641"
}

#1_"7660 Alexanderwilson:Alexanderwilson:1993 VM1:1990 QC" "Sol" #1=
#2_"*Александрвильсон:7660 Alexanderwilson:Alexanderwilson:1993 VM1" "Sol" #2=
#3_"1993 VM1:Alexanderwilson:*Александрвильсон:7660 Alexanderwilson" "Sol" #3=
".:Alexanderwilson:7660 Alexanderwilson:1993 VM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7660 alexanderwilson.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.578
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.639886210314
		SemiMajorAxis	1.910079030531
		Eccentricity	0.139994644082
		Inclination	23.151378378837
		AscendingNode	170.52045537572
		ArgOfPericenter	265.010253595393
		MeanAnomaly	277.580555007065
	}
	UniformRotation
	{
		Period	5.924
	}
	LunarLambert	0.5
	Albedo	0.348
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7660"
}
###### 4-2018
#1_"7672 Hawking:Hawking:1995 UO2:1978 UD8" "Sol" #1=
#2_"*Хокинг:7672 Hawking:Hawking:1995 UO2" "Sol" #2=
#3_"1995 UO2:7672 Hawking:Hawking" "Sol" #3=
".:Hawking:7672 Hawking:1995 UO2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	1.0065
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458200.5  # 2018 Mar 23
		Period	3.380318419693
		SemiMajorAxis	2.252334762521562
		Eccentricity	0.0723236081059722
		Inclination	6.88178473523964
		AscendingNode	22.31050803973267
		ArgOfPericenter	28.03444903139937
		MeanAnomaly	215.0347812654818
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.251
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7672"
}

#1_"7711 Rip:Rip:1994 XF:1951 XT:1951 YL:1994 VL2" "Sol" #1=
#2_"*Рип:7711 Rip:Rip:1994 XF" "Sol" #2=
#3_"1994 XF:*Рип:7711 Rip:Rip" "Sol" #3=
".:Rip:7711 Rip:1994 XF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.905
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.383200240895
		SemiMajorAxis	3.071530896986
		Eccentricity	0.274550218834
		Inclination	12.179195613207
		AscendingNode	61.210436190862
		ArgOfPericenter	355.754644130354
		MeanAnomaly	270.470000960835
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0489
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7711"
}

#1_"7730 Sergerasimov:Sergerasimov:1978 NN1:1935 SE1:1983 PD" "Sol" #1=
#2_"*Сергерасимов:7730 Sergerasimov:Sergerasimov:1978 NN1" "Sol" #2=
#3_"1978 NN1:*Сергерасимов:7730 Sergerasimov:Sergerasimov" "Sol" #3=
".:Sergerasimov:7730 Sergerasimov:1978 NN1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.915
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.819229537974
		SemiMajorAxis	2.853073367998
		Eccentricity	0.287797023084
		Inclination	8.017649283947
		AscendingNode	142.718320968892
		ArgOfPericenter	173.012150054914
		MeanAnomaly	189.713970588155
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0281
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7730"
}

#1_"7750 McEwen:McEwen:1988 QD1:1951 LO" "Sol" #1=
#2_"*МакИвен:7750 McEwen:McEwen:1988 QD1" "Sol" #2=
#3_"1988 QD1:*МакИвен:7750 McEwen:McEwen" "Sol" #3=
".:McEwen:7750 McEwen:1988 QD1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.585449583542
		SemiMajorAxis	2.760042780692
		Eccentricity	0.374768359879
		Inclination	15.858366770706
		AscendingNode	249.323696785575
		ArgOfPericenter	69.684357936777
		MeanAnomaly	265.436056878173
	}
	UniformRotation
	{
		Period	27.8182
	}
	LunarLambert	0.5
	Albedo	0.1036
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7750"
}

#1_"7783 1994 JD:1994 JD" "Sol" #1=
#2_"7783 1994 JD:1994 JD" "Sol" #2=
#3_"1994 JD:7783 1994 JD" "Sol" #3=
".:1994 JD:7783 1994 JD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7783 1994 JD.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.114
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.690345311841
		SemiMajorAxis	1.934341796536
		Eccentricity	0.077202413962
		Inclination	23.534118916805
		AscendingNode	96.223518768539
		ArgOfPericenter	15.169793404465
		MeanAnomaly	274.069884807596
	}
	UniformRotation
	{
		Period	31.83
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7783"
}

#1_"7796 Jaracimrman:Jaracimrman:1996 BG:1973 YE3:1990 VG" "Sol" #1=
#2_"*Ярацимрман:7796 Jaracimrman:Jaracimrman:1996 BG" "Sol" #2=
#3_"1996 BG:*Ярацимрман:7796 Jaracimrman:Jaracimrman" "Sol" #3=
".:Jaracimrman:7796 Jaracimrman:1996 BG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.27
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.352325254595
		SemiMajorAxis	2.665684585584
		Eccentricity	0.141995218347
		Inclination	12.812187162962
		AscendingNode	93.850919848886
		ArgOfPericenter	41.548840841811
		MeanAnomaly	114.42365197825
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0408
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7796"
}

#1_"7812 Billward:Billward:1984 UT" "Sol" #1=
#2_"*Биллвард:7812 Billward:Billward:1984 UT" "Sol" #2=
#3_"1984 UT:*Биллвард:7812 Billward:Billward" "Sol" #3=
".:Billward:7812 Billward:1984 UT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.74
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.641327933255
		SemiMajorAxis	2.782420097289
		Eccentricity	0.230120668635
		Inclination	16.201491461912
		AscendingNode	232.210386105175
		ArgOfPericenter	201.976608483049
		MeanAnomaly	153.985162180164
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0153
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7812"
}

#1_"7821 1991 AC:1991 AC:1989 SA4:1992 GT7" "Sol" #1=
#2_"1991 AC:7821 1991 AC" "Sol" #2=
#3_"1991 AC:7821 1991 AC" "Sol" #3=
".:1991 AC:7821 1991 AC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.905663355238
		SemiMajorAxis	2.887085816506
		Eccentricity	0.01491490475
		Inclination	2.877757067132
		AscendingNode	57.908337147613
		ArgOfPericenter	80.746103589138
		MeanAnomaly	289.666410577244
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.34
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7821"
}

#1_"7835 Myroncope:Myroncope:1993 MC:1990 WV12" "Sol" #1=
#2_"*Миронкоп:7835 Myroncope:Myroncope:1993 MC" "Sol" #2=
#3_"1993 MC:Myroncope:*Миронкоп:7835 Myroncope" "Sol" #3=
".:Myroncope:7835 Myroncope:1993 MC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7835 myroncope.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	5.376
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.077383572274
		SemiMajorAxis	2.552205132506
		Eccentricity	0.234987011187
		Inclination	12.962158564442
		AscendingNode	220.401755180399
		ArgOfPericenter	37.207440312969
		MeanAnomaly	303.188193384411
	}
	UniformRotation
	{
		Period	7.43019
	}
	LunarLambert	0.5
	Albedo	0.085
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7835"
}

#1_"7859 Lhasa:Lhasa:1979 US:1974 RG:1981 ET1:1992 OA10:1993 WP" "Sol" #1=
#2_"*Лгаса:7859 Lhasa:Lhasa:1979 US" "Sol" #2=
#3_"1979 US:*Лгаса:7859 Lhasa:Lhasa" "Sol" #3=
".:Lhasa:7859 Lhasa:1979 US" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.59255279926
		SemiMajorAxis	2.762892391653
		Eccentricity	0.135737548764
		Inclination	3.748488628631
		AscendingNode	8.261353367502
		ArgOfPericenter	35.35222499865
		MeanAnomaly	228.487754463625
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.033
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7859"
}

#1_"7868 Barker:Barker:1984 UX2:1931 RD1" "Sol" #1=
#2_"*Баркер:7868 Barker:Barker:1984 UX2" "Sol" #2=
#3_"1984 UX2:*Баркер:7868 Barker:Barker" "Sol" #3=
".:Barker:7868 Barker:1984 UX2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.215
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.394573004686
		SemiMajorAxis	2.682907219975
		Eccentricity	0.200907879375
		Inclination	12.006358046596
		AscendingNode	15.544744626018
		ArgOfPericenter	324.011823256331
		MeanAnomaly	342.849516841389
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0395
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7868"
}

#1_"7874 1991 BE:1991 BE:1953 AS:1994 XQ5" "Sol" #1=
#2_"1991 BE:7874 1991 BE" "Sol" #2=
#3_"1991 BE:7874 1991 BE" "Sol" #3=
".:1991 BE:7874 1991 BE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.83
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.18303326057
		SemiMajorAxis	2.596103944404
		Eccentricity	0.17012541477
		Inclination	26.847533806352
		AscendingNode	293.628138580508
		ArgOfPericenter	247.145485246813
		MeanAnomaly	208.523968406167
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0946
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7874"
}

#1_"7880 1992 OM7:1992 OM7:1992 OM7:1974 SN:1977 FK2:1979 SV10:1995 AL1" "Sol" #1=
#2_"1992 OM7:7880 1992 OM7" "Sol" #2=
#3_"1992 OM7:7880 1992 OM7" "Sol" #3=
".:1992 OM7:7880 1992 OM7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.83
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.643065016526
		SemiMajorAxis	2.7831142943
		Eccentricity	0.044611832855
		Inclination	3.269186792492
		AscendingNode	292.203927868321
		ArgOfPericenter	5.958527447118
		MeanAnomaly	291.914685349236
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.043
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7880"
}

#1_"7895 Kaseda:Kaseda:1995 DK1:1939 FH:1979 MG9" "Sol" #1=
#2_"*Каседа:7895 Kaseda:Kaseda:1995 DK1" "Sol" #2=
#3_"1995 DK1:*Каседа:7895 Kaseda:Kaseda" "Sol" #3=
".:Kaseda:7895 Kaseda:1939 FH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.255
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.595292946828
		SemiMajorAxis	3.151687031757
		Eccentricity	0.148591339635
		Inclination	13.21753055639
		AscendingNode	133.578928484091
		ArgOfPericenter	37.756571355428
		MeanAnomaly	180.03023471927
	}
	UniformRotation
	{
		Period	5.11
	}
	LunarLambert	0.5
	Albedo	0.0949
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7895"
}

#1_"7896 Svejk:Svejk:1995 EC:1976 YJ4" "Sol" #1=
#2_"*Швейк:7896 Svejk:Svejk:1995 EC" "Sol" #2=
#3_"1995 EC:Svejk:*Швейк:7896 Svejk" "Sol" #3=
".:Svejk:7896 Svejk:1995 EC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7896 svejk.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	7.652
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.557425792089
		SemiMajorAxis	3.13745120372
		Eccentricity	0.137845269999
		Inclination	1.909369127287
		AscendingNode	52.350192944864
		ArgOfPericenter	140.915985063464
		MeanAnomaly	311.011505425841
	}
	UniformRotation
	{
		Period	16.20582
	}
	LunarLambert	0.5
	Albedo	0.083
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7896"
}

#1_"7905 Juzoitami:Juzoitami:1997 OX:1951 EE1:1952 HH1:1979 FF4:1981 PC:1991 LG5" "Sol" #1=
#2_"*Дзюдзоитами:7905 Juzoitami:Juzoitami:1997 OX" "Sol" #2=
#3_"1997 OX:*Дзюдзоитами:7905 Juzoitami:Juzoitami" "Sol" #3=
".:Juzoitami:7905 Juzoitami:1997 OX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7905 juzoitami.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	9.173
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	5.49160997681
		SemiMajorAxis	3.112631121356
		Eccentricity	0.082491272988
		Inclination	12.210034183031
		AscendingNode	94.319737137447
		ArgOfPericenter	292.528849191651
		MeanAnomaly	11.824721379855
	}
	UniformRotation
	{
		Period	2.7276
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7905"
}

#1_"7916 1981 EN:1981 EN:1981 EN:1981 EG35" "Sol" #1=
#2_"1981 EN:7916 1981 EN" "Sol" #2=
#3_"1981 EN:7916 1981 EN" "Sol" #3=
".:1981 EN:7916 1981 EN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.025
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.638707165448
		SemiMajorAxis	2.365697817197
		Eccentricity	0.162975585906
		Inclination	9.588178863733
		AscendingNode	163.941301401353
		ArgOfPericenter	350.485899442345
		MeanAnomaly	111.508447398249
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0212
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7916"
}

#1_"7949 1992 SU:1992 SU:1994 EP5" "Sol" #1=
#2_"1992 SU:7949 1992 SU" "Sol" #2=
#3_"1992 SU:7949 1992 SU" "Sol" #3=
".:1992 SU:7949 1992 SU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.225
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.113516341152
		SemiMajorAxis	2.968071079662
		Eccentricity	0.273220907516
		Inclination	17.603398828232
		AscendingNode	176.440562200877
		ArgOfPericenter	263.40041928319
		MeanAnomaly	79.807794071723
	}
	UniformRotation
	{
		Period	17.91
	}
	LunarLambert	0.5
	Albedo	0.0569
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7949"
}

#1_"7950 Berezov:Berezov:1992 SS26:1959 SE:1982 YF1:1983 AP3:1989 BB2:1995 DB" "Sol" #1=
#2_"*Берёзов:7950 Berezov:Berezov:1992 SS26" "Sol" #2=
#3_"1992 SS26:*Берёзов:7950 Berezov:Berezov" "Sol" #3=
".:Berezov:7950 Berezov:1992 SS26" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.55
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.461890182542
		SemiMajorAxis	3.101390896463
		Eccentricity	0.101934493646
		Inclination	11.657659462387
		AscendingNode	351.570635352792
		ArgOfPericenter	334.225559312239
		MeanAnomaly	64.273167645698
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0663
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7950"
}

#1_"7964 1995 DD2:1995 DD2:1977 EG4:1982 JP4:1986 EY" "Sol" #1=
#2_"7964 1995 DD2:1995 DD2" "Sol" #2=
#3_"1995 DD2:7964 1995 DD2" "Sol" #3=
".:1995 DD2:7964 1995 DD2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"7964 1995 DD2.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.99
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.584466686931
		SemiMajorAxis	2.759648354283
		Eccentricity	0.088512834487
		Inclination	10.244389552697
		AscendingNode	163.383517336392
		ArgOfPericenter	82.824240947022
		MeanAnomaly	200.289039341952
	}
	UniformRotation
	{
		Period	10.224
	}
	LunarLambert	0.5
	Albedo	0.304
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7964"
}

#1_"7965 Katsuhiko:Katsuhiko:1996 BD1:1978 QL:1986 RK2:1992 BP1" "Sol" #1=
#2_"*Кацухико:7965 Katsuhiko:Katsuhiko:1996 BD1" "Sol" #2=
#3_"1996 BD1:*Кацухико:7965 Katsuhiko:Katsuhiko" "Sol" #3=
".:Katsuhiko:7965 Katsuhiko:1996 BD1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.51
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.807683023199
		SemiMajorAxis	2.438381886955
		Eccentricity	0.288903807276
		Inclination	25.021134433585
		AscendingNode	310.066754505042
		ArgOfPericenter	280.339803666878
		MeanAnomaly	277.600633047495
	}
	UniformRotation
	{
		Period	5.3897
	}
	LunarLambert	0.5
	Albedo	0.0634
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7965"
}

#1_"7968 Elst-Pizarro:Elst-Pizarro:1996 N2:1979 OW7:133P" "Sol" #1=
#2_"*Эльст-Писарро:7968 Elst-Pizarro:Elst-Pizarro:1996 N2" "Sol" #2=
#3_"1996 N2:*Эльст-Писарро:7968 Elst-Pizarro:Elst-Pizarro" "Sol" #3=
".:Elst-Pizarro:7968 Elst-Pizarro:1996 N2:133P" "Sol" #4=
{
	Class	"asteroid" # Классифицируется и как комета

	# Class	"comet"
	Mesh	"asteroid-large.cmod"
	Texture	"comet.dds"
	Radius	1.6
	OrbitColor	[ 0.611765 0.317647 0.12549 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	5.621910364726
		SemiMajorAxis	3.161674402655
		Eccentricity	0.160077686832
		Inclination	1.387762362199
		AscendingNode	160.127421000907
		ArgOfPericenter	131.872945819125
		MeanAnomaly	222.903526058723
	}
	UniformRotation
	{
		Period	3.471
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7968"
}

#1_"7979 Pozharskij:Pozharskij:1978 SV7:1990 EM5" "Sol" #1=
#2_"*Пожарский:7979 Pozharskij:Pozharskij:1978 SV7" "Sol" #2=
#3_"1978 SV7:*Пожарский:7979 Pozharskij:Pozharskij" "Sol" #3=
".:Pozharskij:7979 Pozharskij:1978 SV7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.515
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.799744369932
		SemiMajorAxis	2.845377788836
		Eccentricity	0.076666562557
		Inclination	6.762853751157
		AscendingNode	342.975623212557
		ArgOfPericenter	36.350098652549
		MeanAnomaly	188.330028234826
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0493
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7979"
}

#1_"7994 Bethellen:Bethellen:1983 CQ2:1951 EB:1977 AN:1994 EJ2" "Sol" #1=
#2_"*Бетхеллен:7994 Bethellen:Bethellen:1983 CQ2" "Sol" #2=
#3_"1983 CQ2:*Бетхеллен:7994 Bethellen:Bethellen" "Sol" #3=
".:Bethellen:7994 Bethellen:1983 CQ2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.63
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.348332451865
		SemiMajorAxis	3.058253362557
		Eccentricity	0.109905548316
		Inclination	0.044072138259
		AscendingNode	236.553276316413
		ArgOfPericenter	278.698069788951
		MeanAnomaly	338.851445653517
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0391
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7994"
}

#1_"7999 Nesvorny:Nesvorny:1986 RA3:1976 YH6:1988 AT3:1991 NE8:1992 WR9:1994 CD19" "Sol" #1=
#2_"*Несворни:7999 Nesvorny:Nesvorny:1986 RA3" "Sol" #2=
#3_"1986 RA3:*Несворни:7999 Nesvorny:Nesvorny" "Sol" #3=
".:Nesvorny:7999 Nesvorny:1986 RA3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.545
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.333477920189
		SemiMajorAxis	3.052588048243
		Eccentricity	0.08619590555
		Inclination	11.697880050132
		AscendingNode	281.841679384628
		ArgOfPericenter	166.56883857405
		MeanAnomaly	21.885933466322
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0629
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=7999"
}

#1_"8003 Kelvin:Kelvin:1987 RJ:1982 BT10:1984 XC" "Sol" #1=
#2_"*Кельвин:8003 Kelvin:Kelvin:1987 RJ" "Sol" #2=
#3_"1987 RJ:*Кельвин:8003 Kelvin:Kelvin" "Sol" #3=
".:Kelvin:8003 Kelvin:1987 RJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.31435504417
		SemiMajorAxis	2.222937325643
		Eccentricity	0.119538468463
		Inclination	2.844515271598
		AscendingNode	73.954732203299
		ArgOfPericenter	287.413652074532
		MeanAnomaly	77.708620247102
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0258
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8003"
}

#1_"8013 Gordonmoore:Gordonmoore:1990 KA" "Sol" #1=
#2_"*Гордонмур:8013 Gordonmoore:Gordonmoore:1990 KA" "Sol" #2=
#3_"1990 KA:*Гордонмур:8013 Gordonmoore:Gordonmoore" "Sol" #3=
".:Gordonmoore:8013 Gordonmoore:1990 KA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.260549991966
		SemiMajorAxis	2.198813732904
		Eccentricity	0.432069111779
		Inclination	7.571803027928
		AscendingNode	105.586000832326
		ArgOfPericenter	146.749023855712
		MeanAnomaly	183.854603761416
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8013"
}

#1_"8014 1990 MF:1990 MF" "Sol" #1=
#2_"1990 MF:8014 1990 MF" "Sol" #2=
#3_"1990 MF:8014 1990 MF" "Sol" #3=
".:1990 MF:8014 1990 MF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.308981699758
		SemiMajorAxis	1.746927409686
		Eccentricity	0.456002161459
		Inclination	1.864978031957
		AscendingNode	210.299773592265
		ArgOfPericenter	114.331397231018
		MeanAnomaly	194.594464184219
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.12
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8014"
}

#1_"8043 Fukuhara:Fukuhara:1994 XE1:1951 XL1:1976 YV6:1987 YB6" "Sol" #1=
#2_"*Фукугара:8043 Fukuhara:Fukuhara:1994 XE1" "Sol" #2=
#3_"1994 XE1:Fukuhara:*Фукугара:8043 Fukuhara" "Sol" #3=
".:Fukuhara:8043 Fukuhara:1994 XE1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"8043 fukuhara.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.565269406867
		SemiMajorAxis	2.333759507311
		Eccentricity	0.096404303849
		Inclination	8.443784523984
		AscendingNode	74.369679913432
		ArgOfPericenter	344.428907968372
		MeanAnomaly	109.2221685196
	}
	UniformRotation
	{
		Period	22.7606
	}
	LunarLambert	0.5
	Albedo	0.23
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8043"
}

#1_"8062 Okhotsymskij:Okhotsymskij:1977 EZ:1929 CF1:1951 CT1:1982 PL1:1993 RH1" "Sol" #1=
#2_"*Охоцимский:8062 Okhotsymskij:Okhotsymskij:1977 EZ" "Sol" #2=
#3_"1977 EZ:*Охоцимский:8062 Okhotsymskij:Okhotsymskij" "Sol" #3=
".:Okhotsymskij:8062 Okhotsymskij:1977 EZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.495
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.686329008022
		SemiMajorAxis	2.386293881299
		Eccentricity	0.100366106154
		Inclination	12.523557726186
		AscendingNode	329.274689439005
		ArgOfPericenter	155.66783985292
		MeanAnomaly	122.608427004598
	}
	UniformRotation
	{
		Period	5.282
	}
	LunarLambert	0.5
	Albedo	0.0718
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8062"
}

#1_"8067 Helfenstein:Helfenstein:1980 RU:1984 UG2:1989 YV" "Sol" #1=
#2_"*Хельфенстайн:8067 Helfenstein:Helfenstein:1980 RU" "Sol" #2=
#3_"1980 RU:*Хельфенстайн:8067 Helfenstein:Helfenstein" "Sol" #3=
".:Helfenstein:8067 Helfenstein:1980 RU" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.13705528995
		SemiMajorAxis	2.577045472803
		Eccentricity	0.141964453007
		Inclination	15.335695416708
		AscendingNode	344.704777989404
		ArgOfPericenter	30.038723107863
		MeanAnomaly	76.188927124847
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0253
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8067"
}

#1_"8132 Vitginzburg:Vitginzburg:1976 YA6:1991 JJ1" "Sol" #1=
#2_"*Витгинзбург:8132 Vitginzburg:Vitginzburg:1976 YA6" "Sol" #2=
#3_"1976 YA6:*Витгинзбург:8132 Vitginzburg:Vitginzburg" "Sol" #3=
".:Vitginzburg:8132 Vitginzburg:1976 YA6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"8132 vitginzburg.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	7.629
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.256124107393
		SemiMajorAxis	2.626257994335
		Eccentricity	0.104644577538
		Inclination	14.176048599667
		AscendingNode	73.510326545505
		ArgOfPericenter	159.119605862642
		MeanAnomaly	241.898806409033
	}
	UniformRotation
	{
		Period	7.28
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8132"
}

#1_"8146 Jimbell:Jimbell:1983 WG:1980 DM1" "Sol" #1=
#2_"*Джимбелл:8146 Jimbell:Jimbell:1983 WG" "Sol" #2=
#3_"1983 WG:*Джимбелл:8146 Jimbell:Jimbell" "Sol" #3=
".:Jimbell:8146 Jimbell:1983 WG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.701874166416
		SemiMajorAxis	2.806565613996
		Eccentricity	0.216232614682
		Inclination	11.290901265961
		AscendingNode	76.856209926201
		ArgOfPericenter	28.77244457945
		MeanAnomaly	192.414523532097
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0795
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8146"
}

#1_"8157 1988 XG2:1988 XG2:1983 VX4:1992 SB24" "Sol" #1=
#2_"1988 XG2:8157 1988 XG2" "Sol" #2=
#3_"1988 XG2:8157 1988 XG2" "Sol" #3=
".:1988 XG2:8157 1988 XG2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.52
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.685871958686
		SemiMajorAxis	2.800194146237
		Eccentricity	0.195431607404
		Inclination	7.092821277317
		AscendingNode	264.619300820223
		ArgOfPericenter	180.044336518642
		MeanAnomaly	210.494490644696
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0545
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8157"
}

#1_"8223 Bradshaw:Bradshaw:1996 PD:1994 AR11" "Sol" #1=
#2_"*Брадшо:8223 Bradshaw:Bradshaw:1996 PD" "Sol" #2=
#3_"1996 PD:*Брадшо:8223 Bradshaw:Bradshaw" "Sol" #3=
".:Bradshaw:8223 Bradshaw:1996 PD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.522430550032
		SemiMajorAxis	2.734696507336
		Eccentricity	0.229573289737
		Inclination	9.510183832423
		AscendingNode	117.304570623025
		ArgOfPericenter	225.918838078034
		MeanAnomaly	359.808684821769
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0302
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8223"
}

#1_"8259 1983 UG:1983 UG:1983 UG:1966 UD:1992 HX6:1993 TC29" "Sol" #1=
#2_"1983 UG:8259 1983 UG" "Sol" #2=
#3_"1983 UG:8259 1983 UG" "Sol" #3=
".:1983 UG:8259 1983 UG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.384806471796
		SemiMajorAxis	2.254327939685
		Eccentricity	0.221867509186
		Inclination	5.783788243504
		AscendingNode	77.579126376827
		ArgOfPericenter	302.202378128597
		MeanAnomaly	81.538660972906
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.112
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8259"
}

#1_"8292 1992 SU14:1992 SU14:1996 TP" "Sol" #1=
#2_"1992 SU14:8292 1992 SU14" "Sol" #2=
#3_"1992 SU14:8292 1992 SU14" "Sol" #3=
".:1992 SU14:8292 1992 SU14" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.885
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.500360531272
		SemiMajorAxis	2.725792150981
		Eccentricity	0.146528117633
		Inclination	14.542530410038
		AscendingNode	354.01424614487
		ArgOfPericenter	80.280410847581
		MeanAnomaly	303.508596967579
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.168
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8292"
}

#1_"8342 1986 QN3:1986 QN3:1986 QN3:1979 MB1:1981 AV2" "Sol" #1=
#2_"1986 QN3:8342 1986 QN3" "Sol" #2=
#3_"1986 QN3:8342 1986 QN3" "Sol" #3=
".:1986 QN3:8342 1986 QN3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	3.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.321906007186
		SemiMajorAxis	2.226312331278
		Eccentricity	0.14508999018
		Inclination	3.124524204844
		AscendingNode	82.93466814839
		ArgOfPericenter	288.859930207677
		MeanAnomaly	159.604423020403
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0737
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8342"
}

#1_"8354 1989 RF:1989 RF:1978 RC5:1978 TP3:1983 PP2:1992 CS7" "Sol" #1=
#2_"1989 RF:8354 1989 RF" "Sol" #2=
#3_"1989 RF:8354 1989 RF" "Sol" #3=
".:1989 RF:8354 1989 RF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.39
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.738002077878
		SemiMajorAxis	3.205051403732
		Eccentricity	0.145267825902
		Inclination	4.325869962705
		AscendingNode	208.99207451548
		ArgOfPericenter	109.590432452815
		MeanAnomaly	163.545318854595
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0457
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8354"
}

#1_"8359 1989 WD:1989 WD:1991 HB" "Sol" #1=
#2_"1989 WD:8359 1989 WD" "Sol" #2=
#3_"1989 WD:8359 1989 WD" "Sol" #3=
".:1989 WD:8359 1989 WD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"8359 1989 WD.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.112
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.602005488787
		SemiMajorAxis	2.34976327594
		Eccentricity	0.065880748644
		Inclination	7.634338376224
		AscendingNode	63.284723641021
		ArgOfPericenter	128.638763038884
		MeanAnomaly	273.815818355093
	}
	UniformRotation
	{
		Period	2.8911
	}
	LunarLambert	0.5
	Albedo	0.188
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8359"
}

#1_"8380 Tooting:Tooting:1992 SW17:1974 XH" "Sol" #1=
#2_"*Тутинг:8380 Tooting:Tooting:1992 SW17" "Sol" #2=
#3_"1992 SW17:*Тутинг:8380 Tooting:Tooting" "Sol" #3=
".:Tooting:8380 Tooting:1992 SW17" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.065
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.556455895822
		SemiMajorAxis	2.748396029182
		Eccentricity	0.155600057097
		Inclination	14.004850261733
		AscendingNode	280.858254511527
		ArgOfPericenter	94.375725023771
		MeanAnomaly	318.605928356658
	}
	UniformRotation
	{
		Period	36.929
	}
	LunarLambert	0.5
	Albedo	0.1903
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8380"
}

#1_"8405 Asbolus:Asbolus:1995 GO" "Sol" #1=
#2_"*Асбол:8405 Asbolus:Asbolus:1995 GO" "Sol" #2=
#3_"1995 GO:*Асбол:8405 Asbolus:Asbolus" "Sol" #3=
".:Asbolus:8405 Asbolus:1995 GO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	76.462645585739
		SemiMajorAxis	18.014715675965
		Eccentricity	0.619029003148
		Inclination	17.63490283818
		AscendingNode	6.120119730796
		ArgOfPericenter	290.354984968327
		MeanAnomaly	58.314385001631
	}
	UniformRotation
	{
		Period	8.9351
	}
	LunarLambert	0.5
	Albedo	0.13
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8405"
}

#1_"8449 Maslovets:Maslovets:1977 EO1:1972 HF:1982 DG4" "Sol" #1=
#2_"*Масловец:8449 Maslovets:Maslovets:1977 EO1" "Sol" #2=
#3_"1977 EO1:*Масловец:8449 Maslovets:Maslovets" "Sol" #3=
".:Maslovets:8449 Maslovets:1977 EO1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.895
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.29425712173
		SemiMajorAxis	3.037604434554
		Eccentricity	0.15300478234
		Inclination	2.873740302482
		AscendingNode	51.62195096095
		ArgOfPericenter	187.490592143221
		MeanAnomaly	3.984528988956
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0312
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8449"
}

#1_"8486 1989 QV:1989 QV:1996 XP18" "Sol" #1=
#2_"1989 QV:8486 1989 QV" "Sol" #2=
#3_"1989 QV:8486 1989 QV" "Sol" #3=
".:1989 QV:8486 1989 QV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.765
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.614260498989
		SemiMajorAxis	3.158805641967
		Eccentricity	0.139943298502
		Inclination	23.60801775733
		AscendingNode	24.482697704835
		ArgOfPericenter	36.578977698012
		MeanAnomaly	88.408480319377
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0201
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8486"
}

#1_"8487 1989 SQ:1989 SQ:1978 RF4:1994 AL" "Sol" #1=
#2_"1989 SQ:8487 1989 SQ" "Sol" #2=
#3_"1989 SQ:8487 1989 SQ" "Sol" #3=
".:1989 SQ:8487 1989 SQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.49
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.639015427169
		SemiMajorAxis	2.365831425785
		Eccentricity	0.230633453719
		Inclination	4.259053131389
		AscendingNode	301.804371496695
		ArgOfPericenter	107.763429657586
		MeanAnomaly	305.386283725187
	}
	UniformRotation
	{
		Period	9.4323
	}
	LunarLambert	0.5
	Albedo	0.0639
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8487"
}

#1_"8567 1996 HW1:1996 HW1" "Sol" #1=
#2_"1996 HW1:8567 1996 HW1" "Sol" #2=
#3_"1996 HW1:8567 1996 HW1" "Sol" #3=
".:1996 HW1:8567 1996 HW1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"8567 1996 HW1.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.464
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.92627352072
		SemiMajorAxis	2.045837540306
		Eccentricity	0.448590778207
		Inclination	8.436702011989
		AscendingNode	177.167978371312
		ArgOfPericenter	177.071254317828
		MeanAnomaly	47.034982150905
	}
	UniformRotation
	{
		Period	8.7573
	}
	LunarLambert	0.5
	Albedo	0.156
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8567"
}

#1_"8573 Ivanka:Ivanka:1996 VQ:1980 TQ2:1988 FL2" "Sol" #1=
#2_"*Иванка:8573 Ivanka:Ivanka:1996 VQ" "Sol" #2=
#3_"1996 VQ:Ivanka:*Иванка:8573 Ivanka" "Sol" #3=
".:Ivanka:8573 Ivanka:1996 VQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"8573 ivanka.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.354
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.151399977072
		SemiMajorAxis	2.982712399435
		Eccentricity	0.129304431345
		Inclination	13.53052805617
		AscendingNode	33.803896193419
		ArgOfPericenter	81.521243278455
		MeanAnomaly	281.439414552449
	}
	UniformRotation
	{
		Period	8.0331
	}
	LunarLambert	0.5
	Albedo	0.169
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8573"
}

#1_"8579 Hieizan:Hieizan:1996 XV19:1929 UF:1956 PA:1972 TA8:1976 UN5" "Sol" #1=
#2_"*Хиэйдзан:8579 Hieizan:Hieizan:1996 XV19" "Sol" #2=
#3_"1996 XV19:*Хиэйдзан:8579 Hieizan:Hieizan" "Sol" #3=
".:Hieizan:8579 Hieizan:1996 XV19" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.155
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.905310205025
		SemiMajorAxis	2.479885081725
		Eccentricity	0.192362474596
		Inclination	1.933743050513
		AscendingNode	186.521128580172
		ArgOfPericenter	150.898285294896
		MeanAnomaly	319.039377802176
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0313
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8579"
}

#1_"8701 1993 LG2:1993 LG2:1983 VW:1994 PQ" "Sol" #1=
#2_"1993 LG2:8701 1993 LG2" "Sol" #2=
#3_"1993 LG2:8701 1993 LG2" "Sol" #3=
".:1993 LG2:8701 1993 LG2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.945
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.620367635725
		SemiMajorAxis	3.161095971768
		Eccentricity	0.145174298931
		Inclination	6.722136622239
		AscendingNode	199.011738967129
		ArgOfPericenter	123.827378534663
		MeanAnomaly	230.378078879361
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0459
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8701"
}

#1_"8721 AMOS:1996 AO3:1979 YO1:1981 AU1:1986 RA11:1986 RQ17" "Sol" #1=
#2_"AMOS:8721 AMOS:1996 AO3" "Sol" #2=
#3_"1996 AO3:AMOS:8721 AMOS" "Sol" #3=
".:AMOS:8721 AMOS:1996 AO3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.955
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.670332143173
		SemiMajorAxis	3.889292851341
		Eccentricity	0.026323908179
		Inclination	5.4451392791
		AscendingNode	265.312677215261
		ArgOfPericenter	86.767184010476
		MeanAnomaly	264.268087151165
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0235
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8721"
}

#1_"8737 Takehiro:Takehiro:1997 AL13:1983 RB6:1992 DN11" "Sol" #1=
#2_"*Такэхиро:8737 Takehiro:Takehiro:1997 AL13" "Sol" #2=
#3_"1997 AL13:*Такэхиро:8737 Takehiro:Takehiro" "Sol" #3=
".:Takehiro:8737 Takehiro:1997 AL13" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.62
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.502665342851
		SemiMajorAxis	3.116807157295
		Eccentricity	0.115572894967
		Inclination	11.506101036869
		AscendingNode	348.525079411506
		ArgOfPericenter	289.476852477523
		MeanAnomaly	304.162897859129
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0621
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8737"
}

#1_"8802 1981 EW31:1981 EW31:1989 SW1" "Sol" #1=
#2_"1981 EW31:8802 1981 EW31" "Sol" #2=
#3_"1981 EW31:8802 1981 EW31" "Sol" #3=
".:1981 EW31:8802 1981 EW31" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.605
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.477584995576
		SemiMajorAxis	3.107329312973
		Eccentricity	0.12038131109
		Inclination	9.940120202596
		AscendingNode	169.164669098543
		ArgOfPericenter	209.980909380409
		MeanAnomaly	209.883944457504
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0238
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8802"
}

#1_"8813 Leviathan:Leviathan:1983 WF1" "Sol" #1=
#2_"*Левиафан:8813 Leviathan:Leviathan:1983 WF1" "Sol" #2=
#3_"1983 WF1:*Левиафан:8813 Leviathan:Leviathan" "Sol" #3=
".:Leviathan:8813 Leviathan:1983 WF1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.795
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.615403628654
		SemiMajorAxis	3.159234407478
		Eccentricity	0.321053181942
		Inclination	21.093582928001
		AscendingNode	96.207563610437
		ArgOfPericenter	274.564262886404
		MeanAnomaly	212.673867513711
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1664
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8813"
}

#1_"8823 1987 WS3:1987 WS3" "Sol" #1=
#2_"1987 WS3:8823 1987 WS3" "Sol" #2=
#3_"1987 WS3:8823 1987 WS3" "Sol" #3=
".:1987 WS3:8823 1987 WS3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.79
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.118358842388
		SemiMajorAxis	2.569275379318
		Eccentricity	0.242341481678
		Inclination	13.556699558796
		AscendingNode	243.653776559987
		ArgOfPericenter	164.301453673414
		MeanAnomaly	210.328039486125
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0831
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8823"
}

#1_"8860 Rohloff:Rohloff:1991 TE5:1969 EY1:1975 WF:1979 WN2:1995 UF" "Sol" #1=
#2_"*Роглофф:8860 Rohloff:Rohloff:1991 TE5" "Sol" #2=
#3_"1991 TE5:Rohloff:*Роглофф:8860 Rohloff" "Sol" #3=
".:Rohloff:8860 Rohloff:1991 TE5F" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"8860 rohloff.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.442
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.057695084821
		SemiMajorAxis	2.543982607034
		Eccentricity	0.093993730526
		Inclination	13.964681477216
		AscendingNode	15.192098621311
		ArgOfPericenter	295.471615775077
		MeanAnomaly	157.481928487698
	}
	UniformRotation
	{
		Period	18.8411
	}
	LunarLambert	0.5
	Albedo	0.156
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8860"
}

#1_"8861 Jenskandler:Jenskandler:1991 TF7:1977 KS:1994 LB1" "Sol" #1=
#2_"*Йенскандлер:8861 Jenskandler:Jenskandler:1991 TF7" "Sol" #2=
#3_"1991 TF7:*Йенскандлер:8861 Jenskandler:Jenskandler" "Sol" #3=
".:Jenskandler:8861 Jenskandler:1991 TF7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.93
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.19848098776
		SemiMajorAxis	2.602491536024
		Eccentricity	0.204044934391
		Inclination	10.95816428885
		AscendingNode	217.779533357397
		ArgOfPericenter	315.183138634313
		MeanAnomaly	28.5181436811
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0147
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8861"
}

#1_"8889 Mockturtle:Mockturtle:1994 OC" "Sol" #1=
#2_"*Моктартл:8889 Mockturtle:Mockturtle:1994 OC" "Sol" #2=
#3_"1994 OC:*Моктартл:8889 Mockturtle:Mockturtle" "Sol" #3=
".:Mockturtle:8889 Mockturtle:1994 OC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.795
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.293935970953
		SemiMajorAxis	3.037481592153
		Eccentricity	0.139896066864
		Inclination	11.977283914214
		AscendingNode	322.651081865336
		ArgOfPericenter	60.441376847506
		MeanAnomaly	251.060826074321
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0727
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8889"
}

#1_"8891 Irokawa:Irokawa:1994 RC1:1977 SB:1983 UT" "Sol" #1=
#2_"*Ирокава:8891 Irokawa:Irokawa:1994 RC1" "Sol" #2=
#3_"1994 RC1:*Ирокава:8891 Irokawa:Irokawa" "Sol" #3=
".:Irokawa:8891 Irokawa:1994 RC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.535
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.577934149517
		SemiMajorAxis	3.145165142214
		Eccentricity	0.226916388333
		Inclination	9.390377626654
		AscendingNode	192.472516760065
		ArgOfPericenter	191.390932334836
		MeanAnomaly	209.379024409432
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0553
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8891"
}

#1_"8917 1996 EU2:1996 EU2:1976 YH7:1977 AG" "Sol" #1=
#2_"1996 EU2:8917 1996 EU2" "Sol" #2=
#3_"1996 EU2:8917 1996 EU2" "Sol" #3=
".:1996 EU2:8917 1996 EU2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.17
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.297157878113
		SemiMajorAxis	3.410025183616
		Eccentricity	0.113892151992
		Inclination	15.470605934822
		AscendingNode	263.765822173856
		ArgOfPericenter	169.910485982242
		MeanAnomaly	20.390843488618
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0452
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8917"
}

#1_"8951 1997 FO:1997 FO:1976 GC3:1984 WO2:1987 KF3" "Sol" #1=
#2_"1997 FO:8951 1997 FO" "Sol" #2=
#3_"1997 FO:8951 1997 FO" "Sol" #3=
".:1997 FO:8951 1997 FO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.03
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.325088566197
		SemiMajorAxis	3.049386140028
		Eccentricity	0.048418239749
		Inclination	10.170998306272
		AscendingNode	41.516137029708
		ArgOfPericenter	206.203248363204
		MeanAnomaly	50.323641682849
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0692
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8951"
}

#New3
#1_"8985 Tula:Tula:1978 PV3:1995 QQ2" "Sol" #1=
#2_"*Тула:8985 Tula:Tula:1978 PV3" "Sol" #2=
#3_"1978 PV3:*Тула:8985 Tula:Tula" "Sol" #3=
".:Tula:8985 Tula:1978 PV3" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.633
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.386280319199
		SemiMajorAxis	2.254982294045
		Eccentricity	0.201060825336
		Inclination	4.082778586827
		AscendingNode	279.481862894477
		ArgOfPericenter	23.581340924852
		MeanAnomaly	205.611469390279
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.379
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=8985"
}

#1_"9003 Ralphmilliken:Ralphmilliken:1981 UW21:1955 AA:1981 UW19:1983 CO2:1990 ST28:1992 AF6: #1=
#1_1995 US7" "Sol" #1=
#2_"*Ральфмилликен:9003 Ralphmilliken:Ralphmilliken:1981 UW21" "Sol" #2=
#3_"1981 UW21:*Ральфмилликен:9003 Ralphmilliken" "Sol" #3=
".:Ralphmilliken:9003 Ralphmilliken:1981 UW21" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.61
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.639588604408
		SemiMajorAxis	2.781724916092
		Eccentricity	0.074148250262
		Inclination	5.345357909805
		AscendingNode	124.981455626584
		ArgOfPericenter	274.977484955719
		MeanAnomaly	49.828211979689
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0326
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9003"
}

#1_"9090 Chirotenmondai:Chirotenmondai:1995 UW8:1986 XG1:1988 FT3:1994 NZ12" "Sol" #1=
#2_"*Тиротэнмондай:9090 Chirotenmondai:Chirotenmondai:1995 UW8" "Sol" #2=
#3_"1995 UW8:*Тиротэнмондай:9090 Chirotenmondai:Chirotenmondai" "Sol" #3=
".:Chirotenmondai:9090 Chirotenmondai:1995 UW8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.515
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.555379659767
		SemiMajorAxis	2.747963230911
		Eccentricity	0.097924238624
		Inclination	13.741195137543
		AscendingNode	66.16099600519
		ArgOfPericenter	14.004335567855
		MeanAnomaly	41.00493259929
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0609
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9090"
}

#1_"9107 Narukospa:Narukospa:1997 AE4:1981 WB8:1983 JK:1990 RA15" "Sol" #1=
#2_"*Нарукоспа:9107 Narukospa:Narukospa:1997 AE4" "Sol" #2=
#3_"1997 AE4:*Нарукоспа:9107 Narukospa:Narukospa" "Sol" #3=
".:Narukospa:9107 Narukospa:1997 AE4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.535
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.847593342303
		SemiMajorAxis	2.864257014773
		Eccentricity	0.204534190706
		Inclination	6.810865451487
		AscendingNode	126.211005219901
		ArgOfPericenter	13.57283939402
		MeanAnomaly	235.250327655686
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0255
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9107"
}

#1_"9162 Kwiila:Kwiila:1987 OA" "Sol" #1=
#2_"*Квиила:9162 Kwiila:Kwiila:1987 OA" "Sol" #2=
#3_"1987 OA:*Квиила:9162 Kwiila:Kwiila" "Sol" #3=
".:Kwiila:9162 Kwiila:1987 OA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.4705
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.830281008434
		SemiMajorAxis	1.496257639215
		Eccentricity	0.595274859716
		Inclination	9.013478198052
		AscendingNode	180.144011553528
		ArgOfPericenter	235.661660858349
		MeanAnomaly	299.034192931209
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.14
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9162"
}

#1_"9247 1998 MO19:1998 MO19:1950 SM:1989 TK1:1991 GS:2012 AL24" "Sol" #1=
#2_"1998 MO19:9247 1998 MO19" "Sol" #2=
#3_"1998 MO19:9247 1998 MO19" "Sol" #3=
".:1998 MO19:9247 1998 MO19" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.745
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.489454214609
		SemiMajorAxis	3.111816480885
		Eccentricity	0.070384368935
		Inclination	26.496353637911
		AscendingNode	213.24076156834
		ArgOfPericenter	250.408487983208
		MeanAnomaly	171.343339458655
	}
	UniformRotation
	{
		Period	11.479
	}
	LunarLambert	0.5
	Albedo	0.0553
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9247"
}

#1_"9294 1983 EV:1983 EV:1938 DB2:1974 EF:1976 SZ10:1981 UL5" "Sol" #1=
#2_"1983 EV:9294 1983 EV:1938 DB2" "Sol" #2=
#3_"1983 EV:9294 1983 EV:1938 DB2" "Sol" #3=
".:1983 EV:9294 1983 EV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.501185848127
		SemiMajorAxis	2.726125394423
		Eccentricity	0.109183247687
		Inclination	3.616151042699
		AscendingNode	11.570165206268
		ArgOfPericenter	146.204735470464
		MeanAnomaly	31.542732240026
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0418
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9294"
}

#1_"9344 Klopstock:Klopstock:1991 RB4:1995 WK2" "Sol" #1=
#2_"*Клопшток:9344 Klopstock:Klopstock:1991 RB4" "Sol" #2=
#3_"1991 RB4:*Клопшток:9344 Klopstock:Klopstock" "Sol" #3=
".:Klopstock:9344 Klopstock:1991 RB4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.525
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.636396201383
		SemiMajorAxis	2.364696065522
		Eccentricity	0.088164740993
		Inclination	5.029944455112
		AscendingNode	340.404258208479
		ArgOfPericenter	156.329166475813
		MeanAnomaly	17.401378764731
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0116
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9344"
}

#1_"9347 1991 RY21:1991 RY21:1991 RY21:1979 FH4:1996 XY30" "Sol" #1=
#2_"1991 RY21:9347 1991 RY21" "Sol" #2=
#3_"1991 RY21:9347 1991 RY21" "Sol" #3=
".:1991 RY21:9347 1991 RY21" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.615
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.739971497257
		SemiMajorAxis	2.409387909914
		Eccentricity	0.15770744159
		Inclination	3.310832527112
		AscendingNode	101.956551934956
		ArgOfPericenter	129.068492829415
		MeanAnomaly	174.284553566826
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0509
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9347"
}

#1_"9402 1994 UN1:1994 UN1:1988 VQ10:1992 JC5" "Sol" #1=
#2_"1994 UN1:9402 1994 UN1" "Sol" #2=
#3_"1994 UN1:9402 1994 UN1" "Sol" #3=
".:1994 UN1:9402 1994 UN1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.154322020845
		SemiMajorAxis	3.358262780984
		Eccentricity	0.118605829589
		Inclination	9.937791623686
		AscendingNode	217.172924367283
		ArgOfPericenter	157.236351617145
		MeanAnomaly	116.511812552231
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0402
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9402"
}

#1_"9440 1997 FZ1:1997 FZ1:1982 DV5:1990 HN3" "Sol" #1=
#2_"9440 1997 FZ1:1997 FZ1" "Sol" #2=
#3_"1997 FZ1:9440 1997 FZ1" "Sol" #3=
".:1997 FZ1:9440 1997 FZ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"9440 1997 FZ1.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.526
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.693675656093
		SemiMajorAxis	2.389463329516
		Eccentricity	0.145330082937
		Inclination	0.30997562215
		AscendingNode	8.8999090814
		ArgOfPericenter	182.098815342346
		MeanAnomaly	141.563570560259
	}
	UniformRotation
	{
		Period	5.196349
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9440"
}

#1_"9515 Dubner:Dubner:1975 RA2:1993 HT6" "Sol" #1=
#2_"*Дабнер:9515 Dubner:Dubner:1975 RA2" "Sol" #2=
#3_"1975 RA2:*Дабнер:9515 Dubner:Dubner" "Sol" #3=
".:Dubner:9515 Dubner:1975 RA2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.87
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.77460469549
		SemiMajorAxis	2.424239457893
		Eccentricity	0.224436733054
		Inclination	23.70246928522
		AscendingNode	25.422816865495
		ArgOfPericenter	315.079265210451
		MeanAnomaly	151.459824307123
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0738
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9515"
}

#1_"9542 Eryan:Eryan:1983 TU1" "Sol" #1=
#2_"*Эриан:9542 Eryan:Eryan:1983 TU1" "Sol" #2=
#3_"1983 TU1:Eryan:*Эриан:9542 Eryan" "Sol" #3=
".:Eryan:9542 Eryan:1983 TU1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"9542 eryan.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.39
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.716124431495
		SemiMajorAxis	2.399135057149
		Eccentricity	0.117076635057
		Inclination	8.300675120831
		AscendingNode	48.970726832403
		ArgOfPericenter	307.778078996487
		MeanAnomaly	11.295564392449
	}
	UniformRotation
	{
		Period	2.79473
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9542"
}

#1_"9559 1987 DH6:1987 DH6:1983 GG2:1991 BB1" "Sol" #1=
#2_"1987 DH6:9559 1987 DH6" "Sol" #2=
#3_"1987 DH6:9559 1987 DH6" "Sol" #3=
".:1987 DH6:9559 1987 DH6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.423070151742
		SemiMajorAxis	2.694493147775
		Eccentricity	0.107944264276
		Inclination	1.403229318075
		AscendingNode	263.296396224726
		ArgOfPericenter	345.61988502089
		MeanAnomaly	21.525866243386
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0466
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9559"
}

#1_"9563 Kitty:Kitty:1987 SJ1:1969 UQ1:1969 VT" "Sol" #1=
#2_"*Китти:9563 Kitty:Kitty:1987 SJ1" "Sol" #2=
#3_"1987 SJ1:Kitty:*Китти:9563 Kitty" "Sol" #3=
".:Kitty:9563 Kitty:1987 SJ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"9563 kitty.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.668
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.622347300891
		SemiMajorAxis	2.358601605328
		Eccentricity	0.225352475917
		Inclination	1.569756450111
		AscendingNode	202.511786338747
		ArgOfPericenter	150.90311708685
		MeanAnomaly	44.865922191267
	}
	UniformRotation
	{
		Period	5.3673
	}
	LunarLambert	0.5
	Albedo	0.23
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9563"
}

#1_"9661 Hohmann:Hohmann:1996 FU13:1983 YV:1991 XA4" "Sol" #1=
#2_"*Гоман:9661 Hohmann:Hohmann:1996 FU13" "Sol" #2=
#3_"1996 FU13:*Гоман:9661 Hohmann:Hohmann" "Sol" #3=
".:Hohmann:9661 Hohmann:1996 FU13" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.78
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.839830719011
		SemiMajorAxis	3.946380792524
		Eccentricity	0.232862156283
		Inclination	12.987317307571
		AscendingNode	56.752821586623
		ArgOfPericenter	289.030674470085
		MeanAnomaly	24.717172232954
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0745
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9661"
}

#1_"9719 Yakage:Yakage:1977 DF2:1991 EQ1" "Sol" #1=
#2_"*Якагэ:9719 Yakage:Yakage:1977 DF2" "Sol" #2=
#3_"1977 DF2:*Якагэ:9719 Yakage:Yakage" "Sol" #3=
".:Yakage:9719 Yakage:1977 DF2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.885
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.59859902691
		SemiMajorAxis	2.76531681133
		Eccentricity	0.041715700753
		Inclination	5.078079338281
		AscendingNode	4.718565667052
		ArgOfPericenter	119.12669881
		MeanAnomaly	101.22956323805
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0197
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9719"
}

#1_"9799 1996 RJ:1996 RJ:1986 XP5" "Sol" #1=
#2_"1996 RJ:9799 1996 RJ" "Sol" #2=
#3_"1996 RJ:9799 1996 RJ" "Sol" #3=
".:1996 RJ:9799 1996 RJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.83034668677
		SemiMajorAxis	5.191898333941
		Eccentricity	0.046864752598
		Inclination	30.511899076406
		AscendingNode	259.556056217138
		ArgOfPericenter	114.196443430654
		MeanAnomaly	170.140238059428
	}
	UniformRotation
	{
		Period	21.52
	}
	LunarLambert	0.5
	Albedo	0.046
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9799"
}

#1_"9856 1991 EE:1991 EE" "Sol" #1=
#2_"1991 EE:9856 1991 EE" "Sol" #2=
#3_"1991 EE:9856 1991 EE" "Sol" #3=
".:1991 EE:9856 1991 EE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.359034748787
		SemiMajorAxis	2.242870486698
		Eccentricity	0.625714118994
		Inclination	9.826300013235
		AscendingNode	168.165893454175
		ArgOfPericenter	116.182512328015
		MeanAnomaly	337.976073930229
	}
	UniformRotation
	{
		Period	3.045
	}
	LunarLambert	0.5
	Albedo	0.3
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9856"
}

#1_"9920 Bagnulo:Bagnulo:1981 EZ10:1999 DG7" "Sol" #1=
#2_"*Багнуло:9920 Bagnulo:Bagnulo:1981 EZ10" "Sol" #2=
#3_"1981 EZ10:*Багнуло:9920 Bagnulo:Bagnulo" "Sol" #3=
".:Bagnulo:9920 Bagnulo:1981 EZ10" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.71
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.645850328825
		SemiMajorAxis	2.784227218286
		Eccentricity	0.042886333372
		Inclination	3.25727333519
		AscendingNode	264.683436866547
		ArgOfPericenter	30.429144466837
		MeanAnomaly	340.950731249404
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.027
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9920"
}

#1_"9969 Braille:Braille:1992 KD" "Sol" #1=
#2_"*Брайль:9969 Braille:Braille:1992 KD" "Sol" #2=
#3_"1992 KD:*Брайль:9969 Braille:Braille" "Sol" #3=
".:Braille:9969 Braille:1992 KD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"9969 braille.cmod"
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	1.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2451388.5  # 1999 Jul 29
		Period	3.5835965736465
		SemiMajorAxis	2.341750420812260
		Eccentricity	0.4335434953067092
		Inclination	28.94885142204759
		AscendingNode	242.1583629212672
		ArgOfPericenter	355.3586728897821
		MeanAnomaly	1.676369430480154
	}
	UniformRotation
	{
		Period	226.4
	}
	LunarLambert	0.5
	Albedo	0.34
	InfoURL	"https://en.wikipedia.org/wiki/9969_Braille"
}

#1_"9971 Ishihara:Ishihara:1993 HS:1991 YC2:1996 EU1" "Sol" #1=
#2_"*Исихара:9971 Ishihara:Ishihara:1993 HS" "Sol" #2=
#3_"1993 HS:Ishihara:*Исихара:9971 Ishihara" "Sol" #3=
".:Ishihara:9971 Ishihara:1993 HS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"9971 ishihara.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"gaspra.jpg"
	Radius	2.493
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.222149339223
		SemiMajorAxis	2.18151552761
		Eccentricity	0.121395400106
		Inclination	2.748402040033
		AscendingNode	20.551099395903
		ArgOfPericenter	245.999236203748
		MeanAnomaly	97.531508907965
	}
	UniformRotation
	{
		Period	6.7152
	}
	LunarLambert	0.5
	Albedo	0.235
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9971"
}

#1_"9983 Rickfienberg:Rickfienberg:1995 DA:1987 KS2:1993 TS37" "Sol" #1=
#2_"*Рикфинберг:9983 Rickfienberg:Rickfienberg:1995 DA" "Sol" #2=
#3_"1995 DA:Rickfienberg:*Рикфинберг:9983 Rickfienberg" "Sol" #3=
".:Rickfienberg:9983 Rickfienberg:1995 DA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"9983 rickfienberg.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.722
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.453411466465
		SemiMajorAxis	2.706801533272
		Eccentricity	0.115115368034
		Inclination	8.322019251968
		AscendingNode	49.220765014129
		ArgOfPericenter	7.121821234862
		MeanAnomaly	63.316118585319
	}
	UniformRotation
	{
		Period	5.2963
	}
	LunarLambert	0.5
	Albedo	0.167
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=9983"
}

#1_"10046 Creighton:Creighton:1986 JC:1986 LD:1990 KH2:1990 SJ10" "Sol" #1=
#2_"*Крейтон:10046 Creighton:Creighton:1986 JC" "Sol" #2=
#3_"1986 JC:*Крейтон:10046 Creighton:Creighton" "Sol" #3=
".:Creighton:10046 Creighton:1986 JC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.578112911792
		SemiMajorAxis	2.339360895015
		Eccentricity	0.239110420407
		Inclination	8.32297532078
		AscendingNode	101.692453195341
		ArgOfPericenter	177.09785943551
		MeanAnomaly	326.43410064136
	}
	UniformRotation
	{
		Period	6.566
	}
	LunarLambert	0.5
	Albedo	0.0418
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10046"
}

#1_"10050 Rayman:Rayman:1987 MA1:1991 GG12:1995 DX12" "Sol" #1=
#2_"*Рейман:10050 Rayman:Rayman:1987 MA1" "Sol" #2=
#3_"1987 MA1:*Рейман:10050 Rayman:Rayman" "Sol" #3=
".:Rayman:10050 Rayman:1987 MA1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.399520396974
		SemiMajorAxis	2.684920446319
		Eccentricity	0.267653883788
		Inclination	12.216745238942
		AscendingNode	152.35407642326
		ArgOfPericenter	131.879707132867
		MeanAnomaly	78.446578742085
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0722
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10050"
}

#1_"10064 Hirosetamotsu:Hirosetamotsu:1988 UO:1995 GY6" "Sol" #1=
#2_"*Хиросетамотсу:10064 Hirosetamotsu:Hirosetamotsu:1988 UO" "Sol" #2=
#3_"1988 UO:Hirosetamotsu:*Хиросетамотсу:10064 Hirosetamotsu" "Sol" #3=
".:Hirosetamotsu:10064 Hirosetamotsu:1988 UO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"10064 hirosetamotsu.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.812
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.506666305124
		SemiMajorAxis	2.728337757021
		Eccentricity	0.186892650894
		Inclination	9.740401453598
		AscendingNode	31.089063907802
		ArgOfPericenter	310.377643349864
		MeanAnomaly	144.398265096666
	}
	UniformRotation
	{
		Period	8.052
	}
	LunarLambert	0.5
	Albedo	0.244
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10064"
}

#1_"10115 1992 SK:1992 SK:1985 SD:1985 TO2" "Sol" #1=
#2_"1992 SK:10115 1992 SK" "Sol" #2=
#3_"1992 SK:10115 1992 SK" "Sol" #3=
".:1992 SK:10115 1992 SK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"10115 1992 SK.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.469
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.394915956812
		SemiMajorAxis	1.24841763079
		Eccentricity	0.3247272464
		Inclination	15.322232684887
		AscendingNode	8.935488075579
		ArgOfPericenter	233.626582061656
		MeanAnomaly	60.852172575766
	}
	UniformRotation
	{
		Period	7.319
	}
	LunarLambert	0.5
	Albedo	0.28
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10115"
}

#1_"10199 Chariklo:Chariklo:1997 CU26" "Sol" #1=
#2_"*Харикло:10199 Chariklo:Chariklo:1997 CU26" "Sol" #2=
#3_"1997 CU26:*Харикло:10199 Chariklo:Chariklo" "Sol" #3=
".:Chariklo:10199 Chariklo:1997 CU26" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"chariklo.dds"
	Radius	143
	Oblateness	0.328671
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	62.934615411961
		SemiMajorAxis	15.821740368798
		Eccentricity	0.172090627773
		Inclination	23.382362400587
		AscendingNode	300.416187483083
		ArgOfPericenter	242.895770634609
		MeanAnomaly	77.670023037241
	}
	Rings
	{
		Inner	387.2675
		Outer	406.425
		Texture	"chariklo-rings.png"
	}
	UniformRotation
	{
		Period	7.004
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"https://en.wikipedia.org/wiki/10199_Chariklo"
}

#1_"10227 Izanami:Izanami:1997 VO6:1975 WP1:1980 VU:1991 RQ29" "Sol" #1=
#2_"*Идзанами:10227 Izanami:Izanami:1997 VO6" "Sol" #2=
#3_"1997 VO6:*Идзанами:10227 Izanami:Izanami" "Sol" #3=
".:Izanami:10227 Izanami:1997 VO6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.395
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.533612026397
		SemiMajorAxis	3.128482064461
		Eccentricity	0.067873980802
		Inclination	12.657872956858
		AscendingNode	244.166784321559
		ArgOfPericenter	164.540435142688
		MeanAnomaly	35.835970265977
	}
	UniformRotation
	{
		Period	2.92
	}
	LunarLambert	0.5
	Albedo	0.0325
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10227"
}

#1_"10259 Osipovyurij:Osipovyurij:1972 HL:5059 T-2" "Sol" #1=
#2_"*Осиповюрий:10259 Osipovyurij:Osipovyurij:1972 HL" "Sol" #2=
#3_"1972 HL:*Осиповюрий:10259 Osipovyurij:Osipovyurij" "Sol" #3=
".:Osipovyurij:10259 Osipovyurij:1972 HL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.08
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.506464446729
		SemiMajorAxis	3.118241578774
		Eccentricity	0.243748916715
		Inclination	16.568231081186
		AscendingNode	212.279319236941
		ArgOfPericenter	61.024948424155
		MeanAnomaly	259.31100002053
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0523
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10259"
}

#1_"10281 1981 EE45:1981 EE45" "Sol" #1=
#2_"10281 1981 EE45:1981 EE45" "Sol" #2=
#3_"1981 EE45:10281 1981 EE45" "Sol" #3=
".:1981 EE45:10281 1981 EE45" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"10281 1981 EE45.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	6.122
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.507459057991
		SemiMajorAxis	2.72865770293
		Eccentricity	0.038883637957
		Inclination	10.545163317385
		AscendingNode	11.259608323537
		ArgOfPericenter	247.796917789104
		MeanAnomaly	274.979586111438
	}
	UniformRotation
	{
		Period	7.572
	}
	LunarLambert	0.5
	Albedo	0.051
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10281"
}

#1_"10287 Smale:Smale:1982 UK7:1981 JS6:A917 TG" "Sol" #1=
#2_"*Смэйл:10287 Smale:Smale:1982 UK7" "Sol" #2=
#3_"1982 UK7:*Смэйл:10287 Smale:Smale" "Sol" #3=
".:Smale:10287 Smale:1982 UK7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.66
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.812305994328
		SemiMajorAxis	2.440355141064
		Eccentricity	0.245343949453
		Inclination	4.64036038177
		AscendingNode	92.029086998926
		ArgOfPericenter	280.489218279543
		MeanAnomaly	172.972352370636
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0602
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10287"
}

#1_"10288 Saville:Saville:1983 WN:1976 YL7:1990 VO7" "Sol" #1=
#2_"*Савиль:10288 Saville:Saville:1983 WN" "Sol" #2=
#3_"1983 WN:*Савиль:10288 Saville:Saville" "Sol" #3=
".:Saville:10288 Saville:1983 WN" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	3.42
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.558743922197
		SemiMajorAxis	2.33091099677
		Eccentricity	0.249254666097
		Inclination	9.328149334032
		AscendingNode	251.643714091671
		ArgOfPericenter	110.851603443669
		MeanAnomaly	300.310110863453
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0546
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10288"
}

#1_"10291 1985 UT:1985 UT:1985 UT:1975 XM1:1998 BO33" "Sol" #1=
#2_"1985 UT:10291 1985 UT" "Sol" #2=
#3_"1985 UT:10291 1985 UT" "Sol" #3=
".:1985 UT:10291 1985 UT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.151105343996
		SemiMajorAxis	2.982598668008
		Eccentricity	0.109294694527
		Inclination	8.102055541964
		AscendingNode	57.615063166135
		ArgOfPericenter	257.231190757072
		MeanAnomaly	291.935751136067
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0489
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10291"
}

#1_"10299 1988 VS3:1988 VS3:1979 WF5:1994 AH16" "Sol" #1=
#2_"1988 VS3:10299 1988 VS3" "Sol" #2=
#3_"1988 VS3:10299 1988 VS3" "Sol" #3=
".:1988 VS3:10299 1988 VS3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.387247512976
		SemiMajorAxis	2.679924893234
		Eccentricity	0.218658931305
		Inclination	10.304007926204
		AscendingNode	245.912469543564
		ArgOfPericenter	110.880352419072
		MeanAnomaly	21.241968442735
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0706
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10299"
}

#1_"10328 1991 GC1:1991 GC1:1983 GL2:1995 HN" "Sol" #1=
#2_"1991 GC1:10328 1991 GC1" "Sol" #2=
#3_"1991 GC1:10328 1991 GC1" "Sol" #3=
".:1991 GC1:10328 1991 GC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.415
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.043961484073
		SemiMajorAxis	2.538239152709
		Eccentricity	0.204258216178
		Inclination	13.815882646371
		AscendingNode	14.615047580445
		ArgOfPericenter	222.406618004481
		MeanAnomaly	286.12530707599
	}
	UniformRotation
	{
		Period	15.357
	}
	LunarLambert	0.5
	Albedo	0.0519
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10328"
}

#1_"10369 Sinden:Sinden:1995 CE2:1992 OY" "Sol" #1=
#2_"*Синден:10369 Sinden:Sinden:1995 CE2" "Sol" #2=
#3_"1995 CE2:*Синден:10369 Sinden:Sinden" "Sol" #3=
".:Sinden:10369 Sinden:1995 CE2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.213857594011
		SemiMajorAxis	2.608841943961
		Eccentricity	0.040633182587
		Inclination	28.482815689897
		AscendingNode	291.038767530869
		ArgOfPericenter	328.964002931065
		MeanAnomaly	155.05052107936
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0529
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10369"
}

#1_"10386 Romulus:Romulus (asteroid):1996 TS15:1990 TY14" "Sol" #1=
#2_"*Ромул (астероид):10386 Romulus:Romulus (asteroid):1996 TS15" "Sol" #2=
#3_"1996 TS15:*Ромул (астероид):10386 Romulus:Romulus (asteroid)" "Sol" #3=
".:Romulus (asteroid):10386 Romulus:1996 TS15" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.705
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.85371422477
		SemiMajorAxis	3.247996427487
		Eccentricity	0.086315515292
		Inclination	22.979798324184
		AscendingNode	32.373085114233
		ArgOfPericenter	286.949682621629
		MeanAnomaly	106.279018254325
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0611
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10386"
}

#1_"10472 1981 EO20:1981 EO20:1989 TV16" "Sol" #1=
#2_"1981 EO20:10472 1981 EO20" "Sol" #2=
#3_"1981 EO20:10472 1981 EO20" "Sol" #3=
".:1981 EO20:10472 1981 EO20" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"10472 1981 EO20.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.556
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.582475928166
		SemiMajorAxis	2.341262194572
		Eccentricity	0.220858336191
		Inclination	2.758258627266
		AscendingNode	168.940911030919
		ArgOfPericenter	114.300174225569
		MeanAnomaly	287.449329205634
	}
	UniformRotation
	{
		Period	5.98599
	}
	LunarLambert	0.5
	Albedo	0.219
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10472"
}

#1_"10563 Izhdubar:Izhdubar:1993 WD:1991 VJ14" "Sol" #1=
#2_"*Иждубар:10563 Izhdubar:Izhdubar:1993 WD" "Sol" #2=
#3_"1993 WD:*Иждубар:10563 Izhdubar:Izhdubar" "Sol" #3=
".:Izhdubar:10563 Izhdubar:1993 WD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.01037689691
		SemiMajorAxis	1.006893343865
		Eccentricity	0.266375702254
		Inclination	63.461129808961
		AscendingNode	56.56809578557
		ArgOfPericenter	132.187576760882
		MeanAnomaly	194.947507725833
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10563"
}

#1_"10583 Kanetugu:Kanetugu:1995 WC4:1973 YQ1:1989 VR6:1994 NA13" "Sol" #1=
#2_"*Канецугу:10583 Kanetugu:Kanetugu:1995 WC4" "Sol" #2=
#3_"1995 WC4:*Канецугу:10583 Kanetugu:Kanetugu" "Sol" #3=
".:Kanetugu:10583 Kanetugu:1995 WC4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.486124239826
		SemiMajorAxis	3.110557907878
		Eccentricity	0.2253782511
		Inclination	14.678796195562
		AscendingNode	61.698344931907
		ArgOfPericenter	274.363596122116
		MeanAnomaly	228.867328972454
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0485
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10583"
}

#1_"10627 Ookuninushi:Ookuninushi:1998 BW2:1977 CN2:1982 BE10:1991 VO5" "Sol" #1=
#2_"*Окунинуси:10627 Ookuninushi:Ookuninushi:1998 BW2" "Sol" #2=
#3_"1998 BW2:Ookuninushi:*Окунинуси:10627 Ookuninushi" "Sol" #3=
".:Ookuninushi:10627 Ookuninushi:1998 BW2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"10627 ookuninushi.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.577
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.283240109744
		SemiMajorAxis	3.033388930726
		Eccentricity	0.115995761259
		Inclination	8.575439521984
		AscendingNode	108.603536898158
		ArgOfPericenter	269.127478697291
		MeanAnomaly	313.010530870986
	}
	UniformRotation
	{
		Period	4.334986
	}
	LunarLambert	0.5
	Albedo	0.16
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10627"
}

#1_"10637 Heimlich:Heimlich:1998 QP104:1976 US3:1987 UL1:1990 FY3:1996 FM17" "Sol" #1=
#2_"*Геймлих:10637 Heimlich:Heimlich:1998 QP104" "Sol" #2=
#3_"1998 QP104:*Геймлих:10637 Heimlich:Heimlich" "Sol" #3=
".:Heimlich:10637 Heimlich:1998 QP104" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.92
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.667730427553
		SemiMajorAxis	3.178830142042
		Eccentricity	0.020681129399
		Inclination	13.698566238063
		AscendingNode	24.466926021379
		ArgOfPericenter	114.762251007355
		MeanAnomaly	172.635483320464
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0241
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10637"
}

#1_"10672 Kostyukova:Kostyukova:1978 QE:1975 BJ1:1979 YF1:1983 NM:1983 PN2:1995 WB8" "Sol" #1=
#2_"*Костюкова:10672 Kostyukova:Kostyukova:1978 QE" "Sol" #2=
#3_"1978 QE:*Костюкова:10672 Kostyukova:Kostyukova" "Sol" #3=
".:Kostyukova:10672 Kostyukova:1978 QE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.277772395003
		SemiMajorAxis	3.031295699155
		Eccentricity	0.118715116182
		Inclination	15.007607472693
		AscendingNode	283.401636241376
		ArgOfPericenter	63.048185492475
		MeanAnomaly	294.406845169587
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0719
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10672"
}

#1_"10714 1983 QG:1983 QG:1979 YL9" "Sol" #1=
#2_"1983 QG:10714 1983 QG" "Sol" #2=
#3_"1983 QG:10714 1983 QG" "Sol" #3=
".:1983 QG:10714 1983 QG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.455
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.303805726224
		SemiMajorAxis	2.645836303981
		Eccentricity	0.34546784715
		Inclination	14.294344972542
		AscendingNode	80.608602403435
		ArgOfPericenter	279.664885114209
		MeanAnomaly	101.954594504897
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0778
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10714"
}

#1_"10748 1989 CE8:1989 CE8:1992 WL5" "Sol" #1=
#2_"1989 CE8:10748 1989 CE8" "Sol" #2=
#3_"1989 CE8:10748 1989 CE8" "Sol" #3=
".:1989 CE8:10748 1989 CE8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.305
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.508089045443
		SemiMajorAxis	2.728911945221
		Eccentricity	0.091177715685
		Inclination	9.466922624031
		AscendingNode	254.052711252737
		ArgOfPericenter	179.961033947689
		MeanAnomaly	320.895607089817
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0522
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10748"
}

#1_"10766 1990 UB1:1990 UB1:1976 GF7" "Sol" #1=
#2_"1990 UB1:10766 1990 UB1" "Sol" #2=
#3_"1990 UB1:10766 1990 UB1" "Sol" #3=
".:1990 UB1:10766 1990 UB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.065
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.563405315168
		SemiMajorAxis	3.139701298154
		Eccentricity	0.158108867117
		Inclination	14.785129504926
		AscendingNode	32.534582349596
		ArgOfPericenter	15.077896208884
		MeanAnomaly	113.193325949315
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0354
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10766"
}

#1_"10772 1990 YM:1990 YM" "Sol" #1=
#2_"1990 YM:10772 1990 YM" "Sol" #2=
#3_"1990 YM:10772 1990 YM" "Sol" #3=
".:1990 YM:10772 1990 YM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"10772 1990 YM.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.203
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.693955814724
		SemiMajorAxis	2.38958415231
		Eccentricity	0.25095015113
		Inclination	24.386631147987
		AscendingNode	103.776653642905
		ArgOfPericenter	38.205507105498
		MeanAnomaly	209.936218312494
	}
	UniformRotation
	{
		Period	68.7
	}
	LunarLambert	0.5
	Albedo	0.202
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10772"
}

#1_"10784 Noailles:Noailles:1991 RQ11:1990 HG3" "Sol" #1=
#2_"*Ноай:10784 Noailles:Noailles:1991 RQ11" "Sol" #2=
#3_"1991 RQ11:*Ноай:10784 Noailles:Noailles" "Sol" #3=
".:Noailles:10784 Noailles:1991 RQ11" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.895
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.252525154507
		SemiMajorAxis	2.624777286989
		Eccentricity	0.042126004597
		Inclination	15.939970962874
		AscendingNode	134.533522089837
		ArgOfPericenter	56.479507837954
		MeanAnomaly	294.893266863181
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0309
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10784"
}

#1_"10826 1993 SK16:1993 SK16:1981 BT:1983 VG2:1990 VF14" "Sol" #1=
#2_"1993 SK16:10826 1993 SK16" "Sol" #2=
#3_"1993 SK16:10826 1993 SK16" "Sol" #3=
".:1993 SK16:10826 1993 SK16" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"10826 1993 SK16.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.598
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.430404563287
		SemiMajorAxis	2.274528725981
		Eccentricity	0.149380883679
		Inclination	7.658208931
		AscendingNode	260.650175287398
		ArgOfPericenter	32.698940608423
		MeanAnomaly	182.30813958728
	}
	UniformRotation
	{
		Period	13.835
	}
	LunarLambert	0.5
	Albedo	0.236
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10826"
}

#1_"10889 1997 AO1:1997 AO1:1986 VK4:1989 BK2" "Sol" #1=
#2_"1997 AO1:10889 1997 AO1" "Sol" #2=
#3_"1997 AO1:10889 1997 AO1" "Sol" #3=
".:1997 AO1:10889 1997 AO1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.794365554476
		SemiMajorAxis	3.93110863281
		Eccentricity	0.067195704691
		Inclination	5.196276766858
		AscendingNode	112.455503924722
		ArgOfPericenter	172.096851616632
		MeanAnomaly	302.547311108397
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0403
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10889"
}

#1_"10944 1999 FJ26:1999 FJ26:1926 GA1:1932 WF:1979 KA1:1982 BY8:1988 SH4:1991 GV11:1992 TB2: #1=
#1_1996 TO50" "Sol" #1=
#2_"1999 FJ26:10944 1999 FJ26" "Sol" #2=
#3_"1999 FJ26:10944 1999 FJ26" "Sol" #3=
".:1999 FJ26:10944 1999 FJ26" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.855
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.061448471801
		SemiMajorAxis	2.545551162503
		Eccentricity	0.168454160624
		Inclination	4.267799456953
		AscendingNode	261.874114069363
		ArgOfPericenter	343.575928578374
		MeanAnomaly	275.33871408463
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0412
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10944"
}

#1_"10946 1999 HR2:1999 HR2:1968 UF3:1991 RO9:1992 UA10" "Sol" #1=
#2_"1999 HR2:10946 1999 HR2" "Sol" #2=
#3_"1999 HR2:10946 1999 HR2" "Sol" #3=
".:1999 HR2:10946 1999 HR2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.829675185609
		SemiMajorAxis	2.857194558352
		Eccentricity	0.214427970583
		Inclination	15.911246652611
		AscendingNode	47.527827500131
		ArgOfPericenter	63.884199524626
		MeanAnomaly	153.492668797681
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0435
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=10946"
}

#1_"11004 Stenmark:Stenmark:1980 FJ1:1976 SD10:1988 RN7" "Sol" #1=
#2_"*Стенмарк:11004 Stenmark:Stenmark:1980 FJ1" "Sol" #2=
#3_"1980 FJ1:*Стенмарк:11004 Stenmark:Stenmark" "Sol" #3=
".:Stenmark:11004 Stenmark:1980 FJ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.770199263409
		SemiMajorAxis	3.217029715598
		Eccentricity	0.159801600142
		Inclination	16.77427860519
		AscendingNode	351.7544794364
		ArgOfPericenter	347.359115608856
		MeanAnomaly	194.168654346785
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0396
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11004"
}

#1_"11052 1990 WM:1990 WM:1982 BV6:1998 DY2" "Sol" #1=
#2_"11052 1990 WM:1990 WM" "Sol" #2=
#3_"1990 WM:11052 1990 WM" "Sol" #3=
".:1990 WM:11052 1990 WM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"11052 1990 WM.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.586
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.198772109956
		SemiMajorAxis	3.00097044811
		Eccentricity	0.079834089955
		Inclination	12.27977395818
		AscendingNode	98.069504516429
		ArgOfPericenter	166.108957179803
		MeanAnomaly	142.117657713196
	}
	UniformRotation
	{
		Period	5.06904
	}
	LunarLambert	0.5
	Albedo	0.17
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11052"
}

#1_"11058 1991 PN10:1991 PN10:1993 FP3" "Sol" #1=
#2_"1991 PN10:11058 1991 PN10" "Sol" #2=
#3_"1991 PN10:11058 1991 PN10" "Sol" #3=
".:1991 PN10:11058 1991 PN10" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"11058 1991 PN10.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.93
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.731289304035
		SemiMajorAxis	1.953918003297
		Eccentricity	0.070155128589
		Inclination	22.502020133452
		AscendingNode	167.118668524375
		ArgOfPericenter	97.298412491123
		MeanAnomaly	186.882221689536
	}
	UniformRotation
	{
		Period	6.517
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11058"
}

#1_"11066 Sigurd:Sigurd:1992 CC1:1987 GE" "Sol" #1=
#2_"*Сигурд:11066 Sigurd:Sigurd:1992 CC1" "Sol" #2=
#3_"1992 CC1:*Сигурд:11066 Sigurd:Sigurd" "Sol" #3=
".:Sigurd:11066 Sigurd:1992 CC1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.641635465148
		SemiMajorAxis	1.391593363866
		Eccentricity	0.375168442897
		Inclination	36.88456625974
		AscendingNode	349.252371331562
		ArgOfPericenter	21.965913677791
		MeanAnomaly	73.66591099503
	}
	UniformRotation
	{
		Period	8.4958
	}
	LunarLambert	0.5
	Albedo	0.12
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11066"
}

#1_"11096 1994 RU1:1994 RU1:1977 SK:1998 HT115" "Sol" #1=
#2_"1994 RU1:11096 1994 RU1" "Sol" #2=
#3_"1994 RU1:11096 1994 RU1" "Sol" #3=
".:1994 RU1:11096 1994 RU1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.625
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.584553145519
		SemiMajorAxis	3.147652768146
		Eccentricity	0.243447334203
		Inclination	17.01946484227
		AscendingNode	172.12594147503
		ArgOfPericenter	193.786595164693
		MeanAnomaly	212.846039770137
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0697
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11096"
}

#1_"11148 Einhardress:1997 XO8:1981 UZ21:1991 JX2" "Sol" #1=
#2_"*Эйнхардресс:11148 Einhardress:Einhardress:1997 XO8" "Sol" #2=
#3_"1997 XO8:*Эйнхардресс:11148 Einhardress:Einhardress" "Sol" #3=
".:Einhardress:11148 Einhardress:1997 XO8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"11148 einhardress.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.08
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.828493961701
		SemiMajorAxis	2.44725848418
		Eccentricity	0.116349563628
		Inclination	3.878417438303
		AscendingNode	97.450767910318
		ArgOfPericenter	81.464319704578
		MeanAnomaly	313.418251992922
	}
	UniformRotation
	{
		Period	7.7724
	}
	LunarLambert	0.5
	Albedo	0.134
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11148"
}

#1_"11179 1998 FB109:1998 FB109:1979 QB5:1979 QM4" "Sol" #1=
#2_"1998 FB109:11179 1998 FB109" "Sol" #2=
#3_"1998 FB109:11179 1998 FB109" "Sol" #3=
".:1998 FB109:11179 1998 FB109" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.52
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.068755278349
		SemiMajorAxis	2.5486033211
		Eccentricity	0.083381494442
		Inclination	5.47828405715
		AscendingNode	330.891100064126
		ArgOfPericenter	132.847338813232
		MeanAnomaly	114.352169653274
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0161
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11179"
}

#1_"11195 Woomera:Woomera:1999 AY22:1981 AD2" "Sol" #1=
#2_"*Вумера:11195 Woomera:Woomera:1999 AY22" "Sol" #2=
#3_"1999 AY22:*Вумера:11195 Woomera:Woomera" "Sol" #3=
".:Woomera:11195 Woomera:1999 AY22" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.543022385668
		SemiMajorAxis	2.324041056533
		Eccentricity	0.113789491864
		Inclination	3.057198916546
		AscendingNode	292.084502461419
		ArgOfPericenter	202.897386337429
		MeanAnomaly	189.49233967791
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0329
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11195"
}

#1_"11221 1999 JO26:1999 JO26:1976 JV1:1978 TW8:1982 KU" "Sol" #1=
#2_"1999 JO26:11221 1999 JO26" "Sol" #2=
#3_"1999 JO26:11221 1999 JO26" "Sol" #3=
".:1999 JO26:11221 1999 JO26" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.793694414231
		SemiMajorAxis	3.225756554214
		Eccentricity	0.109991778813
		Inclination	12.521187749897
		AscendingNode	49.936252185251
		ArgOfPericenter	261.354638301416
		MeanAnomaly	175.363064328368
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0703
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11221"
}

#1_"11232 1999 JA77:1999 JA77:1978 TF:1979 YK4:1988 LX:1990 UV1:1998 DJ36" "Sol" #1=
#2_"1999 JA77:11232 1999 JA77" "Sol" #2=
#3_"1999 JA77:11232 1999 JA77" "Sol" #3=
".:1999 JA77:11232 1999 JA77" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.355
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.705154673944
		SemiMajorAxis	3.192808080785
		Eccentricity	0.072876392622
		Inclination	11.312294537647
		AscendingNode	91.300869192623
		ArgOfPericenter	155.296362023566
		MeanAnomaly	243.528377302162
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0264
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11232"
}

#1_"11311 Peleus:Peleus:1993 XN2" "Sol" #1=
#2_"*Пелей:11311 Peleus:Peleus:1993 XN2" "Sol" #2=
#3_"1993 XN2:*Пелей:11311 Peleus:Peleus" "Sol" #3=
".:Peleus:11311 Peleus:1993 XN2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.081330237105
		SemiMajorAxis	2.117483471119
		Eccentricity	0.535445391173
		Inclination	25.430504245656
		AscendingNode	59.532573578936
		ArgOfPericenter	313.114265448586
		MeanAnomaly	314.97399304211
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11311"
}

#1_"11313 Kugelgen:Kugelgen:1994 GE10:1979 GG:1997 AJ14:1998 HA46" "Sol" #1=
#2_"*Кюгельген:11313 Kugelgen:Kugelgen:1994 GE10" "Sol" #2=
#3_"1994 GE10:*Кюгельген:11313 Kugelgen:Kugelgen" "Sol" #3=
".:Kugelgen:11313 Kugelgen:1994 GE10" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.775163921091
		SemiMajorAxis	2.424478893703
		Eccentricity	0.041334364986
		Inclination	1.158033802514
		AscendingNode	100.577290887306
		ArgOfPericenter	331.922894553455
		MeanAnomaly	276.888670455511
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0127
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11313"
}

#New4-Name
#1_"11351 Leucus:Leucus:1997 TS25:1996 VP39" "Sol" #1=
#2_"*Лейкус:11351 Leucus:Leucus:1997 TS25" "Sol" #2=
#3_"1997 TS25:*Лейкус:11351 Leucus:Leucus" "Sol" #3=
".:Leucus:11351 Leucus:1997 TS25" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.077
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.1293842033
		SemiMajorAxis	5.279024776422
		Eccentricity	0.064563748669
		Inclination	11.563277548568
		AscendingNode	251.085273603087
		ArgOfPericenter	161.548960995621
		MeanAnomaly	159.937471995456
	}
	UniformRotation
	{
		Period	515
	}
	LunarLambert	0.5
	Albedo	0.079
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11351"
}

#1_"11386 1998 TA18:1998 TA18:1973 YY2:1984 YQ5:1984 YT6:1987 QU9:1991 XJ2" "Sol" #1=
#2_"1998 TA18:11386 1998 TA18" "Sol" #2=
#3_"1998 TA18:11386 1998 TA18" "Sol" #3=
".:1998 TA18:11386 1998 TA18" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.92
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.602198159161
		SemiMajorAxis	2.34984706736
		Eccentricity	0.27757588414
		Inclination	6.862834375433
		AscendingNode	261.396587647244
		ArgOfPericenter	97.391371278091
		MeanAnomaly	185.132577570555
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0458
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11386"
}

#1_"11395 1998 XN77:1998 XN77:1992 GF3" "Sol" #1=
#2_"1998 XN77:11395 1998 XN77" "Sol" #2=
#3_"1998 XN77:11395 1998 XN77" "Sol" #3=
".:1998 TA18:11386 1998 TA18" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32.355
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.909941253776
		SemiMajorAxis	5.215159691842
		Eccentricity	0.066108483398
		Inclination	24.13607736093
		AscendingNode	213.242722329233
		ArgOfPericenter	117.596154274542
		MeanAnomaly	217.433768763443
	}
	UniformRotation
	{
		Period	13.7
	}
	LunarLambert	0.5
	Albedo	0.0669
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11395"
}

#1_"11396 1998 XZ77:1998 XZ77:1992 HU2" "Sol" #1=
#2_"1998 XZ77:11396 1998 XZ77" "Sol" #2=
#3_"1998 XZ77:11396 1998 XZ77" "Sol" #3=
".:1998 XZ77:11396 1998 XZ77" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.90350647341
		SemiMajorAxis	5.213281069098
		Eccentricity	0.063172676563
		Inclination	12.582689547281
		AscendingNode	195.694787301696
		ArgOfPericenter	177.140839478516
		MeanAnomaly	177.426346500394
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0469
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11396"
}

#1_"11474 1982 SM2:1982 SM2:1995 KD" "Sol" #1=
#2_"1982 SM2:11474 1982 SM2" "Sol" #2=
#3_"1982 SM2:11474 1982 SM2" "Sol" #3=
".:1982 SM2:11474 1982 SM2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.413
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	3.433273508034
		SemiMajorAxis	2.27579671792
		Eccentricity	0.196091980626
		Inclination	5.407272244938
		AscendingNode	348.588876878332
		ArgOfPericenter	355.647581130603
		MeanAnomaly	321.177279986138
	}
	UniformRotation
	{
		Period	1917.2214
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11474"
}

#1_"11500 Tomaiyowit:Tomaiyowit:1989 UR" "Sol" #1=
#2_"*Томайёвит:11500 Tomaiyowit:Tomaiyowit:1989 UR" "Sol" #2=
#3_"1989 UR:*Томайёвит:11500 Tomaiyowit:Tomaiyowit" "Sol" #3=
".:Tomaiyowit:11500 Tomaiyowit:1989 UR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.4493
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.122167794849
		SemiMajorAxis	1.079857375677
		Eccentricity	0.355871799293
		Inclination	10.309275059577
		AscendingNode	234.464046239091
		ArgOfPericenter	289.40862668684
		MeanAnomaly	41.301527358875
	}
	UniformRotation
	{
		Period	73
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11500"
}

#1_"11542 Solikamsk:Solikamsk:1992 SU21:1931 BR:1987 FV1" "Sol" #1=
#2_"*Соликамск:11542 Solikamsk:Solikamsk:1992 SU21" "Sol" #2=
#3_"1992 SU21:*Соликамск:11542 Solikamsk:Solikamsk" "Sol" #3=
".:Solikamsk:11542 Solikamsk:1992 SU21" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.86
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.869236551791
		SemiMajorAxis	3.95624275625
		Eccentricity	0.240889364001
		Inclination	6.868561005652
		AscendingNode	16.779647671208
		ArgOfPericenter	49.672661591475
		MeanAnomaly	245.227191249326
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0216
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11542"
}

#1_"11569 Virgilsmith:Virgilsmith:1993 KB2:1983 SK:1983 TK" "Sol" #1=
#2_"*Вирджилсмит:11569 Virgilsmith:Virgilsmith:1993 KB2" "Sol" #2=
#3_"1993 KB2:*Вирджилсмит:11569 Virgilsmith:Virgilsmith" "Sol" #3=
".:Virgilsmith:11569 Virgilsmith:1993 KB2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.155
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.462854430386
		SemiMajorAxis	3.101755900934
		Eccentricity	0.166379302169
		Inclination	18.196588089769
		AscendingNode	175.051090552516
		ArgOfPericenter	102.037466298501
		MeanAnomaly	313.140904081584
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0305
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11569"
}

#1_"11576 1994 CL:1994 CL:1998 FC15" "Sol" #1=
#2_"1994 CL:11576 1994 CL" "Sol" #2=
#3_"1994 CL:11576 1994 CL" "Sol" #3=
".:1994 CL:11576 1994 CL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.525
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.761723037784
		SemiMajorAxis	2.418720820475
		Eccentricity	0.134098844575
		Inclination	10.912778394543
		AscendingNode	356.392017279343
		ArgOfPericenter	256.953139220162
		MeanAnomaly	102.560372779406
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0496
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11576"
}

#1_"11645 1997 BY1:1997 BY1:1991 TA2:1993 CE" "Sol" #1=
#2_"1997 BY1:11645 1997 BY1" "Sol" #2=
#3_"1997 BY1:11645 1997 BY1" "Sol" #3=
".:1997 BY1:11645 1997 BY1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.42
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.073867671654
		SemiMajorAxis	2.550737755278
		Eccentricity	0.186202505448
		Inclination	12.985445830427
		AscendingNode	131.453140638892
		ArgOfPericenter	238.126431052633
		MeanAnomaly	249.777679861952
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0988
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11645"
}

#1_"11700 1998 FT115:1998 FT115:1983 CV1:1988 EX2:1990 TG10" "Sol" #1=
#2_"1998 FT115:11700 1998 FT115" "Sol" #2=
#3_"1998 FT115:11700 1998 FT115" "Sol" #3=
".:1998 FT115:11700 1998 FT115" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"11700 1998 FT115.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.278
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.83599028758
		SemiMajorAxis	2.859684656121
		Eccentricity	0.187904568052
		Inclination	4.241326168026
		AscendingNode	302.58929083968
		ArgOfPericenter	291.542915155062
		MeanAnomaly	297.078007811896
	}
	UniformRotation
	{
		Period	5.52303
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11700"
}

#1_"11885 Summanus:Summanus:1990 SS" "Sol" #1=
#2_"*Сумман:11885 Summanus:Summanus:1990 SS" "Sol" #2=
#3_"1990 SS:*Сумман:11885 Summanus:Summanus" "Sol" #3=
".:Summanus:11885 Summanus:1990 SS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.4095
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.223315739536
		SemiMajorAxis	1.703447004244
		Eccentricity	0.474797195904
		Inclination	19.418876464515
		AscendingNode	359.891766459704
		ArgOfPericenter	116.06646155892
		MeanAnomaly	263.405392299888
	}
	UniformRotation
	{
		Period	7.358
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11885"
}

#1_"11958 Galiani:Galiani:1994 EJ7:1996 XT15" "Sol" #1=
#2_"*Галиани:11958 Galiani:Galiani:1994 EJ7" "Sol" #2=
#3_"1994 EJ7:Galiani:*Галиани:11958 Galiani" "Sol" #3=
".:Galiani:11958 Galiani:1994 EJ7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"11958 galiani.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.465295274909
		SemiMajorAxis	2.289925549763
		Eccentricity	0.145067306365
		Inclination	5.996742000471
		AscendingNode	89.99950898312
		ArgOfPericenter	293.152239906507
		MeanAnomaly	355.538435203594
	}
	UniformRotation
	{
		Period	9.801
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11958"
}

#1_"11990 1995 WM6:1995 WM6:1986 TM3:1997 FA2" "Sol" #1=
#2_"1995 WM6:11990 1995 WM6" "Sol" #2=
#3_"1995 WM6:11990 1995 WM6" "Sol" #3=
".:1995 WM6:11990 1995 WM6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.445
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.375611213534
		SemiMajorAxis	2.675184151681
		Eccentricity	0.176512704159
		Inclination	3.326211444708
		AscendingNode	196.888662759137
		ArgOfPericenter	280.431693227693
		MeanAnomaly	77.169282817206
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0593
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11990"
}

#1_"11995 1995 YB1:1995 YB1:1980 DS3:1994 UE13" "Sol" #1=
#2_"1995 YB1:11995 1995 YB1" "Sol" #2=
#3_"1995 YB1:11995 1995 YB1" "Sol" #3=
".:1995 YB1:11995 1995 YB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"11995 1995 YB1.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	6.43
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.510154793498
		SemiMajorAxis	3.119634621186
		Eccentricity	0.095116138831
		Inclination	5.841305132817
		AscendingNode	119.941809401636
		ArgOfPericenter	90.949825210639
		MeanAnomaly	204.80032431675
	}
	UniformRotation
	{
		Period	12.66498
	}
	LunarLambert	0.5
	Albedo	0.081
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=11995"
}

#1_"12003 Hideosugai:Hideosugai:1996 FM5:1975 VG6:1983 DR" "Sol" #1=
#2_"*Хидеосогаи:12003 Hideosugai:Hideosugai:1996 FM5" "Sol" #2=
#3_"1996 FM5:*Хидеосогаи:12003 Hideosugai:Hideosugai" "Sol" #3=
".:Hideosugai:12003 Hideosugai:1996 FM5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.535
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.163181018725
		SemiMajorAxis	3.361484767062
		Eccentricity	0.091759647906
		Inclination	9.829558210759
		AscendingNode	10.611631860896
		ArgOfPericenter	78.372755921376
		MeanAnomaly	116.638504641292
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0276
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12003"
}

#1_"12045 Klein:1997 FH1:1982 UT7:1986 RB7:1990 RD12" "Sol" #1=
#2_"*Клейн:12045 Klein:1997 FH1:Klein" "Sol" #2=
#3_"1997 FH1:*Клейн:12045 Klein:Klein" "Sol" #3=
".:Klein:12045 Klein:1997 FH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"12045 klein.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.527
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.205172802934
		SemiMajorAxis	2.605256150079
		Eccentricity	0.192197812909
		Inclination	12.723636496995
		AscendingNode	349.991816033799
		ArgOfPericenter	326.43093610114
		MeanAnomaly	108.440192902185
	}
	UniformRotation
	{
		Period	8.9686
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12045"
}

#1_"12080 1998 FC111:1998 FC111:1979 SQ10:1996 CG" "Sol" #1=
#2_"1998 FC111:12080 1998 FC111" "Sol" #2=
#3_"1998 FC111:12080 1998 FC111" "Sol" #3=
".:1998 FC111:12080 1998 FC111" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.221996416461
		SemiMajorAxis	3.009901232457
		Eccentricity	0.093239794272
		Inclination	9.028350597602
		AscendingNode	272.083465616985
		ArgOfPericenter	27.423273712428
		MeanAnomaly	341.626050214586
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0356
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12080"
}

#1_"12098 1998 HV122:1998 HV122:1978 YY:1989 WY2" "Sol" #1=
#2_"1998 HV122:12098 1998 HV122" "Sol" #2=
#3_"1998 HV122:12098 1998 HV122" "Sol" #3=
".:1998 HV122:12098 1998 HV122" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.905
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.474907878722
		SemiMajorAxis	3.10631677899
		Eccentricity	0.212713388966
		Inclination	10.282607312186
		AscendingNode	96.476135991816
		ArgOfPericenter	261.331522067628
		MeanAnomaly	254.202389975956
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0422
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12098"
}

#1_"12365 Yoshitoki:Yoshitoki:1993 YD" "Sol" #1=
#2_"*Ёситоки:12365 Yoshitoki:Yoshitoki:1993 YD" "Sol" #2=
#3_"1993 YD:*Ёситоки:12365 Yoshitoki:Yoshitoki" "Sol" #3=
".:12365 Yoshitoki:Yoshitoki:1993 YD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.765
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.65582401946
		SemiMajorAxis	3.174376658894
		Eccentricity	0.029047040171
		Inclination	14.803632029261
		AscendingNode	100.181602433577
		ArgOfPericenter	76.83875579571
		MeanAnomaly	173.19117890316
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0194
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12365"
}

#1_"12384 Luigimartella:Luigimartella:1994 TC2:1968 QV1:1978 NQ5:1989 SR13:1997 EA44:1999 RG146" "Sol" #1=
#2_"*Луиджимартелла:12384 Luigimartella:Luigimartella:1994 TC2" "Sol" #2=
#3_"1994 TC2:Luigimartella:*Луиджимартелла:12384 Luigimartella" "Sol" #3=
".:Luigimartella:12384 Luigimartella:1994 TC2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"12384 luigimartella.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.714
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.158774971452
		SemiMajorAxis	2.98555851788
		Eccentricity	0.097270031295
		Inclination	9.868340227964
		AscendingNode	322.61682738692
		ArgOfPericenter	348.28627651562
		MeanAnomaly	160.835446642966
	}
	UniformRotation
	{
		Period	6.4399
	}
	LunarLambert	0.5
	Albedo	0.151
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12384"
}

#1_"12444 Prothoon:Prothoon:1996 GE19" "Sol" #1=
#2_"*Протхоон:12444 Prothoon:Prothoon:1996 GE19" "Sol" #2=
#3_"1996 GE19:*Протхоон:12444 Prothoon:Prothoon" "Sol" #3=
".:Prothoon:12444 Prothoon:1996 GE19" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32.155
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.033078165352
		SemiMajorAxis	5.251044398993
		Eccentricity	0.070353485723
		Inclination	30.820850667695
		AscendingNode	213.208972221775
		ArgOfPericenter	65.199637443798
		MeanAnomaly	141.400767726247
	}
	UniformRotation
	{
		Period	15.82
	}
	LunarLambert	0.5
	Albedo	0.039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12444"
}

#1_"12445 Sirataka:Sirataka:1996 HE2:1997 SX4" "Sol" #1=
#2_"*Сиратака:12445 Sirataka:Sirataka:1996 HE2" "Sol" #2=
#3_"1996 HE2:*Сиратака:12445 Sirataka:Sirataka" "Sol" #3=
".:Sirataka:12445 Sirataka:1996 HE2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.495
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.487523614941
		SemiMajorAxis	3.111086836512
		Eccentricity	0.031071634371
		Inclination	10.092450763984
		AscendingNode	72.32805474578
		ArgOfPericenter	187.839823767894
		MeanAnomaly	107.102739871786
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0278
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12445"
}

#1_"12481 Streuvels:Streuvels:1997 EW47:1978 EJ7:1989 TP15" "Sol" #1=
#2_"*Стреувелс:12481 Streuvels:Streuvels:1997 EW47" "Sol" #2=
#3_"1997 EW47:*Стреувелс:12481 Streuvels:Streuvels" "Sol" #3=
".:Streuvels:12481 Streuvels:1997 EW47" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.865
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.64866701336
		SemiMajorAxis	2.785352451482
		Eccentricity	0.154061347626
		Inclination	9.11389692995
		AscendingNode	195.921814317043
		ArgOfPericenter	65.870035097427
		MeanAnomaly	245.108974491362
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0409
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12481"
}

#1_"12551 1998 QQ39:1998 QQ39:1978 EW4:1979 PG:1987 SN21:1991 XV" "Sol" #1=
#2_"1998 QQ39:12551 1998 QQ39" "Sol" #2=
#3_"1998 QQ39:12551 1998 QQ39" "Sol" #3=
".:1998 QQ39:12551 1998 QQ39" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"12551 1998 QQ39.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.041
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.769975539985
		SemiMajorAxis	2.422257002795
		Eccentricity	0.09480119638
		Inclination	5.493776574203
		AscendingNode	8.290401751467
		ArgOfPericenter	256.118590100298
		MeanAnomaly	26.119780468791
	}
	UniformRotation
	{
		Period	11.202
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12551"
}

#1_"12583 Buckjean:Buckjean:1999 RC35:1958 VC1:1978 TP1:1979 YO2:1994 UG1" "Sol" #1=
#2_"*Бакджен:12583 Buckjean:Buckjean:1999 RC35" "Sol" #2=
#3_"1999 RC35:*Бакджен:12583 Buckjean:Buckjean" "Sol" #3=
".:Buckjean:12583 Buckjean:1999 RC35" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.88
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.152310089732
		SemiMajorAxis	2.98306369868
		Eccentricity	0.068404290649
		Inclination	10.870311050499
		AscendingNode	26.730410744113
		ArgOfPericenter	14.078407892811
		MeanAnomaly	324.513149369294
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.032
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12583"
}

#1_"12649 Ascanios:Ascanios:2035 T-3:1988 RW" "Sol" #1=
#2_"*Асканий:12649 Ascanios:Ascanios:1977-12649*:2035 T-3" "Sol" #2=
#3_"1977-12649*:*Асканий:12649 Ascanios:Ascanios:2035 T-3" "Sol" #3=
".:Ascanios:12649 Ascanios:1977-12649*:2035 T-3" "Sol" #4=
{
	Class	"asteroid" # троянский астероид Юпитера, двигающийся в точке Лагранжа L5
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.551
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	11.705012279596
		SemiMajorAxis	5.155163544690609
		Eccentricity	0.1468251640360074
		Inclination	6.571665824914018
		AscendingNode	337.5934431021282
		ArgOfPericenter	342.3297864031546
		MeanAnomaly	178.8365168229411
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.064
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12649"
}

#1_"12711 Tukmit:Tukmit:1991 BB" "Sol" #1=
#2_"*Тукмит:12711 Tukmit:Tukmit:1991 BB" "Sol" #2=
#3_"1991 BB:*Тукмит:12711 Tukmit:Tukmit" "Sol" #3=
".:Tukmit:12711 Tukmit:1991 BB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.292184090579
		SemiMajorAxis	1.186344419258
		Eccentricity	0.272226233139
		Inclination	38.48799343924
		AscendingNode	294.994096676556
		ArgOfPericenter	322.881448351319
		MeanAnomaly	65.26330986687
	}
	UniformRotation
	{
		Period	3.4848
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12711"
}

#1_"12714 Alkimos:Alkimos:1991 GX1:1990 EY1" "Sol" #1=
#2_"*Алким:12714 Alkimos:Alkimos:1991 GX1" "Sol" #2=
#3_"1991 GX1:*Алким:12714 Alkimos:Alkimos" "Sol" #3=
".:Alkimos:12714 Alkimos:1991 GX1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	30.52
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.943273864526
		SemiMajorAxis	5.224885678958
		Eccentricity	0.03695597761
		Inclination	9.50800248226
		AscendingNode	298.909978408314
		ArgOfPericenter	164.02720075979
		MeanAnomaly	98.406341484701
	}
	UniformRotation
	{
		Period	28.48
	}
	LunarLambert	0.5
	Albedo	0.036
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12714"
}

#1_"12738 Satoshimiki:Satoshimiki:1992 AL:1978 SF:1988 CE1" "Sol" #1=
#2_"*Сатошимики:12738 Satoshimiki:Satoshimiki:1992 AL" "Sol" #2=
#3_"1992 AL:*Сатошимики:12738 Satoshimiki:Satoshimiki" "Sol" #3=
".:Satoshimiki:12738 Satoshimiki:1992 AL" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.055768947117
		SemiMajorAxis	2.543177478595
		Eccentricity	0.286535588137
		Inclination	13.298533403036
		AscendingNode	143.04312016078
		ArgOfPericenter	273.639377376196
		MeanAnomaly	276.276900218942
	}
	UniformRotation
	{
		Period	8.7081
	}
	LunarLambert	0.5
	Albedo	0.0419
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12738"
}

#1_"12753 Povenmire:Povenmire:1993 HE:1984 AH1" "Sol" #1=
#2_"*Повенмайр:12753 Povenmire:Povenmire:1993 HE" "Sol" #2=
#3_"1993 HE:Povenmire:*Повенмайр:12753 Povenmire" "Sol" #3=
".:Povenmire:12753 Povenmire:1993 HE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"12753 povenmire.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.806
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.254885672749
		SemiMajorAxis	2.625748515671
		Eccentricity	0.144658972385
		Inclination	14.813605785033
		AscendingNode	93.651787833062
		ArgOfPericenter	111.667251374114
		MeanAnomaly	218.605031186906
	}
	UniformRotation
	{
		Period	17.5752
	}
	LunarLambert	0.5
	Albedo	0.305
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12753"
}

#1_"12774 Pfund:Pfund:1994 PH22:1981 UA25:1981 UO20:1996 DK5" "Sol" #1=
#2_"*Пфунд:12774 Pfund:Pfund:1994 PH22" "Sol" #2=
#3_"1994 PH22:Pfund:*Пфунд:12774 Pfund" "Sol" #3=
".:Pfund:12774 Pfund:1994 PH22" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"12774 pfund.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	2.71
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.433033924564
		SemiMajorAxis	2.698538188438
		Eccentricity	0.205199191575
		Inclination	2.436113844104
		AscendingNode	165.254965400914
		ArgOfPericenter	242.307067655134
		MeanAnomaly	337.998370508309
	}
	UniformRotation
	{
		Period	7.343
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12774"
}

#1_"12923 Zephyr:Zephyr:1999 GK4" "Sol" #1=
#2_"*Зефир:12923 Zephyr:Zephyr:1999 GK4" "Sol" #2=
#3_"1999 GK4:*Зефир:12923 Zephyr:Zephyr" "Sol" #3=
".:Zephyr:12923 Zephyr:1999 GK4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.750185087153
		SemiMajorAxis	1.962919459084
		Eccentricity	0.491698442329
		Inclination	5.299411455978
		AscendingNode	168.223992189005
		ArgOfPericenter	147.003398010875
		MeanAnomaly	200.628145931574
	}
	UniformRotation
	{
		Period	3.891
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12923"
}

#1_"12979 Evgalvasil'ev:Evgalvasil'ev:1978 SB8:1977 HP" "Sol" #1=
#2_"*Евгалвасильев:12979 Evgalvasil'ev:Evgalvasil'ev:1978 SB8" "Sol" #2=
#3_"1978 SB8:Evgalvasil'ev:*Евгалвасильев:12979 Evgalvasil'ev" "Sol" #3=
".:Evgalvasil'ev:12979 Evgalvasil'ev:1978 SB8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"12979 evgalvasilev.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.433
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.415279016251
		SemiMajorAxis	2.267837809969
		Eccentricity	0.17859885711
		Inclination	5.355926867026
		AscendingNode	14.672975407955
		ArgOfPericenter	354.261826546106
		MeanAnomaly	87.579135914658
	}
	UniformRotation
	{
		Period	5.78331
	}
	LunarLambert	0.5
	Albedo	0.41
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12979"
}

#1_"12983 1979 OH1:1979 OH1:1998 XC82:1999 CU2" "Sol" #1=
#2_"1979 OH1:12983 1979 OH1" "Sol" #2=
#3_"1979 OH1:12983 1979 OH1" "Sol" #3=
".:1979 OH1:12983 1979 OH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.835
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.684117981711
		SemiMajorAxis	3.18495466054
		Eccentricity	0.066826989003
		Inclination	12.305542522587
		AscendingNode	137.21047797756
		ArgOfPericenter	109.435097496102
		MeanAnomaly	125.695817428828
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0156
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=12983"
}

#1_"13002 1982 BJ13:1982 BJ13:1991 RP13:1998 OF1" "Sol" #1=
#2_"1982 BJ13:13002 1982 BJ13" "Sol" #2=
#3_"1982 BJ13:13002 1982 BJ13" "Sol" #3=
".:1982 BJ13:13002 1982 BJ13" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"13002 1982 BJ13.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.652
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.715416388114
		SemiMajorAxis	2.398830304949
		Eccentricity	0.085753111611
		Inclination	5.026742991757
		AscendingNode	300.424490563477
		ArgOfPericenter	341.557583310413
		MeanAnomaly	213.052745954173
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13002"
}

#1_"13059 Ducuroir:Ducuroir:1991 BD1" "Sol" #1=
#2_"*Дюкуруа:13059 Ducuroir:Ducuroir:1991 BD1" "Sol" #2=
#3_"1991 BD1:Ducuroir:*Дюкуруа:13059 Ducuroir" "Sol" #3=
".:Ducuroir:13059 Ducuroir:1991 BD1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"13059 ducuroir.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.722
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.1631000677
		SemiMajorAxis	2.587849993441
		Eccentricity	0.095322324676
		Inclination	6.562701663443
		AscendingNode	115.232991126454
		ArgOfPericenter	53.50381989761
		MeanAnomaly	50.360534288503
	}
	UniformRotation
	{
		Period	13.8496
	}
	LunarLambert	0.5
	Albedo	0.26
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13059"
}

#1_"13124 1994 PS:1994 PS" "Sol" #1=
#2_"1994 PS:13124 1994 PS" "Sol" #2=
#3_"1994 PS:13124 1994 PS" "Sol" #3=
".:1994 PS:13124 1994 PS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.47
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.59854947876
		SemiMajorAxis	2.348260019929
		Eccentricity	0.10792095586
		Inclination	11.228334201034
		AscendingNode	154.35153071968
		ArgOfPericenter	31.333412239378
		MeanAnomaly	20.570818607077
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0383
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13124"
}

#1_"13176 Kobedaitenken:Kobedaitenken:1996 HE1:1961 GG:1998 SY27" "Sol" #1=
#2_"*Кобедайтенкен:13176 Kobedaitenken:Kobedaitenken:1996 HE1" "Sol" #2=
#3_"1996 HE1:*Кобедайтенкен:13176 Kobedaitenken:Kobedaitenken" "Sol" #3=
".:Kobedaitenken:13176 Kobedaitenken:1996 HE1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.707996840857
		SemiMajorAxis	3.193868378093
		Eccentricity	0.13777666788
		Inclination	18.702056275456
		AscendingNode	56.932943650516
		ArgOfPericenter	131.426030042586
		MeanAnomaly	111.434354524042
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0258
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13176"
}

#1_"13244 Dannymeyer:Dannymeyer:1998 MJ14:1983 AY4:1989 BV:1997 MB" "Sol" #1=
#2_"*Дэннимейер:13244 Dannymeyer:Dannymeyer:1998 MJ14" "Sol" #2=
#3_"1998 MJ14:*Дэннимейер:13244 Dannymeyer:Dannymeyer" "Sol" #3=
".:Dannymeyer:13244 Dannymeyer:1998 MJ14" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.815
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.628942709203
		SemiMajorAxis	3.164310440266
		Eccentricity	0.011908445144
		Inclination	19.518061259215
		AscendingNode	284.896986628132
		ArgOfPericenter	351.576510103077
		MeanAnomaly	53.636208874857
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0486
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13244"
}

#1_"13249 Marcallen:Marcallen:1998 MD38:1952 BA1:1961 DG" "Sol" #1=
#2_"*Маркаллен:13249 Marcallen:Marcallen:1998 MD38" "Sol" #2=
#3_"1998 MD38:*Маркаллен:13249 Marcallen:Marcallen" "Sol" #3=
".:Marcallen:13249 Marcallen:1998 MD38" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.275
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.369393636961
		SemiMajorAxis	2.672649328061
		Eccentricity	0.1685964674
		Inclination	14.046753752594
		AscendingNode	284.309082532859
		ArgOfPericenter	134.258160606596
		MeanAnomaly	177.481747976676
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0663
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13249"
}

#1_"13295 1998 RE:1998 RE:1939 HB:1975 UU" "Sol" #1=
#2_"1998 RE:13295 1998 RE" "Sol" #2=
#3_"1998 RE:13295 1998 RE" "Sol" #3=
".:1998 RE:13295 1998 RE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.315
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.570228025874
		SemiMajorAxis	3.142267699664
		Eccentricity	0.09740097511
		Inclination	13.670832338128
		AscendingNode	58.209682175727
		ArgOfPericenter	125.306800252868
		MeanAnomaly	213.900239452966
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0465
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13295"
}

#1_"13338 1998 SK119:1998 SK119:1989 UY9:1991 EZ7:1996 FC17" "Sol" #1=
#2_"1998 SK119:13338 1998 SK119" "Sol" #2=
#3_"1998 SK119:13338 1998 SK119" "Sol" #3=
".:1998 SK119:13338 1998 SK119" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"13338 1998 SK119.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.77
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.623801273595
		SemiMajorAxis	2.775411000673
		Eccentricity	0.120406905597
		Inclination	9.337851854044
		AscendingNode	22.27419422384
		ArgOfPericenter	78.100131983832
		MeanAnomaly	278.908177683464
	}
	UniformRotation
	{
		Period	4.129105
	}
	LunarLambert	0.5
	Albedo	0.178
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13338"
}

#1_"13426 1999 VA25:1999 VA25:1975 TY3:1992 SF23" "Sol" #1=
#2_"1999 VA25:13426 1999 VA25" "Sol" #2=
#3_"1999 VA25:13426 1999 VA25" "Sol" #3=
".:1999 VA25:13426 1999 VA25" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.745
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.400487216812
		SemiMajorAxis	2.261284970377
		Eccentricity	0.20731236662
		Inclination	5.536714487306
		AscendingNode	66.48838815427
		ArgOfPericenter	325.3330756856
		MeanAnomaly	178.273398655814
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0134
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13426"
}

#1_"13535 1991 RS13:1991 RS13:1991 SP1:1994 NS9" "Sol" #1=
#2_"1991 RS13:13535 1991 RS13" "Sol" #2=
#3_"1991 RS13:13535 1991 RS13" "Sol" #3=
".:1991 RS13:13535 1991 RS13" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"13535 1991 RS13.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.006
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.344414387287
		SemiMajorAxis	2.236357621401
		Eccentricity	0.142890575216
		Inclination	4.360812397945
		AscendingNode	287.861502361157
		ArgOfPericenter	4.22936163251
		MeanAnomaly	269.658848938178
	}
	UniformRotation
	{
		Period	5.22705
	}
	LunarLambert	0.5
	Albedo	0.251
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13535"
}

#1_"13737 1998 RU76:1998 RU76:1976 OY:1976 PD:1980 TO14:1991 VB6" "Sol" #1=
#2_"1998 RU76:13737 1998 RU76" "Sol" #2=
#3_"1998 RU76:13737 1998 RU76" "Sol" #3=
".:1998 RU76:13737 1998 RU76" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.03
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.640633680069
		SemiMajorAxis	2.366532756487
		Eccentricity	0.251528176108
		Inclination	6.20935787468
		AscendingNode	149.479054603668
		ArgOfPericenter	168.613502941752
		MeanAnomaly	191.715671599196
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0333
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13737"
}

#1_"13832 1999 XR13:1999 XR13:1970 EJ:1971 HP:1980 WM:1983 EZ:1984 KH1" "Sol" #1=
#2_"1999 XR13:13832 1999 XR13" "Sol" #2=
#3_"1999 XR13:13832 1999 XR13" "Sol" #3=
".:1999 XR13:13832 1999 XR13" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	19.465
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.174570037511
		SemiMajorAxis	3.365624645674
		Eccentricity	0.1128172858
		Inclination	16.302049558705
		AscendingNode	85.256397709281
		ArgOfPericenter	126.552423121993
		MeanAnomaly	5.435221695423
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0735
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13832"
}

#1_"13860 Neely:Neely:1999 XH143:1937 OC:1970 NA:1987 QK:1989 YK4" "Sol" #1=
#2_"*Нили:13860 Neely:Neely:1999 XH143" "Sol" #2=
#3_"1999 XH143:*Нили:13860 Neely:Neely" "Sol" #3=
".:Neely:13860 Neely:1999 XH143" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	14.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.496457222764
		SemiMajorAxis	3.114462456791
		Eccentricity	0.199503138294
		Inclination	17.089613336348
		AscendingNode	121.171884100403
		ArgOfPericenter	187.218371751177
		MeanAnomaly	8.242615925805
	}
	UniformRotation
	{
		Period	9.791
	}
	LunarLambert	0.5
	Albedo	0.052
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13860"
}

#1_"13936 1989 HC:1989 HC:1991 TN1:1998 XH48:1999 BV33" "Sol" #1=
#2_"1989 HC:13936 1989 HC" "Sol" #2=
#3_"1989 HC:13936 1989 HC" "Sol" #3=
".:1989 HC:13936 1989 HC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.68
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.73631346489
		SemiMajorAxis	3.204422571973
		Eccentricity	0.007749296425
		Inclination	22.623044476905
		AscendingNode	82.537607040901
		ArgOfPericenter	272.422981875745
		MeanAnomaly	24.167613206539
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0676
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13936"
}

#1_"13952 Nykvist:Nykvist:1990 SN6:1994 WA2" "Sol" #1=
#2_"*Никвист:13952 Nykvist:Nykvist:1990 SN6" "Sol" #2=
#3_"1990 SN6:Nykvist:*Никвист:13952 Nykvist" "Sol" #3=
".:Nykvist:13952 Nykvist:1990 SN6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"13952 nykvist.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.168
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.674890991879
		SemiMajorAxis	2.381355164516
		Eccentricity	0.079786028525
		Inclination	4.863985306409
		AscendingNode	122.218438044658
		ArgOfPericenter	183.660801700428
		MeanAnomaly	116.346532571232
	}
	UniformRotation
	{
		Period	7.349
	}
	LunarLambert	0.5
	Albedo	0.111
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=13952"
}

#1_"14012 Amedee:Amedee:1993 XG:1996 LV2:1998 WB20" "Sol" #1=
#2_"*Амеде:14012 Amedee:Amedee:1993 XG" "Sol" #2=
#3_"1993 XG:*Амеде:14012 Amedee:Amedee" "Sol" #3=
".:Amedee:14012 Amedee:1993 XG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.81
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.852263179342
		SemiMajorAxis	2.866096204649
		Eccentricity	0.126851864189
		Inclination	13.840101806771
		AscendingNode	98.063916734687
		ArgOfPericenter	296.919718588652
		MeanAnomaly	143.890587185111
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0952
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14012"
}

#1_"14031 Rozyo:Rozyo:1994 WF2:1999 AA6" "Sol" #1=
#2_"*Розио:14031 Rozyo:Rozyo:1994 WF2" "Sol" #2=
#3_"1994 WF2:Rozyo:*Розио:14031 Rozyo" "Sol" #3=
".:Rozyo:14031 Rozyo:1994 WF2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"14031 rozyo.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.682
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.169917868356
		SemiMajorAxis	2.590674592561
		Eccentricity	0.1972339261
		Inclination	13.996618306003
		AscendingNode	87.108854657392
		ArgOfPericenter	291.44253456072
		MeanAnomaly	153.587604320198
	}
	UniformRotation
	{
		Period	2.900652
	}
	LunarLambert	0.5
	Albedo	0.375
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14031"
}

#1_"14044 1995 VS1:1995 VS1:1991 RJ8:1999 XH169:2000 BB51" "Sol" #1=
#2_"1995 VS1:14044 1995 VS1" "Sol" #2=
#3_"1995 VS1:14044 1995 VS1" "Sol" #3=
".:1995 VS1:14044 1995 VS1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"14044 1995 VS1.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.074
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.790270882334
		SemiMajorAxis	2.430942564318
		Eccentricity	0.135553137063
		Inclination	6.870275044445
		AscendingNode	49.760509829368
		ArgOfPericenter	329.299655983984
		MeanAnomaly	243.367006329557
	}
	UniformRotation
	{
		Period	9.25874
	}
	LunarLambert	0.5
	Albedo	0.258
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14044"
}

#1_"14120 Espenak:Espenak:1998 QJ54:1980 XJ2:1987 SK25:2000 AG237" "Sol" #1=
#2_"*Эспенак:14120 Espenak:Espenak:1998 QJ54" "Sol" #2=
#3_"1998 QJ54:*Эспенак:14120 Espenak:Espenak" "Sol" #3=
".:Espenak:14120 Espenak:1998 QJ54" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.680435303683
		SemiMajorAxis	2.383749731305
		Eccentricity	0.088814802741
		Inclination	5.98975187419
		AscendingNode	222.967239672936
		ArgOfPericenter	212.623850421923
		MeanAnomaly	84.756677340282
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0368
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14120"
}

#1_"14197 1998 XK72:1998 XK72:1976 SD7:1977 YC" "Sol" #1=
#2_"1998 XK72:14197 1998 XK72" "Sol" #2=
#3_"1998 XK72:14197 1998 XK72" "Sol" #3=
".:1998 XK72:14197 1998 XK72" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"14197 1998 XK72.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.068
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.289512782551
		SemiMajorAxis	3.035789439089
		Eccentricity	0.143712280819
		Inclination	1.285179708734
		AscendingNode	25.832570708994
		ArgOfPericenter	12.967836926702
		MeanAnomaly	193.957797215055
	}
	UniformRotation
	{
		Period	10.7
	}
	LunarLambert	0.5
	Albedo	0.106
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14197"
}

#1_"14203 Hocking:Hocking:1998 YT20:1953 PM1:1996 NJ4" "Sol" #1=
#2_"*Хокинг:14203 Hocking:Hocking:1998 YT20" "Sol" #2=
#3_"1998 YT20:Hocking:*Хокинг:14203 Hocking" "Sol" #3=
".:Hocking:14203 Hocking:1998 YT20" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"14203 hocking.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.636
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.370067317106
		SemiMajorAxis	3.066533299673
		Eccentricity	0.107429738038
		Inclination	9.443134787352
		AscendingNode	307.981216112092
		ArgOfPericenter	347.426961369464
		MeanAnomaly	318.551748230454
	}
	UniformRotation
	{
		Period	9.0857
	}
	LunarLambert	0.5
	Albedo	0.156
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14203"
}

#1_"14208 1999 CR64:1999 CR64:1992 NC" "Sol" #1=
#2_"1999 CR64:14208 1999 CR64" "Sol" #2=
#3_"1999 CR64:14208 1999 CR64" "Sol" #3=
".:1999 CR64:14208 1999 CR64" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.26
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.167415442857
		SemiMajorAxis	2.589638022385
		Eccentricity	0.164284697014
		Inclination	12.784194714362
		AscendingNode	198.200709567326
		ArgOfPericenter	134.176213408882
		MeanAnomaly	90.589802826571
	}
	UniformRotation
	{
		Period	18.2
	}
	LunarLambert	0.5
	Albedo	0.0391
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14208"
}

#1_"14257 2000 AR97:2000 AR97:1942 VT:1962 WC2:1962 XR:1972 VO1:1972 XD2:1972 YB1:1975 VU5:1983 AA5: #1=
#1_1987 FS1" "Sol" #1=
#2_"2000 AR97:14257 2000 AR97" "Sol" #2=
#3_"2000 AR97:14257 2000 AR97" "Sol" #3=
".:2000 AR97:14257 2000 AR97" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"14257 2000 AR97.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.601
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.322605891962
		SemiMajorAxis	2.226625024733
		Eccentricity	0.139232279694
		Inclination	5.167763386537
		AscendingNode	55.269699310737
		ArgOfPericenter	4.269346881297
		MeanAnomaly	123.751907755216
	}
	UniformRotation
	{
		Period	13.584
	}
	LunarLambert	0.5
	Albedo	0.311
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14257"
}

#1_"14268 2000 AK156:2000 AK156:1986 VS7:1989 EB3" "Sol" #1=
#2_"2000 AK156:14268 2000 AK156" "Sol" #2=
#3_"2000 AK156:14268 2000 AK156" "Sol" #3=
".:2000 AK156:14268 2000 AK156" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	28.77
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.035759866859
		SemiMajorAxis	5.251824538011
		Eccentricity	0.088638437373
		Inclination	14.964573619643
		AscendingNode	284.605366560801
		ArgOfPericenter	125.569144743452
		MeanAnomaly	121.218784348716
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0369
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14268"
}

#1_"14341 1983 RV3:1983 RV3:1991 GG11" "Sol" #1=
#2_"1983 RV3:14341 1983 RV3" "Sol" #2=
#3_"1983 RV3:14341 1983 RV3" "Sol" #3=
".:1983 RV3:14341 1983 RV3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.895
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.510556214172
		SemiMajorAxis	2.729907499685
		Eccentricity	0.168184764231
		Inclination	5.424013279935
		AscendingNode	175.672415260332
		ArgOfPericenter	144.817989792136
		MeanAnomaly	346.631046588991
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0405
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14341"
}

#1_"14394 1990 SP15:1990 SP15:1990 SR26:1994 GO:1999 CE62" "Sol" #1=
#2_"1990 SP15:14394 1990 SP15" "Sol" #2=
#3_"1990 SP15:14394 1990 SP15" "Sol" #3=
".:1990 SP15:14394 1990 SP15" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.05
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.787102770588
		SemiMajorAxis	3.223309402751
		Eccentricity	0.072698232495
		Inclination	15.645441898381
		AscendingNode	193.007803351524
		ArgOfPericenter	67.334336395626
		MeanAnomaly	148.159086090598
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0697
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14394"
}

#1_"14402 1991 DB:1991 DB" "Sol" #1=
#2_"1991 DB:14402 1991 DB" "Sol" #2=
#3_"1991 DB:14402 1991 DB" "Sol" #3=
".:1991 DB:14402 1991 DB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.246719479247
		SemiMajorAxis	1.715380355686
		Eccentricity	0.40206407437
		Inclination	11.418421814821
		AscendingNode	158.259286158786
		ArgOfPericenter	51.317463701219
		MeanAnomaly	185.96153763909
	}
	UniformRotation
	{
		Period	2.2656
	}
	LunarLambert	0.5
	Albedo	0.14
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14402"
}

#1_"14569 1998 QB32:1998 QB32:1999 XK208" "Sol" #1=
#2_"1998 QB32:14569 1998 QB32" "Sol" #2=
#3_"1998 QB32:14569 1998 QB32" "Sol" #3=
".:1998 QB32:14569 1998 QB32" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.865
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.924966958224
		SemiMajorAxis	3.974899677238
		Eccentricity	0.286807260309
		Inclination	10.901623659735
		AscendingNode	346.051776564971
		ArgOfPericenter	37.945953651042
		MeanAnomaly	350.803364843729
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0314
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14569"
}

#1_"14612 Irtish:Irtish:1998 SG164:1974 OK1:2000 AF80" "Sol" #1=
#2_"*Иртыш:14612 Irtish:Irtish:1998 SG164" "Sol" #2=
#3_"1998 SG164:*Иртыш:14612 Irtish:Irtish" "Sol" #3=
".:Irtish:14612 Irtish:1998 SG164" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.62
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.602124171382
		SemiMajorAxis	3.154251747431
		Eccentricity	0.096180856128
		Inclination	7.312600190937
		AscendingNode	141.090296117522
		ArgOfPericenter	78.751638763304
		MeanAnomaly	132.083056874457
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0333
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14612"
}

#1_"14646 1998 XO28:1998 XO28:2000 CN36" "Sol" #1=
#2_"1998 XO28:14646 1998 XO28" "Sol" #2=
#3_"1998 XO28:14646 1998 XO28" "Sol" #3=
".:1998 XO28:14646 1998 XO28" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.614294522318
		SemiMajorAxis	2.771605446138
		Eccentricity	0.014262789239
		Inclination	3.083208308181
		AscendingNode	276.32615548826
		ArgOfPericenter	78.512465702981
		MeanAnomaly	238.286552619982
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0166
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14646"
}

#1_"14651 1998 YE5:1998 YE5:1983 HD" "Sol" #1=
#2_"1998 YE5:14651 1998 YE5" "Sol" #2=
#3_"1998 YE5:14651 1998 YE5" "Sol" #3=
".:1998 YE5:14651 1998 YE5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.79
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.630066654489
		SemiMajorAxis	3.164731643518
		Eccentricity	0.188353709117
		Inclination	2.758022739418
		AscendingNode	105.22109942162
		ArgOfPericenter	153.28182658211
		MeanAnomaly	191.108897071646
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0329
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14651"
}

#1_"14691 2000 AK119:2000 AK119:1955 QD:1959 NE:1973 YX1:1988 HN:1989 RW3:1993 MQ:1999 AJ6" "Sol" #1=
#2_"2000 AK119:14691 2000 AK119" "Sol" #2=
#3_"2000 AK119:14691 2000 AK119" "Sol" #3=
".:2000 AK119:14691 2000 AK119" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"14691 2000 AK119.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.264
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.22833829062
		SemiMajorAxis	2.614815290062
		Eccentricity	0.151573300399
		Inclination	12.213666818766
		AscendingNode	270.152360466364
		ArgOfPericenter	19.969170788512
		MeanAnomaly	209.02769564627
	}
	UniformRotation
	{
		Period	3.652
	}
	LunarLambert	0.5
	Albedo	0.148
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14691"
}

#1_"14705 2000 CG2:2000 CG2:1979 VZ:1997 SD34:1998 XT2" "Sol" #1=
#2_"2000 CG2:14705 2000 CG2" "Sol" #2=
#3_"2000 CG2:14705 2000 CG2" "Sol" #3=
".:2000 CG2:14705 2000 CG2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.615204027067
		SemiMajorAxis	2.771969634061
		Eccentricity	0.172781536052
		Inclination	13.02409337847
		AscendingNode	5.159791315143
		ArgOfPericenter	319.277670194781
		MeanAnomaly	269.507601004371
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1062
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14705"
}

#1_"14736 2000 DW97:2000 DW97:1976 SZ6:1987 SQ25:1997 PG:1998 XO29" "Sol" #1=
#2_"2000 DW97:14736 2000 DW97" "Sol" #2=
#3_"2000 DW97:14736 2000 DW97" "Sol" #3=
".:2000 DW97:14736 2000 DW97" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.82
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.343216426687
		SemiMajorAxis	3.056302773681
		Eccentricity	0.138530083838
		Inclination	9.232095668682
		AscendingNode	10.021269625765
		ArgOfPericenter	6.003740034758
		MeanAnomaly	39.565607306631
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0358
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14736"
}

#1_"14822 1984 SR5:1984 SR5:1990 RO4" "Sol" #1=
#2_"1984 SR5:14822 1984 SR5" "Sol" #2=
#3_"1984 SR5:14822 1984 SR5" "Sol" #3=
".:1984 SR5:14822 1984 SR5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.835654881474
		SemiMajorAxis	3.241312707026
		Eccentricity	0.105575385183
		Inclination	5.448114094185
		AscendingNode	17.29531435071
		ArgOfPericenter	347.440631214178
		MeanAnomaly	48.245545445844
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0156
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14822"
}

#1_"14827 Hypnos:Hypnos:1986 JK" "Sol" #1=
#2_"*Гипнос:14827 Hypnos:Hypnos:1986 JK" "Sol" #2=
#3_"1986 JK:*Гипнос:14827 Hypnos:Hypnos" "Sol" #3=
".:Hypnos:14827 Hypnos:1986 JK" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.5625
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.791990206645
		SemiMajorAxis	2.842312421559
		Eccentricity	0.665633785112
		Inclination	1.98077659157
		AscendingNode	57.978243654953
		ArgOfPericenter	238.127446967347
		MeanAnomaly	0.916672776221
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14827"
}

#1_"14951 1996 BS2:1996 BS2:1984 UQ1:1999 BD24" "Sol" #1=
#2_"1996 BS2:14951 1996 BS2" "Sol" #2=
#3_"1996 BS2:14951 1996 BS2" "Sol" #3=
".:1996 BS2:14951 1996 BS2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.397
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	3.357247085492
		SemiMajorAxis	2.242074652325
		Eccentricity	0.201341749174
		Inclination	7.481500899896
		AscendingNode	125.869254827432
		ArgOfPericenter	218.002200906786
		MeanAnomaly	191.607860572754
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.337
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=14951"
}

#1_"15094 Polymele:Polymele:1999 WB2:1997 WR57" "Sol" #1=
#2_"*Полимела:15094 Polymele:Polymele:1999 WB2" "Sol" #2=
#3_"1999 WB2:Polymele:*Полимела:15094 Polymele" "Sol" #3=
".:Polymele:15094 Polymele:1999 WB2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.538
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	11.736471920087
		SemiMajorAxis	5.164396457112
		Eccentricity	0.094389186911
		Inclination	12.991916717042
		AscendingNode	50.329467126336
		ArgOfPericenter	4.885487128041
		MeanAnomaly	219.589774369082
	}
	UniformRotation
	{
		Period	6.1
	}
	LunarLambert	0.5
	Albedo	0.091
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15094"
}

#1_"15161 2000 FQ48:2000 FQ48:1950 OF:1951 XC1:1956 UA:1978 ND4:1979 SU10:1985 VC2:1990 UP6: #1=
#1_1999 DK5" "Sol" #1=
#2_"2000 FQ48:15161 2000 FQ48" "Sol" #2=
#3_"2000 FQ48:15161 2000 FQ48" "Sol" #3=
".:2000 FQ48:15161 2000 FQ48" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.67
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.751308330804
		SemiMajorAxis	3.210004435359
		Eccentricity	0.207500134185
		Inclination	18.175854920263
		AscendingNode	230.937174011887
		ArgOfPericenter	98.772183898394
		MeanAnomaly	89.053767112561
	}
	UniformRotation
	{
		Period	6.663
	}
	LunarLambert	0.5
	Albedo	0.0999
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15161"
}

#1_"15269 1990 XF:1990 XF:1983 AA2:1987 DQ5" "Sol" #1=
#2_"1990 XF:15269 1990 XF" "Sol" #2=
#3_"1990 XF:15269 1990 XF" "Sol" #3=
".:1990 XF:15269 1990 XF" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.585
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.072304039014
		SemiMajorAxis	2.550085030429
		Eccentricity	0.204592052481
		Inclination	11.007867120934
		AscendingNode	292.9556391
		ArgOfPericenter	220.766991855662
		MeanAnomaly	275.174123805887
	}
	UniformRotation
	{
		Period	26.708
	}
	LunarLambert	0.5
	Albedo	0.1553
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15269"
}

#1_"15278 Paquet:Paquet:1991 PG7:1999 NN41" "Sol" #1=
#2_"*Паке:15278 Paquet:Paquet:1991 PG7" "Sol" #2=
#3_"1991 PG7:*Паке:15278 Paquet:Paquet" "Sol" #3=
".:Paquet:15278 Paquet:1991 PG7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	17.33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.981592050166
		SemiMajorAxis	3.993811375014
		Eccentricity	0.216618890672
		Inclination	9.287283867022
		AscendingNode	344.773693493105
		ArgOfPericenter	64.809431416388
		MeanAnomaly	269.028429772404
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0307
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15278"
}

#1_"15410 1997 YZ:1997 YZ:1986 VV:1986 XA2" "Sol" #1=
#2_"1997 YZ:15410 1997 YZ" "Sol" #2=
#3_"1997 YZ:15410 1997 YZ" "Sol" #3=
".:1997 YZ:15410 1997 YZ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.484069960246
		SemiMajorAxis	3.109781360335
		Eccentricity	0.098053174134
		Inclination	17.154993178162
		AscendingNode	237.126073003371
		ArgOfPericenter	298.688002636784
		MeanAnomaly	277.303519398937
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0514
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15410"
}

#1_"15436 1998 VU30:1998 VU30:1962 WO:2000 AS81" "Sol" #1=
#2_"1998 VU30:15436 1998 VU30" "Sol" #2=
#3_"1998 VU30:15436 1998 VU30" "Sol" #3=
".:1998 VU30:15436 1998 VU30" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	42.855
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.887358535226
		SemiMajorAxis	5.208565215797
		Eccentricity	0.044095505762
		Inclination	16.265484801096
		AscendingNode	253.430458991634
		ArgOfPericenter	180.051318135888
		MeanAnomaly	115.344462517825
	}
	UniformRotation
	{
		Period	8.97
	}
	LunarLambert	0.5
	Albedo	0.0381
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15436"
}

#1_"15440 1998 WX4:1998 WX4:1992 LD" "Sol" #1=
#2_"1998 WX4:15440 1998 WX4" "Sol" #2=
#3_"1998 WX4:15440 1998 WX4" "Sol" #3=
".:1998 WX4:15440 1998 WX4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	33.24
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.197246572349
		SemiMajorAxis	5.298696777995
		Eccentricity	0.021832219654
		Inclination	28.73723843254
		AscendingNode	120.572446223853
		ArgOfPericenter	283.22772667
		MeanAnomaly	140.168020793136
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0916
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15440"
}

#1_"15457 1998 YN6:1998 YN6:1995 MU4" "Sol" #1=
#2_"1998 YN6:15457 1998 YN6" "Sol" #2=
#3_"1998 YN6:15457 1998 YN6" "Sol" #3=
".:1998 YN6:15457 1998 YN6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.37
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.753593513118
		SemiMajorAxis	3.210854672008
		Eccentricity	0.074205786474
		Inclination	22.966319180309
		AscendingNode	125.323442815001
		ArgOfPericenter	36.082324013545
		MeanAnomaly	249.726365693477
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0289
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15457"
}

#1_"15514 1999 VW24:1999 VW24:1987 UR5:1998 SJ69" "Sol" #1=
#2_"1999 VW24:15514 1999 VW24" "Sol" #2=
#3_"1999 VW24:15514 1999 VW24" "Sol" #3=
".:1999 VW24:15514 1999 VW24" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.345
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.604984763944
		SemiMajorAxis	3.155325418904
		Eccentricity	0.073532165205
		Inclination	19.588298579148
		AscendingNode	258.32428151402
		ArgOfPericenter	263.310621931171
		MeanAnomaly	167.517423034417
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0664
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15514"
}

#1_"15562 2000 GF48:2000 GF48:1985 SW4:1985 UD:1996 TF2:1999 CW16" "Sol" #1=
#2_"2000 GF48:15562 2000 GF48" "Sol" #2=
#3_"2000 GF48:15562 2000 GF48" "Sol" #3=
".:2000 GF48:15562 2000 GF48" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.68
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.578211295662
		SemiMajorAxis	3.145269322143
		Eccentricity	0.198847247186
		Inclination	11.583174173583
		AscendingNode	24.117532270853
		ArgOfPericenter	217.898909890857
		MeanAnomaly	201.165442931002
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0563
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15562"
}

#1_"15677 1980 TZ5:1980 TZ5:1999 RB173" "Sol" #1=
#2_"1980 TZ5:15677 1980 TZ5" "Sol" #2=
#3_"1980 TZ5:15677 1980 TZ5" "Sol" #3=
".:1980 TZ5:15677 1980 TZ5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"15677 1980 TZ5.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.811955854602
		SemiMajorAxis	2.850201874961
		Eccentricity	0.151055789357
		Inclination	13.337227806061
		AscendingNode	12.980394209108
		ArgOfPericenter	1.153462325818
		MeanAnomaly	205.477474566163
	}
	UniformRotation
	{
		Period	5.6144
	}
	LunarLambert	0.5
	Albedo	0.237
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15677"
}

#1_"15707 1988 RN4:1988 RN4:1983 EQ" "Sol" #1=
#2_"1988 RN4:15707 1988 RN4" "Sol" #2=
#3_"1988 RN4:15707 1988 RN4" "Sol" #3=
".:1988 RN4:15707 1988 RN4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.72
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.158769566535
		SemiMajorAxis	2.58605507603
		Eccentricity	0.256839474927
		Inclination	11.19680851899
		AscendingNode	336.70660731135
		ArgOfPericenter	279.365974312901
		MeanAnomaly	169.694601358522
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.031
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15707"
}

#1_"15712 1989 RN2:1989 RN2:1999 FY31" "Sol" #1=
#2_"1989 RN2:15712 1989 RN2" "Sol" #2=
#3_"1989 RN2:15712 1989 RN2" "Sol" #3=
".:1989 RN2:15712 1989 RN2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.495
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.713598923473
		SemiMajorAxis	3.195957772974
		Eccentricity	0.20361002098
		Inclination	11.188315750439
		AscendingNode	349.130949092782
		ArgOfPericenter	318.713862933426
		MeanAnomaly	192.737505267093
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0386
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15712"
}

#1_"15732 Vitusbering:Vitusbering:1990 VZ5:1985 XZ2:1999 JO83" "Sol" #1=
#2_"*Витусберинг:15732 Vitusbering:Vitusbering:1990 VZ5" "Sol" #2=
#3_"1990 VZ5:*Витусберинг:15732 Vitusbering:Vitusbering" "Sol" #3=
".:Vitusbering:15732 Vitusbering:1990 VZ5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.652318804695
		SemiMajorAxis	3.173064970089
		Eccentricity	0.054191636105
		Inclination	10.417197881655
		AscendingNode	122.535090225421
		ArgOfPericenter	189.561882778388
		MeanAnomaly	199.375918234659
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0408
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15732"
}
###### 4-2018
#1_"15760 Albion:Albion:1992 QB1" "Sol" #1=
#2_"*Альбион:15760 Albion:Albion:1992 QB1" "Sol" #2=
#3_"1992 QB1:15760 Albion:Albion" "Sol" #3=
".:Albion:15760 Albion:1992 QB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Color	[ 1.000 0.609 0.507 ]
	BlendTexture	true
	Radius	54
	Visible	false
	Clickable true
	EllipticalOrbit
	{
		Epoch	2458200.5  # 2018 Mar 23
		Period	288.991711307239
		SemiMajorAxis	43.710400891912
		Eccentricity	0.06597077878
		Inclination	2.186162143948
		AscendingNode	359.407421030794
		ArgOfPericenter	0.155188951253
		MeanAnomaly	32.083132101851
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.2
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15760"
}

#1_"15788 1993 SB:1993 SB" "Sol" #1=
#2_"1993 SB:15788 1993 SB" "Sol" #2=
#3_"1993 SB:15788 1993 SB" "Sol" #3=
".:1993 SB:15788 1993 SB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	247.740394587625
		SemiMajorAxis	39.445041302706
		Eccentricity	0.322346899333
		Inclination	1.939986112401
		AscendingNode	354.937869897709
		ArgOfPericenter	79.300434231523
		MeanAnomaly	348.296025875934
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15788"
}

#1_"15789 1993 SC:1993 SC" "Sol" #1=
#2_"1993 SC:15789 1993 SC" "Sol" #2=
#3_"1993 SC:15789 1993 SC" "Sol" #3=
".:1993 SC:15789 1993 SC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	164
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	248.225945212979
		SemiMajorAxis	39.496563821422
		Eccentricity	0.183601807735
		Inclination	5.165762260971
		AscendingNode	354.738531181118
		ArgOfPericenter	316.997769645523
		MeanAnomaly	63.877073132329
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.022
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15789"
}

#1_"15809 1994 JS:1994 JS" "Sol" #1=
#2_"1994 JS:15809 1994 JS" "Sol" #2=
#3_"1994 JS:15809 1994 JS" "Sol" #3=
".:1994 JS:15809 1994 JS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	60.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	273.063492058172
		SemiMajorAxis	42.089163236739
		Eccentricity	0.214498593831
		Inclination	14.04707950828
		AscendingNode	56.327088803987
		ArgOfPericenter	237.174172370986
		MeanAnomaly	348.86629086263
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15809"
}

#1_"15810 1994 JR1:1994 JR1" "Sol" #1=
#2_"1994 JR1:15810 1994 JR1" "Sol" #2=
#3_"1994 JR1:15810 1994 JR1" "Sol" #3=
".:1994 JR1:15810 1994 JR1" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	63.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457485.5  # 2016 Apr 07
		Period	247.245454304481
		SemiMajorAxis	39.39248777849546
		Eccentricity	0.1188955749596919
		Inclination	3.80822038827738
		AscendingNode	144.6832318250492
		ArgOfPericenter	101.3624763658904
		MeanAnomaly	29.92925327079456
	}
	UniformRotation
	{
		Period	5.4
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15810"
}

#1_"15811 Nusslein-Volhard:Nusslein-Volhard:1994 ND1:1955 SX1:1988 PY2:1989 SG7" "Sol" #1=
#2_"*Нюсляйн-Фольхард:15811 Nusslein-Volhard:Nusslein-Volhard:1994 ND1" "Sol" #2=
#3_"1994 ND1:*Нюсляйн-Фольхард:15811 Nusslein-Volhard:Nusslein-Volhard" "Sol" #3=
".:Nusslein-Volhard:15811 Nusslein-Volhard:1994 ND1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.085
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.755513676041
		SemiMajorAxis	3.211569010644
		Eccentricity	0.166364741473
		Inclination	9.582558039869
		AscendingNode	226.093816222114
		ArgOfPericenter	72.976664539138
		MeanAnomaly	190.412978285466
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0617
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15811"
}

#1_"15820 1994 TB:1994 TB" "Sol" #1=
#2_"1994 TB:15820 1994 TB" "Sol" #2=
#3_"1994 TB:15820 1994 TB" "Sol" #3=
".:1994 TB:15820 1994 TB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	45.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	248.572304862105
		SemiMajorAxis	39.533296045544
		Eccentricity	0.318100569921
		Inclination	12.139049167387
		AscendingNode	317.50081631562
		ArgOfPericenter	99.221729845301
		MeanAnomaly	353.876139994774
	}
	UniformRotation
	{
		Period	6.5
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15820"
}

#1_"15836 1995 DA2:1995 DA2" "Sol" #1=
#2_"1995 DA2:15836 1995 DA2" "Sol" #2=
#3_"1995 DA2:15836 1995 DA2" "Sol" #3=
".:1995 DA2:15836 1995 DA2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	63.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	221.557417396324
		SemiMajorAxis	36.614411759482
		Eccentricity	0.078057626193
		Inclination	6.545394977154
		AscendingNode	127.423339114368
		ArgOfPericenter	337.535325896411
		MeanAnomaly	51.721598321358
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15836"
}

#1_"15874 1996 TL66:1996 TL66" "Sol" #1=
#2_"1996 TL66:15874 1996 TL66" "Sol" #2=
#3_"1996 TL66:15874 1996 TL66" "Sol" #3=
".:1996 TL66:15874 1996 TL66" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	169.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	769.907842200098
		SemiMajorAxis	84.001497316461
		Eccentricity	0.582595311839
		Inclination	23.985354685563
		AscendingNode	217.786884178509
		ArgOfPericenter	184.923781233488
		MeanAnomaly	6.238284227233
	}
	UniformRotation
	{
		Period	12
	}
	LunarLambert	0.5
	Albedo	0.11
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15874"
}

#1_"15875 1996 TP66:1996 TP66" "Sol" #1=
#2_"1996 TP66:15875 1996 TP66" "Sol" #2=
#3_"1996 TP66:15875 1996 TP66" "Sol" #3=
".:1996 TP66:15875 1996 TP66" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.609 0.507 ]
	BlendTexture	true
	Radius	77
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	248.665377149575
		SemiMajorAxis	39.543163663258
		Eccentricity	0.332239391774
		Inclination	5.686394676872
		AscendingNode	316.877766710119
		ArgOfPericenter	75.754041619118
		MeanAnomaly	20.874793028869
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.074
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15875"
}

#1_"15883 1997 CR29:1997 CR29" "Sol" #1=
#2_"1997 CR29:15883 1997 CR29" "Sol" #2=
#3_"1997 CR29:15883 1997 CR29" "Sol" #3=
".:1997 CR29:15883 1997 CR29" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	83.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	325.873583681586
		SemiMajorAxis	47.354432488952
		Eccentricity	0.214411484394
		Inclination	19.113465639533
		AscendingNode	127.116368733093
		ArgOfPericenter	302.483452433867
		MeanAnomaly	64.713685009418
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15883"
}

#1_"15923 1997 VN3:1997 VN3:1991 CR:1995 CF2" "Sol" #1=
#2_"1997 VN3:15923 1997 VN3" "Sol" #2=
#3_"1997 VN3:15923 1997 VN3" "Sol" #3=
".:1997 VN3:15923 1997 VN3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.157598645454
		SemiMajorAxis	2.585569642623
		Eccentricity	0.189877243009
		Inclination	18.109565361222
		AscendingNode	236.942810612343
		ArgOfPericenter	36.422594261988
		MeanAnomaly	177.404246446368
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0459
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15923"
}

#1_"15951 1998 BB2:1998 BB2:1988 FU2:1991 XV5:1997 WG27" "Sol" #1=
#2_"1998 BB2:15951 1998 BB2" "Sol" #2=
#3_"1998 BB2:15951 1998 BB2" "Sol" #3=
".:1998 BB2:15951 1998 BB2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.91
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.545781738982
		SemiMajorAxis	3.133067229431
		Eccentricity	0.127410477438
		Inclination	17.710949811733
		AscendingNode	102.137991583939
		ArgOfPericenter	158.816378331157
		MeanAnomaly	247.467410250123
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0541
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15951"
}

#1_"15958 1998 BE33:1998 BE33:1983 XB2:1987 SR11" "Sol" #1=
#2_"1998 BE33:15958 1998 BE33" "Sol" #2=
#3_"1998 BE33:15958 1998 BE33" "Sol" #3=
".:1998 BE33:15958 1998 BE33" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.595
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.430160677048
		SemiMajorAxis	2.697372033596
		Eccentricity	0.282754589609
		Inclination	10.296716778715
		AscendingNode	167.520673312941
		ArgOfPericenter	257.796232809017
		MeanAnomaly	4.696788627507
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0276
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15958"
}

#1_"15967 Clairearmstrong:Clairearmstrong:1998 DN20:1989 CG7:1999 JB84" "Sol" #1=
#2_"*Клэрармстронг:15967 Clairearmstrong:Clairearmstrong:1998 DN20" "Sol" #2=
#3_"1998 DN20:*Клэрармстронг:15967 Clairearmstrong:Clairearmstrong" "Sol" #3=
".:Clairearmstrong:15967 Clairearmstrong:1998 DN20" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.08
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.290205815076
		SemiMajorAxis	2.640259516279
		Eccentricity	0.286831129573
		Inclination	12.22108260081
		AscendingNode	123.536532656417
		ArgOfPericenter	273.468073519161
		MeanAnomaly	79.774006690421
	}
	UniformRotation
	{
		Period	5.897
	}
	LunarLambert	0.5
	Albedo	0.1194
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=15967"
}

#1_"16009 1999 CM8:1999 CM8:1954 CA:1967 GA:1979 FV3:1997 UA25" "Sol" #1=
#2_"1999 CM8:16009 1999 CM8" "Sol" #2=
#3_"1999 CM8:16009 1999 CM8" "Sol" #3=
".:1999 CM8:16009 1999 CM8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"16009 1999 CM8.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.072
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.040010236517
		SemiMajorAxis	2.536585519225
		Eccentricity	0.156358303197
		Inclination	16.015588996265
		AscendingNode	38.133158062995
		ArgOfPericenter	327.47143902084
		MeanAnomaly	166.416867106984
	}
	UniformRotation
	{
		Period	16.7
	}
	LunarLambert	0.5
	Albedo	0.319
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16009"
}

#1_"16015 Snell:Snell:1999 CK47:2000 KF29" "Sol" #1=
#2_"*Снелл:16015 Snell:Snell:1999 CK47" "Sol" #2=
#3_"1999 CK47:*Снелл:16015 Snell:Snell" "Sol" #3=
".:Snell:16015 Snell:1999 CK47" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.825
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.566527195178
		SemiMajorAxis	3.140875741227
		Eccentricity	0.139250964185
		Inclination	1.950366644059
		AscendingNode	73.908978384692
		ArgOfPericenter	186.072865479571
		MeanAnomaly	215.396983313182
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0125
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16015"
}

#1_"16035 Sasandford:Sasandford:1999 FX32:1986 PM5" "Sol" #1=
#2_"*Сасандфорд:16035 Sasandford:Sasandford:1999 FX32" "Sol" #2=
#3_"1999 FX32:*Сасандфорд:16035 Sasandford:Sasandford" "Sol" #3=
".:Sasandford:16035 Sasandford:1999 FX32" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.59
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.648240853294
		SemiMajorAxis	2.785182220014
		Eccentricity	0.09188232615
		Inclination	9.538010083895
		AscendingNode	128.700755789346
		ArgOfPericenter	164.524849508922
		MeanAnomaly	54.091325535852
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0329
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16035"
}

#1_"16037 Sheehan:Sheehan:1999 GX8:1982 KS1" "Sol" #1=
#2_"*Шихэн:16037 Sheehan:Sheehan:1999 GX8" "Sol" #2=
#3_"1999 GX8:*Шихэн:16037 Sheehan:Sheehan" "Sol" #3=
".:Sheehan:16037 Sheehan:1999 GX8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.905
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.794619489841
		SemiMajorAxis	3.226099914782
		Eccentricity	0.05300110683
		Inclination	15.268572972122
		AscendingNode	187.334372330858
		ArgOfPericenter	98.811184121434
		MeanAnomaly	186.109352686756
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0338
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16037"
}

#1_"16070 1999 RB101:1999 RB101:1982 BD15:1993 BY3" "Sol" #1=
#2_"1999 RB101:16070 1999 RB101" "Sol" #2=
#3_"1999 RB101:16070 1999 RB101" "Sol" #3=
".:1999 RB101:16070 1999 RB101" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32.065
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.625367366115
		SemiMajorAxis	5.131751945029
		Eccentricity	0.123581618843
		Inclination	16.251130579003
		AscendingNode	300.871592636019
		ArgOfPericenter	354.2152202583
		MeanAnomaly	137.66224101053
	}
	UniformRotation
	{
		Period	31.74
	}
	LunarLambert	0.5
	Albedo	0.0516
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16070"
}

#1_"16173 2000 AC98:2000 AC98:1953 JF:1998 WA33" "Sol" #1=
#2_"16173 2000 AC98:2000 AC98" "Sol" #2=
#3_"2000 AC98:16173 2000 AC98" "Sol" #3=
".:2000 AC98:16173 2000 AC98" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"16173 2000 AC98.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.378412738483
		SemiMajorAxis	2.251488168621
		Eccentricity	0.212397438645
		Inclination	5.254325328975
		AscendingNode	71.000389897398
		ArgOfPericenter	193.982415059516
		MeanAnomaly	290.217553679129
	}
	UniformRotation
	{
		Period	6.4842
	}
	LunarLambert	0.5
	Albedo	0.206
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16173"
}

#1_"16216 2000 DR4:2000 DR4:2000 DR4:1980 TK10:1983 EB2:1987 DP5" "Sol" #1=
#2_"2000 DR4:16216 2000 DR4" "Sol" #2=
#3_"2000 DR4:16216 2000 DR4" "Sol" #3=
".:2000 DR4:16216 2000 DR4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"16216 2000 DR4.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	7.338
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.36588077766
		SemiMajorAxis	2.671216650317
		Eccentricity	0.099478821585
		Inclination	9.390467011224
		AscendingNode	5.847252969682
		ArgOfPericenter	239.271287054623
		MeanAnomaly	52.59160577287
	}
	UniformRotation
	{
		Period	10.36816
	}
	LunarLambert	0.5
	Albedo	0.046
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16216"
}

#1_"16257 2000 JY6:2000 JY6:1995 KH2:1998 WL32:1999 CV26" "Sol" #1=
#2_"2000 JY6:16257 2000 JY6" "Sol" #2=
#3_"2000 JY6:16257 2000 JY6" "Sol" #3=
".:2000 JY6:16257 2000 JY6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.623600887604
		SemiMajorAxis	2.775330813042
		Eccentricity	0.113850881634
		Inclination	19.951492603504
		AscendingNode	129.467642055983
		ArgOfPericenter	131.256709860438
		MeanAnomaly	42.474066296883
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0297
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16257"
}

#1_"16392 1981 EP42:1981 EP42" "Sol" #1=
#2_"1981 EP42:16392 1981 EP42" "Sol" #2=
#3_"1981 EP42:16392 1981 EP42" "Sol" #3=
".:1981 EP42:16392 1981 EP42" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.331882603446
		SemiMajorAxis	2.657330980686
		Eccentricity	0.100997880122
		Inclination	3.309333804066
		AscendingNode	190.80222316316
		ArgOfPericenter	206.281859304674
		MeanAnomaly	61.59020267571
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0179
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16392"
}

#1_"16415 1987 QE7:1987 QE7:1998 FA30" "Sol" #1=
#2_"1987 QE7:16415 1987 QE7" "Sol" #2=
#3_"1987 QE7:16415 1987 QE7" "Sol" #3=
".:1987 QE7:16415 1987 QE7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	3.875
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.251940640638
		SemiMajorAxis	2.624536762623
		Eccentricity	0.186796443879
		Inclination	11.841242501115
		AscendingNode	191.047708638868
		ArgOfPericenter	180.717669175974
		MeanAnomaly	130.924432376022
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0811
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16415"
}

#1_"16468 1990 HW1:1990 HW1" "Sol" #1=
#2_"1990 HW1:16468 1990 HW1" "Sol" #2=
#3_"1990 HW1:16468 1990 HW1" "Sol" #3=
".:1990 HW1:16468 1990 HW1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"16468 1990 HW1.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.498
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.09162791147
		SemiMajorAxis	2.558145762547
		Eccentricity	0.059248254487
		Inclination	15.281366571094
		AscendingNode	135.574293734047
		ArgOfPericenter	305.936551055671
		MeanAnomaly	303.398024389082
	}
	UniformRotation
	{
		Period	94.13
	}
	LunarLambert	0.5
	Albedo	0.282
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16468"
}

#1_"16560 Daitor:Daitor:1991 VZ5:1998 MR21:1999 NU24" "Sol" #1=
#2_"*Дайтор:16560 Daitor:Daitor:1991 VZ5" "Sol" #2=
#3_"1991 VZ5:*Дайтор:16560 Daitor:Daitor" "Sol" #3=
".:Daitor:16560 Daitor:1991 VZ5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.71
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.382865988973
		SemiMajorAxis	5.060137060408
		Eccentricity	0.039419730649
		Inclination	15.305918826347
		AscendingNode	100.757433072919
		ArgOfPericenter	158.619012298946
		MeanAnomaly	159.965041301014
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0292
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16560"
}

#1_"16593 1992 UB3:1992 UB3:1979 VB:1999 GB20" "Sol" #1=
#2_"1992 UB3:16593 1992 UB3" "Sol" #2=
#3_"1992 UB3:16593 1992 UB3" "Sol" #3=
".:992 UB3:16593 1992 UB3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.885
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.323910835469
		SemiMajorAxis	2.654069869142
		Eccentricity	0.121056309306
		Inclination	13.172110677929
		AscendingNode	43.675878780514
		ArgOfPericenter	312.569183852491
		MeanAnomaly	80.73102402808
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0489
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16593"
}

#1_"16671 1994 AF3:1994 AF3:1989 EF9:1998 XK38" "Sol" #1=
#2_"1994 AF3:16671 1994 AF3" "Sol" #2=
#3_"1994 AF3:16671 1994 AF3" "Sol" #3=
".:1994 AF3:16671 1994 AF3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.935
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.318252350258
		SemiMajorAxis	3.046775764038
		Eccentricity	0.190594175608
		Inclination	11.537486872594
		AscendingNode	284.310385801141
		ArgOfPericenter	157.934743697555
		MeanAnomaly	359.942543810651
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16671"
}

#1_"16684 1994 JQ1:1994 JQ1" "Sol" #1=
#2_"1994 JQ1:16684 1994 JQ1" "Sol" #2=
#3_"1994 JQ1:16684 1994 JQ1" "Sol" #3=
".:1994 JQ1:16684 1994 JQ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	91.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	292.972219608748
		SemiMajorAxis	44.110856721999
		Eccentricity	0.048699775161
		Inclination	3.739950663494
		AscendingNode	25.59735855998
		ArgOfPericenter	248.654696578886
		MeanAnomaly	325.363455979182
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16684"
}

#1_"16774 1996 VP1:1996 VP1" "Sol" #1=
#2_"1996 VP1:16774 1996 VP1" "Sol" #2=
#3_"1996 VP1:16774 1996 VP1" "Sol" #3=
".:1996 VP1:16774 1996 VP1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.295
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.313751847904
		SemiMajorAxis	2.649911098228
		Eccentricity	0.289615746129
		Inclination	13.353308612481
		AscendingNode	269.061442784165
		ArgOfPericenter	83.101935375375
		MeanAnomaly	110.646438602191
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1658
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16774"
}

#1_"16785 1997 AL1:1997 AL1:1983 RX5:1992 DM13" "Sol" #1=
#2_"1997 AL1:16785 1997 AL1" "Sol" #2=
#3_"1997 AL1:16785 1997 AL1" "Sol" #3=
".:1997 AL1:16785 1997 AL1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.845
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.609931561497
		SemiMajorAxis	3.157181678602
		Eccentricity	0.09714575399
		Inclination	18.407514894281
		AscendingNode	300.81793026713
		ArgOfPericenter	90.969856958548
		MeanAnomaly	147.378020846195
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0481
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16785"
}

#1_"16786 1997 AT1:1997 AT1:1952 BC2:1969 AF1:1979 YH:1990 WZ13" "Sol" #1=
#2_"1997 AT1:16786 1997 AT1" "Sol" #2=
#3_"1997 AT1:16786 1997 AT1" "Sol" #3=
".:1997 AT1:16786 1997 AT1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"16786 1997 AT1.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	12.298
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.646288032232
		SemiMajorAxis	3.170807555861
		Eccentricity	0.107672565822
		Inclination	12.637987758752
		AscendingNode	296.70590655597
		ArgOfPericenter	171.135832271803
		MeanAnomaly	62.409324666576
	}
	UniformRotation
	{
		Period	4.0231
	}
	LunarLambert	0.5
	Albedo	0.046
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16786"
}

#1_"16834 1997 WU22:1997 WU22" "Sol" #1=
#2_"1997 WU22:16834 1997 WU22" "Sol" #2=
#3_"1997 WU22:16834 1997 WU22" "Sol" #3=
".:1997 WU22:16834 1997 WU22" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.935
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.778387753849
		SemiMajorAxis	1.4678404037
		Eccentricity	0.442006550449
		Inclination	15.988220412045
		AscendingNode	260.820007743087
		ArgOfPericenter	334.29606289604
		MeanAnomaly	52.505993708442
	}
	UniformRotation
	{
		Period	9.345
	}
	LunarLambert	0.5
	Albedo	0.22
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16834"
}

#1_"16847 Sanpoloamosciano:Sanpoloamosciano:1997 XK10:1951 XR" "Sol" #1=
#2_"*Санполоамоскиано:16847 Sanpoloamosciano:Sanpoloamosciano:1997 XK10" "Sol" #2=
#3_"1997 XK10:*Санполоамоскиано:16847 Sanpoloamosciano:Sanpoloamosciano" "Sol" #3=
".:Sanpoloamosciano:16847 Sanpoloamosciano:1997 XK10" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"16847 sanpoloamosciano.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.295
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.178416166628
		SemiMajorAxis	2.594193263617
		Eccentricity	0.180959180949
		Inclination	14.914587956733
		AscendingNode	257.642540034039
		ArgOfPericenter	152.705230797895
		MeanAnomaly	93.825196877625
	}
	UniformRotation
	{
		Period	8.182
	}
	LunarLambert	0.5
	Albedo	0.151
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16847"
}

#1_"16878 Tombickler:Tombickler:1998 BL9:1989 CA4" "Sol" #1=
#2_"*Томбиклер:16878 Tombickler:Tombickler:1998 BL9" "Sol" #2=
#3_"1998 BL9:*Томбиклер:16878 Tombickler:Tombickler" "Sol" #3=
".:Tombickler:16878 Tombickler:1998 BL9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.255
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.387932147509
		SemiMajorAxis	2.68020368936
		Eccentricity	0.188841508453
		Inclination	11.966662221809
		AscendingNode	140.87519786
		ArgOfPericenter	273.203543345011
		MeanAnomaly	20.370310710558
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0483
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16878"
}

#1_"16913 1998 EK9:1998 EK9:1987 BA" "Sol" #1=
#2_"1998 EK9:16913 1998 EK9:1987 BA" "Sol" #2=
#3_"1998 EK9:16913 1998 EK9:1987 BA" "Sol" #3=
".:1998 EK9:16913 1998 EK9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.68422241476
		SemiMajorAxis	2.385384678765
		Eccentricity	0.131296935042
		Inclination	25.892264928294
		AscendingNode	125.412126190827
		ArgOfPericenter	297.330256411664
		MeanAnomaly	250.221415387595
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0679
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16913"
}

#1_"16955 1998 KU48:1998 KU48:1982 BM8:1991 NA5:1999 SY7" "Sol" #1=
#2_"1998 KU48:16955 1998 KU48" "Sol" #2=
#3_"1998 KU48:16955 1998 KU48" "Sol" #3=
".:1998 KU48:16955 1998 KU48" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"16955 1998 KU48.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.966
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.786384065018
		SemiMajorAxis	2.429280370846
		Eccentricity	0.102182544043
		Inclination	12.820771932084
		AscendingNode	104.436518844791
		ArgOfPericenter	41.580929478508
		MeanAnomaly	56.267575522848
	}
	UniformRotation
	{
		Period	5.2597
	}
	LunarLambert	0.5
	Albedo	0.164
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=16955"
}

#1_"Iphthime System" "Sol"  # Барицентр #1=
#2_"*Система Ифтимы:Iphthime System" "Sol"  # Барицентр #2=
#3_"Iphthime System" "Sol"  # Барицентр #3=
".:Iphthime System" "Sol"  # Барицентр #4=
{
	Class	"asteroid"
	Mesh	""
	Radius	56
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458200.5  # 2018 Mar 23
		Period	11.824449003494
		SemiMajorAxis	5.190172674923
		Eccentricity	0.070401721362
		Inclination	15.036372003607
		AscendingNode	241.559536244221
		ArgOfPericenter	134.715771285261
		MeanAnomaly	261.735542142512
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-16974.html"
}

#1_"16974 Iphthime:Iphthime:1998 WR21:1974 WX:1986 WS" "Sol/Iphthime System" #1=
#2_"*Ифтима:16974 Iphthime:Iphthime:1998 WR21" "Sol/Iphthime System" #2=
#3_"1998 WR21:16974 Iphthime:Iphthime" "Sol/Iphthime System" #3=
".:Iphthime:16974 Iphthime:1998 WR21" "Sol/Iphthime System" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	3.29
		SemiMajorAxis	56
		ArgOfPericenter	180
	}
	UniformRotation
	{
		Period	78.96
	}
	LunarLambert	0.5
	Albedo	0.065
	InfoURL	"https://en.wikipedia.org/wiki/16974_Iphthime"
}

#1_"2013 16974 I" "Sol/Iphthime System" #1=
#2_"2013 16974 I" "Sol/Iphthime System" #2=
#3_"2013 16974 I" "Sol/Iphthime System" #3=
".:2013 16974 I" "Sol/Iphthime System" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid.dds"
	Radius	17.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	3.29
		SemiMajorAxis	123
    }
	UniformRotation
	{
		Period	78.96
	}
	LunarLambert	0.5
	Albedo	0.065
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-16974.html"
}

#1_"17109 1999 JF52:1999 JF52:1227 T-3:1986 WT4" "Sol" #1=
#2_"1999 JF52:17109 1999 JF52" "Sol" #2=
#3_"1999 JF52:17109 1999 JF52" "Sol" #3=
".:1999 JF52:17109 1999 JF52" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	13.52
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.607549388934
		SemiMajorAxis	2.768903782723
		Eccentricity	0.172192795718
		Inclination	7.567406367519
		AscendingNode	260.968124215612
		ArgOfPericenter	81.248080243981
		MeanAnomaly	50.277466721971
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0265
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17109"
}

#1_"17111 1999 JH52:1999 JH52:1979 RA1:1992 CY2" "Sol" #1=
#2_"1999 JH52:17111 1999 JH52" "Sol" #2=
#3_"1999 JH52:17111 1999 JH52" "Sol" #3=
".:1999 JH52:17111 1999 JH52" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"17111 1999 JH52.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	6.418
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.254964528315
		SemiMajorAxis	3.022556244318
		Eccentricity	0.126659129164
		Inclination	8.616480312107
		AscendingNode	265.362024410278
		ArgOfPericenter	81.427841757839
		MeanAnomaly	39.479617899514
	}
	UniformRotation
	{
		Period	8.89847
	}
	LunarLambert	0.5
	Albedo	0.098
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17111"
}

#1_"17175 1999 SS3:1999 SS3:1976 SD11:1981 RL1:1987 RC5:1987 SU24:1998 RW38" "Sol" #1=
#2_"1999 SS3:17175 1999 SS3" "Sol" #2=
#3_"1999 SS3:17175 1999 SS3" "Sol" #3=
".:1999 SS3:17175 1999 SS3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.648225643963
		SemiMajorAxis	3.171532922396
		Eccentricity	0.085133894331
		Inclination	21.673575694532
		AscendingNode	355.449291338159
		ArgOfPericenter	81.147052787427
		MeanAnomaly	239.705050186292
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0714
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17175"
}

#1_"17252 2000 GJ127:2000 GJ127:1978 NT2:1992 AS3" "Sol" #1=
#2_"2000 GJ127:17252 2000 GJ127" "Sol" #2=
#3_"2000 GJ127:17252 2000 GJ127" "Sol" #3=
".:2000 GJ127:17252 2000 GJ127" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.235
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.547912092284
		SemiMajorAxis	3.13386953446
		Eccentricity	0.21991669887
		Inclination	15.890338599713
		AscendingNode	118.054088029117
		ArgOfPericenter	228.949074449472
		MeanAnomaly	157.33425788903
	}
	UniformRotation
	{
		Period	8.824
	}
	LunarLambert	0.5
	Albedo	0.0246
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17252"
}

#1_"17266 2000 KT6:2000 KT6:1964 TP2:1978 UW2:1994 CH11:1999 GF38" "Sol" #1=
#2_"2000 KT6:17266 2000 KT6" "Sol" #2=
#3_"2000 KT6:17266 2000 KT6" "Sol" #3=
".:2000 KT6:17266 2000 KT6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.195
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.671552067401
		SemiMajorAxis	2.794486360906
		Eccentricity	0.225988891548
		Inclination	8.50004568979
		AscendingNode	128.244888853944
		ArgOfPericenter	282.87104508242
		MeanAnomaly	241.423711728665
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0289
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17266"
}

#1_"17297 3560 P-L:3560 P-L:1974 DH1:1994 RP8:1997 CB20" "Sol" #1=
#2_"1960-17297*:17297 3560 P-L" "Sol" #2=
#3_"1960-17297*:17297 3560 P-L" "Sol" #3=
".:1960-17297*:17297 3560 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.325
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.652173543107
		SemiMajorAxis	3.173010605801
		Eccentricity	0.102170768199
		Inclination	15.261322607272
		AscendingNode	353.461659831026
		ArgOfPericenter	18.998575097728
		MeanAnomaly	195.5292821363
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0554
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17297"
}

#1_"1978 VF11 System" "Sol" #1=
#2_"*Система 1978 VF11:1978 VF11 System" "Sol" #2=
#3_"1978 VF11 System:*Система 1978 VF11" "Sol" #3=
".:1978 VF11 System" "Sol" #4=
{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	16
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.092579957677
		SemiMajorAxis	5.268340589432
		Eccentricity	0.078790013352
		Inclination	11.645548389842
		AscendingNode	252.150310723803
		ArgOfPericenter	118.237384245261
		MeanAnomaly	60.160056203685
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-17365.html"
}

#1_"17365 1978 VF11:1978 VF11:1998 MM49:1999 RE121" "Sol/1978 VF11 System" #1=
#2_"1978 VF11:17365 1978 VF11" "Sol/1978 VF11 System" #2=
#3_"1978 VF11:17365 1978 VF11" "Sol/1978 VF11 System" #3=
".:1978 VF11:17365 1978 VF11" "Sol/1978 VF11 System" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.528
		SemiMajorAxis	16
		ArgOfPericenter	180
	}
	UniformRotation
	{
		Period	12.672
	}
	LunarLambert	0.5
	Albedo	0.074
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17365"
}

#1_"2005 17365 I" "Sol/1978 VF11 System" #1=
#2_"2005 17365 I" "Sol/1978 VF11 System" #2=
#3_"2005 17365 I" "Sol/1978 VF11 System" #3=
".:2005 17365 I" "Sol/1978 VF11 System" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid.dds"
	Radius	13.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.528
		SemiMajorAxis	27
	}
	UniformRotation
	{
		Period	12.672
	}
	LunarLambert	0.5
	Albedo	0.074
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-17365.html"
}

#1_"17389 1981 EN30:1981 EN30:1998 HE64" "Sol" #1=
#2_"1981 EN30:17389 1981 EN30" "Sol" #2=
#3_"1981 EN30:17389 1981 EN30" "Sol" #3=
".:1981 EN30:17389 1981 EN30" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.457774320169
		SemiMajorAxis	3.09983264448
		Eccentricity	0.181970832502
		Inclination	1.936218770855
		AscendingNode	58.842754452278
		ArgOfPericenter	278.965726700919
		MeanAnomaly	261.299867726038
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0357
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17389"
}

#1_"17445 Avatcha:Avatcha:1989 YC5:1977 US2:1996 CH9" "Sol" #1=
#2_"*Авача:17445 Avatcha:Avatcha:1989 YC5" "Sol" #2=
#3_"1989 YC5:*Авача:17445 Avatcha:Avatcha" "Sol" #3=
".:Avatcha:17445 Avatcha:1989 YC5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.18
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.619561528131
		SemiMajorAxis	3.160793708695
		Eccentricity	0.263860067715
		Inclination	15.179742691558
		AscendingNode	311.775701591113
		ArgOfPericenter	47.248382643607
		MeanAnomaly	217.92647221076
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0389
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17445"
}

#1_"17463 1990 UO5:1990 UO5:1983 AT4:2000 JH" "Sol" #1=
#2_"1990 UO5:17463 1990 UO5" "Sol" #2=
#3_"1990 UO5:17463 1990 UO5" "Sol" #3=
".:1990 UO5:17463 1990 UO5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.132140196477
		SemiMajorAxis	2.57500393554
		Eccentricity	0.14756669351
		Inclination	12.462036276731
		AscendingNode	66.922476309154
		ArgOfPericenter	29.151850247947
		MeanAnomaly	258.998364819879
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0419
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17463"
}

#1_"17657 Himawari:Himawari:1996 VO4:1998 KJ2" "Sol" #1=
#2_"*Химавари:17657 Himawari:Himawari:1996 VO4" "Sol" #2=
#3_"1996 VO4:*Химавари:17657 Himawari:Himawari" "Sol" #3=
".:Himawari:17657 Himawari:1996 VO4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.52
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.675803984874
		SemiMajorAxis	1.927365419184
		Eccentricity	0.087281523875
		Inclination	23.07216801905
		AscendingNode	52.50692160453
		ArgOfPericenter	289.149781851576
		MeanAnomaly	335.382824929523
	}
	UniformRotation
	{
		Period	5.507
	}
	LunarLambert	0.5
	Albedo	0.0313
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17657"
}

#1_"17683 Kanagawa:Kanagawa:1997 AR16:1999 RE21" "Sol" #1=
#2_"*Канагава:17683 Kanagawa:Kanagawa:1997 AR16" "Sol" #2=
#3_"1997 AR16:*Канагава:17683 Kanagawa:Kanagawa" "Sol" #3=
".:Kanagawa:17683 Kanagawa:1997 AR16" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.04
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.158021099644
		SemiMajorAxis	2.98526764996
		Eccentricity	0.157812472604
		Inclination	18.296048357122
		AscendingNode	358.732479823023
		ArgOfPericenter	194.553706609921
		MeanAnomaly	140.978330472762
	}
	UniformRotation
	{
		Period	5.895
	}
	LunarLambert	0.5
	Albedo	0.0302
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17683"
}

#1_"17711 1997 WA7:1997 WA7:1949 HV:1991 LL:1995 KM5" "Sol" #1=
#2_"1997 WA7:17711 1997 WA7" "Sol" #2=
#3_"1997 WA7:17711 1997 WA7" "Sol" #3=
".:1997 WA7:17711 1997 WA7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.925
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.174187697159
		SemiMajorAxis	2.592442788868
		Eccentricity	0.194463971806
		Inclination	15.202350360115
		AscendingNode	96.055395074773
		ArgOfPericenter	191.782604225177
		MeanAnomaly	212.791081155007
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1515
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17711"
}

#1_"17839 1998 HN95:1998 HN95:1989 SJ13" "Sol" #1=
#2_"1998 HN95:17839 1998 HN95" "Sol" #2=
#3_"1998 HN95:17839 1998 HN95" "Sol" #3=
".:1998 HN95:17839 1998 HN95" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.925
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.342439074353
		SemiMajorAxis	3.056006337787
		Eccentricity	0.155521082082
		Inclination	15.175357993341
		AscendingNode	224.625957215812
		ArgOfPericenter	147.01614733911
		MeanAnomaly	255.831711771553
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0711
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=17839"
}

#1_"18039 1999 ND49:1999 ND49:1984 WF2:1996 CO8:1998 KD28" "Sol" #1=
#2_"1999 ND49:18039 1999 ND49" "Sol" #2=
#3_"1999 ND49:18039 1999 ND49" "Sol" #3=
".:1999 ND49:18039 1999 ND49" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.13
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.391192979363
		SemiMajorAxis	3.074570460932
		Eccentricity	0.072146331784
		Inclination	8.093655451593
		AscendingNode	277.137206304313
		ArgOfPericenter	138.455144322202
		MeanAnomaly	206.381283405369
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0205
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18039"
}

#1_"18053 1999 RU208:1999 RU208:1998 QW79" "Sol" #1=
#2_"1999 RU208:18053 1999 RU208" "Sol" #2=
#3_"1999 RU208:18053 1999 RU208" "Sol" #3=
".:1999 RU208:18053 1999 RU208" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.14
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.927061957784
		SemiMajorAxis	2.895475409012
		Eccentricity	0.252522155022
		Inclination	12.258891069291
		AscendingNode	228.153259200543
		ArgOfPericenter	314.329109457936
		MeanAnomaly	224.169302990618
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0277
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18053"
}

#1_"18153 2000 OC61:2000 OC61:1972 RC4:1983 RV4:1992 CS1:1998 FV96" "Sol" #1=
#2_"2000 OC61:18153 2000 OC61" "Sol" #2=
#3_"2000 OC61:18153 2000 OC61" "Sol" #3=
".:2000 OC61:18153 2000 OC61" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.16
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.512844399767
		SemiMajorAxis	3.120649705359
		Eccentricity	0.20572220135
		Inclination	15.058441759181
		AscendingNode	329.620066122503
		ArgOfPericenter	352.645447914282
		MeanAnomaly	233.244442881799
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0743
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18153"
}

#1_"18219 6260 P-L:6260 P-L:1994 SQ" "Sol" #1=
#2_"1960-18219*:18219 6260 P-L" "Sol" #2=
#3_"1960-18219*:18219 6260 P-L" "Sol" #3=
".:1960-18219*:18219 6260 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.675693771733
		SemiMajorAxis	3.181807017845
		Eccentricity	0.047932254937
		Inclination	16.219815168171
		AscendingNode	353.491293699719
		ArgOfPericenter	172.011653148529
		MeanAnomaly	42.322559202148
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0892
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18219"
}

#1_"18300 1979 PA:1979 PA:1987 OU" "Sol" #1=
#2_"1979 PA:18300 1979 PA" "Sol" #2=
#3_"1979 PA:18300 1979 PA" "Sol" #3=
".:1979 PA:18300 1979 PA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.795
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.093192170525
		SemiMajorAxis	2.558797719475
		Eccentricity	0.26478230106
		Inclination	12.044179295075
		AscendingNode	227.374349417439
		ArgOfPericenter	67.386150508779
		MeanAnomaly	243.614886341649
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0278
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18300"
}

#1_"18331 1987 DQ6:1987 DQ6:1932 CM" "Sol" #1=
#2_"1987 DQ6:18331 1987 DQ6" "Sol" #2=
#3_"1987 DQ6:18331 1987 DQ6" "Sol" #3=
".:1987 DQ6:18331 1987 DQ6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.467955915957
		SemiMajorAxis	3.103686649946
		Eccentricity	0.083431148532
		Inclination	16.072410611151
		AscendingNode	352.442045839394
		ArgOfPericenter	17.254534932725
		MeanAnomaly	172.823858443476
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0365
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18331"
}

#1_"18333 1987 OV:1987 OV:1998 FJ27:1999 NE44:2000 RE56" "Sol" #1=
#2_"1987 OV:18333 1987 OV" "Sol" #2=
#3_"1987 OV:18333 1987 OV" "Sol" #3=
".:1987 OV:18333 1987 OV" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.43
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.119756365768
		SemiMajorAxis	2.569856584843
		Eccentricity	0.176213219093
		Inclination	8.475593129028
		AscendingNode	190.745586048778
		ArgOfPericenter	149.975560364748
		MeanAnomaly	214.50506159188
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.026
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18333"
}

#1_"18377 1991 SH1:1991 SH1:1999 LY25" "Sol" #1=
#2_"1991 SH1:18377 1991 SH1" "Sol" #2=
#3_"1991 SH1:18377 1991 SH1" "Sol" #3=
".:1991 SH1:18377 1991 SH1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.31
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.133247403904
		SemiMajorAxis	2.575463896729
		Eccentricity	0.196480364771
		Inclination	14.013777036653
		AscendingNode	74.141379189005
		ArgOfPericenter	199.754872391147
		MeanAnomaly	263.571395066475
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0442
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18377"
}

#1_"18483 1995 YY2:1995 YY2:1955 UZ1:1989 WH6" "Sol" #1=
#2_"1995 YY2:18483 1995 YY2" "Sol" #2=
#3_"1995 YY2:18483 1995 YY2" "Sol" #3=
".:1995 YY2:18483 1995 YY2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.525
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.547568860815
		SemiMajorAxis	3.133740278178
		Eccentricity	0.243689861565
		Inclination	10.810783303592
		AscendingNode	100.139744955894
		ArgOfPericenter	268.231757409038
		MeanAnomaly	220.761125156034
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0802
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18483"
}

#1_"18487 1996 AU3:1996 AU3:1999 XN215" "Sol" #1=
#2_"1996 AU3:18487 1996 AU3" "Sol" #2=
#3_"1996 AU3:18487 1996 AU3" "Sol" #3=
".:1996 AU3:18487 1996 AU3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"18487 1996 AU3.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.556
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.290955952622
		SemiMajorAxis	2.640567271535
		Eccentricity	0.180494314348
		Inclination	15.11200517608
		AscendingNode	133.689033431078
		ArgOfPericenter	195.594825605143
		MeanAnomaly	118.188214567941
	}
	UniformRotation
	{
		Period	6.512
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18487"
}

#1_"18595 1998 BR1:1998 BR1:1999 GY4" "Sol" #1=
#2_"1998 BR1:18595 1998 BR1" "Sol" #2=
#3_"1998 BR1:18595 1998 BR1" "Sol" #3=
".:1998 BR1:18595 1998 BR1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.205
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.643209253165
		SemiMajorAxis	2.367648763605
		Eccentricity	0.256675164179
		Inclination	5.829274700283
		AscendingNode	43.875161275456
		ArgOfPericenter	311.91147045945
		MeanAnomaly	327.715874038299
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0346
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18595"
}

#1_"18666 1998 FT53:1998 FT53:1961 VT:1978 RP1:1991 SB4" "Sol" #1=
#2_"1998 FT53:18666 1998 FT53" "Sol" #2=
#3_"1998 FT53:18666 1998 FT53" "Sol" #3=
".:1998 FT53:18666 1998 FT53" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.355
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.293659244125
		SemiMajorAxis	2.641676188964
		Eccentricity	0.176717533462
		Inclination	12.144311089151
		AscendingNode	348.600204170469
		ArgOfPericenter	357.370288162442
		MeanAnomaly	167.718986348799
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0303
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18666"
}

#1_"18732 1998 KP19:1998 KP19:1992 HN6:2000 SY276" "Sol" #1=
#2_"1998 KP19:18732 1998 KP19" "Sol" #2=
#3_"1998 KP19:18732 1998 KP19" "Sol" #3=
".:1998 KP19:18732 1998 KP19" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.325
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.864808450646
		SemiMajorAxis	3.252098966148
		Eccentricity	0.101033240618
		Inclination	22.863913907568
		AscendingNode	216.856781333187
		ArgOfPericenter	77.897882539177
		MeanAnomaly	240.492643258122
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0242
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18732"
}

#1_"18827 1999 NA26:1999 NA26:1999 NA26:1989 RV5:1998 HE120" "Sol" #1=
#2_"1999 NA26:18827 1999 NA26" "Sol" #2=
#3_"1999 NA26:18827 1999 NA26" "Sol" #3=
".:1999 NA26:18827 1999 NA26" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.095
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.333775313672
		SemiMajorAxis	3.052701521586
		Eccentricity	0.115913057682
		Inclination	15.210662754131
		AscendingNode	107.063065727752
		ArgOfPericenter	237.059203028202
		MeanAnomaly	280.647440344551
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.036
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18827"
}

#1_"18916 2000 OG44:2000 OG44:1977 SD" "Sol" #1=
#2_"2000 OG44:18916 2000 OG44" "Sol" #2=
#3_"2000 OG44:18916 2000 OG44" "Sol" #3=
".:2000 OG44:18916 2000 OG44" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	7.546660331063
		SemiMajorAxis	3.847373954468
		Eccentricity	0.58577863504
		Inclination	7.417026697057
		AscendingNode	301.679970812079
		ArgOfPericenter	98.461116346774
		MeanAnomaly	304.337100105994
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.111
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18916"
}

#1_"18996 Torasan:Torasan:2000 RR53:1978 YN1:1988 RD9:1999 NS51" "Sol" #1=
#2_"*Торасан:18996 Torasan:Torasan:2000 RR53" "Sol" #2=
#3_"2000 RR53:*Торасан:18996 Torasan:Torasan" "Sol" #3=
".:Torasan:18996 Torasan:2000 RR53" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.730799853832
		SemiMajorAxis	3.202368898607
		Eccentricity	0.034742939687
		Inclination	20.491606782169
		AscendingNode	241.190505390166
		ArgOfPericenter	211.565602754548
		MeanAnomaly	92.999580040854
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0714
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=18996"
}

#1_"19255 1994 VK8:1994 VK8" "Sol" #1=
#2_"1994 VK8:19255 1994 VK8" "Sol" #2=
#3_"1994 VK8:19255 1994 VK8" "Sol" #3=
".:1994 VK8:19255 1994 VK8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	87.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	282.010106111685
		SemiMajorAxis	43.003550445046
		Eccentricity	0.034711357227
		Inclination	1.487961035489
		AscendingNode	72.3878336289
		ArgOfPericenter	107.430632984675
		MeanAnomaly	271.108147862949
	}
	UniformRotation
	{
		Period	9
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=19255"
}

#1_"19299 1996 SZ4:1996 SZ4" "Sol" #1=
#2_"1996 SZ4:19299 1996 SZ4" "Sol" #2=
#3_"1996 SZ4:19299 1996 SZ4" "Sol" #3=
".:1996 SZ4:19299 1996 SZ4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	249.861705120075
		SemiMajorAxis	39.669890169344
		Eccentricity	0.259463112247
		Inclination	4.742378510686
		AscendingNode	16.016016000555
		ArgOfPericenter	30.628449136696
		MeanAnomaly	5.14959387509
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=19299"
}

#1_"19308 1996 TO66:1996 TO66" "Sol" #1=
#2_"1996 TO66:19308 1996 TO66" "Sol" #2=
#3_"1996 TO66:19308 1996 TO66" "Sol" #3=
".:1996 TO66:19308 1996 TO66" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"haumeanfamily.dds"
	Radius	100
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	284.26842448245
		SemiMajorAxis	43.232824855227
		Eccentricity	0.118689875521
		Inclination	27.480550428445
		AscendingNode	355.275113608532
		ArgOfPericenter	239.29557433571
		MeanAnomaly	135.677869849567
	}
	UniformRotation
	{
		Period	7.92
	}
	LunarLambert	0.5
	Albedo	0.7
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=19308"
}

#1_"19356 1997 GH3:1997 GH3" "Sol" #1=
#2_"1997 GH3:19356 1997 GH3" "Sol" #2=
#3_"1997 GH3:19356 1997 GH3" "Sol" #3=
".:1997 GH3:19356 1997 GH3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.455
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.958820000026
		SemiMajorAxis	2.502486263564
		Eccentricity	0.563041053849
		Inclination	3.003269040164
		AscendingNode	186.701856859868
		ArgOfPericenter	333.855188359494
		MeanAnomaly	179.004076660048
	}
	UniformRotation
	{
		Period	6.714
	}
	LunarLambert	0.5
	Albedo	0.34
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=19356"
}

#1_"19517 Robertocarlos:Robertocarlos:1998 SK164:1970 GM2:1994 WD2" "Sol" #1=
#2_"*Робертокарлос:19517 Robertocarlos:Robertocarlos:1998 SK164" "Sol" #2=
#3_"1998 SK164:*Робертокарлос:19517 Robertocarlos:Robertocarlos" "Sol" #3=
".:Robertocarlos:19517 Robertocarlos:1998 SK164" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.785
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.352912811915
		SemiMajorAxis	2.665924489108
		Eccentricity	0.14250878287
		Inclination	7.552878902794
		AscendingNode	103.706565063605
		ArgOfPericenter	84.866097338953
		MeanAnomaly	111.312829132614
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0605
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=19517"
}

#1_"19521 Chaos:Chaos:1998 WH24" "Sol" #1=
#2_"*Хаос:19521 Chaos:Chaos:1998 WH24" "Sol" #2=
#3_"1998 WH24:*Хаос:19521 Chaos:Chaos" "Sol" #3=
".:Chaos:19521 Chaos:1998 WH24" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	300
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	311.355238689112
		SemiMajorAxis	45.937284248341
		Eccentricity	0.107954342926
		Inclination	12.037508936202
		AscendingNode	49.989281303915
		ArgOfPericenter	57.52567525546
		MeanAnomaly	336.892338216847
	}
	UniformRotation
	{
		Period	95.64
	}
	LunarLambert	0.5
	Albedo	0.050
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=19521"
}

#1_"19565 1999 KF4:1999 KF4:1972 TB" "Sol" #1=
#2_"1999 KF4:19565 1999 KF4" "Sol" #2=
#3_"1999 KF4:19565 1999 KF4" "Sol" #3=
".:1999 KF4:19565 1999 KF4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.11
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.397832893143
		SemiMajorAxis	3.077094416151
		Eccentricity	0.299468685024
		Inclination	23.402950665327
		AscendingNode	247.218551921818
		ArgOfPericenter	55.052951856926
		MeanAnomaly	303.248657823229
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0558
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=19565"
}

#1_"19608 1999 NC57:1999 NC57:1984 WJ4:1998 KB47" "Sol" #1=
#2_"1999 NC57:19608 1999 NC57" "Sol" #2=
#3_"1999 NC57:19608 1999 NC57" "Sol" #3=
".:1999 NC57:19608 1999 NC57" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"19608 1999 NC57.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.324
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.279381936334
		SemiMajorAxis	3.031911962658
		Eccentricity	0.103979362454
		Inclination	10.362764816905
		AscendingNode	262.59067227651
		ArgOfPericenter	112.971414259756
		MeanAnomaly	83.329343346962
	}
	UniformRotation
	{
		Period	9.1936
	}
	LunarLambert	0.5
	Albedo	0.16
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=19608"
}

#1_"19615 1999 OB3:1999 OB3:1989 WT4" "Sol" #1=
#2_"1999 OB3:19615 1999 OB3" "Sol" #2=
#3_"1999 OB3:19615 1999 OB3" "Sol" #3=
".:1999 OB3:19615 1999 OB3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.34
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.163127320826
		SemiMajorAxis	2.987237516912
		Eccentricity	0.095995938438
		Inclination	12.258138007101
		AscendingNode	256.25734667362
		ArgOfPericenter	89.749000479199
		MeanAnomaly	11.790083108098
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.046
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=19615"
}

#1_"19732 1999 XF165:1999 XF165" "Sol" #1=
#2_"1999 XF165:19732 1999 XF165" "Sol" #2=
#3_"1999 XF165:19732 1999 XF165" "Sol" #3=
".:1999 XF165:19732 1999 XF165" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.635
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.758220259502
		SemiMajorAxis	2.417219104717
		Eccentricity	0.208566523379
		Inclination	12.4994570221
		AscendingNode	89.487555451401
		ArgOfPericenter	246.59636440835
		MeanAnomaly	137.328239548825
	}
	UniformRotation
	{
		Period	12.57
	}
	LunarLambert	0.5
	Albedo	0.0985
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=19732"
}

#1_"19848 Yeungchuchiu:Yeungchuchiu:2000 TR:1998 KR38:1999 SY6" "Sol" #1=
#2_"*Енгчучиу:19848 Yeungchuchiu:Yeungchuchiu:2000 TR" "Sol" #2=
#3_"2000 TR:*Енгчучиу:19848 Yeungchuchiu:Yeungchuchiu" "Sol" #3=
".:Yeungchuchiu:19848 Yeungchuchiu:2000 TR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"19848 yeungchuchiu.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	5.218183557188
		SemiMajorAxis	3.008435927372
		Eccentricity	0.077113162176
		Inclination	11.059394013466
		AscendingNode	54.764266123092
		ArgOfPericenter	350.212642607848
		MeanAnomaly	303.058031046614
	}
	UniformRotation
	{
		Period	3.45
	}
	LunarLambert	0.5
	Albedo	0.17
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=19848"
}

#1_"19862 2556 P-L:2556 P-L:1988 SU3" "Sol" #1=
#2_"1960-19862*:19862 2556 P-L" "Sol" #2=
#3_"1960-19862*:19862 2556 P-L" "Sol" #3=
".:1960-19862*:19862 2556 P-L" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.594912533045
		SemiMajorAxis	3.151544178495
		Eccentricity	0.228597205683
		Inclination	10.730781620391
		AscendingNode	23.155903867652
		ArgOfPericenter	20.449628574366
		MeanAnomaly	221.932756386421
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=19862"
}

#1_"19926 1979 YQ:1979 YQ:1954 XE:1987 WL" "Sol" #1=
#2_"1979 YQ:19926 1979 YQ" "Sol" #2=
#3_"1979 YQ:19926 1979 YQ" "Sol" #3=
".:1979 YQ:19926 1979 YQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.149124633245
		SemiMajorAxis	2.582055178271
		Eccentricity	0.243669562512
		Inclination	9.062267965647
		AscendingNode	84.035046068159
		ArgOfPericenter	318.773723789512
		MeanAnomaly	177.786736187285
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0316
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=19926"
}

#1_"20000 Varuna:Varuna:2000 WR106" "Sol" #1=
#2_"*Варуна:20000 Varuna:Varuna:2000 WR106" "Sol" #2=
#3_"2000 WR106:*Варуна:20000 Varuna:Varuna" "Sol" #3=
".:Varuna:20000 Varuna:2000 WR106" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"varuna.dds"
	BumpMap	"varuna-bump.png"
	BumpHeight	5
	SemiAxes	[ 429.5 226.65 226.65 ]
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	281.486379995795
		SemiMajorAxis	42.950292166367
		Eccentricity	0.051397794599
		Inclination	17.197193082315
		AscendingNode	97.334981311581
		ArgOfPericenter	266.361340319674
		MeanAnomaly	111.771559335474
	}
	UniformRotation
	{
		Period	6.3436
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"https://en.wikipedia.org/wiki/20000_Varuna"
}

#1_"20098 1994 WC2:1994 WC2" "Sol" #1=
#2_"1994 WC2:20098 1994 WC2" "Sol" #2=
#3_"1994 WC2:20098 1994 WC2" "Sol" #3=
".:1994 WC2:20098 1994 WC2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.67
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.635385184802
		SemiMajorAxis	2.780044519496
		Eccentricity	0.16985019726
		Inclination	10.277458234831
		AscendingNode	89.317095312892
		ArgOfPericenter	248.705697885
		MeanAnomaly	174.854805299359
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0821
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20098"
}

#1_"20099 1994 WB3:1994 WB3:1999 RO1" "Sol" #1=
#2_"1994 WB3:20099 1994 WB3" "Sol" #2=
#3_"1994 WB3:20099 1994 WB3" "Sol" #3=
".:1994 WB3:20099 1994 WB3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.515
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.495332152823
		SemiMajorAxis	3.114037442701
		Eccentricity	0.186222997904
		Inclination	2.382577156607
		AscendingNode	110.53586434945
		ArgOfPericenter	304.261409434894
		MeanAnomaly	243.047460033087
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0236
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20099"
}

#1_"20108 1995 QZ9:1995 QZ9" "Sol" #1=
#2_"1995 QZ9:20108 1995 QZ9" "Sol" #2=
#3_"1995 QZ9:20108 1995 QZ9" "Sol" #3=
".:1995 QZ9:20108 1995 QZ9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	63.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	247.852311288475
		SemiMajorAxis	39.456919937684
		Eccentricity	0.144297500249
		Inclination	19.578903665834
		AscendingNode	188.060842529705
		ArgOfPericenter	143.379115318118
		MeanAnomaly	57.01149444828
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20108"
}

#1_"20161 1996 TR66:1996 TR66" "Sol" #1=
#2_"1996 TR66:20161 1996 TR66" "Sol" #2=
#3_"1996 TR66:20161 1996 TR66" "Sol" #3=
".:1996 TR66:20161 1996 TR66" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	69.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	329.59955938455
		SemiMajorAxis	47.71470906669207
		Eccentricity	0.3964298555567283
		Inclination	12.44560948747892
		AscendingNode	343.1597063713031
		ArgOfPericenter	309.1542617560048
		MeanAnomaly	52.41758613026091
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20161"
}

#1_"20293 Sirichelson:Sirichelson:1998 FQ72:1980 TJ7" "Sol" #1=
#2_"*Сиричелсон:20293 Sirichelson:Sirichelson:1998 FQ72" "Sol" #2=
#3_"1998 FQ72:*Сиричелсон:20293 Sirichelson:Sirichelson" "Sol" #3=
".:Sirichelson:20293 Sirichelson:1998 FQ72" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.075
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.815217475065
		SemiMajorAxis	2.441597458783
		Eccentricity	0.195043959227
		Inclination	3.257480371506
		AscendingNode	30.752005070486
		ArgOfPericenter	317.17823493
		MeanAnomaly	355.496306099042
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0141
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20293"
}

#1_"20329 Manfro:Manfro:1998 HQ43" "Sol" #1=
#2_"*Манфро:20329 Manfro:Manfro:1998 HQ43" "Sol" #2=
#3_"1998 HQ43:Manfro:*Манфро:20329 Manfro" "Sol" #3=
".:Manfro:20329 Manfro:1998 HQ43" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"20329 manfro.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.332
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.684228063167
		SemiMajorAxis	2.38538711684
		Eccentricity	0.043651500258
		Inclination	5.696301227858
		AscendingNode	48.512201040254
		ArgOfPericenter	59.942153154554
		MeanAnomaly	129.700701341026
	}
	UniformRotation
	{
		Period	8.80724
	}
	LunarLambert	0.5
	Albedo	0.227
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20329"
}

#1_"20461 Dioretsa:Dioretsa:1999 LD31" "Sol" #1=
#2_"*Диоретса:20461 Dioretsa:Dioretsa:1999 LD31" "Sol" #2=
#3_"1999 LD31:*Диоретса:20461 Dioretsa:Dioretsa" "Sol" #3=
".:Dioretsa:20461 Dioretsa:1999 LD31" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	115.936298942309
		SemiMajorAxis	23.776111018455
		Eccentricity	0.899477840507
		Inclination	160.403583611246
		AscendingNode	297.220975626018
		ArgOfPericenter	102.44746218977
		MeanAnomaly	46.843937165752
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.03
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20461"
}

#1_"20569 1999 RP132:1999 RP132:1984 BN1:1990 BU2" "Sol" #1=
#2_"1999 RP132:20569 1999 RP132" "Sol" #2=
#3_"1999 RP132:20569 1999 RP132" "Sol" #3=
".:1999 RP132:20569 1999 RP132" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.115
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.650747659087
		SemiMajorAxis	3.172476942621
		Eccentricity	0.230126849629
		Inclination	12.861441018269
		AscendingNode	312.301480316852
		ArgOfPericenter	98.896377363802
		MeanAnomaly	203.957408522526
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0612
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20569"
}

#1_"20570 Molchan:Molchan:1999 RV133:1992 QG2:1999 RP102" "Sol" #1=
#2_"*Молчан:20570 Molchan:Molchan:1999 RV133" "Sol" #2=
#3_"1999 RV133:Molchan:*Молчан:20570 Molchan" "Sol" #3=
".:Molchan:20570 Molchan:1999 RV133" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"20570 molchan.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.18
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.509446544171
		SemiMajorAxis	2.309335080766
		Eccentricity	0.109433230298
		Inclination	5.985338948086
		AscendingNode	276.915797720348
		ArgOfPericenter	11.296491584371
		MeanAnomaly	31.461777459148
	}
	UniformRotation
	{
		Period	4.1315
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20570"
}

#1_"20602 1999 RC198:1999 RC198:1966 UA:1990 CW:2000 WQ72" "Sol" #1=
#2_"1999 RC198:20602 1999 RC198" "Sol" #2=
#3_"1999 RC198:20602 1999 RC198" "Sol" #3=
".:1999 RC198:20602 1999 RC198" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.435
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.564156684882
		SemiMajorAxis	3.139983981539
		Eccentricity	0.204949083692
		Inclination	14.270603852964
		AscendingNode	333.082810857082
		ArgOfPericenter	106.603843570656
		MeanAnomaly	215.232429669411
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0377
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20602"
}

#1_"20617 1999 SA7:1999 SA7:1982 SO7:1997 BR9" "Sol" #1=
#2_"1999 SA7:20617 1999 SA7" "Sol" #2=
#3_"1999 SA7:20617 1999 SA7" "Sol" #3=
".:1999 SA7:20617 1999 SA7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.615
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.79931456977
		SemiMajorAxis	3.227842307275
		Eccentricity	0.061561570049
		Inclination	21.45281213847
		AscendingNode	350.309503380031
		ArgOfPericenter	85.854501589366
		MeanAnomaly	128.612008707131
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0785
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20617"
}

#1_"20635 1999 TV96:1999 TV96:1987 RA2:1987 SD2:1993 SF2" "Sol" #1=
#2_"1999 TV96:20635 1999 TV96" "Sol" #2=
#3_"1999 TV96:20635 1999 TV96" "Sol" #3=
".:1999 TV96:20635 1999 TV96" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.905
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.766891265483
		SemiMajorAxis	3.215800070633
		Eccentricity	0.061691506704
		Inclination	21.918908797761
		AscendingNode	172.014536922133
		ArgOfPericenter	231.169342313973
		MeanAnomaly	205.259647387787
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0589
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20635"
}

#1_"20675 1999 VK6:1999 VK6:1992 LD2:1998 QR80" "Sol" #1=
#2_"1999 VK6:20675 1999 VK6" "Sol" #2=
#3_"1999 VK6:20675 1999 VK6" "Sol" #3=
".:1999 VK6:20675 1999 VK6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.28
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.1922256985
		SemiMajorAxis	2.998450659175
		Eccentricity	0.09724073332
		Inclination	13.548849589973
		AscendingNode	239.793959183905
		ArgOfPericenter	99.440126617591
		MeanAnomaly	41.879331550379
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0693
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20675"
}

#1_"20707 1999 WW4:1999 WW4:1988 XF3:1991 LC5" "Sol" #1=
#2_"1999 WW4:20707 1999 WW4" "Sol" #2=
#3_"1999 WW4:20707 1999 WW4" "Sol" #3=
".:1999 WW4:20707 1999 WW4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.23
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.640368359168
		SemiMajorAxis	3.168590946137
		Eccentricity	0.041286520234
		Inclination	11.49246634316
		AscendingNode	100.878687505246
		ArgOfPericenter	191.719865692338
		MeanAnomaly	23.680085913071
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0355
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20707"
}

#1_"20725 1999 XP120:1999 XP120:1983 VL7:1988 VZ8" "Sol" #1=
#2_"1999 XP120:20725 1999 XP120" "Sol" #2=
#3_"1999 XP120:20725 1999 XP120" "Sol" #3=
".:1999 XP120:20725 1999 XP120" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"20725 1999 XP120.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.26309093778
		SemiMajorAxis	3.025671546455
		Eccentricity	0.108162308789
		Inclination	10.194254889921
		AscendingNode	41.053377471615
		ArgOfPericenter	77.778198341867
		MeanAnomaly	48.716949959261
	}
	UniformRotation
	{
		Period	3.601296
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20725"
}

#1_"20741 Jeanmichelreess:Jeanmichelreess:1999 XA230:1984 BH" "Sol" #1=
#2_"*Дженмичелрисс:20741 Jeanmichelreess:Jeanmichelreess:1999 XA230" "Sol" #2=
#3_"1999 XA230:*Дженмичелрисс:20741 Jeanmichelreess:Jeanmichelreess" "Sol" #3=
".:Jeanmichelreess:20741 Jeanmichelreess:1999 XA230" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.015
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.704139346719
		SemiMajorAxis	3.192429260658
		Eccentricity	0.252411891844
		Inclination	12.316506710029
		AscendingNode	304.255889364775
		ArgOfPericenter	199.086359254716
		MeanAnomaly	148.949810619902
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0329
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20741"
}

#1_"20762 2000 EE36:2000 EE36:1990 KT3:1999 AM8" "Sol" #1=
#2_"2000 EE36:20762 2000 EE36" "Sol" #2=
#3_"2000 EE36:20762 2000 EE36" "Sol" #3=
".:2000 EE36:20762 2000 EE36" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9.24
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.577611195249
		SemiMajorAxis	3.14504374072
		Eccentricity	0.178694006363
		Inclination	16.035070354939
		AscendingNode	88.231254771205
		ArgOfPericenter	350.250938179007
		MeanAnomaly	300.277702281042
	}
	UniformRotation
	{
		Period	8.891
	}
	LunarLambert	0.5
	Albedo	0.1299
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20762"
}

#1_"20802 2000 SR179:2000 SR179:1979 VR1:1983 SQ:1998 FD34" "Sol" #1=
#2_"2000 SR179:20802 2000 SR179" "Sol" #2=
#3_"2000 SR179:20802 2000 SR179" "Sol" #3=
".:2000 SR179:20802 2000 SR179" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.915
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.214966551701
		SemiMajorAxis	2.609299635184
		Eccentricity	0.238418505333
		Inclination	4.923202527358
		AscendingNode	341.802855584184
		ArgOfPericenter	30.600273743775
		MeanAnomaly	144.028274874294
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0241
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20802"
}

#1_"20810 2000 SE266:2000 SE266:1965 VD:1971 BA1:1998 HT47" "Sol" #1=
#2_"2000 SE266:20810 2000 SE266" "Sol" #2=
#3_"2000 SE266:20810 2000 SE266" "Sol" #3=
".:2000 SE266:20810 2000 SE266" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.94
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.379018258789
		SemiMajorAxis	2.67657264967
		Eccentricity	0.163983572527
		Inclination	8.913804367175
		AscendingNode	63.416987640681
		ArgOfPericenter	358.855222259846
		MeanAnomaly	57.691515198733
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1251
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20810"
}

#1_"20848 2000 UA105:2000 UA105:1983 JD" "Sol" #1=
#2_"2000 UA105:20848 2000 UA105" "Sol" #2=
#3_"2000 UA105:20848 2000 UA105" "Sol" #3=
".:2000 UA105:20848 2000 UA105" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.255
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.08956706507
		SemiMajorAxis	2.5572867095
		Eccentricity	0.237346803636
		Inclination	13.883966569374
		AscendingNode	47.213075279319
		ArgOfPericenter	222.718182789226
		MeanAnomaly	239.086494232364
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0737
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20848"
}

#1_"20898 Fountainhills:Fountainhills:2000 WE147:1975 BE:1994 NA1" "Sol" #1=
#2_"*Фаунтинхиллс:20898 Fountainhills:Fountainhills:2000 WE147" "Sol" #2=
#3_"2000 WE147:*Фаунтинхиллс:20898 Fountainhills:Fountainhills" "Sol" #3=
".:Fountainhills:20898 Fountainhills:2000 WE147" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.655
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	8.689515373072
		SemiMajorAxis	4.226604091202
		Eccentricity	0.465082435824
		Inclination	45.520048483928
		AscendingNode	293.254210535482
		ArgOfPericenter	234.638634760671
		MeanAnomaly	192.375127858018
	}
	UniformRotation
	{
		Period	12.84
	}
	LunarLambert	0.5
	Albedo	0.0505
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20898"
}

#1_"20899 2000 XB3:2000 XB3:1983 NN" "Sol" #1=
#2_"2000 XB3:20899 2000 XB3" "Sol" #2=
#3_"2000 XB3:20899 2000 XB3" "Sol" #3=
".:2000 XB3:20899 2000 XB3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.835
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.130500903904
		SemiMajorAxis	2.574322857652
		Eccentricity	0.302738660719
		Inclination	11.940131213596
		AscendingNode	296.714257163205
		ArgOfPericenter	34.374596483913
		MeanAnomaly	195.394708871728
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.043
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=20899"
}

#1_"21018 1988 VV1:1988 VV1:2000 AL9" "Sol" #1=
#2_"1988 VV1:21018 1988 VV1" "Sol" #2=
#3_"1988 VV1:21018 1988 VV1" "Sol" #3=
".:1988 VV1:21018 1988 VV1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.66
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.985842153861
		SemiMajorAxis	2.918458677889
		Eccentricity	0.251221580606
		Inclination	12.516818347061
		AscendingNode	302.538487897206
		ArgOfPericenter	356.561310934978
		MeanAnomaly	150.080631632258
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0908
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=21018"
}

#1_"21078 1991 RR16:1991 RR16:1991 RR16:1985 UC6:1998 WF20" "Sol" #1=
#2_"1991 RR16:21078 1991 RR16" "Sol" #2=
#3_"1991 RR16:21078 1991 RR16" "Sol" #3=
".:1991 RR16:21078 1991 RR16" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.915
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.261279803707
		SemiMajorAxis	3.397060434359
		Eccentricity	0.086787282219
		Inclination	8.076463936492
		AscendingNode	23.511146387454
		ArgOfPericenter	282.638420673272
		MeanAnomaly	300.391794643175
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.022
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=21078"
}

#1_"21411 Abifraeman:Abifraeman:1998 FY66:1979 HM3:1994 GG10" "Sol" #1=
#2_"*Абифримен:21411 Abifraeman:Abifraeman:1998 FY66" "Sol" #2=
#3_"1998 FY66:Abifraeman:*Абифримен:21411 Abifraeman" "Sol" #3=
".:Abifraeman:21411 Abifraeman:1998 FY66" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"21411 abifraeman.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.42
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.827955946498
		SemiMajorAxis	2.447029204621
		Eccentricity	0.061231853087
		Inclination	7.929695116926
		AscendingNode	169.25302333628
		ArgOfPericenter	215.798711713599
		MeanAnomaly	142.7044204036
	}
	UniformRotation
	{
		Period	11.0202
	}
	LunarLambert	0.5
	Albedo	0.3
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=21411"
}

#1_"21555 Levary:Levary:1998 QF70:1987 SK24:1996 FJ16" "Sol" #1=
#2_"*Левари:21555 Levary:Levary:1998 QF70" "Sol" #2=
#3_"1998 QF70:*Левари:21555 Levary:Levary" "Sol" #3=
".:Levary:21555 Levary:1998 QF70" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.585
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.715387530267
		SemiMajorAxis	3.196624721385
		Eccentricity	0.086136482032
		Inclination	15.703939085404
		AscendingNode	212.378865550978
		ArgOfPericenter	243.545215742338
		MeanAnomaly	199.46060563009
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0481
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=21555"
}

#1_"21570 Muralidhar:Muralidhar:1998 RK33:1994 SK3:1997 EF49:1998 TF30" "Sol" #1=
#2_"*Муралидхар:21570 Muralidhar:Muralidhar:1998 RK33" "Sol" #2=
#3_"1998 RK33:*Муралидхар:21570 Muralidhar:Muralidhar" "Sol" #3=
".:Muralidhar:21570 Muralidhar:1998 RK33" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.89
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.170475744105
		SemiMajorAxis	2.590905651038
		Eccentricity	0.140134980849
		Inclination	13.176327813136
		AscendingNode	2.018880339058
		ArgOfPericenter	254.453902076551
		MeanAnomaly	35.551757410253
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0203
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=21570"
}

#1_"21587 Christopynn:Christopynn:1998 SE132:1992 MG" "Sol" #1=
#2_"*Христопинн:21587 Christopynn:Christopynn:1998 SE132" "Sol" #2=
#3_"1998 SE132:*Христопинн:21587 Christopynn:Christopynn" "Sol" #3=
".:Christopynn:21587 Christopynn:1998 SE132" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.64
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.820192777698
		SemiMajorAxis	2.853453525869
		Eccentricity	0.065530138456
		Inclination	12.444675269665
		AscendingNode	219.694229826117
		ArgOfPericenter	81.789527643284
		MeanAnomaly	203.784612677195
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0476
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=21587"
}

#1_"21592 1998 VJ5:1998 VJ5:1998 VJ5:1988 TG4:1993 VR5" "Sol" #1=
#2_"1998 VJ5:21592 1998 VJ5" "Sol" #2=
#3_"1998 VJ5:21592 1998 VJ5" "Sol" #3=
".:1998 VJ5:21592 1998 VJ5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.565
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.868367830872
		SemiMajorAxis	2.872434413405
		Eccentricity	0.23691786061
		Inclination	11.466595869176
		AscendingNode	21.60555016391
		ArgOfPericenter	288.175155479264
		MeanAnomaly	185.917081069076
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0821
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=21592"
}

#1_"21596 1998 WG7:1998 WG7:1986 LR:1993 FU55" "Sol" #1=
#2_"1998 WG7:21596 1998 WG7" "Sol" #2=
#3_"1998 WG7:21596 1998 WG7" "Sol" #3=
".:1998 WG7:21596 1998 WG7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	3.85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.672764870632
		SemiMajorAxis	2.380436581597
		Eccentricity	0.230204591723
		Inclination	6.087636402145
		AscendingNode	96.999794275391
		ArgOfPericenter	217.119326290898
		MeanAnomaly	224.311870862992
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0472
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=21596"
}

#1_"21688 1999 RK37:1999 RK37:1986 RL2" "Sol" #1=
#2_"1999 RK37:21688 1999 RK37" "Sol" #2=
#3_"1999 RK37:21688 1999 RK37" "Sol" #3=
".:1999 RK37:21688 1999 RK37" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.09
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.664981078954
		SemiMajorAxis	1.922164793618
		Eccentricity	0.07556754455
		Inclination	25.499372891036
		AscendingNode	329.247240487298
		ArgOfPericenter	45.1621534399
		MeanAnomaly	211.656943069552
	}
	UniformRotation
	{
		Period	5.696
	}
	LunarLambert	0.5
	Albedo	0.0503
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=21688"
}

#1_"21792 1999 ST7:1999 ST7:1994 VT2" "Sol" #1=
#2_"1999 ST7:21792 1999 ST7" "Sol" #2=
#3_"1999 ST7:21792 1999 ST7" "Sol" #3=
".:1999 ST7:21792 1999 ST7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.095
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.677942385264
		SemiMajorAxis	3.182647347651
		Eccentricity	0.236802671482
		Inclination	10.125332220616
		AscendingNode	26.021031002154
		ArgOfPericenter	43.698796228316
		MeanAnomaly	185.560394090204
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0554
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=21792"
}

#1_"21900 Orus:Orus:1999 VQ10:1998 VD18" "Sol" #1=
#2_"*Орус:21900 Orus:Orus:1999 VQ10" "Sol" #2=
#3_"1999 VQ10:Orus:*Орус:21900 Orus" "Sol" #3=
".:Orus:21900 Orus:1999 VQ10" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.405
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	11.611081390746
		SemiMajorAxis	5.127546939265
		Eccentricity	0.0355644929
		Inclination	8.467756058321
		AscendingNode	258.560844351336
		ArgOfPericenter	180.460728939171
		MeanAnomaly	169.841253881692
	}
	UniformRotation
	{
		Period	13.45
	}
	LunarLambert	0.5
	Albedo	0.075
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=21900"
}

#1_"21967 1999 WS9:1999 WS9:1983 ED3:1993 LN1" "Sol" #1=
#2_"1999 WS9:21967 1999 WS9" "Sol" #2=
#3_"1999 WS9:21967 1999 WS9" "Sol" #3=
".:1999 WS9:21967 1999 WS9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.07
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.391428758061
		SemiMajorAxis	2.681627349217
		Eccentricity	0.082478826234
		Inclination	10.360911133006
		AscendingNode	81.440266432692
		ArgOfPericenter	210.526589889334
		MeanAnomaly	307.259959915274
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.069
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=21967"
}

#1_"22018 1999 XK105:1999 XK105:1998 QE66" "Sol" #1=
#2_"1999 XK105:22018 1999 XK105" "Sol" #2=
#3_"1999 XK105:22018 1999 XK105" "Sol" #3=
".:1999 XK105:22018 1999 XK105" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"22018 1999 XK105.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.597
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.321955345953
		SemiMajorAxis	3.04818987378
		Eccentricity	0.110829271667
		Inclination	9.70846577367
		AscendingNode	274.305780611867
		ArgOfPericenter	128.838440895799
		MeanAnomaly	109.613727415079
	}
	UniformRotation
	{
		Period	17.0575
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=22018"
}

#1_"22097 2000 BH4:2000 BH4:1938 CD:1991 RX11" "Sol" #1=
#2_"2000 BH4:22097 2000 BH4" "Sol" #2=
#3_"2000 BH4:22097 2000 BH4" "Sol" #3=
".:2000 BH4:22097 2000 BH4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	12.36
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.652344702358
		SemiMajorAxis	3.173074662266
		Eccentricity	0.181501027843
		Inclination	16.146116622527
		AscendingNode	322.588603553326
		ArgOfPericenter	217.108447982655
		MeanAnomaly	159.959890306881
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0317
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=22097"
}

#1_"22147 2000 WP32:2000 WP32:1999 NV30" "Sol" #1=
#2_"2000 WP32:22147 2000 WP32" "Sol" #2=
#3_"2000 WP32:22147 2000 WP32" "Sol" #3=
".:2000 WP32:22147 2000 WP32" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.51
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.473051292076
		SemiMajorAxis	3.105614487447
		Eccentricity	0.2077547637
		Inclination	12.611060424373
		AscendingNode	100.512837896988
		ArgOfPericenter	250.634378911335
		MeanAnomaly	257.021154640598
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0292
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=22147"
}

#1_"22298 1990 EJ:1990 EJ:1968 DJ:1998 SE110" "Sol" #1=
#2_"1990 EJ:22298 1990 EJ" "Sol" #2=
#3_"1990 EJ:22298 1990 EJ" "Sol" #3=
".:1990 EJ:22298 1990 EJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"22298 1990 EJ.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.346
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.458194866853
		SemiMajorAxis	3.099991880036
		Eccentricity	0.161142005754
		Inclination	8.862797135746
		AscendingNode	345.525920306797
		ArgOfPericenter	212.8772266192
		MeanAnomaly	310.576861557849
	}
	UniformRotation
	{
		Period	2.985538
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=22298"
}

#1_"22464 1997 AG14:1997 AG14:1962 WR1:1991 VK14:1998 LD2" "Sol" #1=
#2_"1997 AG14:22464 1997 AG14" "Sol" #2=
#3_"1997 AG14:22464 1997 AG14" "Sol" #3=
".:1997 AG14:22464 1997 AG14" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.165448898494
		SemiMajorAxis	2.588823282612
		Eccentricity	0.220884336212
		Inclination	14.330397672849
		AscendingNode	73.420522618514
		ArgOfPericenter	356.601791430418
		MeanAnomaly	170.664432305441
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0828
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=22464"
}

#1_"22805 1999 RR2:1999 RR2:2000 SL231" "Sol" #1=
#2_"1999 RR2:22805 1999 RR2" "Sol" #2=
#3_"1999 RR2:22805 1999 RR2" "Sol" #3=
".:1999 RR2:22805 1999 RR2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	6.265
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.579090494789
		SemiMajorAxis	3.145599803876
		Eccentricity	0.163581108804
		Inclination	17.322237672073
		AscendingNode	259.218323160309
		ArgOfPericenter	172.475143826477
		MeanAnomaly	204.751341546748
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1352
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=22805"
}

#1_"22955 1999 TH251:1999 TH251:1998 QJ67" "Sol" #1=
#2_"1999 TH251:22955 1999 TH251" "Sol" #2=
#3_"1999 TH251:22955 1999 TH251" "Sol" #3=
".:1999 TH251:22955 1999 TH251" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.622823715234
		SemiMajorAxis	2.775019804241
		Eccentricity	0.118290277776
		Inclination	21.678798832756
		AscendingNode	309.033922258438
		ArgOfPericenter	75.703370279755
		MeanAnomaly	146.816242214777
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0304
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=22955"
}

#1_"23059 Paulpaino:1999 XT45:1991 PM9:1998 MZ20" "Sol" #1=
#2_"*Полпэино:23059 Paulpaino:1999 XT45" "Sol" #2=
#3_"1999 XT45:*Полпэино:23059 Paulpaino" "Sol" #3=
".:Paulpaino:23059 Paulpaino:1999 XT45" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.025
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.609749539166
		SemiMajorAxis	2.353129950645
		Eccentricity	0.193964871573
		Inclination	1.91651496072
		AscendingNode	300.678309761604
		ArgOfPericenter	325.367564299619
		MeanAnomaly	200.847970167067
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0146
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=23059"
}

#1_"23099 1999 XA160:1999 XA160:1978 AJ" "Sol" #1=
#2_"1999 XA160:23099 1999 XA160" "Sol" #2=
#3_"1999 XA160:23099 1999 XA160" "Sol" #3=
".:1999 XA160:23099 1999 XA160" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16.575
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.583754703147
		SemiMajorAxis	3.147352740652
		Eccentricity	0.109740744359
		Inclination	20.961939249682
		AscendingNode	100.718812277687
		ArgOfPericenter	9.55427226155
		MeanAnomaly	230.942930261729
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0443
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=23099"
}

#1_"23103 1999 XK169:1999 XK169:1998 QU67" "Sol" #1=
#2_"1999 XK169:23103 1999 XK169" "Sol" #2=
#3_"1999 XK169:23103 1999 XK169" "Sol" #3=
".:1999 XK169:23103 1999 XK169" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.995
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.124453932846
		SemiMajorAxis	2.972301956602
		Eccentricity	0.114317545514
		Inclination	10.715799234167
		AscendingNode	286.193268900832
		ArgOfPericenter	116.765322781067
		MeanAnomaly	6.189094921509
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0436
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=23103"
}

#1_"23129 2000 AO100:2000 AO100:1972 XU2:1980 FX11:1997 LW10" "Sol" #1=
#2_"2000 AO100:23129 2000 AO100" "Sol" #2=
#3_"2000 AO100:23129 2000 AO100" "Sol" #3=
".:2000 AO100:23129 2000 AO100" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.31
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.388395798655
		SemiMajorAxis	3.073506890145
		Eccentricity	0.102515363298
		Inclination	19.009755370945
		AscendingNode	68.075306128423
		ArgOfPericenter	317.06653792
		MeanAnomaly	309.385521216047
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0601
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=23129"
}

#1_"23167 2000 GL124:2000 GL124:1974 UJ:1978 NZ7:1999 CG53" "Sol" #1=
#2_"2000 GL124:23167 2000 GL124" "Sol" #2=
#3_"2000 GL124:23167 2000 GL124" "Sol" #3=
".:2000 GL124:23167 2000 GL124" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	5.545
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.527080700671
		SemiMajorAxis	2.736570805127
		Eccentricity	0.227992524792
		Inclination	9.126438869985
		AscendingNode	110.444778338405
		ArgOfPericenter	241.250064416613
		MeanAnomaly	333.964265093577
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1437
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=23167"
}

#1_"23578 Baedeker:Baedeker:1995 DR13:1999 XB85" "Sol" #1=
#2_"*Бедекер:23578 Baedeker:Baedeker:1995 DR13" "Sol" #2=
#3_"1995 DR13:Baedeker:*Бедекер:23578 Baedeker" "Sol" #3=
".:Baedeker:23578 Baedeker:1995 DR13" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"23578 baedeker.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	4.846
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.489317533821
		SemiMajorAxis	3.111764827019
		Eccentricity	0.151170171904
		Inclination	1.772905465648
		AscendingNode	125.569793692037
		ArgOfPericenter	62.442974418528
		MeanAnomaly	335.505904596239
	}
	UniformRotation
	{
		Period	8.1715
	}
	LunarLambert	0.5
	Albedo	0.075
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=23578"
}

#1_"23707 Chambliss:Chambliss:1997 TZ7:1981 UM6:1996 HJ25" "Sol" #1=
#2_"*Чамблисс:23707 Chambliss:Chambliss:1997 TZ7" "Sol" #2=
#3_"1997 TZ7:Chambliss:*Чамблисс:23707 Chambliss" "Sol" #3=
".:Chambliss:23707 Chambliss:1997 TZ7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"23707 chambliss.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.599
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.523268073008
		SemiMajorAxis	3.124582144856
		Eccentricity	0.241860278978
		Inclination	16.885237286879
		AscendingNode	50.106131957766
		ArgOfPericenter	286.164313690102
		MeanAnomaly	200.968210952451
	}
	UniformRotation
	{
		Period	5.06632
	}
	LunarLambert	0.5
	Albedo	0.179
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=23707"
}

#1_"23873 1998 RL76:1998 RL76:1992 LC2:2000 AE158" "Sol" #1=
#2_"1998 RL76:23873 1998 RL76" "Sol" #2=
#3_"1998 RL76:23873 1998 RL76" "Sol" #3=
".:1998 RL76:23873 1998 RL76" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"23873 1998 RL76.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.832
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.898038533912
		SemiMajorAxis	2.884093462783
		Eccentricity	0.087663355472
		Inclination	3.285525880185
		AscendingNode	95.05313488763
		ArgOfPericenter	255.95733721731
		MeanAnomaly	282.053519249119
	}
	UniformRotation
	{
		Period	13.8559
	}
	LunarLambert	0.5
	Albedo	0.166
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=23873"
}

#1_"23956 1998 VD9:1998 VD9:1993 TH13" "Sol" #1=
#2_"1998 VD9:23956 1998 VD9" "Sol" #2=
#3_"1998 VD9:23956 1998 VD9" "Sol" #3=
".:1998 VD9:23956 1998 VD9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.92
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.926608727435
		SemiMajorAxis	2.895297840384
		Eccentricity	0.121533198825
		Inclination	16.377953604023
		AscendingNode	211.41764869511
		ArgOfPericenter	140.041649954663
		MeanAnomaly	130.74610539964
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0531
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=23956"
}

#1_"23977 1999 GW6:1999 GW6" "Sol" #1=
#2_"1999 GW6:23977 1999 GW6" "Sol" #2=
#3_"1999 GW6:23977 1999 GW6" "Sol" #3=
".:1999 GW6:23977 1999 GW6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.095
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.279629445008
		SemiMajorAxis	2.635918489473
		Eccentricity	0.124756674729
		Inclination	26.015234390806
		AscendingNode	209.110226744279
		ArgOfPericenter	120.370769540374
		MeanAnomaly	118.79752073236
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0425
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=23977"
}

#1_"24013 1999 RR113:1999 RR113:2000 YP34" "Sol" #1=
#2_"1999 RR113:24013 1999 RR113" "Sol" #2=
#3_"1999 RR113:24013 1999 RR113" "Sol" #3=
".:1999 RR113:24013 1999 RR113" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	4.455
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.076615008551
		SemiMajorAxis	2.551884404949
		Eccentricity	0.204333215169
		Inclination	13.433749604573
		AscendingNode	303.017593016458
		ArgOfPericenter	102.712387795006
		MeanAnomaly	223.7906671845
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1282
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=24013"
}

#1_"24035 1999 SJ2:1999 SJ2" "Sol" #1=
#2_"1999 SJ2:24035 1999 SJ2" "Sol" #2=
#3_"1999 SJ2:24035 1999 SJ2" "Sol" #3=
".:1999 SJ2:24035 1999 SJ2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.055
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.048291390413
		SemiMajorAxis	2.540050640039
		Eccentricity	0.274649943808
		Inclination	13.579640037921
		AscendingNode	353.693316698699
		ArgOfPericenter	38.388472696923
		MeanAnomaly	257.191531121176
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0512
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=24035"
}

#1_"24127 1999 VZ52:1999 VZ52:1982 YU1:1983 AL3" "Sol" #1=
#2_"1999 VZ52:24127 1999 VZ52" "Sol" #2=
#3_"1999 VZ52:24127 1999 VZ52" "Sol" #3=
".:1999 VZ52:24127 1999 VZ52" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.955
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.704188474282
		SemiMajorAxis	3.192447590744
		Eccentricity	0.070608838645
		Inclination	22.707202683039
		AscendingNode	84.110918974594
		ArgOfPericenter	271.53425454959
		MeanAnomaly	314.970760946739
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0851
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=24127"
}

#1_"24388 2000 AB175:2000 AB175" "Sol" #1=
#2_"2000 AB175:24388 2000 AB175" "Sol" #2=
#3_"2000 AB175:24388 2000 AB175" "Sol" #3=
".:2000 AB175:24388 2000 AB175" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.385
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.304486779069
		SemiMajorAxis	3.041516050925
		Eccentricity	0.168013519228
		Inclination	14.913374234531
		AscendingNode	242.974525409298
		ArgOfPericenter	283.19027591
		MeanAnomaly	238.145369878109
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0374
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=24388"
}

#1_"24761 Ahau:Ahau:1993 BW2" "Sol" #1=
#2_"*Ахау:24761 Ahau:Ahau:1993 BW2" "Sol" #2=
#3_"1993 BW2:*Ахау:24761 Ahau:Ahau" "Sol" #3=
".:Ahau:24761 Ahau:1993 BW2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.712
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.542399084517
		SemiMajorAxis	1.334931673904
		Eccentricity	0.305889939888
		Inclination	21.921080523781
		AscendingNode	121.094838731386
		ArgOfPericenter	287.48300252
		MeanAnomaly	105.446957607105
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.11
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=24761"
}

#1_"24835 1995 SM55:1995 SM55" "Sol" #1=
#2_"1995 SM55:24835 1995 SM55" "Sol" #2=
#3_"1995 SM55:24835 1995 SM55" "Sol" #3=
".:1995 SM55:24835 1995 SM55" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"haumeanfamily.dds"
	Radius	87
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	271.08048127273
		SemiMajorAxis	41.88514569968032
		Eccentricity	0.1073711174903945
		Inclination	27.07069838826567
		AscendingNode	21.07406061481964
		ArgOfPericenter	71.60156889847794
		MeanAnomaly	327.0117309575745
	}
	UniformRotation
	{
		Period	8.08
	}
	LunarLambert	0.5
	Albedo	0.7
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=24835"
}

#1_"24952 1997 QJ4:1997 QJ4" "Sol" #1=
#2_"1997 QJ4:24952 1997 QJ4" "Sol" #2=
#3_"1997 QJ4:24952 1997 QJ4" "Sol" #3=
".:1997 QJ4:24952 1997 QJ4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	66.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	247.08359384227
		SemiMajorAxis	39.375293577186
		Eccentricity	0.227327763737
		Inclination	16.587260977628
		AscendingNode	346.910986183981
		ArgOfPericenter	82.411107498267
		MeanAnomaly	335.809590109357
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=24952"
}

#1_"24978 1998 HJ151:1998 HJ151" "Sol" #1=
#2_"1998 HJ151:24978 1998 HJ151" "Sol" #2=
#3_"1998 HJ151:24978 1998 HJ151" "Sol" #3=
".:1998 HJ151:24978 1998 HJ151" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	69.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	285.008668409984
		SemiMajorAxis	43.307845410838
		Eccentricity	0.050904291086
		Inclination	2.390857154777
		AscendingNode	50.412761327
		ArgOfPericenter	125.541712578983
		MeanAnomaly	70.439839134116
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=24978"
}

#1_"24980 1998 KF2:1998 KF2:1980 VF2:2001 CC46" "Sol" #1=
#2_"1998 KF2:24980 1998 KF2" "Sol" #2=
#3_"1998 KF2:24980 1998 KF2" "Sol" #3=
".:1998 KF2:24980 1998 KF2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.754767889268
		SemiMajorAxis	2.41573854337
		Eccentricity	0.219048524423
		Inclination	22.9346069887
		AscendingNode	46.762986722496
		ArgOfPericenter	298.30989898457
		MeanAnomaly	66.605919991496
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0871
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=24980"
}

#1_"25000 Astrometria:Astrometria:1998 OW5" "Sol" #1=
#2_"*Астрометрия:25000 Astrometria:Astrometria:1998 OW5" "Sol" #2=
#3_"1998 OW5:*Астрометрия:25000 Astrometria:Astrometria" "Sol" #3=
".:Astrometria:25000 Astrometria:1998 OW5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	11.385
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.629283300399
		SemiMajorAxis	3.164438081218
		Eccentricity	0.097268518976
		Inclination	14.935722572204
		AscendingNode	142.061747958292
		ArgOfPericenter	12.751015535211
		MeanAnomaly	132.750238154943
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0311
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=25000"
}

#1_"25143 Itokawa:Itokawa:1998 SF36" "Sol" #1=
#2_"*Итокава:25143 Itokawa:Itokawa:1998 SF36" "Sol" #2=
#3_"1998 SF36:*Итокава:25143 Itokawa:Itokawa" "Sol" #3=
".:Itokawa:25143 Itokawa:1998 SF36" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"25143 itokawa.cmod"
	Orientation	[ 90 0 1 0 ]
	Radius	0.2675
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.5236988653184
		SemiMajorAxis	1.324119845185226
		Eccentricity	0.2800494589196127
		Inclination	1.621460231737667
		AscendingNode	69.08143643597246
		ArgOfPericenter	162.8103324760146
		MeanAnomaly	333.9418224137787
	}
	BodyFrame { EquatorJ2000 {} }
	UniformRotation
	{
		Period	12.132
		Inclination	156.30
		AscendingNode	180.53
	}
	LunarLambert	0.5
	Albedo	0.53
	InfoURL	"https://en.wikipedia.org/wiki/25143_Itokawa"
}

#1_"25330 1999 KV4:1999 KV4:1979 WC2" "Sol" #1=
#2_"1999 KV4:25330 1999 KV4" "Sol" #2=
#3_"1999 KV4:25330 1999 KV4" "Sol" #3=
".:1999 KV4:25330 1999 KV4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.605
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.911984383587
		SemiMajorAxis	1.540461181968
		Eccentricity	0.370843629762
		Inclination	14.328763703355
		AscendingNode	50.624384452604
		ArgOfPericenter	85.962005324821
		MeanAnomaly	73.420901617132
	}
	UniformRotation
	{
		Period	4.919
	}
	LunarLambert	0.5
	Albedo	0.052
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=25330"
}

#1_"25343 1999 RA44:1999 RA44:1992 SO26:1999 UC6" "Sol" #1=
#2_"1999 RA44:25343 1999 RA44" "Sol" #2=
#3_"1999 RA44:25343 1999 RA44" "Sol" #3=
".:1999 RA44:25343 1999 RA44" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.515
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.429574716198
		SemiMajorAxis	2.274161891279
		Eccentricity	0.114776269619
		Inclination	7.203788244339
		AscendingNode	52.68561455778
		ArgOfPericenter	75.829183160312
		MeanAnomaly	76.905593364096
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0252
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=25343"
}

#1_"25453 1999 XU11:1999 XU11" "Sol" #1=
#2_"1999 XU11:25453 1999 XU11" "Sol" #2=
#3_"1999 XU11:25453 1999 XU11" "Sol" #3=
".:1999 XU11:25453 1999 XU11" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.347821529868
		SemiMajorAxis	3.058058591096
		Eccentricity	0.126160271181
		Inclination	13.669065565427
		AscendingNode	264.780023198479
		ArgOfPericenter	144.431073934448
		MeanAnomaly	294.538467764912
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0957
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=25453"
}

#1_"25699 2000 AD127:2000 AD127:1986 NH1" "Sol" #1=
#2_"2000 AD127:25699 2000 AD127" "Sol" #2=
#3_"2000 AD127:25699 2000 AD127" "Sol" #3=
".:2000 AD127:25699 2000 AD127" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	9.835
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.368485911621
		SemiMajorAxis	3.065931237621
		Eccentricity	0.098075080959
		Inclination	12.418181704849
		AscendingNode	293.138883983443
		ArgOfPericenter	51.747961235063
		MeanAnomaly	59.38932531502
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0346
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=25699"
}

#1_"25785 2000 CY45:2000 CY45:1975 VR9:1984 SX1:1992 GC7:1992 HC6:1998 XV80" "Sol" #1=
#2_"2000 CY45:25785 2000 CY45" "Sol" #2=
#3_"2000 CY45:25785 2000 CY45" "Sol" #3=
".:2000 CY45:25785 2000 CY45" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.530468771604
		SemiMajorAxis	2.737936002776
		Eccentricity	0.282080887608
		Inclination	5.9747969178
		AscendingNode	198.457186376679
		ArgOfPericenter	144.714281337823
		MeanAnomaly	251.371177743598
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0238
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=25785"
}

#1_"25843 2000 EQ84:2000 EQ84:1975 TE4:1992 UY9" "Sol" #1=
#2_"2000 EQ84:25843 2000 EQ84" "Sol" #2=
#3_"2000 EQ84:25843 2000 EQ84" "Sol" #3=
".:2000 EQ84:25843 2000 EQ84" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	10.745
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.637686074078
		SemiMajorAxis	3.167586314586
		Eccentricity	0.071879899491
		Inclination	10.5951533862
		AscendingNode	192.104126148637
		ArgOfPericenter	258.237831340125
		MeanAnomaly	279.098780481981
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0167
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=25843"
}

#1_"26125 1992 RG:1992 RG:1951 RG1:1999 FA23:2000 GK108" "Sol" #1=
#2_"1992 RG:26125 1992 RG" "Sol" #2=
#3_"1992 RG:26125 1992 RG" "Sol" #3=
".:1992 RG:26125 1992 RG" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.345
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.548331565387
		SemiMajorAxis	2.745128062614
		Eccentricity	0.28569075203
		Inclination	9.219170610638
		AscendingNode	164.053836831883
		ArgOfPericenter	194.716947518119
		MeanAnomaly	314.175809989673
	}
	UniformRotation
	{
		Period	4.2005
	}
	LunarLambert	0.5
	Albedo	0.0975
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=26125"
}

#1_"26171 1996 BY2:1996 BY2:1998 QY24" "Sol" #1=
#2_"1996 BY2:26171 1996 BY2" "Sol" #2=
#3_"1996 BY2:26171 1996 BY2" "Sol" #3=
".:1996 BY2:26171 1996 BY2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	4.805
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.90677752988
		SemiMajorAxis	2.480506213636
		Eccentricity	0.190287041772
		Inclination	4.103195909656
		AscendingNode	158.113506379023
		ArgOfPericenter	287.615294343508
		MeanAnomaly	329.833690612691
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=26171"
}

#1_"26181 1996 GQ21:1996 GQ21" "Sol" #1=
#2_"1996 GQ21:26181 1996 GQ21" "Sol" #2=
#3_"1996 GQ21:26181 1996 GQ21" "Sol" #3=
".:1996 GQ21:26181 1996 GQ21" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	200.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	909.541430286731
		SemiMajorAxis	93.873466608273
		Eccentricity	0.592964674483
		Inclination	13.34065809759
		AscendingNode	194.134689316281
		ArgOfPericenter	356.386031146298
		MeanAnomaly	9.965947112845
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=26181"
}

#1_"26241 1998 QY40:1998 QY40:1977 SG:1991 RP33" "Sol" #1=
#2_"1998 QY40:26241 1998 QY40" "Sol" #2=
#3_"1998 QY40:26241 1998 QY40" "Sol" #3=
".:1998 QY40:26241 1998 QY40" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"26241 1998 QY40.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.365
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.499496668766
		SemiMajorAxis	2.30496811154
		Eccentricity	0.207422709144
		Inclination	5.732625981962
		AscendingNode	178.620121710097
		ArgOfPericenter	192.670230595117
		MeanAnomaly	79.24487566918
	}
	UniformRotation
	{
		Period	12.8346
	}
	LunarLambert	0.5
	Albedo	0.313
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=26241"
}

#1_"26260 1998 RA2:1998 RA2:2000 AX192" "Sol" #1=
#2_"1998 RA2:26260 1998 RA2" "Sol" #2=
#3_"1998 RA2:26260 1998 RA2" "Sol" #3=
".:1998 RA2:26260 1998 RA2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	6.755
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.357693541445
		SemiMajorAxis	2.667876091429
		Eccentricity	0.135071423425
		Inclination	10.493540917116
		AscendingNode	233.593660268933
		ArgOfPericenter	279.473287388925
		MeanAnomaly	122.232056628997
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.067
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=26260"
}

#1_"26308 1998 SM165:1998 SM165" "Sol" #1=
#2_"1998 SM165:26308 1998 SM165" "Sol" #2=
#3_"1998 SM165:26308 1998 SM165" "Sol" #3=
".:1998 SM165:26308 1998 SM165" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	134
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	328.391529644277
		SemiMajorAxis	47.598050222685
		Eccentricity	0.369072016389
		Inclination	13.513497491958
		AscendingNode	183.185767255318
		ArgOfPericenter	130.991957400325
		MeanAnomaly	44.010121939438
	}
	UniformRotation
	{
		Period	8.4
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=26308"
}

#1_"2001 26308 I" "Sol/26308 1998 SM165" #1=
#2_"2001 26308 I" "Sol/26308 1998 SM165" #2=
#3_"2001 26308 I" "Sol/26308 1998 SM165" #3=
".:2001 26308 I" "Sol/26308 1998 SM165" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid.dds"
	Radius	40.5
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EclipticJ2000	{ Center "Sol/(26308) 1998 SM165" }
	}    
	EllipticalOrbit
	{
		Epoch	2452700.0  # 2003 Mar 01 12:00
		Period	130.158
		SemiMajorAxis	11377
		Eccentricity	0.4727
		Inclination	81.57
		AscendingNode	47.09
		ArgOfPericenter	114.9
		MeanAnomaly	280.5
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-26308.html"
}

#1_"26375 1999 DE9:1999 DE9" "Sol" #1=
#2_"1999 DE9:26375 1999 DE9" "Sol" #2=
#3_"1999 DE9:26375 1999 DE9" "Sol" #3=
".:1999 DE9:26375 1999 DE9" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	230.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	418.356771821231
		SemiMajorAxis	55.936128023732
		Eccentricity	0.422648528895
		Inclination	7.605433613239
		AscendingNode	322.895060577338
		ArgOfPericenter	159.986136322818
		MeanAnomaly	24.567250370624
	}
	UniformRotation
	{
		Period	24
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=26375"
}

#1_"26387 1999 TG2:1999 TG2:1997 EJ52" "Sol" #1=
#2_"1999 TG2:26387 1999 TG2" "Sol" #2=
#3_"1999 TG2:26387 1999 TG2" "Sol" #3=
".:1999 TG2:26387 1999 TG2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"26387 1999 TG2.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.584
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.659130125621
		SemiMajorAxis	2.789530356483
		Eccentricity	0.083342817654
		Inclination	8.945658736674
		AscendingNode	358.777268884362
		ArgOfPericenter	182.45303120959
		MeanAnomaly	101.201969448234
	}
	UniformRotation
	{
		Period	5.1472
	}
	LunarLambert	0.5
	Albedo	0.377
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=26387"
}

#1_"26460 2000 AZ120:2000 AZ120" "Sol" #1=
#2_"2000 AZ120:26460 2000 AZ120" "Sol" #2=
#3_"2000 AZ120:26460 2000 AZ120" "Sol" #3=
".:2000 AZ120:26460 2000 AZ120" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"26460 2000 AZ120.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.758
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.340549837125
		SemiMajorAxis	2.660874326185
		Eccentricity	0.149690023895
		Inclination	15.879063871674
		AscendingNode	143.073070433139
		ArgOfPericenter	105.418811501134
		MeanAnomaly	225.43038728324
	}
	UniformRotation
	{
		Period	5.48
	}
	LunarLambert	0.5
	Albedo	0.197
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=26460"
}

#1_"26604 2000 FO25:2000 FO25:1968 TH:1980 FD4" "Sol" #1=
#2_"2000 FO25:26604 2000 FO25" "Sol" #2=
#3_"2000 FO25:26604 2000 FO25" "Sol" #3=
".:2000 FO25:26604 2000 FO25" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	3.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.91575038398
		SemiMajorAxis	2.891042080177
		Eccentricity	0.35105360439
		Inclination	15.116569137099
		AscendingNode	173.037388226717
		ArgOfPericenter	229.253641690007
		MeanAnomaly	116.635553305426
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.4331
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=26604"
}

#1_"26662 2000 WB181:2000 WB181:1974 HE3:1987 SU30:1991 RC1:1999 JQ85" "Sol" #1=
#2_"2000 WB181:26662 2000 WB181" "Sol" #2=
#3_"2000 WB181:26662 2000 WB181" "Sol" #3=
".:2000 WB181:26662 2000 WB181" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	7.045
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.134299771987
		SemiMajorAxis	2.575901038236
		Eccentricity	0.25991209143
		Inclination	11.522774231011
		AscendingNode	196.15647580564
		ArgOfPericenter	95.440522693992
		MeanAnomaly	252.080012347978
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.0186
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=26662"
}

#1_"26732 Damianpeach:Damianpeach:2001 HB16:1978 WX12:1995 VU" "Sol" #1=
#2_"*Дамианпич:26732 Damianpeach:Damianpeach:2001 HB16" "Sol" #2=
#3_"2001 HB16:26732 Damianpeach:Damianpeach" "Sol" #3=
".:Damianpeach:26732 Damianpeach:2001 HB16" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	1.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458200.5  # 2018 Mar 23
		Period	3.454537769068
		SemiMajorAxis	2.285183933531
		Eccentricity	0.10242011091
		Inclination	2.376377145631
		AscendingNode	266.576005175648
		ArgOfPericenter	57.571150262024
		MeanAnomaly	231.859439299557
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.104
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=26732"
}

#1_"27225 1999 GB17:1999 GB17:1977 DF11:1979 UB5:1984 YC3:1984 YL7" "Sol" #1=
#2_"1999 GB17:27225 1999 GB17" "Sol" #2=
#3_"1999 GB17:27225 1999 GB17" "Sol" #3=
".:1999 GB17:27225 1999 GB17" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"27225 1999 GB17.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.376169142376
		SemiMajorAxis	2.675411553157
		Eccentricity	0.115755431559
		Inclination	13.491657792527
		AscendingNode	20.954765026201
		ArgOfPericenter	166.905165037051
		MeanAnomaly	29.474112964378
	}
	UniformRotation
	{
		Period	3.853858
	}
	LunarLambert	0.5
	Albedo	0.363
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=27225"
}

#1_"28133 Kylebardwell:Kylebardwell:1998 SS130:1991 PO9" "Sol" #1=
#2_"*Кайлбардвелл:28133 Kylebardwell:Kylebardwell:1998 SS130" "Sol" #2=
#3_"1998 SS130:Kylebardwell:*Кайлбардвелл:28133 Kylebardwell" "Sol" #3=
".:Kylebardwell:28133 Kylebardwell:1998 SS130" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"28133 kylebardwell.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.679
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.275948199528
		SemiMajorAxis	2.205731011024
		Eccentricity	0.130238472117
		Inclination	2.546409546975
		AscendingNode	344.099369814068
		ArgOfPericenter	262.48998343173
		MeanAnomaly	340.370850027202
	}
	UniformRotation
	{
		Period	5.46284
	}
	LunarLambert	0.5
	Albedo	0.309
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=28133"
}

#1_"28736 2000 GE133:2000 GE133" "Sol" #1=
#2_"2000 GE133:28736 2000 GE133" "Sol" #2=
#3_"2000 GE133:28736 2000 GE133" "Sol" #3=
".:2000 GE133:28736 2000 GE133" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"28736 2000 GE133.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	3.202
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.445698563491
		SemiMajorAxis	2.281284167337
		Eccentricity	0.067296861021
		Inclination	9.742744408072
		AscendingNode	131.207420798352
		ArgOfPericenter	28.361384141225
		MeanAnomaly	8.037889716922
	}
	UniformRotation
	{
		Period	4.658
	}
	LunarLambert	0.5
	Albedo	0.093
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=28736"
}

#1_"28887 2000 KQ58:2000 KQ58:1988 DM1:1999 CB32" "Sol" #1=
#2_"1988 DM1:28887 2000 KQ58" "Sol" #2=
#3_"1988 DM1:28887 2000 KQ58" "Sol" #3=
".:2000 KQ58:28887 2000 KQ58" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"28887 2000 KQ58.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.196
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.727823019278
		SemiMajorAxis	2.404167501983
		Eccentricity	0.257653612109
		Inclination	13.79064980946
		AscendingNode	100.485377031065
		ArgOfPericenter	291.066866307003
		MeanAnomaly	19.010237708952
	}
	UniformRotation
	{
		Period	6.8429
	}
	LunarLambert	0.5
	Albedo	0.332
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=28887"
}

#1_"28978 Ixion:Ixion:2001 KX76" "Sol" #1=
#2_"*Иксион:28978 Ixion:Ixion:2001 KX76" "Sol" #2=
#3_"2001 KX76:*Иксион:28978 Ixion:Ixion" "Sol" #3=
".:Ixion:28978 Ixion:2001 KX76" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	308.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458200.5  # 2018 Mar 23
		Period	250.267192068746
		SemiMajorAxis	39.712797304978
		Eccentricity	0.242215549692
		Inclination	19.580788128563
		AscendingNode	70.991108341519
		ArgOfPericenter	298.578486340711
		MeanAnomaly	284.989387403958
	}
	UniformRotation
	{
		Period	12.4
	}
	LunarLambert	0.5
	Albedo	0.141
	InfoURL	"https://en.wikipedia.org/wiki/28978_Ixion"
}

#1_"29075 1950 DA:1950 DA:2000 YK66" "Sol" #1=
#2_"1950 DA:29075 1950 DA" "Sol" #2=
#3_"1950 DA:29075 1950 DA" "Sol" #3=
".:1950 DA:29075 1950 DA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"29075 1950 DA.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	0.73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2455259.5  # 2010 Mar 04
		Period	2.214445130345
		SemiMajorAxis	1.698913031756
		Eccentricity	0.507371570349
		Inclination	12.181570674
		AscendingNode	356.776332840293
		ArgOfPericenter	224.523460435839
		MeanAnomaly	5.379370545185
	}
	UniformRotation
	{
		Period	2.1216
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"https://en.wikipedia.org/wiki/(29075)_1950_DA"
}

#1_"29308 1993 UF1:1993 UF1:2000 EH50" "Sol" #1=
#2_"1993 UF1:29308 1993 UF1" "Sol" #2=
#3_"1993 UF1:29308 1993 UF1" "Sol" #3=
".:1993 UF1:29308 1993 UF1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"29308 1993 UF1.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.141
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.67292323959
		SemiMajorAxis	1.925981848588
		Eccentricity	0.092510594547
		Inclination	21.134800379607
		AscendingNode	35.966958300685
		ArgOfPericenter	312.149386667274
		MeanAnomaly	301.217575638228
	}
	UniformRotation
	{
		Period	9.81
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=29308"
}

#1_"Eurydamas System" "Sol" #1=
#2_"*Система Эвридаманта:Eurydamas System" "Sol" #2=
#3_"Eurydamas System:*Система Эвридаманта" "Sol" #3=
".:Eurydamas System" "Sol" #4=
{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.135518895455
		SemiMajorAxis	5.280804611905
		Eccentricity	0.072296082805
		Inclination	15.234770933941
		AscendingNode	143.372994105863
		ArgOfPericenter	135.314808148497
		MeanAnomaly	161.258165247915
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-29314.html"
}

#1_"29314 Eurydamas:Eurydamas:1994 CR18:2000 TR49" "Sol/Eurydamas System" #1=
#2_"*Эвридамант:29314 Eurydamas:Eurydamas:1994 CR18" "Sol/Eurydamas System" #2=
#3_"1994 CR18:*Эвридамант:29314 Eurydamas:Eurydamas" "Sol/Eurydamas System" #3=
".:Eurydamas:29314 Eurydamas:1994 CR18" "Sol/Eurydamas System" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.6265
		SemiMajorAxis	12
		ArgOfPericenter	180
	}
	UniformRotation
	{
		Period	15.035
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=29314"
}

#1_"2005 29314 I" "Sol/Eurydamas System" #1=
#2_"2005 29314 I" "Sol/Eurydamas System" #2=
#3_"2005 29314 I" "Sol/Eurydamas System" #3=
".:2005 29314 I" "Sol/Eurydamas System" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid.dds"
	Radius	12
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.6265
		SemiMajorAxis	29
	}
	UniformRotation
	{
		Period	15.035
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-29314.html"
}

#1_"29777 1999 CK46:1999 CK46:1955 FD:1977 DC5" "Sol" #1=
#2_"1999 CK46:29777 1999 CK46" "Sol" #2=
#3_"1999 CK46:29777 1999 CK46" "Sol" #3=
".:1999 CK46:29777 1999 CK46" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"29777 1999 CK46.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.867
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.549569176931
		SemiMajorAxis	3.134493532404
		Eccentricity	0.17579080745
		Inclination	7.606735637668
		AscendingNode	338.258183347126
		ArgOfPericenter	257.185789117111
		MeanAnomaly	26.94565438406
	}
	UniformRotation
	{
		Period	3.6295
	}
	LunarLambert	0.5
	Albedo	0.224
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=29777"
}

#1_"29981 1999 TD10:1999 TD10" "Sol" #1=
#2_"1999 TD10:29981 1999 TD10" "Sol" #2=
#3_"1999 TD10:29981 1999 TD10" "Sol" #3=
".:1999 TD10:29981 1999 TD10" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	48
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	958.801261403717
		SemiMajorAxis	97.232980017076
		Eccentricity	0.87315676965
		Inclination	5.958720475646
		AscendingNode	184.730166153924
		ArgOfPericenter	172.75526766197
		MeanAnomaly	5.675916740068
	}
	UniformRotation
	{
		Period	15.382
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=29981"
}

#1_"31060 1996 TB6:1996 TB6:1978 TS8:1987 WQ" "Sol" #1=
#2_"1996 TB6:31060 1996 TB6" "Sol" #2=
#3_"1996 TB6:31060 1996 TB6" "Sol" #3=
".:1996 TB6:31060 1996 TB6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"31060 1996 TB6.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.824
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.517215224791
		SemiMajorAxis	2.732593644841
		Eccentricity	0.309450408034
		Inclination	12.255722614261
		AscendingNode	31.45829229498
		ArgOfPericenter	346.301338774284
		MeanAnomaly	191.397313348292
	}
	UniformRotation
	{
		Period	5.103
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=31060"
}

#1_"31383 1998 XJ94:1998 XJ94:1977 JF:1978 TB5:1990 KK3:2000 OG19" "Sol" #1=
#2_"1998 XJ94:31383 1998 XJ94" "Sol" #2=
#3_"1998 XJ94:31383 1998 XJ94" "Sol" #3=
".:1998 XJ94:31383 1998 XJ94" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"31383 1998 XJ94.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.052
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.231167789695
		SemiMajorAxis	2.185584183145
		Eccentricity	0.099378056927
		Inclination	4.439993862513
		AscendingNode	175.929109460007
		ArgOfPericenter	53.233769017291
		MeanAnomaly	278.994260544214
	}
	UniformRotation
	{
		Period	4.1678
	}
	LunarLambert	0.5
	Albedo	0.289
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=31383"
}

#1_"31485 1999 CM51:1999 CM51:1980 YJ:1984 UA4" "Sol" #1=
#2_"1999 CM51:31485 1999 CM51" "Sol" #2=
#3_"1999 CM51:31485 1999 CM51" "Sol" #3=
".:1999 CM51:31485 1999 CM51" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"31485 1999 CM51.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	4.92
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.332617752473
		SemiMajorAxis	2.65763161657
		Eccentricity	0.202115165211
		Inclination	14.65292057732
		AscendingNode	347.032951495643
		ArgOfPericenter	48.174415541552
		MeanAnomaly	156.916023095918
	}
	UniformRotation
	{
		Period	6.001
	}
	LunarLambert	0.5
	Albedo	0.092
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=31485"
}

#1_"32511 2001 NX17:2001 NX17:2000 JV64" "Sol" #1=
#2_"2001 NX17:32511 2001 NX17" "Sol" #2=
#3_"2001 NX17:32511 2001 NX17" "Sol" #3=
".:2001 NX17:32511 2001 NX17" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11.304827510221
		SemiMajorAxis	5.03698307983
		Eccentricity	0.426686629002
		Inclination	8.932575580626
		AscendingNode	285.799767876887
		ArgOfPericenter	345.46898662403
		MeanAnomaly	73.21230620215
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.043
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=32511"
}

#1_"32575 2001 QY78:2001 QY78:1961 TT:1971 SA3:1981 UF15:2000 GG164" "Sol" #1=
#2_"2001 QY78:32575 2001 QY78" "Sol" #2=
#3_"2001 QY78:32575 2001 QY78" "Sol" #3=
".:2001 QY78:32575 2001 QY78" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"32575 2001 QY78.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.916
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.319782971134
		SemiMajorAxis	2.225363670092
		Eccentricity	0.336990954947
		Inclination	2.231188977626
		AscendingNode	229.129687658615
		ArgOfPericenter	98.218110189355
		MeanAnomaly	269.902195292762
	}
	UniformRotation
	{
		Period	4.5344
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=32575"
}

#1_"32776 Nriag:Nriag:1987 KG5:1999 CM5" "Sol" #1=
#2_"*NRIAG:32776 Nriag:Nriag:1987 KG5" "Sol" #2=
#3_"1987 KG5:Nriag:*NRIAG:32776 Nriag" "Sol" #3=
".:Nriag:32776 Nriag:1987 KG5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"32776 nriag.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.146
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.213865044479
		SemiMajorAxis	2.608845019067
		Eccentricity	0.16848475057
		Inclination	15.009193734731
		AscendingNode	142.555632462613
		ArgOfPericenter	148.347325708396
		MeanAnomaly	347.975032387641
	}
	UniformRotation
	{
		Period	3.985
	}
	LunarLambert	0.5
	Albedo	0.195
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=32776"
}

#1_"32799 1990 QN1:1990 QN1:2000 OX67" "Sol" #1=
#2_"1990 QN1:32799 1990 QN1" "Sol" #2=
#3_"1990 QN1:32799 1990 QN1" "Sol" #3=
".:1990 QN1:32799 1990 QN1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"32799 1990 QN1.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.624
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.429016044991
		SemiMajorAxis	2.273914913472
		Eccentricity	0.117931704579
		Inclination	4.530264025433
		AscendingNode	318.229829561975
		ArgOfPericenter	315.326779669192
		MeanAnomaly	316.624283382987
	}
	UniformRotation
	{
		Period	9.49636
	}
	LunarLambert	0.5
	Albedo	0.221
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=32799"
}

#1_"33001 1997 CU29:1997 CU29" "Sol" #1=
#2_"1997 CU29:33001 1997 CU29" "Sol" #2=
#3_"1997 CU29:33001 1997 CU29" "Sol" #3=
".:1997 CU29:33001 1997 CU29" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	110.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	289.05159948017
		SemiMajorAxis	43.716439463355
		Eccentricity	0.035219338166
		Inclination	1.451529386263
		AscendingNode	350.361350149912
		ArgOfPericenter	259.584942650288
		MeanAnomaly	247.500526290815
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=33001"
}

#1_"33116 1998 BO12:1998 BO12:1999 LX26" "Sol" #1=
#2_"1998 BO12:33116 1998 BO12" "Sol" #2=
#3_"1998 BO12:33116 1998 BO12" "Sol" #3=
".:1998 BO12:33116 1998 BO12" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"33116 1998 BO12.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.216
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.570581209643
		SemiMajorAxis	2.336076937432
		Eccentricity	0.166574819338
		Inclination	7.605817168987
		AscendingNode	112.714205335037
		ArgOfPericenter	144.337212979721
		MeanAnomaly	347.321314410046
	}
	UniformRotation
	{
		Period	6.345
	}
	LunarLambert	0.5
	Albedo	0.359
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=33116"
}

#1_"33340 1998 VG44:1998 VG44" "Sol" #1=
#2_"1998 VG44:33340 1998 VG44" "Sol" #2=
#3_"1998 VG44:33340 1998 VG44" "Sol" #3=
".:1998 VG44:33340 1998 VG44" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	199
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	248.263132413105
		SemiMajorAxis	39.50050842641
		Eccentricity	0.256550548356
		Inclination	3.034266668531
		AscendingNode	127.994963561438
		ArgOfPericenter	324.618689253897
		MeanAnomaly	1.236534617784
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=33340"
}

#1_"33342 1998 WT24:1998 WT24" "Sol" #1=
#2_"1998 WT24:33342 1998 WT24" "Sol" #2=
#3_"1998 WT24:33342 1998 WT24" "Sol" #3=
".:1998 WT24:33342 1998 WT24" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"33342 1998 WT24.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.21
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.608907066613
		SemiMajorAxis	0.718392640598
		Eccentricity	0.418026731344
		Inclination	7.342977242254
		AscendingNode	81.987177062609
		ArgOfPericenter	167.341831299975
		MeanAnomaly	324.948672489495
	}
	UniformRotation
	{
		Period	3.697
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=33342"
}

#1_"33776 1999 RB158:1999 RB158:1997 HB6" "Sol" #1=
#2_"1999 RB158:33776 1999 RB158" "Sol" #2=
#3_"1999 RB158:33776 1999 RB158" "Sol" #3=
".:1999 RB158:33776 1999 RB158" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"33776 1999 RB158.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	9.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.643290702861
		SemiMajorAxis	3.169685308746
		Eccentricity	0.100240723206
		Inclination	16.510408139177
		AscendingNode	354.562176438939
		ArgOfPericenter	305.514397341759
		MeanAnomaly	65.99374463914
	}
	UniformRotation
	{
		Period	16.9593
	}
	LunarLambert	0.5
	Albedo	0.052
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=33776"
}

#1_"33854 2000 HH53:2000 HH53:1981 US26" "Sol" #1=
#2_"2000 HH53:33854 2000 HH53" "Sol" #2=
#3_"2000 HH53:33854 2000 HH53" "Sol" #3=
".:2000 HH53:33854 2000 HH53" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"33854 2000 HH53.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.92
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.099680192462
		SemiMajorAxis	2.962714659273
		Eccentricity	0.163719756476
		Inclination	13.561009808494
		AscendingNode	51.690010488765
		ArgOfPericenter	278.032802433118
		MeanAnomaly	23.204618329886
	}
	UniformRotation
	{
		Period	4.423484
	}
	LunarLambert	0.5
	Albedo	0.226
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=33854"
}

#1_"33974 2000 ND17:2000 ND17" "Sol" #1=
#2_"2000 ND17:33974 2000 ND17" "Sol" #2=
#3_"2000 ND17:33974 2000 ND17" "Sol" #3=
".:2000 ND17:33974 2000 ND17" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"33974 2000 ND17.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	3.544
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.829098669334
		SemiMajorAxis	2.447516172442
		Eccentricity	0.10838273594
		Inclination	5.396900858709
		AscendingNode	20.997372476954
		ArgOfPericenter	18.095726806413
		MeanAnomaly	47.113908320923
	}
	UniformRotation
	{
		Period	4.67868
	}
	LunarLambert	0.5
	Albedo	0.061
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=33974"
}

#1_"34318 2000 QV192:2000 QV192" "Sol" #1=
#2_"2000 QV192:34318 2000 QV192" "Sol" #2=
#3_"2000 QV192:34318 2000 QV192" "Sol" #3=
".:2000 QV192:34318 2000 QV192" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"34318 2000 QV192.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.33
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.484238378593
		SemiMajorAxis	3.109845028567
		Eccentricity	0.240188612695
		Inclination	17.243785493416
		AscendingNode	136.994381565049
		ArgOfPericenter	319.727836026657
		MeanAnomaly	272.108383561582
	}
	UniformRotation
	{
		Period	6.35105
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=34318"
}

#1_"34484 2000 SR124:2000 SR124:1999 KZ14" "Sol" #1=
#2_"2000 SR124:34484 2000 SR124" "Sol" #2=
#3_"2000 SR124:34484 2000 SR124" "Sol" #3=
".:2000 SR124:34484 2000 SR124" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"34484 2000 SR124.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.854
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.681923671314
		SemiMajorAxis	2.38439234675
		Eccentricity	0.161802991508
		Inclination	3.237799385545
		AscendingNode	107.927033246362
		ArgOfPericenter	129.243553138141
		MeanAnomaly	304.003079843912
	}
	UniformRotation
	{
		Period	6.174
	}
	LunarLambert	0.5
	Albedo	0.268
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=34484"
}

#1_"34817 Shiominemoto:Shiominemoto:2001 SE116" "Sol" #1=
#2_"*Шиоминемото:34817 Shiominemoto:Shiominemoto:2001 SE116" "Sol" #2=
#3_"2001 SE116:*Шиоминемото:34817 Shiominemoto:Shiominemoto" "Sol" #3=
".:Shiominemoto:34817 Shiominemoto:2001 SE116" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"34817 shiominemoto.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.18
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	2.575537064551
		SemiMajorAxis	1.878911831959
		Eccentricity	0.118224405047
		Inclination	22.227302565673
		AscendingNode	285.967773216402
		ArgOfPericenter	70.415543593673
		MeanAnomaly	130.633154581699
	}
	UniformRotation
	{
		Period	6.382
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=34817"
}

#1_"35218 1994 WU2:1994 WU2:1999 FH49" "Sol" #1=
#2_"1994 WU2:35218 1994 WU2" "Sol" #2=
#3_"1994 WU2:35218 1994 WU2" "Sol" #3=
".:1994 WU2:35218 1994 WU2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"35218 1994 WU2.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.284
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.251444943582
		SemiMajorAxis	2.194718384
		Eccentricity	0.20611594781
		Inclination	4.969858722878
		AscendingNode	64.250778377212
		ArgOfPericenter	287.943381229541
		MeanAnomaly	359.707882577948
	}
	UniformRotation
	{
		Period	11.56991
	}
	LunarLambert	0.5
	Albedo	0.295
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=35218"
}

#1_"35671 1998 SN165:1998 SN165" "Sol" #1=
#2_"1998 SN165:35671 1998 SN165" "Sol" #2=
#3_"1998 SN165:35671 1998 SN165" "Sol" #3=
".:1998 SN165:35671 1998 SN165" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	230
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	232.85441228245
		SemiMajorAxis	37.848689455017
		Eccentricity	0.04443479891
		Inclination	4.608880482313
		AscendingNode	192.109002673488
		ArgOfPericenter	266.611106896508
		MeanAnomaly	283.28871446684
	}
	UniformRotation
	{
		Period	8.84
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=35671"
}

#1_"35928 1999 JV107:1999 JV107:2000 WO1" "Sol" #1=
#2_"1999 JV107:35928 1999 JV107" "Sol" #2=
#3_"1999 JV107:35928 1999 JV107" "Sol" #3=
".:1999 JV107:35928 1999 JV107" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"35928 1999 JV107.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.894
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.092789521091
		SemiMajorAxis	2.558629909886
		Eccentricity	0.108554612151
		Inclination	10.729967678905
		AscendingNode	61.990838093516
		ArgOfPericenter	328.192016092266
		MeanAnomaly	316.860722473104
	}
	UniformRotation
	{
		Period	7.26361
	}
	LunarLambert	0.5
	Albedo	0.234
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=35928"
}

#1_"35965 1999 LH13:1999 LH13" "Sol" #1=
#2_"1999 LH13:35965 1999 LH13" "Sol" #2=
#3_"1999 LH13:35965 1999 LH13" "Sol" #3=
".:1999 LH13:35965 1999 LH13" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"35965 1999 LH13.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.612
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.529869235957
		SemiMajorAxis	2.318285630484
		Eccentricity	0.134608894994
		Inclination	6.799387273669
		AscendingNode	139.469940799559
		ArgOfPericenter	144.812144167422
		MeanAnomaly	344.553311008433
	}
	UniformRotation
	{
		Period	6.76072
	}
	LunarLambert	0.5
	Albedo	0.427
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=35965"
}

#1_"36303 2000 JM54:2000 JM54" "Sol" #1=
#2_"2000 JM54:36303 2000 JM54" "Sol" #2=
#3_"2000 JM54:36303 2000 JM54" "Sol" #3=
".:2000 JM54:36303 2000 JM54" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"36303 2000 JM54.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.298
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.306684278847
		SemiMajorAxis	2.219506147329
		Eccentricity	0.189289242336
		Inclination	4.485922474468
		AscendingNode	77.076759665624
		ArgOfPericenter	246.65198059379
		MeanAnomaly	312.058526376035
	}
	UniformRotation
	{
		Period	4.93652
	}
	LunarLambert	0.5
	Albedo	0.288
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=36303"
}

#1_"36487 2000 QJ42:2000 QJ42:1989 CD5:1999 GL35" "Sol" #1=
#2_"2000 QJ42:36487 2000 QJ42" "Sol" #2=
#3_"2000 QJ42:36487 2000 QJ42" "Sol" #3=
".:2000 QJ42:36487 2000 QJ42" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"36487 2000 QJ42.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.298
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.210277970527
		SemiMajorAxis	2.176153991789
		Eccentricity	0.083313882674
		Inclination	4.557498677204
		AscendingNode	319.728787756768
		ArgOfPericenter	118.861705828634
		MeanAnomaly	310.148600754428
	}
	UniformRotation
	{
		Period	8.1509
	}
	LunarLambert	0.5
	Albedo	0.315
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=36487"
}

#1_"36944 2000 SD249:2000 SD249:1998 FL140" "Sol" #1=
#2_"2000 SD249:36944 2000 SD249" "Sol" #2=
#3_"2000 SD249:36944 2000 SD249" "Sol" #3=
".:2000 SD249:36944 2000 SD249" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"36944 2000 SD249.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.916
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.530611021208
		SemiMajorAxis	2.737993313737
		Eccentricity	0.086096693126
		Inclination	6.633025190302
		AscendingNode	347.011119937259
		ArgOfPericenter	151.122106189944
		MeanAnomaly	91.727380391846
	}
	UniformRotation
	{
		Period	6.09677
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=36944"
}

#1_"37117 Narcissus:Narcissus:2000 VU2:2000 VW55" "Sol" #1=
#2_"*Нарцисс:37117 Narcissus:Narcissus:2000 VU2" "Sol" #2=
#3_"2000 VU2:*Нарцисс:37117 Narcissus:Narcissus" "Sol" #3=
".:Narcissus:37117 Narcissus:2000 VU2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	18.020428914729
		SemiMajorAxis	6.873394656366
		Eccentricity	0.554130793025
		Inclination	13.814362660597
		AscendingNode	248.594039486304
		ArgOfPericenter	180.253904981748
		MeanAnomaly	278.169667883962
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.088
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=37117"
}

#1_"37655 Illapa:Illapa:1994 PM" "Sol" #1=
#2_"*Ильяпа:37655 Illapa:Illapa:1994 PM" "Sol" #2=
#3_"1994 PM:*Ильяпа:37655 Illapa:Illapa" "Sol" #3=
".:Illapa:37655 Illapa:1994 PM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.675
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.796770684614
		SemiMajorAxis	1.477938289211
		Eccentricity	0.752485723278
		Inclination	18.001461997988
		AscendingNode	139.701481107276
		ArgOfPericenter	303.71498251911
		MeanAnomaly	80.076129513423
	}
	UniformRotation
	{
		Period	2.6556
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=37655"
}

#1_"38083 Rhadamanthus:Rhadamanthus:1999 HX11" "Sol" #1=
#2_"*Радамант:38083 Rhadamanthus:Rhadamanthus:1999 HX11" "Sol" #2=
#3_"1999 HX11:*Радамант:38083 Rhadamanthus:Rhadamanthus" "Sol" #3=
".:Rhadamanthus:38083 Rhadamanthus:1999 HX11" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	100.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	244.69757621657
		SemiMajorAxis	39.121392986745
		Eccentricity	0.154854432292
		Inclination	12.729478985438
		AscendingNode	9.973453946747
		ArgOfPericenter	81.521146503865
		MeanAnomaly	96.071485814756
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=38083"
}

#1_"38084 1999 HB12:1999 HB12" "Sol" #1=
#2_"1999 HB12:38084 1999 HB12" "Sol" #2=
#3_"1999 HB12:38084 1999 HB12" "Sol" #3=
".:1999 HB12:38084 1999 HB12" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	417.115326132905
		SemiMajorAxis	55.825415415221
		Eccentricity	0.416572077178
		Inclination	13.140059460705
		AscendingNode	166.363454458882
		ArgOfPericenter	66.272747543312
		MeanAnomaly	356.547467555921
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=38084"
}

#1_"38086 Beowulf:Beowulf:1999 JB" "Sol" #1=
#2_"*Беовульф:38086 Beowulf:Beowulf:1999 JB" "Sol" #2=
#3_"1999 JB:*Беовульф:38086 Beowulf:Beowulf" "Sol" #3=
".:Beowulf:38086 Beowulf:1999 JB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.712
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.692470544197
		SemiMajorAxis	1.420175265416
		Eccentricity	0.566299832844
		Inclination	23.670831482515
		AscendingNode	165.353863882717
		ArgOfPericenter	178.884170764335
		MeanAnomaly	20.42711687146
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=38086"
}

#1_"Huya System" "Sol" #1=
#2_"*Система Гуйи:Huya System" "Sol" #2=
#3_"Huya System:*Система Гуйи" "Sol" #3=
".:Huya System" "Sol" #4=
{
	Class	"asteroid"
	Mesh	""
	Radius	220
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	251.034650308289
		SemiMajorAxis	39.793943532235
		Eccentricity	0.282900115533
		Inclination	15.465507019854
		AscendingNode	169.251094573659
		ArgOfPericenter	67.890359902978
		MeanAnomaly	3.693348169818
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-38628.html"
}

#1_"38628 Huya:Huya:2000 EB173" "Sol/Huya System" #1=
#2_"*Гуйя:38628 Huya:Huya:2000 EB173" "Sol/Huya System" #2=
#3_"2000 EB173:*Гуйя:38628 Huya:Huya" "Sol/Huya System" #3=
".:Huya:38628 Huya:2000 EB173" "Sol/Huya System" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"huya.dds"
	BumpMap	"huya-bump.png"
	BumpHeight	5
	Radius	203
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	3.2
		SemiMajorAxis	220
		ArgOfPericenter	180
	}
	UniformRotation
	{
		Period	5.28
	}
	LunarLambert	0.5
	Albedo	0.083
	InfoURL	"https://en.wikipedia.org/wiki/38628_Huya"
}

#1_"2012 38628 I" "Sol/Huya System" #1=
#2_"2012 38628 I" "Sol/Huya System" #2=
#3_"2012 38628 I" "Sol/Huya System" #3=
".:2012 38628 I" "Sol/Huya System" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"huya.dds"
	Radius	106.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	3.2
		SemiMajorAxis	1520
	}
	UniformRotation
	{
		Period	5.28
	}
	LunarLambert	0.5
	Albedo	0.083
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-38628.html"
}

#1_"40104 1998 QE4:1998 QE4" "Sol" #1=
#2_"1998 QE4:40104 1998 QE4" "Sol" #2=
#3_"1998 QE4:40104 1998 QE4" "Sol" #3=
".:1998 QE4:40104 1998 QE4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"40104 1998 QE4.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.414
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.186120313236
		SemiMajorAxis	2.99609967174
		Eccentricity	0.085037888242
		Inclination	10.734859619905
		AscendingNode	113.207149037553
		ArgOfPericenter	214.946731352416
		MeanAnomaly	217.417340791231
	}
	UniformRotation
	{
		Period	4.4747
	}
	LunarLambert	0.5
	Albedo	0.13
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=40104"
}

#1_"40314 1999 KR16:1999 KR16" "Sol" #1=
#2_"1999 KR16:40314 1999 KR16" "Sol" #2=
#3_"1999 KR16:40314 1999 KR16" "Sol" #3=
".:1999 KR16:40314 1999 KR16" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	127
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	341.063328386534
		SemiMajorAxis	48.814766448709
		Eccentricity	0.303883301503
		Inclination	24.79935106998
		AscendingNode	205.605003047433
		ArgOfPericenter	58.414946489671
		MeanAnomaly	344.065211311267
	}
	UniformRotation
	{
		Period	11.7
	}
	LunarLambert	0.5
	Albedo	0.204
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=40314"
}

#1_"40478 1999 RT54:1999 RT54:1977 RA16:1991 GK9" "Sol" #1=
#2_"1999 RT54:40478 1999 RT54" "Sol" #2=
#3_"1999 RT54:40478 1999 RT54" "Sol" #3=
".:1999 RT54:40478 1999 RT54" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"40478 1999 RT54.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.843
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.691567268091
		SemiMajorAxis	2.388553956182
		Eccentricity	0.177712224177
		Inclination	0.829933729918
		AscendingNode	188.944509941743
		ArgOfPericenter	88.663357843252
		MeanAnomaly	301.598529775549
	}
	UniformRotation
	{
		Period	3.886734
	}
	LunarLambert	0.5
	Albedo	0.226
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=40478"
}

#1_"40806 1999 TX41:1999 TX41:1998 EB1" "Sol" #1=
#2_"1999 TX41:40806 1999 TX41" "Sol" #2=
#3_"1999 TX41:40806 1999 TX41" "Sol" #3=
".:1999 TX41:40806 1999 TX41" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"40806 1999 TX41.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.155
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.632055864321
		SemiMajorAxis	2.362814051897
		Eccentricity	0.162495988941
		Inclination	1.641030486408
		AscendingNode	250.4907384093
		ArgOfPericenter	355.873322821637
		MeanAnomaly	15.163815641331
	}
	UniformRotation
	{
		Period	6.415
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=40806"
}

#1_"42301 2001 UR163:2001 UR163" "Sol" #1=
#2_"2001 UR163:42301 2001 UR163" "Sol" #2=
#3_"2001 UR163:42301 2001 UR163" "Sol" #3=
".:2001 UR163:42301 2001 UR163" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.732 0.476 ]
	BlendTexture	true
	Radius	318
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	369.247394116423
		SemiMajorAxis	51.468260592026
		Eccentricity	0.281702475138
		Inclination	0.752307037728
		AscendingNode	302.277655729761
		ArgOfPericenter	342.511590437213
		MeanAnomaly	76.206641618462
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=42301"
}

#1_"Typhon-Echidna" "Sol" #1=
#2_"*Тифон-Ехидна:Typhon-Echidna" "Sol" #2=
#3_"Typhon-Echidna:*Тифон-Ехидна" "Sol" #3=
".:Typhon-Echidna" "Sol" #4=
{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	111
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	235.882733242784
		SemiMajorAxis	38.176135734022
		Eccentricity	0.540814077516
		Inclination	2.425096126661
		AscendingNode	351.908297686875
		ArgOfPericenter	159.135523429766
		MeanAnomaly	13.042859303108
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-42355.html"
}

#1_"42355 Typhon:Typhon:2002 CR46" "Sol/Typhon-Echidna" #1=
#2_"*Тифон:42355 Typhon:Typhon:2002 CR46" "Sol/Typhon-Echidna" #2=
#3_"2002 CR46:*Тифон:42355 Typhon:Typhon" "Sol/Typhon-Echidna" #3=
".:Typhon:42355 Typhon:2002 CR46" "Sol/Typhon-Echidna" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	81
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Typhon-Echidna" }
    }
	EllipticalOrbit
	{
		Epoch	2454000.0  # 2006 Sept 21 12:00
		Period	18.982
		SemiMajorAxis	225
		Eccentricity	0.507
		Inclination	42.0
		AscendingNode	254.0
		ArgOfPericenter	174.0
		MeanAnomaly	11.0
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Typhon-Echidna" }
        }
	UniformRotation
	{
		Period	9.67
		Inclination	42.0
		AscendingNode	254.0
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=42355"
}

#1_"Echidna:42355 Typhon I:Typhon I:2006 42355 I" "Sol/Typhon-Echidna" #1=
#2_"*Ехидна:Echidna:42355 Typhon I:*Тифон I:Typhon I:2006 42355 I" "Sol/Typhon-Echidna" #2=
#3_"2006 42355 I:*Ехидна:Echidna:42355 Typhon I:*Тифон I:Typhon I" "Sol/Typhon-Echidna" #3=
".:Echidna:42355 Typhon I:Typhon I:2006 42355 I" "Sol/Typhon-Echidna" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	44.5
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Typhon-Echidna" }
    }
	EllipticalOrbit
	{
		Epoch	2454000.0  # 2006 Sept 21 12:00
		Period	18.982
		SemiMajorAxis	1355
		Eccentricity	0.507
		Inclination	42.0
		AscendingNode	254.0
		ArgOfPericenter	354.0
		MeanAnomaly	11.0
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Typhon-Echidna" }
	}
 	UniformRotation
	{
		Period	9.67
		Inclination	42.0
		AscendingNode	254.0
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-42355.html"
}

#1_"42923 1999 SR18:1999 SR18:1972 LA1" "Sol" #1=
#2_"1999 SR18:42923 1999 SR18" "Sol" #2=
#3_"1999 SR18:42923 1999 SR18" "Sol" #3=
".:1972 LA1:42923 1999 SR18" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"42923 1999 SR18.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.487
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.322700083298
		SemiMajorAxis	2.226667105718
		Eccentricity	0.185350682203
		Inclination	6.810228352213
		AscendingNode	117.646015456517
		ArgOfPericenter	168.626830422665
		MeanAnomaly	140.303341462191
	}
	UniformRotation
	{
		Period	8.392
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=42923"
}

#1_"43163 1999 XB127:1999 XB127:1998 QG69" "Sol" #1=
#2_"1999 XB127:43163 1999 XB127" "Sol" #2=
#3_"1999 XB127:43163 1999 XB127" "Sol" #3=
".:1998 QG69:43163 1999 XB127" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"43163 1999 XB127.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	4.39
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.285945013014
		SemiMajorAxis	3.034424194881
		Eccentricity	0.038011648303
		Inclination	11.843572675993
		AscendingNode	269.613149804089
		ArgOfPericenter	45.915438636766
		MeanAnomaly	198.874950756635
	}
	UniformRotation
	{
		Period	5.2066
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=43163"
}

#1_"43574 2001 FU192:2001 FU192" "Sol" #1=
#2_"2001 FU192:43574 2001 FU192" "Sol" #2=
#3_"2001 FU192:43574 2001 FU192" "Sol" #3=
".:2001 FU192:43574 2001 FU192" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"43574 2001 FU192.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.413
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.21518089722
		SemiMajorAxis	2.609388095664
		Eccentricity	0.213228561909
		Inclination	5.138880802843
		AscendingNode	44.603078575589
		ArgOfPericenter	322.137806876351
		MeanAnomaly	111.948739076512
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=43574"
}

#1_"43788 1990 RB3:1990 RB3:1986 TF4:2001 FN50" "Sol" #1=
#2_"1990 RB3:43788 1990 RB3" "Sol" #2=
#3_"1990 RB3:43788 1990 RB3" "Sol" #3=
".:1990 RB3:43788 1990 RB3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	4.192836240411
		SemiMajorAxis	2.600158358696
		Eccentricity	0.203492892677
		Inclination	18.40354265589
		AscendingNode	179.97616608527
		ArgOfPericenter	190.373287536384
		MeanAnomaly	50.731269056458
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.182
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=43788"
}

#1_"44417 1998 SS146:1998 SS146:1980 FU5:2000 AE180" "Sol" #1=
#2_"1998 SS146:44417 1998 SS146" "Sol" #2=
#3_"1998 SS146:44417 1998 SS146" "Sol" #3=
".:1998 SS146:44417 1998 SS146" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"44417 1998 SS146.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.741
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.178118901035
		SemiMajorAxis	2.993017188018
		Eccentricity	0.021366215747
		Inclination	9.647778711413
		AscendingNode	190.460389491317
		ArgOfPericenter	72.868189894863
		MeanAnomaly	319.232504749627
	}
	UniformRotation
	{
		Period	7.6322
	}
	LunarLambert	0.5
	Albedo	0.199
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=44417"
}

#1_"44600 1999 RU10:1999 RU10:2000 YT34" "Sol" #1=
#2_"1999 RU10:44600 1999 RU10" "Sol" #2=
#3_"1999 RU10:44600 1999 RU10" "Sol" #3=
".:1999 RU10:44600 1999 RU10" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"44600 1999 RU10.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.944
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.665344518746
		SemiMajorAxis	1.922339547903
		Eccentricity	0.057723982722
		Inclination	20.586525020558
		AscendingNode	332.049456955594
		ArgOfPericenter	202.144497271969
		MeanAnomaly	354.422866212942
	}
	UniformRotation
	{
		Period	6.211
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=44600"
}

#1_"45864 2000 UO97:2000 UO97:1991 DA2" "Sol" #1=
#2_"2000 UO97:45864 2000 UO97" "Sol" #2=
#3_"2000 UO97:45864 2000 UO97" "Sol" #3=
".:2000 UO97:45864 2000 UO97" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"45864 2000 UO97.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.14
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.520880729328
		SemiMajorAxis	2.314348415807
		Eccentricity	0.104835469797
		Inclination	5.879678011962
		AscendingNode	275.495282614631
		ArgOfPericenter	201.302700588909
		MeanAnomaly	166.901401317189
	}
	UniformRotation
	{
		Period	5.13544
	}
	LunarLambert	0.5
	Albedo	0.35
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=45864"
}

#1_"46376 2001 XD3:2001 XD3" "Sol" #1=
#2_"2001 XD3:46376 2001 XD3" "Sol" #2=
#3_"2001 XD3:46376 2001 XD3" "Sol" #3=
".:2001 XD3:46376 2001 XD3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"46376 2001 XD3.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.893
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.742707646806
		SemiMajorAxis	1.959359875062
		Eccentricity	0.090190728178
		Inclination	18.120065554515
		AscendingNode	275.379968658772
		ArgOfPericenter	34.638000653593
		MeanAnomaly	314.040342868792
	}
	UniformRotation
	{
		Period	5.73569
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=46376"
}

#1_"47035 1998 WS:1998 WS:1976 UA21:1982 GD" "Sol" #1=
#2_"1998 WS:47035 1998 WS" "Sol" #2=
#3_"1998 WS:47035 1998 WS" "Sol" #3=
".:1998 WS:47035 1998 WS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"47035 1998 WS.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.788
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.330409771553
		SemiMajorAxis	2.656728621544
		Eccentricity	0.393652573124
		Inclination	27.497268760721
		AscendingNode	9.001619390128
		ArgOfPericenter	94.832248538898
		MeanAnomaly	291.446471417494
	}
	UniformRotation
	{
		Period	3.99
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=47035"
}

#1_"Lempo System" "Sol" #1=
#2_"*Система Лемпо:Lempo System" "Sol" #2=
#3_"Lempo System:*Система Лемпо" "Sol" #3=
".:Lempo System" "Sol" #4=
{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	382
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	245.480888687632
		SemiMajorAxis	39.204837346215
		Eccentricity	0.220699149764
		Inclination	8.419678691067
		AscendingNode	97.061160316441
		ArgOfPericenter	294.936207934323
		MeanAnomaly	3.488579371382
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-47171.html"
}

#1_"47171 Lempo:1999 TC36 A1" "Sol/Lempo System" #1=
#2_"*Лемпо:47171 Lempo:1999 TC36 A1" "Sol/Lempo System" #2=
#3_"1999 TC36 A1:*Лемпо:47171 Lempo" "Sol/Lempo System" #3=
".:47171 Lempo:1999 TC36 A1" "Sol/Lempo System" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.00 0.609 0.507 ]
	BlendTexture	true
	Radius	136
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	1.907
		SemiMajorAxis	382
		ArgOfPericenter	180
	}
	UniformRotation
	{
		Period	45.768
	}
	LunarLambert	0.5
	Albedo	0.079
	InfoURL	"https://en.wikipedia.org/wiki/(47171)_1999_TC36"
}

#New4-Name
#1_"Hiisi:47171 Lempo II:Lempo II:1999 TC36 A2" "Sol/Lempo System" #1=
#2_"*Хийси:Hiisi:47171 Lempo II:Lempo II:1999 TC36 A2" "Sol/Lempo System" #2=
#3_"1999 TC36 A2:*Хийси:Hiisi:47171 Lempo II:Lempo II" "Sol/Lempo System" #3=
".:Hiisi:47171 Lempo II:Lempo II:1999 TC36 A2" "Sol/Lempo System" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.609 0.507 ]
	BlendTexture	true
	Radius	125.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	1.907
		SemiMajorAxis	485
	}
	UniformRotation
	{
		Period	45.768
	}
	LunarLambert	0.5
	Albedo	0.079
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-47171.html"
}

#New4-Name
#1_"Paha:47171 Lempo I:Lempo I:2001 47171 I:1999 TC36 B" "Sol/Lempo System" #1=
#2_"*Паха:47171 Lempo I:Lempo I:2001 47171 I:1999 TC36 B" "Sol/Lempo System" #2=
#3_"1999 TC36 B:*Паха:47171 Lempo I:Lempo I:2001 47171 I" "Sol/Lempo System" #3=
".:Paha:47171 Lempo I:Lempo I:2001 47171 I:1999 TC36 B" "Sol/Lempo System" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.609 0.507 ]
	BlendTexture	true
	Radius	66
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	50.3
		SemiMajorAxis	7411
	}
	LunarLambert	0.5
	Albedo	0.079
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-47171.html"
}

#1_"47508 2000 AQ58:2000 AQ58" "Sol" #1=
#2_"2000 AQ58:47508 2000 AQ58" "Sol" #2=
#3_"2000 AQ58:47508 2000 AQ58" "Sol" #3=
".:2000 AQ58:47508 2000 AQ58" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"47508 2000 AQ58.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.93
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.500720414595
		SemiMajorAxis	2.725937465866
		Eccentricity	0.028072667972
		Inclination	10.28521235975
		AscendingNode	108.78338810499
		ArgOfPericenter	99.681108173109
		MeanAnomaly	206.403706043484
	}
	UniformRotation
	{
		Period	5.05521
	}
	LunarLambert	0.5
	Albedo	0.298
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=47508"
}

#1_"48268 2002 AK1:2002 AK1:2000 LW13" "Sol" #1=
#2_"2000 LW13:48268 2002 AK1" "Sol" #2=
#3_"2000 LW13:48268 2002 AK1" "Sol" #3=
".:2002 AK1:48268 2002 AK1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"48268 2002 AK1.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	3.487
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.321376079583
		SemiMajorAxis	2.653032524797
		Eccentricity	0.19072593584
		Inclination	14.315777998005
		AscendingNode	120.009653518493
		ArgOfPericenter	206.882683157478
		MeanAnomaly	273.669901929466
	}
	UniformRotation
	{
		Period	4.250546
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=48268"
}

#1_"48639 1995 TL8:1995 TL8" "Sol" #1=
#2_"1995 TL8:48639 1995 TL8" "Sol" #2=
#3_"1995 TL8:48639 1995 TL8" "Sol" #3=
".:1995 TL8:48639 1995 TL8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	175
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	380.829715496401
		SemiMajorAxis	52.538993744942
		Eccentricity	0.235735831147
		Inclination	0.242935313258
		AscendingNode	260.999147022634
		ArgOfPericenter	84.346950386786
		MeanAnomaly	40.98728349567
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=48639"
}

#1_"2002 48639 I" "Sol/48639 1995 TL8" #1=
#2_"2002 48639 I" "Sol/48639 1995 TL8" #2=
#3_"2002 48639 I" "Sol/48639 1995 TL8" #3=
".:2002 48639 I" "Sol/48639 1995 TL8" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	80
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	1.4
		SemiMajorAxis	420
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-48639.html"
}

#1_"48842 1998 BA44:1998 BA44:2001 ON21" "Sol" #1=
#2_"1998 BA44:48842 1998 BA44" "Sol" #2=
#3_"1998 BA44:48842 1998 BA44" "Sol" #3=
".:1998 BA44:48842 1998 BA44" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"48842 1998 BA44.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	8.51
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.572253283062
		SemiMajorAxis	3.143029309977
		Eccentricity	0.077764301714
		Inclination	15.709282834368
		AscendingNode	332.849525323856
		ArgOfPericenter	21.49959734207
		MeanAnomaly	272.955918549625
	}
	UniformRotation
	{
		Period	6.1841
	}
	LunarLambert	0.5
	Albedo	0.051
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=48842"
}

#1_"50000 Quaoar:Quaoar:2002 LM60" "Sol" #1=
#2_"*Квавар:50000 Quaoar:Quaoar:2002 LM60" "Sol" #2=
#3_"2002 LM60:*Квавар:50000 Quaoar:Quaoar" "Sol" #3=
".:Quaoar:50000 Quaoar:2002 LM60" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"quaoar.dds"
	NormalMap	"quaoar-normal.*"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	535
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	286.915511494408
		SemiMajorAxis	43.500797328411
		Eccentricity	0.035753383409
		Inclination	7.986455383438
		AscendingNode	188.751626335942
		ArgOfPericenter	150.85448137954
		MeanAnomaly	293.34958176384
	}
	UniformRotation
	{
		Period	8.839
	}
	LunarLambert	0.5
	Albedo	0.109
	InfoURL	"https://en.wikipedia.org/wiki/50000_Quaoar"
}

#1_"Weywot:50000 Quaoar I:Quaoar I:2006 50000 I" "Sol/50000 Quaoar" #1=
#2_"*Вейвот:Weywot:50000 Quaoar I:*Квавар I:Quaoar I:2006 50000 I" "Sol/50000 Quaoar" #2=
#3_"2006 50000 I:*Вейвот:Weywot:50000 Quaoar I:*Квавар I:Quaoar I" "Sol/50000 Quaoar" #3=
".:Weywot:50000 Quaoar I:Quaoar I:2006 50000 I" "Sol/50000 Quaoar" #4=

{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Color	[ 1.00 0.670 0.375 ]
	BlendTexture	true
	Radius	40.5
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EclipticJ2000	{ Center "Sol/50000 Quaoar" }
    }
	EllipticalOrbit
	{
		Period	12.26
		SemiMajorAxis	13800
		Eccentricity	0.148
		Inclination	14.0
		AscendingNode	1.0
		ArgOfPericenter	348.0
	}
	LunarLambert	0.5
	Albedo	0.109
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-50000.html"
}

#1_"52246 Donaldjohanson:Donaldjohanson:1981 EQ5:1998 YF26" "Sol" #1=
#2_"*Дональдджохансон:52246 Donaldjohanson:Donaldjohanson:1981 EQ5" "Sol" #2=
#3_"1981 EQ5:Donaldjohanson:*Дональдджохансон:52246 Donaldjohanson" "Sol" #3=
".:Donaldjohanson:52246 Donaldjohanson:1981 EQ5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.948
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.68122403875
		SemiMajorAxis	2.384090285198
		Eccentricity	0.185723645177
		Inclination	4.419202772805
		AscendingNode	262.851331702357
		ArgOfPericenter	213.000875797668
		MeanAnomaly	317.070039342646
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.103
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=52246"
}

#1_"52723 1998 GP2:1998 GP2:1981 FM1:2001 QC79" "Sol" #1=
#2_"1998 GP2:52723 1998 GP2" "Sol" #2=
#3_"1998 GP2:52723 1998 GP2" "Sol" #3=
".:1998 GP2:52723 1998 GP2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"52723 1998 GP2.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	6.625
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.645616286914
		SemiMajorAxis	3.17055606115
		Eccentricity	0.062439492346
		Inclination	17.87610406758
		AscendingNode	36.061627856797
		ArgOfPericenter	264.640122388227
		MeanAnomaly	3.033518662356
	}
	UniformRotation
	{
		Period	11.90781
	}
	LunarLambert	0.5
	Albedo	0.11
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=52723"
}

#1_"52747 1998 HM151:1998 HM151" "Sol" #1=
#2_"1998 HM151:52747 1998 HM151" "Sol" #2=
#3_"1998 HM151:52747 1998 HM151" "Sol" #3=
".:1998 HM151:52747 1998 HM151" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	295.22942428813
		SemiMajorAxis	44.337134866596
		Eccentricity	0.057124776644
		Inclination	0.543738972241
		AscendingNode	63.92679624938
		ArgOfPericenter	248.32045514102
		MeanAnomaly	312.739591849038
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=52747"
}

#1_"52760 1998 ML14:1998 ML14" "Sol" #1=
#2_"1998 ML14:52760 1998 ML14" "Sol" #2=
#3_"1998 ML14:52760 1998 ML14" "Sol" #3=
".:1998 ML14:52760 1998 ML14" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"52760 1998 ML14.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.748975106901
		SemiMajorAxis	2.41325326798
		Eccentricity	0.620987660768
		Inclination	2.432378748828
		AscendingNode	338.81971906017
		ArgOfPericenter	20.164157600239
		MeanAnomaly	118.257148596104
	}
	UniformRotation
	{
		Period	14.28
	}
	LunarLambert	0.5
	Albedo	0.18
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=52760"
}

#1_"52820 1998 RS2:1998 RS2:1981 JU4:2001 MK5" "Sol" #1=
#2_"1998 RS2:52820 1998 RS2" "Sol" #2=
#3_"1998 RS2:52820 1998 RS2" "Sol" #3=
".:1998 RS2:52820 1998 RS2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"52820 1998 RS2.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	1.989
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.293545955101
		SemiMajorAxis	2.213623127264
		Eccentricity	0.203358920907
		Inclination	2.448068485394
		AscendingNode	74.601596737084
		ArgOfPericenter	210.07305969587
		MeanAnomaly	89.603470371945
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.041
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=52820"
}

#1_"52872 Okyrhoe:Okyrhoe:1998 SG35" "Sol" #1=
#2_"*Окироя:52872 Okyrhoe:Okyrhoe:1998 SG35" "Sol" #2=
#3_"1998 SG35:*Окироя:52872 Okyrhoe:Okyrhoe" "Sol" #3=
".:Okyrhoe:52872 Okyrhoe:1998 SG35" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	24.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	24.093726954252
		SemiMajorAxis	8.341878397817
		Eccentricity	0.306925742912
		Inclination	15.661994139132
		AscendingNode	173.050672315463
		ArgOfPericenter	337.631685037017
		MeanAnomaly	102.743280239513
	}
	UniformRotation
	{
		Period	9.72
	}
	LunarLambert	0.5
	Albedo	0.03
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=52872"
}

#1_"53311 Deucalion:Deucalion:1999 HU11" "Sol" #1=
#2_"*Девкалион:53311 Deucalion:Deucalion:1999 HU11" "Sol" #2=
#3_"1999 HU11:*Девкалион:53311 Deucalion:Deucalion" "Sol" #3=
".:Deucalion:53311 Deucalion:1999 HU11" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	110.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	293.427594680869
		SemiMajorAxis	44.156553397155
		Eccentricity	0.060673770939
		Inclination	0.366288645027
		AscendingNode	51.430951437801
		ArgOfPericenter	239.081986608028
		MeanAnomaly	299.759491238757
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=53311"
}

#1_"53319 1999 JM8:1999 JM8:1990 HD1" "Sol" #1=
#2_"1999 JM8:53319 1999 JM8" "Sol" #2=
#3_"1999 JM8:53319 1999 JM8" "Sol" #3=
".:1999 JM8:53319 1999 JM8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	3.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.485154775156
		SemiMajorAxis	2.719648775577
		Eccentricity	0.645765016999
		Inclination	13.884666217119
		AscendingNode	133.6970008499
		ArgOfPericenter	166.789575698274
		MeanAnomaly	160.02341916852
	}
	UniformRotation
	{
		Period	136
	}
	LunarLambert	0.5
	Albedo	0.03
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=53319"
}

#1_"54509 YORP:2000 PH5" "Sol" #1=
#2_"YORP:54509 YORP:2000 PH5" "Sol" #2=
#3_"2000 PH5:YORP:54509 YORP" "Sol" #3=
".:YORP:54509 YORP:2000 PH5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"54509 yorp.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.075
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.009105670118
		SemiMajorAxis	1.006048604073
		Eccentricity	0.23003539922
		Inclination	1.59974887942
		AscendingNode	278.320019130492
		ArgOfPericenter	278.806875590774
		MeanAnomaly	183.170612736442
	}
	UniformRotation
	{
		Period	0.2029
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=54509"
}

#1_"54520 2000 PJ30:2000 PJ30:1999 OO4" "Sol" #1=
#2_"2000 PJ30:54520 2000 PJ30" "Sol" #2=
#3_"2000 PJ30:54520 2000 PJ30" "Sol" #3=
".:2000 PJ30:54520 2000 PJ30" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	55.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1352.64737786539
		SemiMajorAxis	122.306891500183
		Eccentricity	0.76695364294
		Inclination	5.71928708666
		AscendingNode	293.334276159191
		ArgOfPericenter	303.302746859558
		MeanAnomaly	11.229191911718
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=54520"
}

#1_"54598 Bienor:Bienor:2000 QC243" "Sol" #1=
#2_"*Биенор:54598 Bienor:Bienor:2000 QC243" "Sol" #2=
#3_"2000 QC243:*Биенор:54598 Bienor:Bienor" "Sol" #3=
".:Bienor:54598 Bienor:2000 QC243" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.885 0.782 ]
	BlendTexture	true
	Radius	103.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	67.083035013518
		SemiMajorAxis	16.509591738166
		Eccentricity	0.2020240052
		Inclination	20.753748815208
		AscendingNode	337.893227685635
		ArgOfPericenter	152.664775177126
		MeanAnomaly	289.816832352351
	}
	UniformRotation
	{
		Period	9.14
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=54598"
}

#1_"54850 2001 OZ11:2001 OZ11:1996 VM38" "Sol" #1=
#2_"2001 OZ11:54850 2001 OZ11" "Sol" #2=
#3_"2001 OZ11:54850 2001 OZ11" "Sol" #3=
".:2001 OZ11:54850 2001 OZ11" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"54850 2001 OZ11.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	5.082
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.295509887741
		SemiMajorAxis	3.038083602508
		Eccentricity	0.210077613122
		Inclination	9.349825957426
		AscendingNode	66.229647520427
		ArgOfPericenter	310.111892960534
		MeanAnomaly	313.388766576855
	}
	UniformRotation
	{
		Period	4.222157
	}
	LunarLambert	0.5
	Albedo	0.075
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=54850"
}

#1_"55200 2001 RO19:2001 RO19:1996 SL" "Sol" #1=
#2_"2001 RO19:55200 2001 RO19" "Sol" #2=
#3_"2001 RO19:55200 2001 RO19" "Sol" #3=
".:2001 RO19:55200 2001 RO19" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"55200 2001 RO19.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	3.395
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.369039435936
		SemiMajorAxis	3.066141978397
		Eccentricity	0.137191221509
		Inclination	2.282393574686
		AscendingNode	25.645509137785
		ArgOfPericenter	54.944584121082
		MeanAnomaly	225.881927476576
	}
	UniformRotation
	{
		Period	18.391
	}
	LunarLambert	0.5
	Albedo	0.032
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=55200"
}

#1_"55565 2002 AW197:2002 AW197" "Sol" #1=
#2_"2002 AW197:55565 2002 AW197" "Sol" #2=
#3_"2002 AW197:55565 2002 AW197" "Sol" #3=
".:2002 AW197:55565 2002 AW197" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	367
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	327.45458650153
		SemiMajorAxis	47.50747155598051
		Eccentricity	0.1299130054972144
		Inclination	24.33298092458305
		AscendingNode	297.4107993216403
		ArgOfPericenter	293.228355614586
		MeanAnomaly	292.6022119780332
	}
	UniformRotation
	{
		Period	8.86
	}
	LunarLambert	0.5
	Albedo	0.117
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=55565"
}

#1_"55636 2002 TX300:2002 TX300" "Sol" #1=
#2_"2002 TX300:55636 2002 TX300" "Sol" #2=
#3_"2002 TX300:55636 2002 TX300" "Sol" #3=
".:2002 TX300:55636 2002 TX300" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"haumeanfamily.dds"
	Radius	143
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	284.13851457379
		SemiMajorAxis	43.21965232835
		Eccentricity	0.121348113956
		Inclination	25.880735285541
		AscendingNode	324.710710955781
		ArgOfPericenter	340.1504094938
		MeanAnomaly	71.257274142208
	}
	UniformRotation
	{
		Period	8.12
	}
	LunarLambert	0.5
	Albedo	0.88
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=55636"
}

#1_"55637 2002 UX25:2002 UX25" "Sol" #1=
#2_"2002 UX25:55637 2002 UX25" "Sol" #2=
#3_"2002 UX25:55637 2002 UX25" "Sol" #3=
".:2002 UX25:55637 2002 UX25" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	332.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	279.235062064985
		SemiMajorAxis	42.720975880565
		Eccentricity	0.14460004683
		Inclination	19.450948147439
		AscendingNode	204.64617590605
		ArgOfPericenter	277.376053111648
		MeanAnomaly	294.05899478554
	}
	UniformRotation
	{
		Period	14.382
	}
	LunarLambert	0.5
	Albedo	0.115
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=55637"
}

#1_"2007 55637 I" "Sol/55637 2002 UX25" #1=
#2_"2007 55637 I" "Sol/55637 2002 UX25" #2=
#3_"2007 55637 I" "Sol/55637 2002 UX25" #3=
".:2007 55637 I" "Sol/55637 2002 UX25" #4=
{
	Class	"moon"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	105
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	8.309
		SemiMajorAxis	4770
		Eccentricity	0.17
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-55637.html"
}

#1_"57394 2001 RD84:2001 RD84" "Sol" #1=
#2_"2001 RD84:57394 2001 RD84" "Sol" #2=
#3_"2001 RD84:57394 2001 RD84" "Sol" #3=
".:2001 RD84:57394 2001 RD84" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"57394 2001 RD84.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.012
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	3.544904606367
		SemiMajorAxis	2.324864077199
		Eccentricity	0.057535400226
		Inclination	3.650366728825
		AscendingNode	321.864844697313
		ArgOfPericenter	140.506816463495
		MeanAnomaly	215.238391467287
	}
	UniformRotation
	{
		Period	6.74
	}
	LunarLambert	0.5
	Albedo	0.299
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=57394"
}

#1_"Logos-Zoe" "Sol" #1=
#2_"*Логос-Зоя:Logos-Zoe" "Sol" #2=
#3_"Logos-Zoe:*Логос-Зоя" "Sol" #3=
".:Logos-Zoe" "Sol" #4=
{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	1316
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	306.860040123005
		SemiMajorAxis	45.49406636567
		Eccentricity	0.123715351445
		Inclination	2.894719083955
		AscendingNode	132.494602106907
		ArgOfPericenter	338.37553925648
		MeanAnomaly	55.892820016926
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-58534.html"
}

#1_"58534 Logos:Logos:1997 CQ29" "Sol/Logos-Zoe" #1=
#2_"*Логос:58534 Logos:Logos:1997 CQ29" "Sol/Logos-Zoe" #2=
#3_"1997 CQ29:*Логос:58534 Logos:Logos" "Sol/Logos-Zoe" #3=
".:Logos:58534 Logos:1997 CQ29" "Sol/Logos-Zoe" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	41
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Logos-Zoe" }
    }
	EllipticalOrbit
	{
		Epoch	2452600.0  # 2002 Nov 21 12:00
		Period	309.87
		SemiMajorAxis	2900
		Eccentricity	0.5463
		Inclination	95.43
		AscendingNode	16.07
		ArgOfPericenter	43.8
		MeanAnomaly	259.47
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Logos-Zoe" }
    }
	UniformRotation
	{
		Period	7436.88
		Inclination	95.43
		AscendingNode	16.07
	}
	LunarLambert	0.5
	Albedo	0.39
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=58534"
}

#1_"Zoe:58534 Logos I:Logos I:2001 58534 I" "Sol/Logos-Zoe" #1=
#2_"*Зоя:Zoe:58534 Logos I:*Логос I:Logos I:2001 58534 I" "Sol/Logos-Zoe" #2=
#3_"2001 58534 I:*Зоя:Zoe:58534 Logos I:*Логос I:Logos I" "Sol/Logos-Zoe" #3=
".:Zoe:58534 Logos I:Logos I:2001 58534 I" "Sol/Logos-Zoe" #4=

{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	33.5
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Logos-Zoe" }
    }
	EllipticalOrbit
	{
		Epoch	2452600.0  # 2002 Nov 21 12:00
		Period	309.87
		SemiMajorAxis	5317
		Eccentricity	0.5463
		Inclination	95.43
		AscendingNode	16.07
		ArgOfPericenter	223.8
		MeanAnomaly	259.47
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Logos-Zoe" }
    }
	UniformRotation
	{
		Period	7436.88
		Inclination	95.43
		AscendingNode	16.07
	}
	LunarLambert	0.5
	Albedo	0.39
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-58534.html"
}

#1_"59358 1999 CL158:1999 CL158:1999 CL158" "Sol" #1=
#2_"1999 CL158:59358 1999 CL158" "Sol" #2=
#3_"1999 CL158:59358 1999 CL158" "Sol" #3=
".:1999 CL158:59358 1999 CL158" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	87.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	269.774894086691
		SemiMajorAxis	41.750551724215
		Eccentricity	0.211465828721
		Inclination	10.013079076025
		AscendingNode	120.03226834
		ArgOfPericenter	329.553539716099
		MeanAnomaly	42.866811447901
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=59358"
}

#1_"60151 1999 UZ6:1999 UZ6:2002 PO98" "Sol" #1=
#2_"1999 UZ6:60151 1999 UZ6" "Sol" #2=
#3_"1999 UZ6:60151 1999 UZ6" "Sol" #3=
".:1999 UZ6:60151 1999 UZ6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"60151 1999 UZ6.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.155
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.339976443953
		SemiMajorAxis	2.234378794709
		Eccentricity	0.208169596155
		Inclination	5.992778610831
		AscendingNode	96.762552403973
		ArgOfPericenter	260.594796146174
		MeanAnomaly	107.968719785442
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=60151"
}

#1_"60558 Echeclus:Echeclus:2000 EC98:2002 GJ27:174P" "Sol" #1=
#2_"*Эхекл:60558 Echeclus:Echeclus:2000 EC98:174P" "Sol" #2=
#3_"2000 EC98:*Эхекл:60558 Echeclus:Echeclus:174P" "Sol" #3=
".:Echeclus:60558 Echeclus:2000 EC98" "Sol" #4=
{
	Class	"asteroid" # Астероид из группы кентавров / Классифицируется и как комета

	# Class	"comet"
	Mesh	"asteroid-large.cmod"
	Texture	"comet.dds"
	Radius	29.5
	OrbitColor	[ 0.611765 0.317647 0.12549 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	34.9032811218
		SemiMajorAxis	10.68001924561
		Eccentricity	0.455408275982
		Inclination	4.344667829847
		AscendingNode	173.335877897905
		ArgOfPericenter	162.855286614728
		MeanAnomaly	13.169423931197
	}
	UniformRotation
	{
		Period	26.802
	}
	LunarLambert	0.5
	Albedo	0.077
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=60558"
}

#1_"60608 2000 EE173:2000 EE173" "Sol" #1=
#2_"2000 EE173:60608 2000 EE173" "Sol" #2=
#3_"2000 EE173:60608 2000 EE173" "Sol" #3=
".:2000 EE173:60608 2000 EE173" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	58.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	350.806058130894
		SemiMajorAxis	49.74001611074
		Eccentricity	0.545934543882
		Inclination	5.949242332733
		AscendingNode	293.974510062711
		ArgOfPericenter	235.551990663769
		MeanAnomaly	7.879961543697
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=60608"
}

#1_"63166 2000 YW17:2000 YW17" "Sol" #1=
#2_"63166 2000 YW17:2000 YW17" "Sol" #2=
#3_"2000 YW17:63166 2000 YW17" "Sol" #3=
".:2000 YW17:63166 2000 YW17" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"63166 2000 YW17.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.233
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.306040480633
		SemiMajorAxis	3.042109935282
		Eccentricity	0.106254467425
		Inclination	11.140413157682
		AscendingNode	105.450687799045
		ArgOfPericenter	303.120456389773
		MeanAnomaly	25.544947597225
	}
	UniformRotation
	{
		Period	9.9524
	}
	LunarLambert	0.5
	Albedo	0.203
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=63166"
}

#1_"64480 2001 VG45:2001 VG45" "Sol" #1=
#2_"2001 VG45:64480 2001 VG45" "Sol" #2=
#3_"2001 VG45:64480 2001 VG45" "Sol" #3=
".:2001 VG45:64480 2001 VG45" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"64480 2001 VG45.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.748
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.734121216243
		SemiMajorAxis	2.406874651231
		Eccentricity	0.196795980112
		Inclination	1.60169757047
		AscendingNode	27.103017679808
		ArgOfPericenter	347.171503616223
		MeanAnomaly	72.914845063224
	}
	UniformRotation
	{
		Period	6.49717
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=64480"
}

#1_"65407 2002 RP120:2002 RP120" "Sol" #1=
#2_"2002 RP120:65407 2002 RP120" "Sol" #2=
#3_"2002 RP120:65407 2002 RP120" "Sol" #3=
".:2002 RP120:65407 2002 RP120" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	7.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	406.648473268507
		SemiMajorAxis	54.887564765551
		Eccentricity	0.954752660274
		Inclination	119.105628678187
		AscendingNode	39.159384550491
		ArgOfPericenter	358.016003738307
		MeanAnomaly	10.776255404919
	}
	UniformRotation
	{
		Period	200
	}
	LunarLambert	0.5
	Albedo	0.098
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=65407"
}

#1_"Ceto-Phorcys" "Sol" #1=
#2_"*Кето-Форкий:Ceto-Phorcys" "Sol" #2=
#3_"Ceto-Phorcys:*Кето-Форкий" "Sol" #3=
".:Ceto-Phorcys" "Sol" #4=
{
	Class	"asteroid" # Барицентр
	Mesh	""
	Radius	570
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1034.37146446553
		SemiMajorAxis	102.27721314498
		Eccentricity	0.825904948796
		Inclination	22.27219573046
		AscendingNode	171.881103480617
		ArgOfPericenter	319.886838778823
		MeanAnomaly	8.814027977404
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-65489.html"
}

#1_"65489 Ceto:Ceto:2003 FX128" "Sol/Ceto-Phorcys" #1=
#2_"*Кето:65489 Ceto:Ceto:2003 FX128" "Sol/Ceto-Phorcys" #2=
#3_"2003 FX128:*Кето:65489 Ceto:Ceto" "Sol/Ceto-Phorcys" #3=
".:Ceto:65489 Ceto:2003 FX128" "Sol/Ceto-Phorcys" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	111.5
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Ceto-Phorcys" }
    }
	EllipticalOrbit
	{
		Period	9.554
		SemiMajorAxis	572
		Eccentricity	0.004
		Inclination	68.8
		ArgOfPericenter	180
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Ceto-Phorcys" }
    }
	UniformRotation
	{
		Period	4.43
		Inclination	68.8
	}
	LunarLambert	0.5
	Albedo	0.056
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=65489"
}

#1_"Phorcys:65489 Ceto I:Ceto I:2006 65489 I" "Sol/Ceto-Phorcys" #1=
#2_"*Форкий:Phorcys:65489 Ceto I:*Кето I:Ceto I:2006 65489 I" "Sol/Ceto-Phorcys" #2=
#3_"2006 65489 I:*Форкий:Phorcys:65489 Ceto I:*Кето I:Ceto I" "Sol/Ceto-Phorcys" #3=
".:Phorcys:65489 Ceto I:Ceto I:2006 65489 I" "Sol/Ceto-Phorcys" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	85.5
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Ceto-Phorcys" }
    }
	EllipticalOrbit
	{
		Period	9.554
		SemiMajorAxis	1268
		Eccentricity	0.004
		Inclination	68.8
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Ceto-Phorcys" }
    }
	UniformRotation
	{
		Period	4.43
		Inclination	68.8
	}
	LunarLambert	0.5
	Albedo	0.056
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-65489.html"
}

#1_"65803 Didymos:Didymos:1996 GT" "Sol" #1=
#2_"*Дидим:65803 Didymos:Didymos:1996 GT" "Sol" #2=
#3_"1996 GT:*Дидим:65803 Didymos:Didymos" "Sol" #3=
".:Didymos:65803 Didymos:1996 GT" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.375
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.108785394349
		SemiMajorAxis	1.644432766401
		Eccentricity	0.383752494179
		Inclination	3.407650302229
		AscendingNode	73.233292728302
		ArgOfPericenter	319.250402711419
		MeanAnomaly	96.832826104036
	}
	UniformRotation
	{
		Period	2.2593
	}
	LunarLambert	0.5
	Albedo	0.17
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=65803"
}

#1_"2003 65803 I" "Sol/65803 Didymos" #1=
#2_"2003 65803 I" "Sol/65803 Didymos" #2=
#3_"2003 65803 I" "Sol/65803 Didymos" #3=
".:2003 65803 I" "Sol/65803 Didymos" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.085
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.4958
		SemiMajorAxis	1.18
		Eccentricity	0.06
	}
	LunarLambert	0.5
	Albedo	0.17
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-65803.html"
}

#1_"66076 1998 RD53:1998 RD53:1980 DK3:1999 XC209" "Sol" #1=
#2_"1998 RD53:66076 1998 RD53" "Sol" #2=
#3_"1998 RD53:66076 1998 RD53" "Sol" #3=
".:1998 RD53:66076 1998 RD53" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"66076 1998 RD53.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	3.914
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.176045965088
		SemiMajorAxis	2.99221834619
		Eccentricity	0.054496947402
		Inclination	9.802635194121
		AscendingNode	357.239392009725
		ArgOfPericenter	141.818226249071
		MeanAnomaly	63.277776518113
	}
	UniformRotation
	{
		Period	8.93855
	}
	LunarLambert	0.5
	Albedo	0.095
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=66076"
}

#1_"66391 1999 KW4:1999 KW4" "Sol" #1=
#2_"1999 KW4:66391 1999 KW4" "Sol" #2=
#3_"1999 KW4:66391 1999 KW4" "Sol" #3=
".:1999 KW4:66391 1999 KW4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"66391 1999 KW4.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.00 0.670 0.375 ]
	BlendTexture	true
	Radius	0.766
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.514754955112
		SemiMajorAxis	0.642285654945
		Eccentricity	0.688462314706
		Inclination	38.885763605861
		AscendingNode	244.922042834552
		ArgOfPericenter	192.616867792487
		MeanAnomaly	244.179082896138
	}
	UniformRotation
	{
		Period	2.7645
		Inclination	156.1
	}
	LunarLambert	0.5
	Albedo	0.26
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=66391"
}

#1_"2001 66391 I" "Sol/66391 1999 KW4" #1=
#2_"2001 66391 I" "Sol/66391 1999 KW4" #2=
#3_"2001 66391 I" "Sol/66391 1999 KW4" #3=
".:2001 66391 I" "Sol/66391 1999 KW4" #4=
{
	Class	"moon"
	Mesh	"2001 66391 I.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	0.2855
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.7259
		SemiMajorAxis	2.548
		Eccentricity	0.0004
		# Inclination	156.1
		AscendingNode	105.4
		ArgOfPericenter	319.7
	}
	UniformRotation
	{
		Period	17.4216
		MeridianAngle	240
	}
	LunarLambert	0.5
	Albedo	0.26
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-66391.html"
}

#1_"2001 66391 I" "Sol/66391 1999 KW4" #1=
#2_"2001 66391 I" "Sol/66391 1999 KW4" #2=
#3_"2001 66391 I" "Sol/66391 1999 KW4" #3=
".:2001 66391 I" "Sol/66391 1999 KW4" #4=

{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	848
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	287.732646515574
		SemiMajorAxis	43.58335165152
		Eccentricity	0.084855574306
		Inclination	0.563096991331
		AscendingNode	84.635857449696
		ArgOfPericenter	195.92868420587
		MeanAnomaly	57.947455350986
	}
	LunarLambert	0.5
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-66652.html"
}

#1_"66652 Borasisi:Borasisi:1999 RZ253" "Sol/Borasisi-Pabu" #1=
#2_"*Борасизи:66652 Borasisi:Borasisi:1999 RZ253" "Sol/Borasisi-Pabu" #2=
#3_"1999 RZ253:*Борасизи:66652 Borasisi:Borasisi" "Sol/Borasisi-Pabu" #3=
".:Borasisi:66652 Borasisi:1999 RZ253" "Sol/Borasisi-Pabu" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	63
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Borasisi-Pabu" }
    }
	EllipticalOrbit
	{
		Epoch	2451900.0  # 2000 Dec 21 12:00
		Period	46.2888
		SemiMajorAxis	1600
		Eccentricity	0.4700
		Inclination	54.31
		AscendingNode	70.44
		ArgOfPericenter	58.85
		MeanAnomaly	214.4
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Borasisi-Pabu" }
    }
	UniformRotation
	{
		Period	6.4
		Inclination	54.31
		AscendingNode	70.44
	}
	LunarLambert	0.5
	Albedo	0.175
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=66652"
}

#1_"Pabu:66652 Borasisi I:Borasisi I:2003 66652 I" "Sol/Borasisi-Pabu" #1=
#2_"*Пабу:Pabu:66652 Borasisi I:*Борасизи I:Borasisi I:2003 66652 I" "Sol/Borasisi-Pabu" #2=
#3_"2003 66652 I:*Пабу:Pabu:66652 Borasisi I:*Борасизи I:Borasisi I" "Sol/Borasisi-Pabu" #3=
".:Pabu:66652 Borasisi I:Borasisi I:2003 66652 I" "Sol/Borasisi-Pabu" #4=

{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	51.5
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Borasisi-Pabu" }
    }
	EllipticalOrbit
	{
		Epoch	2451900.0  # 2000 Dec 21 12:00
		Period	46.2888
		SemiMajorAxis	2928
		Eccentricity	0.4700
		Inclination	54.31
		AscendingNode	70.44
		ArgOfPericenter	238.85
		MeanAnomaly	214.4
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Borasisi-Pabu" }
    }
	UniformRotation
	{
		Period	6.4
		Inclination	54.31
		AscendingNode	70.44
	}
	LunarLambert	0.5
	Albedo	0.175
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-66652.html"
}

#1_"67404 2000 PG26:2000 PG26:1984 YS6:2000 WO159" "Sol" #1=
#2_"2000 PG26:67404 2000 PG26" "Sol" #2=
#3_"2000 PG26:67404 2000 PG26" "Sol" #3=
".:2000 PG26:67404 2000 PG26" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"67404 2000 PG26.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.848
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.752719575485
		SemiMajorAxis	1.964125252509
		Eccentricity	0.096115615222
		Inclination	17.209834527672
		AscendingNode	274.032050165934
		ArgOfPericenter	197.297702192334
		MeanAnomaly	235.419877045324
	}
	UniformRotation
	{
		Period	5.398
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=67404"
}

#1_"69117 2003 EX2:2003 EX2:1980 WA5:1994 NV9:1998 XQ78" "Sol" #1=
#2_"2003 EX2:69117 2003 EX2" "Sol" #2=
#3_"2003 EX2:69117 2003 EX2" "Sol" #3=
".:2003 EX2:69117 2003 EX2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"69117 2003 EX2.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.522
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.591210664578
		SemiMajorAxis	2.345066268864
		Eccentricity	0.335751529896
		Inclination	5.013240002928
		AscendingNode	93.523970792123
		ArgOfPericenter	281.367216274838
		MeanAnomaly	53.780187348296
	}
	UniformRotation
	{
		Period	4.74608
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=69117"
}

#1_"Hermes System" "Sol" #1=
#2_"*Система Гермеса:Hermes System" "Sol" #2=
#3_"Hermes System:*Система Гермеса" "Sol" #3=
".:Hermes System" "Sol" #4=

{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	0.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.128873194254
		SemiMajorAxis	1.654859246368
		Eccentricity	0.624080748017
		Inclination	6.067913784683
		AscendingNode	34.239766248961
		ArgOfPericenter	92.720516712496
		MeanAnomaly	52.909788447231
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-69230.html"
}

#1_"69230 Hermes:Hermes:1937 UB" "Sol/Hermes System" #1=
#2_"*Гермес:69230 Hermes:Hermes:1937 UB" "Sol/Hermes System" #2=
#3_"1937 UB:*Гермес:69230 Hermes:Hermes" "Sol/Hermes System" #3=
".:Hermes:69230 Hermes:1937 UB" "Sol/Hermes System" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.5789
		SemiMajorAxis	0.5
		ArgOfPericenter	180
	}
	UniformRotation
	{
		Period	13.894
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=69230"
}

#1_"2003 69230 I" "Sol/Hermes System" #1=
#2_"2003 69230 I" "Sol/Hermes System" #2=
#3_"2003 69230 I" "Sol/Hermes System" #3=
".:2003 69230 I" "Sol/Hermes System" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.27
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.5789
		SemiMajorAxis	0.6
	}
	UniformRotation
	{
		Period	13.892
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-69230.html"
}

#1_"69749 1998 MZ1:1998 MZ1" "Sol" #1=
#2_"1998 MZ1:69749 1998 MZ1" "Sol" #2=
#3_"1998 MZ1:69749 1998 MZ1" "Sol" #3=
".:1998 MZ1:69749 1998 MZ1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	3.691
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	4.576893953353
		SemiMajorAxis	2.756608547513
		Eccentricity	0.302171214708
		Inclination	9.164781789859
		AscendingNode	92.467090458269
		ArgOfPericenter	168.911924697062
		MeanAnomaly	1.41720947135
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.039
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=69749"
}

#1_"69986 1998 WW24:1998 WW24" "Sol" #1=
#2_"1998 WW24:69986 1998 WW24" "Sol" #2=
#3_"1998 WW24:69986 1998 WW24" "Sol" #3=
".:1998 WW24:69986 1998 WW24" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	249.106248664244
		SemiMajorAxis	39.589888589396
		Eccentricity	0.225605088444
		Inclination	13.929265701617
		AscendingNode	233.976302812092
		ArgOfPericenter	147.355485217109
		MeanAnomaly	40.611389889607
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=69986"
}

#1_"69987 1998 WA25:1998 WA25:1998 WA25" "Sol" #1=
#2_"1998 WA25:69987 1998 WA25" "Sol" #2=
#3_"1998 WA25:69987 1998 WA25" "Sol" #3=
".:1998 WA25:69987 1998 WA25" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	80
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	278.321101463376
		SemiMajorAxis	42.627705311694
		Eccentricity	0.02021585314
		Inclination	1.046615695385
		AscendingNode	136.33249310829
		ArgOfPericenter	223.878069329946
		MeanAnomaly	68.419892250678
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=69987"
}

#1_"69988 1998 WA31:1998 WA31" "Sol" #1=
#2_"1998 WA31:69988 1998 WA31" "Sol" #2=
#3_"1998 WA31:69988 1998 WA31" "Sol" #3=
".:1998 WA31:69988 1998 WA31" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	410.124367170189
		SemiMajorAxis	55.19989445508
		Eccentricity	0.427251048068
		Inclination	9.467811812101
		AscendingNode	20.781401955182
		ArgOfPericenter	309.844223838996
		MeanAnomaly	42.103270561947
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=69988"
}

#1_"69990 1998 WU31:1998 WU31" "Sol" #1=
#2_"1998 WU31:69990 1998 WU31" "Sol" #2=
#3_"1998 WU31:69990 1998 WU31" "Sol" #3=
".:1998 WU31:69990 1998 WU31" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	48
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	247.094232064848
		SemiMajorAxis	39.376423775337
		Eccentricity	0.186873065126
		Inclination	6.575050850327
		AscendingNode	237.15818296134
		ArgOfPericenter	142.880386380549
		MeanAnomaly	43.596499311971
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=69990"
}

#1_"71011 1999 XE45:1999 XE45:2002 LE33" "Sol" #1=
#2_"1999 XE45:71011 1999 XE45" "Sol" #2=
#3_"1999 XE45:71011 1999 XE45" "Sol" #3=
".:1999 XE45:71011 1999 XE45" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"71011 1999 XE45.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.748
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.540333400166
		SemiMajorAxis	2.741908944073
		Eccentricity	0.068021484008
		Inclination	6.086359482357
		AscendingNode	67.169617337675
		ArgOfPericenter	260.322656957599
		MeanAnomaly	7.680537327372
	}
	UniformRotation
	{
		Period	4.69449
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=71011"
}

#1_"74155 1998 QK93:1998 QK93:2000 GX27" "Sol" #1=
#2_"1998 QK93:74155 1998 QK93" "Sol" #2=
#3_"1998 QK93:74155 1998 QK93" "Sol" #3=
".:1998 QK93:74155 1998 QK93" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"74155 1998 QK93.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.968
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.356021920187
		SemiMajorAxis	2.667193778868
		Eccentricity	0.152410384063
		Inclination	13.31118933764
		AscendingNode	20.938755095719
		ArgOfPericenter	77.044759530879
		MeanAnomaly	35.361276712893
	}
	UniformRotation
	{
		Period	15.968
	}
	LunarLambert	0.5
	Albedo	0.219
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=74155"
}

#1_"75167 1999 VF128:1999 VF128:2001 HJ5" "Sol" #1=
#2_"1999 VF128:75167 1999 VF128" "Sol" #2=
#3_"1999 VF128:75167 1999 VF128" "Sol" #3=
".:1999 VF128:75167 1999 VF128:" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"75167 1999 VF128.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.266
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.474351235785
		SemiMajorAxis	2.29391336854
		Eccentricity	0.159009457083
		Inclination	4.295291183028
		AscendingNode	233.794603391823
		ArgOfPericenter	298.451470336899
		MeanAnomaly	238.645604652342
	}
	UniformRotation
	{
		Period	10.27743
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=75167"
}

#1_"75495 1999 XM181:1999 XM181:2002 PK51" "Sol" #1=
#2_"1999 XM181:75495 1999 XM181" "Sol" #2=
#3_"1999 XM181:75495 1999 XM181" "Sol" #3=
".:1999 XM181:75495 1999 XM181" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"75495 1999 XM181.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.996
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.711343459628
		SemiMajorAxis	2.397076880981
		Eccentricity	0.167762049805
		Inclination	7.883303192108
		AscendingNode	326.45828351608
		ArgOfPericenter	107.810889344465
		MeanAnomaly	223.50913917028
	}
	UniformRotation
	{
		Period	14.6818
	}
	LunarLambert	0.5
	Albedo	0.256
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=75495"
}

#1_"76214 2000 EV64:2000 EV64" "Sol" #1=
#2_"2000 EV64:76214 2000 EV64" "Sol" #2=
#3_"2000 EV64:76214 2000 EV64" "Sol" #3=
".:2000 EV64:76214 2000 EV64" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"76214 2000 EV64.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.594
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.681483820062
		SemiMajorAxis	2.798445690622
		Eccentricity	0.158453869149
		Inclination	3.398346108579
		AscendingNode	350.890578897658
		ArgOfPericenter	266.584999349929
		MeanAnomaly	160.530028573245
	}
	UniformRotation
	{
		Period	9.27775
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=76214"
}

#1_"77677 2001 MA25:2001 MA25:2000 AN163" "Sol" #1=
#2_"2001 MA25:77677 2001 MA25" "Sol" #2=
#3_"2001 MA25:77677 2001 MA25" "Sol" #3=
".:2001 MA25:77677 2001 MA25" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"77677 2001 MA25.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.748
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.842401622333
		SemiMajorAxis	2.453181625638
		Eccentricity	0.289841850011
		Inclination	3.183343437677
		AscendingNode	233.207606027265
		ArgOfPericenter	331.519075495046
		MeanAnomaly	86.117803264734
	}
	UniformRotation
	{
		Period	5.304712
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=77677"
}

#1_"78420 2002 QU40:2002 QU40" "Sol" #1=
#2_"2002 QU40:78420 2002 QU40" "Sol" #2=
#3_"2002 QU40:78420 2002 QU40" "Sol" #3=
".:2002 QU40:78420 2002 QU40" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"78420 2002 QU40.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.892
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.394093329777
		SemiMajorAxis	3.075673065665
		Eccentricity	0.24544656716
		Inclination	5.64788620721
		AscendingNode	334.115215823775
		ArgOfPericenter	29.692747759141
		MeanAnomaly	213.214225231717
	}
	UniformRotation
	{
		Period	4.9
	}
	LunarLambert	0.5
	Albedo	0.159
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=78420"
}

#1_"78799 2002 XW93:2002 XW93" "Sol" #1=
#2_"2002 XW93:78799 2002 XW93" "Sol" #2=
#3_"2002 XW93:78799 2002 XW93" "Sol" #3=
".:2002 XW93:78799 2002 XW93" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Radius	292
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	230.623246826328
		SemiMajorAxis	37.606529203355
		Eccentricity	0.244974674723
		Inclination	14.359700131802
		AscendingNode	46.845240408581
		ArgOfPericenter	247.861469628414
		MeanAnomaly	138.133143799689
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=78799"
}

#1_"Sila-Nunam" "Sol" #1=
#2_"*Сила-Нунам:Sila-Nunam" "Sol" #2=
#3_"Sila-Nunam:*Сила-Нунам" "Sol" #3=
".:Sila-Nunam" "Sol" #4=
{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	1254
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	293.33831247936
		SemiMajorAxis	44.147595834143
		Eccentricity	0.016524015246
		Inclination	2.237894132287
		AscendingNode	304.32358074995
		ArgOfPericenter	216.907788023568
		MeanAnomaly	336.078844174258
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-79360.html"
}

#1_"79360 Sila:Sila:1997 CS29" "Sol/Sila-Nunam" #1=
#2_"*Сила:79360 Sila:Sila:1997 CS29" "Sol/Sila-Nunam" #2=
#3_"1997 CS29:*Сила:79360 Sila:Sila" "Sol/Sila-Nunam" #3=
".:Sila:79360 Sila:1997 CS29" "Sol/Sila-Nunam" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.609 0.507 ]
	BlendTexture	true
	Radius	124.5
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Sila-Nunam" }
    }
	EllipticalOrbit
	{
		Period	12.50995
		SemiMajorAxis	1277
		Eccentricity	0.018
		Inclination	103.51
		AscendingNode	140.76
		ArgOfPericenter	146.0
		MeanAnomaly	16.3
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Sila-Nunam" }
    }
	UniformRotation
	{
		Period	300.2388
		Inclination	103.51
		AscendingNode	140.76
	}
	LunarLambert	0.5
	Albedo	0.086
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=79360"
}

#1_"Nunam:79360 Sila I:Sila I:2005 79360 I" "Sol/Sila-Nunam" #1=
#2_"*Нунам:Nunam:79360 Sila I:*Сила I:Sila I:2005 79360 I" "Sol/Sila-Nunam" #2=
#3_"2005 79360 I:*Нунам:Nunam:79360 Sila I:*Сила I:Sila I" "Sol/Sila-Nunam" #3=
".:Nunam:79360 Sila I:Sila I:2005 79360 I" "Sol/Sila-Nunam" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.609 0.507 ]
	BlendTexture	true
	Radius	118
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Sila-Nunam" }
    }
	EllipticalOrbit
	{
		Period	12.50995
		SemiMajorAxis	1500
		Eccentricity	0.018
		Inclination	103.51
		AscendingNode	140.76
		ArgOfPericenter	326.0
		MeanAnomaly	16.3
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Sila-Nunam" }
	}
	UniformRotation
	{
		Period	300.2388
		Inclination	103.51
		AscendingNode	140.76
	}
	LunarLambert	0.5
	Albedo	0.086
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-79360.html"
}

#1_"79436 1997 TD6:1997 TD6" "Sol" #1=
#2_"1997 TD6:79436 1997 TD6" "Sol" #2=
#3_"1997 TD6:79436 1997 TD6" "Sol" #3=
".:1997 TD6:79436 1997 TD6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"79436 1997 TD6.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.526
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.522066951553
		SemiMajorAxis	2.734549927629
		Eccentricity	0.184158881822
		Inclination	16.168997690362
		AscendingNode	23.461834819075
		ArgOfPericenter	356.15170102306
		MeanAnomaly	96.967403397786
	}
	UniformRotation
	{
		Period	3.635352
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=79436"
}

#1_"79969 1999 CP133:1999 CP133" "Sol" #1=
#2_"1999 CP133:79969 1999 CP133" "Sol" #2=
#3_"1999 CP133:79969 1999 CP133" "Sol" #3=
".:1999 CP133:79969 1999 CP133" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	69.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	207.624013419261
		SemiMajorAxis	35.062772433049
		Eccentricity	0.087008377095
		Inclination	3.170660808534
		AscendingNode	334.15992567
		ArgOfPericenter	159.166331948913
		MeanAnomaly	47.578924867943
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=79969"
}

#1_"79978 1999 CC158:1999 CC158" "Sol" #1=
#2_"1999 CC158:79978 1999 CC158" "Sol" #2=
#3_"1999 CC158:79978 1999 CC158" "Sol" #3=
".:1999 CC158:79978 1999 CC158" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	152
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	400.452190089952
		SemiMajorAxis	54.328574999724
		Eccentricity	0.279065875919
		Inclination	18.700486786781
		AscendingNode	337.022194208142
		ArgOfPericenter	102.483775151012
		MeanAnomaly	41.049981269836
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=79978"
}

#1_"79983 1999 DF9:1999 DF9:1999 DF9" "Sol" #1=
#2_"1999 DF9:79983 1999 DF9" "Sol" #2=
#3_"1999 DF9:79983 1999 DF9" "Sol" #3=
".:1999 DF9:79983 1999 DF9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	132.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	319.347991865277
		SemiMajorAxis	46.72012451221
		Eccentricity	0.148582423256
		Inclination	9.797063383087
		AscendingNode	334.80857107066
		ArgOfPericenter	177.371288490192
		MeanAnomaly	17.318195743675
	}
	UniformRotation
	{
		Period	6.65
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=79983"
}

#1_"80112 1999 RN61:1999 RN61:1996 VO31" "Sol" #1=
#2_"1999 RN61:80112 1999 RN61" "Sol" #2=
#3_"1999 RN61:80112 1999 RN61" "Sol" #3=
".:1999 RN61:80112 1999 RN61" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"80112 1999 RN61.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.006
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.302772557795
		SemiMajorAxis	2.217755390202
		Eccentricity	0.211330974893
		Inclination	4.898738578003
		AscendingNode	140.498637126713
		ArgOfPericenter	267.072297333567
		MeanAnomaly	51.543227127119
	}
	UniformRotation
	{
		Period	4.923622
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=80112"
}

#1_"80276 1999 XL32:1999 XL32:2001 KZ39" "Sol" #1=
#2_"1999 XL32:80276 1999 XL32" "Sol" #2=
#3_"1999 XL32:80276 1999 XL32" "Sol" #3=
".:1999 XL32:80276 1999 XL32" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"80276 1999 XL32.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.87
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.373611285964
		SemiMajorAxis	2.674368938762
		Eccentricity	0.121327397933
		Inclination	16.448391065557
		AscendingNode	116.720536158812
		ArgOfPericenter	94.763224769113
		MeanAnomaly	249.524211801066
	}
	UniformRotation
	{
		Period	5.56
	}
	LunarLambert	0.5
	Albedo	0.348
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=80276"
}

#1_"81740 2000 JA46:2000 JA46" "Sol" #1=
#2_"2000 JA46:81740 2000 JA46" "Sol" #2=
#3_"2000 JA46:81740 2000 JA46" "Sol" #3=
".:2000 JA46:81740 2000 JA46" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"81740 2000 JA46.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.546
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.313945421633
		SemiMajorAxis	2.649990371732
		Eccentricity	0.123017415636
		Inclination	10.233780919289
		AscendingNode	242.69321554333
		ArgOfPericenter	220.930855227646
		MeanAnomaly	81.30887108441
	}
	UniformRotation
	{
		Period	9.343
	}
	LunarLambert	0.5
	Albedo	0.293
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=81740"
}

#1_"81911 2000 NV9:2000 NV9:1981 EN37" "Sol" #1=
#2_"2000 NV9:81911 2000 NV9" "Sol" #2=
#3_"2000 NV9:81911 2000 NV9" "Sol" #3=
".:2000 NV9:81911 2000 NV9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"81911 2000 NV9.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.645
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.490208770245
		SemiMajorAxis	2.721691441831
		Eccentricity	0.189857904105
		Inclination	12.76827057413
		AscendingNode	191.773607659449
		ArgOfPericenter	140.841305865454
		MeanAnomaly	218.518955608328
	}
	UniformRotation
	{
		Period	6.9548
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=81911"
}

#1_"82075 2000 YW134:2000 YW134:2001 XG201" "Sol" #1=
#2_"2000 YW134:82075 2000 YW134" "Sol" #2=
#3_"2000 YW134:82075 2000 YW134" "Sol" #3=
".:2000 YW134:82075 2000 YW134" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	250
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	445.392015738607
		SemiMajorAxis	58.320711922613
		Eccentricity	0.293468047837
		Inclination	19.7680748431
		AscendingNode	126.940857756802
		ArgOfPericenter	317.007934689085
		MeanAnomaly	28.694329118179
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=82075"
}

#1_"2002 82075 I" "Sol/82075 2000 YW134" #1=
#2_"2002 82075 I" "Sol/82075 2000 YW134" #2=
#3_"2002 82075 I" "Sol/82075 2000 YW134" #3=
".:2002 82075 I" "Sol/82075 2000 YW134" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	10
		SemiMajorAxis	1900
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-82075.html"
}

#1_"82155 2001 FZ173:2001 FZ173" "Sol" #1=
#2_"2001 FZ173:82155 2001 FZ173" "Sol" #2=
#3_"2001 FZ173:82155 2001 FZ173" "Sol" #3=
".:2001 FZ173:82155 2001 FZ173" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	132.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	800.00278922229
		SemiMajorAxis	86.176502857737
		Eccentricity	0.624066983474
		Inclination	12.704395520021
		AscendingNode	2.365431336127
		ArgOfPericenter	199.137585558221
		MeanAnomaly	1.8430904623
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=82155"
}

#1_"82158 2001 FP185:2001 FP185" "Sol" #1=
#2_"2001 FP185:82158 2001 FP185" "Sol" #2=
#3_"2001 FP185:82158 2001 FP185" "Sol" #3=
".:2001 FP185:82158 2001 FP185" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	166
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3327.3431753826
		SemiMajorAxis	222.8740964088366
		Eccentricity	0.8463768237488414
		Inclination	30.76951414362034
		AscendingNode	179.3166095497007
		ArgOfPericenter	6.835007939350096
		MeanAnomaly	1.189349449093769
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.046
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=82158"
}

#1_"82642 2001 PX5:2001 PX5" "Sol" #1=
#2_"2001 PX5:82642 2001 PX5" "Sol" #2=
#3_"2001 PX5:82642 2001 PX5" "Sol" #3=
".:2001 PX5:82642 2001 PX5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"82642 2001 PX5.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.868
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.258048653904
		SemiMajorAxis	3.023738749155
		Eccentricity	0.228078560829
		Inclination	10.069208840052
		AscendingNode	130.098254711618
		ArgOfPericenter	290.27691012201
		MeanAnomaly	282.125507603457
	}
	UniformRotation
	{
		Period	11.61144
	}
	LunarLambert	0.5
	Albedo	0.135
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=82642"
}

#1_"84522 2002 TC302:2002 TC302" "Sol" #1=
#2_"2002 TC302:84522 2002 TC302" "Sol" #2=
#3_"2002 TC302:84522 2002 TC302" "Sol" #3=
".:2002 TC302:84522 2002 TC302" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	292.05
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	413.135101906162
		SemiMajorAxis	55.469714338254
		Eccentricity	0.296602921433
		Inclination	35.073544417722
		AscendingNode	23.880024717635
		ArgOfPericenter	86.745653870366
		MeanAnomaly	321.549771220683
	}
	UniformRotation
	{
		Period	5.41
	}
	LunarLambert	0.5
	Albedo	0.115
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=84522"
}

#1_"84719 2002 VR128:2002 VR128" "Sol" #1=
#2_"2002 VR128:84719 2002 VR128" "Sol" #2=
#3_"2002 VR128:84719 2002 VR128" "Sol" #3=
".:2002 VR128:84719 2002 VR128" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.00 0.609 0.507 ]
	BlendTexture	true
	Radius	224.25
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	247.564771591726
		SemiMajorAxis	39.426397391003
		Eccentricity	0.262185430895
		Inclination	14.027716308241
		AscendingNode	23.122201699317
		ArgOfPericenter	288.468567709644
		MeanAnomaly	71.323384307762
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.052
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=84719"
}

#1_"84922 2003 VS2:2003 VS2" "Sol" #1=
#2_"2003 VS2:84922 2003 VS2" "Sol" #2=
#3_"2003 VS2:84922 2003 VS2" "Sol" #3=
".:2003 VS2:84922 2003 VS2" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	261.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	248.73356315552
		SemiMajorAxis	39.55039203099317
		Eccentricity	0.07823518625105152
		Inclination	14.76956296074794
		AscendingNode	302.8231893455951
		ArgOfPericenter	114.5901528388983
		MeanAnomaly	13.60461003245032
	}
	UniformRotation
	{
		Period	7.42
	}
	LunarLambert	0.5
	Albedo	0.147
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=84922"
}

#1_"85182 1991 AQ:1991 AQ:1994 RD" "Sol" #1=
#2_"1991 AQ:85182 1991 AQ" "Sol" #2=
#3_"1991 AQ:85182 1991 AQ" "Sol" #3=
".:1991 AQ:85182 1991 AQ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.55
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.31280910576
		SemiMajorAxis	2.222246031488
		Eccentricity	0.776347248735
		Inclination	3.128421437145
		AscendingNode	339.720439673891
		ArgOfPericenter	242.904500734335
		MeanAnomaly	67.804969348634
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.21
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=85182"
}

#1_"85489 1997 SV2:1997 SV2:2002 ME1" "Sol" #1=
#2_"1997 SV2:85489 1997 SV2" "Sol" #2=
#3_"1997 SV2:85489 1997 SV2" "Sol" #3=
".:1997 SV2:85489 1997 SV2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"85489 1997 SV2.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	4.236
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	5.515524832258
		SemiMajorAxis	3.121661163034
		Eccentricity	0.23826550992
		Inclination	23.759800706352
		AscendingNode	191.370690193793
		ArgOfPericenter	134.893384008678
		MeanAnomaly	205.73715843987
	}
	UniformRotation
	{
		Period	5.79502
	}
	LunarLambert	0.5
	Albedo	0.025
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=85489"
}

#1_"85532 1997 WD21:1997 WD21" "Sol" #1=
#2_"1997 WD21:85532 1997 WD21" "Sol" #2=
#3_"1997 WD21:85532 1997 WD21" "Sol" #3=
".:1997 WD21:85532 1997 WD21" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"85532 1997 WD21.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.958
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.41546383216
		SemiMajorAxis	2.691403129
		Eccentricity	0.150309289381
		Inclination	13.474521415402
		AscendingNode	242.63156202
		ArgOfPericenter	160.244627063817
		MeanAnomaly	151.204151075414
	}
	UniformRotation
	{
		Period	4.7682
	}
	LunarLambert	0.5
	Albedo	0.219
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=85532"
}

#1_"85585 Mjolnir:Mjolnir:1998 FG2" "Sol" #1=
#2_"*Мьёльнир:85585 Mjolnir:Mjolnir:1998 FG2" "Sol" #2=
#3_"1998 FG2:*Мьёльнир:85585 Mjolnir:Mjolnir" "Sol" #3=
".:Mjolnir:85585 Mjolnir:1998 FG2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.1125
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.477973012463
		SemiMajorAxis	1.297494526608
		Eccentricity	0.356289336246
		Inclination	4.083287382385
		AscendingNode	2.369177304306
		ArgOfPericenter	95.350949023499
		MeanAnomaly	156.884765354014
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=85585"
}

#1_"85627 1998 HP151:1998 HP151" "Sol" #1=
#2_"1998 HP151:85627 1998 HP151" "Sol" #2=
#3_"1998 HP151:85627 1998 HP151" "Sol" #3=
".:1998 HP151:85627 1998 HP151" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	291.403581043952
		SemiMajorAxis	43.953262974386
		Eccentricity	0.085326447296
		Inclination	1.513002478818
		AscendingNode	55.94214692286
		ArgOfPericenter	250.889776271769
		MeanAnomaly	312.877882825319
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=85627"
}

#1_"85633 1998 KR65:1998 KR65" "Sol" #1=
#2_"1998 KR65:85633 1998 KR65" "Sol" #2=
#3_"1998 KR65:85633 1998 KR65" "Sol" #3=
".:1998 KR65:85633 1998 KR65" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	100.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	285.315891202006
		SemiMajorAxis	43.33896205029
		Eccentricity	0.032964082672
		Inclination	1.19003638326
		AscendingNode	101.941634057479
		ArgOfPericenter	338.080589376028
		MeanAnomaly	246.748638488755
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=85633"
}

#1_"85640 1998 OX4:1998 OX4:2002 PJ34" "Sol" #1=
#2_"1998 OX4:85640 1998 OX4" "Sol" #2=
#3_"1998 OX4:85640 1998 OX4" "Sol" #3=
".:1998 OX4:85640 1998 OX4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.13
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.986897420622
		SemiMajorAxis	1.580440544356
		Eccentricity	0.485724586008
		Inclination	4.513606878608
		AscendingNode	299.713970784506
		ArgOfPericenter	117.123421193866
		MeanAnomaly	29.299002507006
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=85640"
}

#1_"85953 1999 FK21:1999 FK21" "Sol" #1=
#2_"1999 FK21:85953 1999 FK21" "Sol" #2=
#3_"1999 FK21:85953 1999 FK21" "Sol" #3=
".:1999 FK21:85953 1999 FK21" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.295
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.63494937067
		SemiMajorAxis	0.738732597465
		Eccentricity	0.703114267425
		Inclination	12.60632131526
		AscendingNode	180.503115372601
		ArgOfPericenter	172.365846738647
		MeanAnomaly	170.092939020534
	}
	UniformRotation
	{
		Period	28.1
	}
	LunarLambert	0.5
	Albedo	0.32
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=85953"
}

#1_"86039 1999 NC43:1999 NC43:1999 NC43" "Sol" #1=
#2_"1999 NC43:86039 1999 NC43" "Sol" #2=
#3_"1999 NC43:86039 1999 NC43" "Sol" #3=
".:1999 NC43:86039 1999 NC43" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.11
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.334129810598
		SemiMajorAxis	1.759588852843
		Eccentricity	0.579190440192
		Inclination	7.123563606332
		AscendingNode	311.814532784129
		ArgOfPericenter	120.574227664456
		MeanAnomaly	137.471880444336
	}
	UniformRotation
	{
		Period	34.49
	}
	LunarLambert	0.5
	Albedo	0.14
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=86039"
}

#1_"86047 1999 OY3:1999 OY3" "Sol" #1=
#2_"1999 OY3:86047 1999 OY3" "Sol" #2=
#3_"1999 OY3:86047 1999 OY3" "Sol" #3=
".:1999 OY3:86047 1999 OY3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"haumeanfamily.dds"
	Radius	36.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	288.689813046518
		SemiMajorAxis	43.679953899538
		Eccentricity	0.169292031911
		Inclination	24.277403835298
		AscendingNode	301.871965157076
		ArgOfPericenter	303.756540272828
		MeanAnomaly	61.177028254892
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.7
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=86047"
}

#1_"86257 1999 TK207:1999 TK207:2002 TQ221" "Sol" #1=
#2_"1999 TK207:86257 1999 TK207" "Sol" #2=
#3_"1999 TK207:86257 1999 TK207" "Sol" #3=
".:1999 TK207:86257 1999 TK207" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"86257 1999 TK207.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	2.101
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.668284411895
		SemiMajorAxis	1.92375285724
		Eccentricity	0.084092013742
		Inclination	18.653932774998
		AscendingNode	281.49763433199
		ArgOfPericenter	261.314345950192
		MeanAnomaly	14.095908007092
	}
	UniformRotation
	{
		Period	32.408
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=86257"
}

#1_"87269 2000 OO67:2000 OO67" "Sol" #1=
#2_"2000 OO67:87269 2000 OO67" "Sol" #2=
#3_"2000 OO67:87269 2000 OO67" "Sol" #3=
".:2000 OO67:87269 2000 OO67" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12694.7695697961
		SemiMajorAxis	544.182301736956
		Eccentricity	0.961803163999
		Inclination	20.073163393242
		AscendingNode	142.397042755303
		ArgOfPericenter	212.451239030804
		MeanAnomaly	0.273023297542
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=87269"
}

#1_"88161 2000 XK18:2000 XK18:1981 US12:2001 XR16" "Sol" #1=
#2_"2000 XK18:88161 2000 XK18" "Sol" #2=
#3_"2000 XK18:88161 2000 XK18" "Sol" #3=
".:2000 XK18:88161 2000 XK18" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"88161 2000 XK18.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	5.278
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.701498226706
		SemiMajorAxis	2.806416012158
		Eccentricity	0.253676538296
		Inclination	13.986529493511
		AscendingNode	298.245425841384
		ArgOfPericenter	71.961502883233
		MeanAnomaly	198.281237639896
	}
	UniformRotation
	{
		Period	6.806
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=88161"
}

#1_"Teharonhiawako-Sawiskera" "Sol" #1=
#2_"*Таронхайавагон-Тавискарон:Teharonhiawako-Sawiskera" "Sol" #2=
#3_"Teharonhiawako-Sawiskera:*Таронхайавагон-Тавискарон" "Sol" #3=
".:Teharonhiawako-Sawiskera" "Sol" #4=

{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	5726
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	290.503758960022
		SemiMajorAxis	43.862734461943
		Eccentricity	0.03080079468
		Inclination	2.586240385403
		AscendingNode	304.826584251464
		ArgOfPericenter	234.205433027341
		MeanAnomaly	159.433587151458
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-88611.html"
}

#1_"88611 Teharonhiawako:Teharonhiawako:2001 QT297" "Sol/Teharonhiawako-Sawiskera" #1=
#2_"*Таронхайавагон:88611 Teharonhiawako:Teharonhiawako:2001 QT297" "Sol/Teharonhiawako-Sawiskera" #2=
#3_"2001 QT297:*Таронхайавагон:88611 Teharonhiawako:Teharonhiawako" "Sol/Teharonhiawako-Sawiskera" #3=
".:Teharonhiawako:88611 Teharonhiawako:2001 QT297" "Sol/Teharonhiawako-Sawiskera" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	89
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Teharonhiawako-Sawiskera" }
    }
	EllipticalOrbit
	{
		Epoch	2452000.0  # 2001 Mar 31 12:00
		Period	828.76
		SemiMajorAxis	7629
		Eccentricity	0.2494
		Inclination	144.42
		AscendingNode	54.22
		ArgOfPericenter	200.1
		MeanAnomaly	296.2
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Teharonhiawako-Sawiskera" }
    }
	UniformRotation
	{
		Period	9.505
		Inclination	144.42
		AscendingNode	54.22
	}
	LunarLambert	0.5
	Albedo	0.275
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=88611"
}

#1_"Sawiskera:88611 Teharonhiawako I:Teharonhiawako I:2001 88611 I" "Sol/Teharonhiawako-Sawiskera" #1=
#2_"*Тавискарон:Sawiskera:88611 Teharonhiawako I:*Таронхайавагон I:Teharonhiawako I:2001 88611 I" "Sol/Teharonhiawako-Sawiskera" #2=
#3_"2001 88611 I:*Тавискарон:Sawiskera:88611 Teharonhiawako I:*Таронхайавагон I:Teharonhiawako I" "Sol/Teharonhiawako-Sawiskera" #3=
".:Sawiskera:88611 Teharonhiawako I:Teharonhiawako I:2001 88611 I" "Sol/Teharonhiawako-Sawiskera" #4=

{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	64.5
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Teharonhiawako-Sawiskera" }
    }
	EllipticalOrbit
	{
		Epoch	2452000.0  # 2001 Mar 31 12:00
		Period	828.76
		SemiMajorAxis	20041
		Eccentricity	0.2494
		Inclination	144.42
		AscendingNode	54.22
		ArgOfPericenter	20.1
		MeanAnomaly	296.2
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Teharonhiawako-Sawiskera" }
	}
	UniformRotation
	{
		Period	9.50
		Inclination	144.42
		AscendingNode	54.22
	}
	LunarLambert	0.5
	Albedo	0.275
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-88611.html"
}

#1_"89309 2001 VN36:2001 VN36" "Sol" #1=
#2_"2001 VN36:89309 2001 VN36" "Sol" #2=
#3_"2001 VN36:89309 2001 VN36" "Sol" #3=
".:2001 VN36:89309 2001 VN36" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"89309 2001 VN36.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.103
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.342108412526
		SemiMajorAxis	2.235329523716
		Eccentricity	0.206433344129
		Inclination	6.021078606658
		AscendingNode	92.841912646134
		ArgOfPericenter	267.240751069245
		MeanAnomaly	250.028290658491
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=89309"
}

#1_"89764 2002 AW61:2002 AW61" "Sol" #1=
#2_"2002 AW61:89764 2002 AW61" "Sol" #2=
#3_"2002 AW61:89764 2002 AW61" "Sol" #3=
".:2002 AW61:89764 2002 AW61" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"89764 2002 AW61.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.919
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.139861310419
		SemiMajorAxis	2.578210621221
		Eccentricity	0.108768151809
		Inclination	12.542202131923
		AscendingNode	313.339496364772
		ArgOfPericenter	32.703626703159
		MeanAnomaly	17.335810070567
	}
	UniformRotation
	{
		Period	5.93513
	}
	LunarLambert	0.5
	Albedo	0.301
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=89764"
}

#1_"90265 2003 CL5:2003 CL5:1998 SZ168" "Sol" #1=
#2_"2003 CL5:90265 2003 CL5" "Sol" #2=
#3_"2003 CL5:90265 2003 CL5" "Sol" #3=
".:2003 CL5:90265 2003 CL5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"90265 2003 CL5.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.326
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.343131114782
		SemiMajorAxis	2.235785515301
		Eccentricity	0.207300975313
		Inclination	5.994860995493
		AscendingNode	95.634648173935
		ArgOfPericenter	261.948762145042
		MeanAnomaly	183.00047738601
	}
	UniformRotation
	{
		Period	23.42
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=90265"
}

#1_"90377 Sedna:Sedna:2003 VB12" "Sol" #1=
#2_"*Седна:90377 Sedna:Sedna:2003 VB12" "Sol" #2=
#3_"2003 VB12:*Седна:90377 Sedna:Sedna" "Sol" #3=
".:Sedna:90377 Sedna:2003 VB12" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"sedna.dds"
	NormalMap	"sedna-normal.*"
	Radius	497.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	10772.6945596826

		SemiMajorAxis	487.765144689144
		Eccentricity	0.844091242231
		Inclination	11.929002849013
		AscendingNode	144.45958578027
		ArgOfPericenter	311.612977237478
		MeanAnomaly	358.026861006874
	}
	UniformRotation
	{
		Period	10.273
	}
	LunarLambert	0.5
	Albedo	0.32
	InfoURL	"https://en.wikipedia.org/wiki/90377_Sedna"
}

"Orcus-Vanth" "Sol"  # Барицентр
{
	Class	"asteroid"
	Mesh	""
	Radius	1120
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458200.5  # 2018 Mar 23
		Period	246.93816362717
		SemiMajorAxis	39.359841534644
		Eccentricity	0.221248837172
		Inclination	20.587223786989
		AscendingNode	268.755699512011
		ArgOfPericenter	72.262273657391
		MeanAnomaly	178.665005122646
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-90482.html"
}

#1_"90482 Orcus:Orcus:2004 DW" "Sol/Orcus-Vanth" #1=
#2_"*Орк:90482 Orcus:Orcus:2004 DW" "Sol/Orcus-Vanth" #2=
#3_"2004 DW:90482 Orcus:Orcus" "Sol/Orcus-Vanth" #3=
".:Orcus:90482 Orcus:2004 DW" "Sol/Orcus-Vanth" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"orcus.dds"
	BumpMap	"orcus-bump.png"
	BumpHeight	5
	Radius	455
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2454439.28  # 2007 Dec 04 18:43:12
		Period	9.539
		SemiMajorAxis	1121
		Eccentricity	0.001
		Inclination	90.2
		AscendingNode	50.0
		ArgOfPericenter	180
		MeanAnomaly	143.1
	}
	UniformRotation
	{
		Period	228.936
		Inclination	90.2
		AscendingNode	50.0
	}
	LunarLambert	0.5
	Albedo	0.231
	InfoURL	"https://en.wikipedia.org/wiki/90482_Orcus"
}

#1_"Vanth:90482 Orcus I:Orcus I:2005 90482 I" "Sol/Orcus-Vanth" #1=
#2_"*Вант:Vanth:90482 Orcus I:*Орк I:Orcus I:2005 90482 I" "Sol/Orcus-Vanth" #2=
#3_"2005 90482 I:Vanth:90482 Orcus I:Orcus I" "Sol/Orcus-Vanth" #3=
".:Vanth:90482 Orcus I:Orcus I:2005 90482 I" "Sol/Orcus-Vanth" #4=

{
	Class	"asteroid"
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	237.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2454439.28  # 2007 Dec 04 18:43:12
		Period	9.539
		SemiMajorAxis	7885
		Eccentricity	0.001
		Inclination	90.2
		AscendingNode	50.0
		MeanAnomaly	143.1
	}
	UniformRotation
	{
		Period	228.936
		Inclination	90.2
		AscendingNode	50.0
    }
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-90482.html"
}

#1_"90568 2004 GV9:2004 GV9" "Sol" #1=
#2_"2004 GV9:90568 2004 GV9" "Sol" #2=
#3_"2004 GV9:90568 2004 GV9" "Sol" #3=
".:2004 GV9:90568 2004 GV9" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	340
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	272.762425440753
		SemiMajorAxis	42.058220563358
		Eccentricity	0.079949758533
		Inclination	21.998660987955
		AscendingNode	250.577333452633
		ArgOfPericenter	291.862641158942
		MeanAnomaly	34.482142614556
	}
	UniformRotation
	{
		Period	5.86
	}
	LunarLambert	0.5
	Albedo	0.077
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=90568"
}

#1_"91063 1998 FX62:1998 FX62:2000 SF144" "Sol" #1=
#2_"1998 FX62:91063 1998 FX62" "Sol" #2=
#3_"1998 FX62:91063 1998 FX62" "Sol" #3=
".:1998 FX62:91063 1998 FX62" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"91063 1998 FX62.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.792
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.279385571283
		SemiMajorAxis	2.635818350373
		Eccentricity	0.116520286229
		Inclination	13.312925305487
		AscendingNode	7.22274085018
		ArgOfPericenter	107.482549276859
		MeanAnomaly	212.243948844348
	}
	UniformRotation
	{
		Period	15.2404
	}
	LunarLambert	0.5
	Albedo	0.262
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=91063"
}

#1_"91133 1998 HK151:1998 HK151" "Sol" #1=
#2_"1998 HK151:91133 1998 HK151" "Sol" #2=
#3_"1998 HK151:91133 1998 HK151" "Sol" #3=
".:1998 HK151:91133 1998 HK151" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	66.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	246.500207686257
		SemiMajorAxis	39.313290134734
		Eccentricity	0.228196315632
		Inclination	5.940749056611
		AscendingNode	50.227630684708
		ArgOfPericenter	180.277384970979
		MeanAnomaly	23.847772985546
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=91133"
}

#1_"91554 1999 RZ215:1999 RZ215" "Sol" #1=
#2_"1999 RZ215:91554 1999 RZ215" "Sol" #2=
#3_"1999 RZ215:91554 1999 RZ215" "Sol" #3=
".:1999 RZ215:91554 1999 RZ215" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1011.76728515793
		SemiMajorAxis	100.781686180248
		Eccentricity	0.692798263068
		Inclination	25.547103246485
		AscendingNode	341.675812115588
		ArgOfPericenter	335.575438774135
		MeanAnomaly	5.761034799979
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=91554"
}

#1_"94808 2001 XM167:2001 XM167:1997 SR33" "Sol" #1=
#2_"2001 XM167:94808 2001 XM167" "Sol" #2=
#3_"2001 XM167:94808 2001 XM167" "Sol" #3=
".:2001 XM167:94808 2001 XM167" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"94808 2001 XM167.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.006
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.514940888464
		SemiMajorAxis	2.311744762444
		Eccentricity	0.191694559713
		Inclination	1.083413024143
		AscendingNode	220.975040048059
		ArgOfPericenter	169.086790053836
		MeanAnomaly	155.839442073649
	}
	UniformRotation
	{
		Period	10.66092
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=94808"
}

#1_"95625 2002 GX32:2002 GX32:1994 JV" "Sol" #1=
#2_"2002 GX32:95625 2002 GX32" "Sol" #2=
#3_"2002 GX32:95625 2002 GX32" "Sol" #3=
".:2002 GX32:95625 2002 GX32" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	387.075523109925
		SemiMajorAxis	53.111879634543
		Eccentricity	0.377366818943
		Inclination	13.930281294291
		AscendingNode	28.133447660327
		ArgOfPericenter	185.57786423319
		MeanAnomaly	16.796843684019
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=95625"
}

#1_"96177 1984 BC:1984 BC" "Sol" #1=
#2_"1984 BC:96177 1984 BC" "Sol" #2=
#3_"1984 BC:96177 1984 BC" "Sol" #3=
".:1984 BC:96177 1984 BC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.534507149562
		SemiMajorAxis	3.495181691695
		Eccentricity	0.533589769911
		Inclination	21.355960052338
		AscendingNode	129.461625769312
		ArgOfPericenter	43.674692831802
		MeanAnomaly	255.216728603042
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=96177"
}

#1_"96461 1998 HS36:1998 HS36:2002 QK46" "Sol" #1=
#2_"1998 HS36:96461 1998 HS36" "Sol" #2=
#3_"1998 HS36:96461 1998 HS36" "Sol" #3=
".:1998 HS36:96461 1998 HS36" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"96461 1998 HS36.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3.627018581296
		SemiMajorAxis	2.360628895348
		Eccentricity	0.276839313214
		Inclination	4.239635259527
		AscendingNode	27.467537047084
		ArgOfPericenter	201.259227609315
		MeanAnomaly	53.155165583427
	}
	UniformRotation
	{
		Period	12.67641
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=96461"
}

#1_"97346 2000 AF10:2000 AF10:1995 WS8" "Sol" #1=
#2_"2000 AF10:97346 2000 AF10" "Sol" #2=
#3_"2000 AF10:97346 2000 AF10" "Sol" #3=
".:2000 AF10:97346 2000 AF10" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"97346 2000 AF10.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	5.009
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.224914291031
		SemiMajorAxis	2.613403492703
		Eccentricity	0.145511264893
		Inclination	12.524301112722
		AscendingNode	47.545586895209
		ArgOfPericenter	200.670691996003
		MeanAnomaly	201.235678012878
	}
	UniformRotation
	{
		Period	7.65364
	}
	LunarLambert	0.5
	Albedo	0.062
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=97346"
}

#1_"99667 2002 JO1:2002 JO1" "Sol" #1=
#2_"2002 JO1:99667 2002 JO1" "Sol" #2=
#3_"2002 JO1:99667 2002 JO1" "Sol" #3=
".:2002 JO1:99667 2002 JO1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"99667 2002 JO1.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	1.934
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.636672842385
		SemiMajorAxis	2.780559338948
		Eccentricity	0.138353555345
		Inclination	6.682988377271
		AscendingNode	164.565474565156
		ArgOfPericenter	334.344542637826
		MeanAnomaly	141.93802877531
	}
	UniformRotation
	{
		Period	5.07877
	}
	LunarLambert	0.5
	Albedo	0.129
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=99667"
}

#1_"99907 1989 VA:1989 VA" "Sol" #1=
#2_"1989 VA:99907 1989 VA" "Sol" #2=
#3_"1989 VA:99907 1989 VA" "Sol" #3=
".:1989 VA:99907 1989 VA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.621715825397
		SemiMajorAxis	0.728432218956
		Eccentricity	0.594680269056
		Inclination	28.797715154124
		AscendingNode	225.605558091847
		ArgOfPericenter	2.840806077198
		MeanAnomaly	293.906527124054
	}
	UniformRotation
	{
		Period	2.514
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=99907"
}

#1_"99942 Apophis:Apophis:2004 MN4" "Sol" #1=
#2_"*Апофис:99942 Apophis:Apophis:2004 MN4" "Sol" #2=
#3_"2004 MN4:*Апофис:99942 Apophis:Apophis" "Sol" #3=
".:Apophis:99942 Apophis:2004 MN4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"99942 apophis.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"apophis.jpg"
	Radius	0.1625
	Visible	false
	Clickable	false
	Timeline
	[
		{
			Ending	2461679.5  # 2027 Oct 01
			EllipticalOrbit
			{
				Epoch	2461679.5  # 2027 Oct 01
				Period	0.8857935539765032
				SemiMajorAxis	0.9223226532679485
				Eccentricity	0.1911785139465703
				Inclination	3.341269445319867
				AscendingNode	203.8876489505309
				ArgOfPericenter	126.6976798003219
				MeanAnomaly	348.3005711236792
			}
			UniformRotation
			{
				Period	30.4
			}
		}
		{
			Ending	2465424.5  # 2038 Jan 01
			SampledOrbit	"Apophis 2027-10-01 - 2038-01-01.xyzv"
			UniformRotation
			{
				Period	30.4
			}
		}
		{
			EllipticalOrbit
			{
				Epoch	2465424.5  # 2038 Jan 01
				Period	1.156960082400556
				SemiMajorAxis	1.102063913563053
				Eccentricity	0.1887841570598544
				Inclination	2.235530347595946
				AscendingNode	203.4772513114713
				ArgOfPericenter	71.92724509554216
				MeanAnomaly	142.0691109161438
			}
			UniformRotation
			{
				Period	30.4
			}
		}
	]
	LunarLambert	0.5
	Albedo	0.23
	InfoURL	"https://en.wikipedia.org/wiki/99942_Apophis"
}

#1_"100004 1983 VA:1983 VA" "Sol" #1=
#2_"1983 VA:100004 1983 VA" "Sol" #2=
#3_"1983 VA:100004 1983 VA" "Sol" #3=
".:1983 VA:100004 1983 VA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.183338623904
		SemiMajorAxis	2.59623028738
		Eccentricity	0.699612510557
		Inclination	16.28403447971
		AscendingNode	77.338420419211
		ArgOfPericenter	12.070172203766
		MeanAnomaly	127.867226190315
	}
	UniformRotation
	{
		Period	3.1643
	}
	LunarLambert	0.5
	Albedo	0.0668
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=100004"
}

#1_"101429 1998 VF31:1998 VF31" "Sol" #1=
#2_"1998 VF31:101429 1998 VF31" "Sol" #2=
#3_"1998 VF31:101429 1998 VF31" "Sol" #3=
".:1998 VF31:101429 1998 VF31" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.799
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.881762017365
		SemiMajorAxis	1.524184932238
		Eccentricity	0.100328001087
		Inclination	31.294790383307
		AscendingNode	221.322391024706
		ArgOfPericenter	310.526627748271
		MeanAnomaly	91.916892687217
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=101429"
}

#1_"101955 Bennu:Bennu:1999 RQ36" "Sol" #1=
#2_"*Бенну:101955 Bennu:Bennu:1999 RQ36" "Sol" #2=
#3_"1999 RQ36:*Бенну:101955 Bennu:Bennu" "Sol" #3=
".:Bennu:101955 Bennu:1999 RQ36" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"101955 bennu.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"bennu.png"
	Radius	0.2625
	Visible	false
	Clickable	false
	Timeline
	[
		{
			Ending	2458455.5  # 2018 Dec 03
			EllipticalOrbit
			{
				Epoch	2458455.5  # 2018 Dec 03
				Period	1.19470831962297
				SemiMajorAxis	1.125906839069414
				Eccentricity	0.2037294967480565
				Inclination	6.034294611323767
				AscendingNode	2.018429891578222
				ArgOfPericenter	66.30470010136663
				MeanAnomaly	328.0138309849828
			}
			UniformRotation
			{
				Period	4.288
				Inclination	176
			}
		}
		{
			Ending	2458545.5  # 2019 Mar 03
			SampledTrajectory
			{
				Source	"101955 Bennu-OSIRIS-REx.xyzv"
				DoublePrecision	true
				Interpolation	"cubic"
			}
			UniformRotation
			{
				Period	4.288
				Inclination	176
			}
		}
		{
			EllipticalOrbit
			{
				Epoch	2458545.5  # 2019 Mar 03
				Period	1.19470963376294
				SemiMajorAxis	1.12590766470966
				Eccentricity	0.2037297850155811
				Inclination	6.034265530073895
				AscendingNode	2.017107694594038
				ArgOfPericenter	66.30419253611505
				MeanAnomaly	42.26442770090173
			}
			UniformRotation
			{
				Period	4.288
				Inclination	176
			}
		}
	]
	LunarLambert	0.5
	Albedo	0.046
	InfoURL	"https://en.wikipedia.org/wiki/101955_Bennu"
}

#1_"118228 1996 TQ66:1996 TQ66" "Sol" #1=
#2_"1996 TQ66:118228 1996 TQ66" "Sol" #2=
#3_"1996 TQ66:118228 1996 TQ66" "Sol" #3=
".:1996 TQ66:118228 1996 TQ66" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	83.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	248.17373021823
		SemiMajorAxis	39.491024821649
		Eccentricity	0.122765156784
		Inclination	14.677926730525
		AscendingNode	10.799870243742
		ArgOfPericenter	20.952208135812
		MeanAnomaly	22.055531989011
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=118228"
}

#1_"118378 1999 HT11:1999 HT11" "Sol" #1=
#2_"1999 HT11:118378 1999 HT11" "Sol" #2=
#3_"1999 HT11:118378 1999 HT11" "Sol" #3=
".:1999 HT11:118378 1999 HT11" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	290.011022768162
		SemiMajorAxis	43.813122089386
		Eccentricity	0.112777977867
		Inclination	5.056953037743
		AscendingNode	87.876338986373
		ArgOfPericenter	187.270025262051
		MeanAnomaly	321.627756339319
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=118378"
}

#1_"118379 1999 HC12:1999 HC12" "Sol" #1=
#2_"1999 HC12:118379 1999 HC12" "Sol" #2=
#3_"1999 HC12:118379 1999 HC12" "Sol" #3=
".:1999 HC12:118379 1999 HC12" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	66.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	305.743789929036
		SemiMajorAxis	45.383671631953
		Eccentricity	0.236671962093
		Inclination	15.346805227046
		AscendingNode	57.021820622771
		ArgOfPericenter	95.435519805098
		MeanAnomaly	61.847776145905
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=118379"
}

#1_"118401 LINEAR:LINEAR:1999 RE70:2001 AR7:176P" "Sol" #1=
#2_"1999 RE70:118401 LINEAR:176P" "Sol" #2=
#3_"1999 RE70:118401 LINEAR:176P" "Sol" #3=
".:LINEAR:118401 LINEAR:1999 RE70:176P" "Sol" #4=
{
	Class	"asteroid"
	# Class	"comet"  # Классифицируется и как комета

	Mesh	"asteroid-large.cmod"
	Texture	"comet.dds"
	Radius	1.75
	OrbitColor	[ 0.611765 0.317647 0.12549 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	5.712946461969
		SemiMajorAxis	3.195714461169
		Eccentricity	0.192767648376
		Inclination	0.234668437188
		AscendingNode	345.98082500931
		ArgOfPericenter	35.385897479477
		MeanAnomaly	321.303480840184
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=118401"
}

#1_"118702 2000 OM67:2000 OM67" "Sol" #1=
#2_"2000 OM67:118702 2000 OM67" "Sol" #2=
#3_"2000 OM67:118702 2000 OM67" "Sol" #3=
".:2000 OM67:118702 2000 OM67" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	963.662275093099
		SemiMajorAxis	97.561343069403
		Eccentricity	0.598129817611
		Inclination	23.39835908652
		AscendingNode	327.168802622651
		ArgOfPericenter	348.634604795277
		MeanAnomaly	9.708871935991
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=118702"
}

#1_"119068 2001 KC77:2001 KC77" "Sol" #1=
#2_"2001 KC77:119068 2001 KC77" "Sol" #2=
#3_"2001 KC77:119068 2001 KC77" "Sol" #3=
".:2001 KC77:119068 2001 KC77" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	100.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	408.143007409495
		SemiMajorAxis	55.021966145214
		Eccentricity	0.356967290911
		Inclination	12.90718695986
		AscendingNode	57.83375597522
		ArgOfPericenter	179.600220966021
		MeanAnomaly	12.629380204559
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=119068"
}

#1_"119070 2001 KP77:2001 KP77" "Sol" #1=
#2_"2001 KP77:119070 2001 KP77" "Sol" #2=
#3_"2001 KP77:119070 2001 KP77" "Sol" #3=
".:2001 KP77:119070 2001 KP77" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	87.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	288.082985260497
		SemiMajorAxis	43.618722078526
		Eccentricity	0.174939174863
		Inclination	3.313270737103
		AscendingNode	21.938137775822
		ArgOfPericenter	217.421334140879
		MeanAnomaly	16.951879171697
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=119070"
}

#1_"119878 2002 CY224:2002 CY224" "Sol" #1=
#2_"2002 CY224:119878 2002 CY224" "Sol" #2=
#3_"2002 CY224:119878 2002 CY224" "Sol" #3=
".:2002 CY224:119878 2002 CY224" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	132.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	401.089645115414
		SemiMajorAxis	54.386214575543
		Eccentricity	0.351055794026
		Inclination	15.699803492453
		AscendingNode	316.997934024155
		ArgOfPericenter	152.047136860031
		MeanAnomaly	21.279646771844
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=119878"
}

#1_"119951 2002 KX14:2002 KX14" "Sol" #1=
#2_"2002 KX14:119951 2002 KX14" "Sol" #2=
#3_"2002 KX14:119951 2002 KX14" "Sol" #3=
".:2002 KX14:119951 2002 KX14" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	227.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	241.346395170168
		SemiMajorAxis	38.763389295253
		Eccentricity	0.042711364793
		Inclination	0.405168072422
		AscendingNode	286.531890953245
		ArgOfPericenter	75.314646478061
		MeanAnomaly	256.231939530748
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.097
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=119951"
}

#1_"119979 2002 WC19:2002 WC19" "Sol" #1=
#2_"2002 WC19:119979 2002 WC19" "Sol" #2=
#3_"2002 WC19:119979 2002 WC19" "Sol" #3=
".:2002 WC19:119979 2002 WC19" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	220
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	334.133975621627
		SemiMajorAxis	48.151330351112
		Eccentricity	0.265635875803
		Inclination	9.16851012515
		AscendingNode	109.774228203243
		ArgOfPericenter	43.751685314506
		MeanAnomaly	315.338191526945
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=119979"
}

#1_"2007 119979 I" "Sol/119979 2002 WC19" #1=
#2_"2007 119979 I" "Sol/119979 2002 WC19" #2=
#3_"2007 119979 I" "Sol/119979 2002 WC19" #3=
".:2007 119979 I" "Sol/119979 2002 WC19" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	69.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	8.403
		SemiMajorAxis	4090
		Eccentricity	0.2
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-119979.html"
}

#1_"120132 2003 FY128:2003 FY128" "Sol" #1=
#2_"2003 FY128:120132 2003 FY128" "Sol" #2=
#3_"2003 FY128:120132 2003 FY128" "Sol" #3=
".:2003 FY128:120132 2003 FY128" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	230
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	350.157344290925
		SemiMajorAxis	49.678677394686
		Eccentricity	0.254779873065
		Inclination	11.757549458248
		AscendingNode	341.681693231551
		ArgOfPericenter	174.744865808829
		MeanAnomaly	27.536272108272
	}
	UniformRotation
	{
		Period	8.54
	}
	LunarLambert	0.5
	Albedo	0.079
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=120132"
}

#1_"120178 2003 OP32:2003 OP32" "Sol" #1=
#2_"2003 OP32:120178 2003 OP32" "Sol" #2=
#3_"2003 OP32:120178 2003 OP32" "Sol" #3=
".:2003 OP32:120178 2003 OP32" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"haumeanfamily.dds"
	Radius	115
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	282.408833018304
		SemiMajorAxis	43.044075315769
		Eccentricity	0.104876294825
		Inclination	27.200516779859
		AscendingNode	182.953109866643
		ArgOfPericenter	67.179072460662
		MeanAnomaly	70.474305888034
	}
	UniformRotation
	{
		Period	9.71
	}
	LunarLambert	0.5
	Albedo	0.7
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=120178"
}

#1_"120216 2004 EW95:2004 EW95" "Sol" #1=
#2_"120216 2004 EW95:2004 EW95" "Sol" #2=
#3_"2004 EW95:120216 2004 EW95" "Sol" #3=
".:120216 2004 EW95:2004 EW95" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	145.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458200.5  # 2018 Mar 23
		Period	250.930302048397
		SemiMajorAxis	39.782915263202
		Eccentricity	0.321932979997
		Inclination	29.234319990182
		AscendingNode	25.703626475526
		ArgOfPericenter	204.669075998977
		MeanAnomaly	359.952933151652
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"https://en.wikipedia.org/wiki/(120216)_2004_EW95"
}
#1_"120347 Salacia:Salacia:2004 SB60" "Sol" #1=
#2_"*Салация:120347 Salacia:Salacia:2004 SB60" "Sol" #2=
#3_"2004 SB60:*Салация:120347 Salacia:Salacia" "Sol" #3=
".:Salacia:120347 Salacia:2004 SB60" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"salacia.dds"
	BumpMap	"salacia-bump.png"
	BumpHeight	5
	Radius	427
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	271.34257595919
		SemiMajorAxis	41.9121391737
		Eccentricity	0.109867525084
		Inclination	23.927222040054
		AscendingNode	279.998157637044
		ArgOfPericenter	309.068268477084
		MeanAnomaly	122.759261213297
	}
	UniformRotation
	{
		Period	6.5
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"https://en.wikipedia.org/wiki/120347_Salacia"
}

#1_"Actaea:120347 Salacia I:Salacia I:2006 120347 I" "Sol/120347 Salacia" #1=
#2_"*Актея:Actaea:120347 Salacia I:*Салация I:Salacia I:2006 120347 I" "Sol/120347 Salacia" #2=
#3_"2006 120347 I:*Актея:Actaea:120347 Salacia I:*Салация I:Salacia I" "Sol/120347 Salacia" #3=
".:Actaea:120347 Salacia I:Salacia I:2006 120347 I" "Sol/120347 Salacia" #4=

{
	Class	"moon"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"salacia.dds"
	Radius	143
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	5.49380
		SemiMajorAxis	5619
		Eccentricity	0.0084
	}
	LunarLambert	0.5
	Albedo	0.044
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-120347.html"
}

#1_"120348 2004 TY364:2004 TY364" "Sol" #1=
#2_"2004 TY364:120348 2004 TY364" "Sol" #2=
#3_"2004 TY364:120348 2004 TY364" "Sol" #3=
".:2004 TY364:120348 2004 TY364" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Radius	256
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	242.369594445682
		SemiMajorAxis	38.872871489097
		Eccentricity	0.067337557774
		Inclination	24.850899971259
		AscendingNode	140.625596875251
		ArgOfPericenter	357.565425916948
		MeanAnomaly	266.498028535913
	}
	UniformRotation
	{
		Period	11.7
	}
	LunarLambert	0.5
	Albedo	0.107
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=120348"
}

#1_"121514 1999 UJ7:1999 UJ7:2002 AC180" "Sol" #1=
#2_"1999 UJ7:121514 1999 UJ7" "Sol" #2=
#3_"1999 UJ7:121514 1999 UJ7" "Sol" #3=
".:1999 UJ7:121514 1999 UJ7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.882193782051
		SemiMajorAxis	1.524418069783
		Eccentricity	0.039136919906
		Inclination	16.749537481645
		AscendingNode	347.379840761632
		ArgOfPericenter	48.287274683014
		MeanAnomaly	20.548595409686
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=121514"
}

#1_"126154 2001 YH140:2001 YH140" "Sol" #1=
#2_"2001 YH140:126154 2001 YH140" "Sol" #2=
#3_"2001 YH140:126154 2001 YH140" "Sol" #3=
".:2001 YH140:126154 2001 YH140" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	172.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	278.390199226644
		SemiMajorAxis	42.634760369589
		Eccentricity	0.145944707379
		Inclination	11.061336192939
		AscendingNode	108.820655153065
		ArgOfPericenter	356.29467193068
		MeanAnomaly	18.23386711768
	}
	UniformRotation
	{
		Period	13.25
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=126154"
}

#1_"126619 2002 CX154:2002 CX154" "Sol" #1=
#2_"2002 CX154:126619 2002 CX154" "Sol" #2=
#3_"2002 CX154:126619 2002 CX154" "Sol" #3=
".:2002 CX154:126619 2002 CX154" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	83.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	612.711944975661
		SemiMajorAxis	72.13822131663
		Eccentricity	0.473298662276
		Inclination	15.947744369769
		AscendingNode	346.925452577111
		ArgOfPericenter	161.481051945297
		MeanAnomaly	11.971592105992
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=126619"
}

#1_"127546 2002 XU93:2002 XU93" "Sol" #1=
#2_"2002 XU93:127546 2002 XU93" "Sol" #2=
#3_"2002 XU93:127546 2002 XU93" "Sol" #3=
".:2002 XU93:127546 2002 XU93" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	83.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	556.025355702522
		SemiMajorAxis	67.617264360339
		Eccentricity	0.689427364623
		Inclination	77.898256819217
		AscendingNode	90.285882822886
		ArgOfPericenter	28.146939587376
		MeanAnomaly	4.006360680553
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=127546"
}

#1_"130391 2000 JG81:2000 JG81" "Sol" #1=
#2_"2000 JG81:130391 2000 JG81" "Sol" #2=
#3_"2000 JG81:130391 2000 JG81" "Sol" #3=
".:2000 JG81:130391 2000 JG81" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	55.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	326.833029933341
		SemiMajorAxis	47.447335114302
		Eccentricity	0.280995675477
		Inclination	23.451035791774
		AscendingNode	45.956081525262
		ArgOfPericenter	169.211228857924
		MeanAnomaly	20.420134684349
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=130391"
}

#1_"131696 2001 XT254:2001 XT254" "Sol" #1=
#2_"2001 XT254:131696 2001 XT254" "Sol" #2=
#3_"2001 XT254:131696 2001 XT254" "Sol" #3=
".:2001 XT254:131696 2001 XT254" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	391.02376854217
		SemiMajorAxis	53.472436055917
		Eccentricity	0.328754190863
		Inclination	0.516190376192
		AscendingNode	359.632338774403
		ArgOfPericenter	133.013748632343
		MeanAnomaly	359.099133729222
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=131696"
}

#1_"132524 APL:2002 JF56" "Sol" #1=
#2_"APL:132524 APL:2002 JF56" "Sol" #2=
#3_"2002 JF56:APL:132524 APL" "Sol" #3=
".:APL:132524 APL:2002 JF56" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2453899.5  # 2006 Jun 13
		Period	4.2066743461856
		SemiMajorAxis	2.605876286628448
		Eccentricity	0.2714355390920677
		Inclination	4.163281385976950
		AscendingNode	51.78946343547695
		ArgOfPericenter	262.0254463743247
		MeanAnomaly	297.2221938933485
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=132524"
}

#1_"134210 2005 PQ21:2005 PQ21:2001 QG331:2002 PM149" "Sol" #1=
#2_"2005 PQ21:134210 2005 PQ21" "Sol" #2=
#3_"2005 PQ21:134210 2005 PQ21" "Sol" #3=
".:2005 PQ21:134210 2005 PQ21" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	96
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	484.561090275121
		SemiMajorAxis	61.691721646303
		Eccentricity	0.390113572318
		Inclination	6.494380124066
		AscendingNode	316.407011756059
		ArgOfPericenter	22.192608828353
		MeanAnomaly	5.379219223843
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=134210"
}

#1_"136120 2003 LG7:2003 LG7:2003 LG7" "Sol" #1=
#2_"2003 LG7:136120 2003 LG7" "Sol" #2=
#3_"2003 LG7:136120 2003 LG7" "Sol" #3=
".:2003 LG7:136120 2003 LG7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	490.577109194616
		SemiMajorAxis	62.201289042515
		Eccentricity	0.479271259768
		Inclination	20.110536608096
		AscendingNode	238.34822020071
		ArgOfPericenter	341.967611140157
		MeanAnomaly	13.51022477273
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=136120"
}

#1_"136564 1977 VA:1977 VA" "Sol" #1=
#2_"1977 VA:136564 1977 VA" "Sol" #2=
#3_"1977 VA:136564 1977 VA" "Sol" #3=
".:1977 VA:136564 1977 VA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.547800086203
		SemiMajorAxis	1.865397672172
		Eccentricity	0.394309792679
		Inclination	2.981268104255
		AscendingNode	224.538452026814
		ArgOfPericenter	172.510899269204
		MeanAnomaly	203.789964078616
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.25
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=136564"
}

#1_"136617 1994 CC:1994 CC" "Sol" #1=
#2_"1994 CC:136617 1994 CC" "Sol" #2=
#3_"1994 CC:136617 1994 CC" "Sol" #3=
".:1994 CC:136617 1994 CC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"136617 1994 CC.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.345
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.096656076886
		SemiMajorAxis	1.638121070917
		Eccentricity	0.41697994637
		Inclination	4.6818320178
		AscendingNode	268.592198923188
		ArgOfPericenter	24.801095284226
		MeanAnomaly	210.846116013397
	}
	UniformRotation
	{
		Period	2.38860
	}
	LunarLambert	0.5
	Albedo	0.42
	InfoURL	"https://en.wikipedia.org/wiki/(136617)_1994_CC"
}

#1_"2009 136617 I" "Sol/136617 1994 CC" #1=
#2_"2009 136617 I" "Sol/136617 1994 CC" #2=
#3_"2009 136617 I" "Sol/136617 1994 CC" #3=
".:2009 136617 I" "Sol/136617 1994 CC" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.0565
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2454994.5  # 2009 Jun 12
		Period	1.243
		SemiMajorAxis	1.729
		Eccentricity	0.002
		Inclination	83.376
		AscendingNode	59.209
		ArgOfPericenter	130.980
		MeanAnomaly	233.699
	}
	LunarLambert	0.5
	Albedo	0.42
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-136617.html"
}

#1_"2009 136617 II" "Sol/136617 1994 CC" #1=
#2_"2009 136617 II" "Sol/136617 1994 CC" #2=
#3_"2009 136617 II" "Sol/136617 1994 CC" #3=
".:2009 136617 II" "Sol/136617 1994 CC" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.04
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2454994.5  # 2009 Jun 12
		Period	8.376
		SemiMajorAxis	6.130
		Eccentricity	0.192
		Inclination	71.709
		AscendingNode	96.229
		ArgOfPericenter	96.229
		MeanAnomaly	6.070
	}
	LunarLambert	0.5
	Albedo	0.42
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-136617.html"
}

#1_"137052 Tjelvar:Tjelvar:1998 VO33" "Sol" #1=
#2_"*Тьельвар:137052 Tjelvar:Tjelvar:1998 VO33" "Sol" #2=
#3_"1998 VO33:*Тьельвар:137052 Tjelvar:Tjelvar" "Sol" #3=
".:Tjelvar:137052 Tjelvar:1998 VO33" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.394203112298
		SemiMajorAxis	1.24799227495
		Eccentricity	0.809546438013
		Inclination	14.917192593879
		AscendingNode	64.328068266679
		ArgOfPericenter	209.872447266868
		MeanAnomaly	228.151195002417
	}
	UniformRotation
	{
		Period	9.02
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=137052"
}

#1_"137108 1999 AN10:1999 AN10" "Sol" #1=
#2_"1999 AN10:137108 1999 AN10" "Sol" #2=
#3_"1999 AN10:137108 1999 AN10" "Sol" #3=
".:1999 AN10:137108 1999 AN10" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.65
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.761979373915
		SemiMajorAxis	1.458797729178
		Eccentricity	0.562034055501
		Inclination	39.933128359268
		AscendingNode	314.410320339485
		ArgOfPericenter	268.300870762375
		MeanAnomaly	322.927178550314
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=137108"
}

#1_"137184 1999 JG63:1999 JG63" "Sol" #1=
#2_"1999 JG63:137184 1999 JG63" "Sol" #2=
#3_"1999 JG63:137184 1999 JG63" "Sol" #3=
".:1999 JG63:137184 1999 JG63" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.092919897778
		SemiMajorAxis	2.96009576931
		Eccentricity	0.557278169306
		Inclination	8.018045458255
		AscendingNode	50.246918546327
		ArgOfPericenter	248.207595969014
		MeanAnomaly	357.732097240792
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.193
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=137184"
}

#1_"137295 1999 RB216:1999 RB216" "Sol" #1=
#2_"1999 RB216:137295 1999 RB216" "Sol" #2=
#3_"1999 RB216:137295 1999 RB216" "Sol" #3=
".:1999 RB216:137295 1999 RB216" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	76.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	327.390775803834
		SemiMajorAxis	47.501299538045
		Eccentricity	0.29173980032
		Inclination	12.703848849732
		AscendingNode	175.768055493706
		ArgOfPericenter	209.068934067587
		MeanAnomaly	0.448326036538
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=137295"
}

#1_"139056 2001 FY:2001 FY" "Sol" #1=
#2_"2001 FY:139056 2001 FY" "Sol" #2=
#3_"2001 FY:139056 2001 FY" "Sol" #3=
".:2001 FY:139056 2001 FY" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.16
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.590256170674
		SemiMajorAxis	1.886063641868
		Eccentricity	0.32718484782
		Inclination	4.733319342533
		AscendingNode	111.26568807951
		ArgOfPericenter	110.415764515776
		MeanAnomaly	89.724295002256
	}
	UniformRotation
	{
		Period	5.207
	}
	LunarLambert	0.5
	Albedo	0.52
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=139056"
}

#1_"2001 QG298 System" "Sol" #1=
#2_"*Система 2001 QG298:2001 QG298 System" "Sol" #2=
#3_"2001 QG298 System:*Система 2001 QG298" "Sol" #3=
".:2001 QG298 System" "Sol" #4=
{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	68
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	246.377579567947
		SemiMajorAxis	39.300250755328
		Eccentricity	0.191793092693
		Inclination	6.497709636413
		AscendingNode	162.595637100203
		ArgOfPericenter	209.685636351959
		MeanAnomaly	5.523935834278
	}
	LunarLambert	0.5
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-139775.html"
}

#1_"139775 2001 QG298:2001 QG298" "Sol/2001 QG298 System" #1=
#2_"2001 QG298:139775 2001 QG298" "Sol/2001 QG298 System" #2=
#3_"2001 QG298:139775 2001 QG298" "Sol/2001 QG298 System" #3=
".:2001 QG298:139775 2001 QG298" "Sol/2001 QG298 System" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"asteroid-smooth.dds"
	SemiAxes	[ 82 65 58 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.573933
		SemiMajorAxis	68
		ArgOfPericenter	180
	}
	UniformRotation
	{
		Period	13.774392
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=139775"
}

#1_"2004 139775 I" "Sol/2001 QG298 System" #1=
#2_"2004 139775 I" "Sol/2001 QG298 System" #2=
#3_"2004 139775 I" "Sol/2001 QG298 System" #3=
".:2004 139775 I" "Sol/2001 QG298 System" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	SemiAxes	[ 84 80 75 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.573933
		SemiMajorAxis	104

	}
	UniformRotation
	{
		Period	13.774392
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-139775.html"
}

#1_"144897 2004 UX10:2004 UX10" "Sol" #1=
#2_"2004 UX10:144897 2004 UX10" "Sol" #2=
#3_"2004 UX10:144897 2004 UX10" "Sol" #3=
".:2004 UX10:144897 2004 UX10" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Mesh	"roughsphere.cmod"
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	180.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	243.566720923704
		SemiMajorAxis	39.000768496989
		Eccentricity	0.039467730112
		Inclination	9.539410473516
		AscendingNode	148.073146966571
		ArgOfPericenter	152.678907843053
		MeanAnomaly	92.559501730266
	}
	UniformRotation
	{
		Period	5.68
	}
	LunarLambert	0.5
	Albedo	0.141
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=144897"
}

#1_"144898 2004 VD17:2004 VD17" "Sol" #1=
#2_"2004 VD17:144898 2004 VD17" "Sol" #2=
#3_"2004 VD17:144898 2004 VD17" "Sol" #3=
".:2004 VD17:144898 2004 VD17" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.425
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.85224693068
		SemiMajorAxis	1.508205271317
		Eccentricity	0.588809139832
		Inclination	4.222025076826
		AscendingNode	224.107491026974
		ArgOfPericenter	90.850791385795
		MeanAnomaly	189.991242547533
	}
	UniformRotation
	{
		Period	1.99
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=144898"
}

#1_"145451 2005 RM43:2005 RM43" "Sol" #1=
#2_"2005 RM43:145451 2005 RM43" "Sol" #2=
#3_"2005 RM43:145451 2005 RM43" "Sol" #3=
".:2005 RM43:145451 2005 RM43" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	290
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	869.504174663059
		SemiMajorAxis	91.098028750743
		Eccentricity	0.614357311909
		Inclination	28.733717157024
		AscendingNode	84.65871875454
		ArgOfPericenter	318.600115168187
		MeanAnomaly	4.118950598732
	}
	UniformRotation
	{
		Period	6.71
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=145451"
}

#1_"145452 2005 RN43:2005 RN43" "Sol" #1=
#2_"2005 RN43:145452 2005 RN43" "Sol" #2=
#3_"2005 RN43:145452 2005 RN43" "Sol" #3=
".:2005 RN43:145452 2005 RN43" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Radius	339.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	266.10986673041
		SemiMajorAxis	41.37155551941084
		Eccentricity	0.01985749870233349
		Inclination	19.29786164154896
		AscendingNode	186.9500389108745
		ArgOfPericenter	178.1102024692385
		MeanAnomaly	333.6951630339105
	}
	UniformRotation
	{
		Period	6.95
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=145452"
}

#1_"145453 2005 RR43:2005 RR43" "Sol" #1=
#2_"2005 RR43:145453 2005 RR43" "Sol" #2=
#3_"2005 RR43:145453 2005 RR43" "Sol" #3=
".:2005 RR43:145453 2005 RR43" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"haumeanfamily.dds"
	Radius	126
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	284.82794259775
		SemiMajorAxis	43.28953562166471
		Eccentricity	0.1380955065692717
		Inclination	28.4770333340465
		AscendingNode	85.88153268520851
		ArgOfPericenter	280.4803733066424
		MeanAnomaly	41.33963140400324
	}
	UniformRotation
	{
		Period	7.87
	}
	LunarLambert	0.5
	Albedo	0.703
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=145453"
}

#1_"145474 2005 SA278:2005 SA278" "Sol" #1=
#2_"2005 SA278:145474 2005 SA278" "Sol" #2=
#3_"2005 SA278:145474 2005 SA278" "Sol" #3=
".:2005 SA278:145474 2005 SA278" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	126.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	895.754390714049
		SemiMajorAxis	92.922416547851
		Eccentricity	0.644647228889
		Inclination	16.292011938044
		AscendingNode	170.423241749447
		ArgOfPericenter	277.148100449363
		MeanAnomaly	351.124897563848
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=145474"
}

#1_"145480 2005 TB190:2005 TB190" "Sol" #1=
#2_"2005 TB190:145480 2005 TB190" "Sol" #2=
#3_"2005 TB190:145480 2005 TB190" "Sol" #3=
".:2005 TB190:145480 2005 TB190" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	232
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	653.20548723816
		SemiMajorAxis	75.282566202623
		Eccentricity	0.386382154602
		Inclination	26.520367249428
		AscendingNode	180.435263380944
		ArgOfPericenter	171.713201338672
		MeanAnomaly	358.815686911217
	}
	UniformRotation
	{
		Period	12.68
	}
	LunarLambert	0.5
	Albedo	0.148
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=145480"
}

#1_"145779 1998 CC:1998 CC:2002 PK77" "Sol" #1=
#2_"1998 CC:145779 1998 CC:2002 PK77" "Sol" #2=
#3_"1998 CC:145779 1998 CC:2002 PK77" "Sol" #3=
".:1998 CC:145779 1998 CC:2002 PK77" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.219211752371
		SemiMajorAxis	2.180189422001
		Eccentricity	0.150804794903
		Inclination	4.00449659319
		AscendingNode	71.254796809856
		ArgOfPericenter	185.446822982284
		MeanAnomaly	343.43731544386
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=145779"
}

#1_"148209 2000 CR105:2000 CR105" "Sol" #1=
#2_"2000 CR105:148209 2000 CR105" "Sol" #2=
#3_"2000 CR105:148209 2000 CR105" "Sol" #3=
".:2000 CR105:148209 2000 CR105" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	121
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	3370.3130819425
		SemiMajorAxis	224.7888139673991
		Eccentricity	0.8029690647599231
		Inclination	22.74112050640455
		AscendingNode	128.2733303478163
		ArgOfPericenter	317.1329388688043
		MeanAnomaly	5.521227836815775
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=148209"
}

#1_"Altjira System" "Sol" #1=
#2_"*Система Альчеры:Altjira System" "Sol" #2=
#3_"Altjira System:*Система Альчеры" "Sol" #3=
".:Altjira System" "Sol" #4=

{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	2729
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	295.37504146466
		SemiMajorAxis	44.35171272196187
		Eccentricity	0.05839038150209473
		Inclination	5.20462398507132
		AscendingNode	1.989458444017555
		ArgOfPericenter	300.1561628060923
		MeanAnomaly	120.5090911992867
	}
	LunarLambert	0.5
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-148780.html"
}

#1_"148780 Altjira:Altjira:2001 UQ18" "Sol/Altjira System" #1=
#2_"*Альчера:148780 Altjira:Altjira:2001 UQ18" "Sol/Altjira System" #2=
#3_"2001 UQ18:*Альчера:148780 Altjira:Altjira" "Sol/Altjira System" #3=
".:Altjira:148780 Altjira:2001 UQ18" "Sol/Altjira System" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	123
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Altjira System" }
    }
	EllipticalOrbit
	{
		Epoch	2454300.0  # 2007 Jul 18 12:00
		Period	139.561
		SemiMajorAxis	4163
		Eccentricity	0.3445
		Inclination	35.19
		AscendingNode	312.73
		ArgOfPericenter	281.96
		MeanAnomaly	224.89
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Altjira System" }
    }
	UniformRotation
	{
		Period	3349.464
		Inclination	35.19
		AscendingNode	312.73
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=148780"
}

#1_"2007 148780 I" "Sol/Altjira System" #1=
#2_"2007 148780 I" "Sol/Altjira System" #2=
#3_"2007 148780 I" "Sol/Altjira System" #3=
".:2007 148780 I" "Sol/Altjira System" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	110.5
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Altjira System" }
    }
	EllipticalOrbit
	{
		Epoch	2454300.0  # 2007 Jul 18 12:00
		Period	139.561
		SemiMajorAxis	5741
		Eccentricity	0.3445
		Inclination	35.19
		AscendingNode	312.73
		ArgOfPericenter	101.96
		MeanAnomaly	224.89
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Altjira System" }
    }
	UniformRotation
	{
		Period	3349.464
		Inclination	35.19
		AscendingNode	312.73
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-148780.html"
}

#1_"150642 2001 CZ31:2001 CZ31" "Sol" #1=
#2_"2001 CZ31:150642 2001 CZ31" "Sol" #2=
#3_"2001 CZ31:150642 2001 CZ31" "Sol" #3=
".:2001 CZ31:150642 2001 CZ31" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	152
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	306.99743795583
		SemiMajorAxis	45.50764545479061
		Eccentricity	0.1245191861308613
		Inclination	10.19585572310743
		AscendingNode	136.1892078214684
		ArgOfPericenter	45.69886771483842
		MeanAnomaly	337.5916984055242
	}
	UniformRotation
	{
		Period	4.71
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=150642"
}

#1_"152558 1990 SA:1990 SA" "Sol" #1=
#2_"1990 SA:152558 1990 SA" "Sol" #2=
#3_"1990 SA:152558 1990 SA" "Sol" #3=
".:1990 SA:152558 1990 SA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.857843001634
		SemiMajorAxis	2.013817495825
		Eccentricity	0.441843873958
		Inclination	38.124592279428
		AscendingNode	172.216740289524
		ArgOfPericenter	115.096963654073
		MeanAnomaly	198.386290694598
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.17
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=152558"
}

#1_"153201 2000 WO107:2000 WO107" "Sol" #1=
#2_"2000 WO107:153201 2000 WO107" "Sol" #2=
#3_"2000 WO107:153201 2000 WO107" "Sol" #3=
".:2000 WO107:153201 2000 WO107" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.297
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.870069272585
		SemiMajorAxis	0.911374947159
		Eccentricity	0.780718772872
		Inclination	7.773224199661
		AscendingNode	69.278494877248
		ArgOfPericenter	213.688819017579
		MeanAnomaly	101.083957157602
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=153201"
}

#1_"153591 2001 SN263:2001 SN263" "Sol" #1=
#2_"2001 SN263:153591 2001 SN263" "Sol" #2=
#3_"2001 SN263:153591 2001 SN263" "Sol" #3=
".:2001 SN263:153591 2001 SN263" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"153591 2001 SN263.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	1.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	2.799987481931
		SemiMajorAxis	1.98654584314
		Eccentricity	0.478340124434
		Inclination	6.685342513971
		AscendingNode	325.82616399852
		ArgOfPericenter	172.862868844488
		MeanAnomaly	148.566955534222
	}
	UniformRotation
	{
		Period	3.423
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"https://en.wikipedia.org/wiki/(153591)_2001_SN263"
}

#1_"2008 153591 II" "Sol/153591 2001 SN263" #1=
#2_"2008 153591 II" "Sol/153591 2001 SN263" #2=
#3_"2008 153591 II" "Sol/153591 2001 SN263" #3=
".:2008 153591 II" "Sol/153591 2001 SN263" #4=
{
	Class	"moon"
	Mesh	"2008 153591 II.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	0.23
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2454509.5  # 2008 Feb 13
		Period	0.686
		SemiMajorAxis	3.804
		Eccentricity	0.016
		Inclination	165.045
		AscendingNode	198.689
		ArgOfPericenter	292.435
		MeanAnomaly	248.816
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-153591.html"
}

#1_"2008 153591 I" "Sol/153591 2001 SN263" #1=
#2_"2008 153591 I" "Sol/153591 2001 SN263" #2=
#3_"2008 153591 I" "Sol/153591 2001 SN263" #3=
".:2008 153591 I" "Sol/153591 2001 SN263" #4=
{
	Class	"moon"
	Mesh	"2008 153591 I.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	0.53
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2454509.5  # 2008 Feb 13
		Period	6.225
		SemiMajorAxis	16.633
		Eccentricity	0.015
		Inclination	157.486
		AscendingNode	161.144
		ArgOfPericenter	131.249
		MeanAnomaly	212.658
	}
	LunarLambert	0.5
	Albedo	0.048
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-153591.html"
}

#1_"153814 2001 WN5:2001 WN5" "Sol" #1=
#2_"2001 WN5:153814 2001 WN5" "Sol" #2=
#3_"2001 WN5:153814 2001 WN5" "Sol" #3=
".:2001 WN5:153814 2001 WN5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.47
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.239369238734
		SemiMajorAxis	1.711637018442
		Eccentricity	0.467584449897
		Inclination	1.921672922321
		AscendingNode	277.614498419862
		ArgOfPericenter	44.424467932795
		MeanAnomaly	326.251868751136
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=153814"
}

#1_"160148 2001 KV76:2001 KV76" "Sol" #1=
#2_"2001 KV76:160148 2001 KV76" "Sol" #2=
#3_"2001 KV76:160148 2001 KV76" "Sol" #3=
".:2001 KV76:160148 2001 KV76" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	60.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	580.437589555563
		SemiMajorAxis	69.582210027193
		Eccentricity	0.505802858237
		Inclination	15.314510224789
		AscendingNode	39.605258966035
		ArgOfPericenter	228.770065012206
		MeanAnomaly	352.800688392756
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=160148"
}

#1_"161989 Cacus:Cacus:1978 CA" "Sol" #1=
#2_"*Какус:161989 Cacus:Cacus:1978 CA" "Sol" #2=
#3_"1978 CA:*Какус:161989 Cacus:Cacus" "Sol" #3=
".:Cacus:161989 Cacus:1978 CA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.95
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.190203448943
		SemiMajorAxis	1.123074762818
		Eccentricity	0.213943726586
		Inclination	26.060917658887
		AscendingNode	161.247059954823
		ArgOfPericenter	102.154218395515
		MeanAnomaly	237.272138554963
	}
	UniformRotation
	{
		Period	3.7538
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=161989"
}

#1_"162000 1990 OS:1990 OS" "Sol" #1=
#2_"1990 OS:162000 1990 OS" "Sol" #2=
#3_"1990 OS:162000 1990 OS" "Sol" #3=
".:1990 OS:162000 1990 OS" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.174249419219
		SemiMajorAxis	1.678291675051
		Eccentricity	0.462344524936
		Inclination	1.095110794504
		AscendingNode	346.635517539883
		ArgOfPericenter	21.416187726753
		MeanAnomaly	47.997006761075
	}
	UniformRotation
	{
		Period	2.536
	}
	LunarLambert	0.5
	Albedo	0.21
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=162000"
}

#1_"2003 162000 I" "Sol/162000 1990 OS" #1=
#2_"2003 162000 I" "Sol/162000 1990 OS" #2=
#3_"2003 162000 I" "Sol/162000 1990 OS" #3=
".:2003 162000 I" "Sol/162000 1990 OS" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.025
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.875
		SemiMajorAxis	0.6
	}
	LunarLambert	0.5
	Albedo	0.21
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-162000.html"
}

#1_"162058 1997 AE12:1997 AE12" "Sol" #1=
#2_"1997 AE12:162058 1997 AE12" "Sol" #2=
#3_"1997 AE12:162058 1997 AE12" "Sol" #3=
".:1997 AE12:162058 1997 AE12" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.579
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.646630178199
		SemiMajorAxis	2.369130658885
		Eccentricity	0.551700074654
		Inclination	4.89182250493
		AscendingNode	305.640853956771
		ArgOfPericenter	59.673791232388
		MeanAnomaly	27.105962761354
	}
	UniformRotation
	{
		Period	1880
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=162058"
}
###### New name
#1_"162173 Ryugu:Ryugu:1999 JU3" "Sol" #1=
#2_"*Рюгу:162173 Ryugu:Ryugu:1999 JU3" "Sol" #2=
#3_"1999 JU3:162173 Ryugu:Ryugu" "Sol" #3=
".:Ryugu:162173 Ryugu:1999 JU3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"162173 ryugu.cmod"
	Texture	"ryugu.dds"
	Radius	0.5
	Timeline
	[
		{
			Ending	2458296.5  # 2018 Jun 27
			EllipticalOrbit
			{
				Epoch	2458296.5  # 2018 Jun 27
				Period	1.29745085497172
				SemiMajorAxis	1.189565817713647
				Eccentricity	0.1902806628911246
				Inclination	5.884026432814216
				AscendingNode	251.5891564747533
				ArgOfPericenter	211.4360617387174
				MeanAnomaly	18.89663494681858
			}
			UniformRotation
			{
				Period	7.627
				Inclination	180
			}
		}
		{
			Ending	2458847.5  # 2019 Dec 30
			SampledTrajectory
			{
				Source	"162173 Ryugu-Hayabusa 2.xyzv"
				DoublePrecision	true
				Interpolation	"cubic"
			}
			UniformRotation
			{
				Period	7.627
				Inclination	180
			}
		}
		{
			EllipticalOrbit
			{
				Epoch	2458847.5  # 2019 Dec 30
				Period	1.29744030347096
				SemiMajorAxis	1.189559368286759
				Eccentricity	0.1903616668880864
				Inclination	5.884206232254718
				AscendingNode	251.586899798793
				ArgOfPericenter	211.4423367348706
				MeanAnomaly	77.45950275596302
			}
			UniformRotation
			{
				Period	7.627
				Inclination	180
			}
		}
	]
	LunarLambert	0.5
	Albedo	0.02
	InfoURL	"https://en.wikipedia.org/wiki/162173_Ryugu"
}

AltSurface "Topography" "Sol/162173 Ryugu"
{
	Texture	"ryugu-topo.dds"
	LunarLambert	0.5
}

#1_"162421 2000 ET70:2000 ET70" "Sol" #1=
#2_"2000 ET70:162421 2000 ET70" "Sol" #2=
#3_"2000 ET70:162421 2000 ET70" "Sol" #3=
".:2000 ET70:162421 2000 ET70" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"162421 2000 ET70.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	0.528
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	0.920980850087
		SemiMajorAxis	0.946589316348
		Eccentricity	0.123669209361
		Inclination	22.32462450654
		AscendingNode	331.159619161844
		ArgOfPericenter	46.087999376122
		MeanAnomaly	353.271844409468
	}
	UniformRotation
	{
		Period	8.947
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=162421"
}

#1_"163693 Atira:Atira:2003 CP20" "Sol" #1=
#2_"*Атира:163693 Atira:Atira:2003 CP20" "Sol" #2=
#3_"2003 CP20:*Атира:163693 Atira:Atira" "Sol" #3=
".:Atira:163693 Atira:2003 CP20" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	2.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.637957337843
		SemiMajorAxis	0.741063841214
		Eccentricity	0.32217028181
		Inclination	25.617859721004
		AscendingNode	103.922476222848
		ArgOfPericenter	252.933923085109
		MeanAnomaly	336.798084387897
	}
	UniformRotation
	{
		Period	2.9745
	}
	LunarLambert	0.5
	Albedo	0.022
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=163693"
}


#1_"2017 163693 I" "Sol/163693 Atira" #1=
#2_"2017 163693 I" "Sol/163693 Atira" #2=
#3_"2017 163693 I" "Sol/163693 Atira" #3=
".:2017 163693 I" "Sol/163693 Atira" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid.dds"
	Radius	0.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.646
		SemiMajorAxis	6
	}
	LunarLambert	0.5
	Albedo	0.022
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-163693.html"
}

#1_"168318 1989 DA:1989 DA" "Sol" #1=
#2_"1989 DA:168318 1989 DA" "Sol" #2=
#3_"1989 DA:168318 1989 DA" "Sol" #3=
".:1989 DA:168318 1989 DA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.45
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.179087534216
		SemiMajorAxis	2.162035675393
		Eccentricity	0.542942409951
		Inclination	6.493054312568
		AscendingNode	349.196575932805
		ArgOfPericenter	139.76791806924
		MeanAnomaly	46.988616367353
	}
	UniformRotation
	{
		Period	3.925
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=168318"
}

#1_"Varda-Ilmare" "Sol" #1=
#2_"*Варда-Ильмарэ:Varda-Ilmare" "Sol" #2=
#3_"Varda-Ilmare:*Варда-Ильмарэ" "Sol" #3=
".:Varda-Ilmare" "Sol" #4=

{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	558
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	311.92460834973


		SemiMajorAxis	45.993270310875
		Eccentricity	0.13989038875
		Inclination	21.495719802872
		AscendingNode	183.955157090336
		ArgOfPericenter	181.202844315792
		MeanAnomaly	270.690837140974
	}
	LunarLambert	0.5
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-174567.html"
}

#1_"174567 Varda:Varda:2003 MW12" "Sol/Varda-Ilmare" #1=
#2_"*Варда:174567 Varda:Varda:2003 MW12" "Sol/Varda-Ilmare" #2=
#3_"2003 MW12:*Варда:174567 Varda:Varda" "Sol/Varda-Ilmare" #3=
".:Varda:174567 Varda:2003 MW12" "Sol/Varda-Ilmare" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"varda.dds"
	BumpMap	"varda-bump.png"
	BumpHeight	5
	Radius	352.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	5.7508
		SemiMajorAxis	568
		Eccentricity	0.017
		ArgOfPericenter	180
	}
	UniformRotation
	{
		Period	5.91
	}
	LunarLambert	0.5
	Albedo	0.102
	InfoURL	"https://en.wikipedia.org/wiki/174567_Varda"
}

#1_"Ilmare:174567 Varda I:Varda I:2006 174567 I" "Sol/Varda-Ilmare" #1=
#2_"*Ильмарэ:Ilmare:174567 Varda I:*Варда I:Varda I:2006 174567 I" "Sol/Varda-Ilmare" #2=
#3_"2006 174567 I:*Ильмарэ:Ilmare:174567 Varda I:*Варда I:Varda I" "Sol/Varda-Ilmare" #3=
".:Ilmare:174567 Varda I:Varda I:2006 174567 I" "Sol/Varda-Ilmare" #4=

{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"varda.dds"
	Radius	180.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	5.7508
		SemiMajorAxis	4232
		Eccentricity	0.017
	}
	UniformRotation
	{
		Period	5.91
	}
	LunarLambert	0.5
	Albedo	0.102
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-174567.html"
}

#1_"175113 2004 PF115:2004 PF115" "Sol" #1=
#2_"2004 PF115:175113 2004 PF115" "Sol" #2=
#3_"2004 PF115:175113 2004 PF115" "Sol" #3=
".:2004 PF115:175113 2004 PF115" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Radius	203.15
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	242.004759399782
		SemiMajorAxis	38.833851890936
		Eccentricity	0.070715421045
		Inclination	13.362169350055
		AscendingNode	84.670521165779
		ArgOfPericenter	83.127362807039
		MeanAnomaly	164.944893309514
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.113
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=175113"
}

#1_"181708 1993 FW:1993 FW" "Sol" #1=
#2_"1993 FW:181708 1993 FW" "Sol" #2=
#3_"1993 FW:181708 1993 FW" "Sol" #3=
".:1993 FW:181708 1993 FW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.609 0.507 ]
	BlendTexture	true
	Radius	87.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	290.303370011245
		SemiMajorAxis	43.842561187537
		Eccentricity	0.050136297021
		Inclination	7.74051420421
		AscendingNode	187.866384573579
		ArgOfPericenter	39.963322064701
		MeanAnomaly	350.065586862188
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=181708"
}

#1_"181902 1999 RD215:1999 RD215" "Sol" #1=
#2_"1999 RD215:181902 1999 RD215" "Sol" #2=
#3_"1999 RD215:181902 1999 RD215" "Sol" #3=
".:1999 RD215:181902 1999 RD215" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1346.64704612088
		SemiMajorAxis	121.944922031793
		Eccentricity	0.691366075543
		Inclination	25.946314852174
		AscendingNode	210.309345880462
		ArgOfPericenter	138.303363713706
		MeanAnomaly	6.922770463881
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=181902"
}

#1_"184212 2004 PB112:2004 PB112" "Sol" #1=
#2_"2004 PB112:184212 2004 PB112" "Sol" #2=
#3_"2004 PB112:184212 2004 PB112" "Sol" #3=
".:2004 PB112:184212 2004 PB112" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	80
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1104.65415189398
		SemiMajorAxis	106.859240872557
		Eccentricity	0.669242489161
		Inclination	15.457002219799
		AscendingNode	356.809283054346
		ArgOfPericenter	3.842118261362
		MeanAnomaly	1.031744913956
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=184212"
}

#1_"185105 2006 SV23:2006 SV23" "Sol" #1=
#2_"2006 SV23:185105 2006 SV23" "Sol" #2=
#3_"2006 SV23:185105 2006 SV23" "Sol" #3=
".:2006 SV23:185105 2006 SV23" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.748
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	4.602221540841
		SemiMajorAxis	2.766768859933707
		Eccentricity	0.1529351287078979
		Inclination	12.97742572134231
		AscendingNode	22.04808479250988
		ArgOfPericenter	338.8921153107527
		MeanAnomaly	330.6300604719124
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=185105"
}

#1_"202421 2005 UQ513:2005 UQ513" "Sol" #1=
#2_"2005 UQ513:202421 2005 UQ513" "Sol" #2=
#3_"2005 UQ513:202421 2005 UQ513" "Sol" #3=
".:2005 UQ513:202421 2005 UQ513" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	249
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	284.892263079519
		SemiMajorAxis	43.296052536111
		Eccentricity	0.148767553769
		Inclination	25.736298047835
		AscendingNode	307.908691015783
		ArgOfPericenter	221.073278613123
		MeanAnomaly	223.425574098944
	}
	UniformRotation
	{
		Period	7.03
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=202421"
}

#1_"208996 2003 AZ84:2003 AZ84" "Sol" #1=
#2_"2003 AZ84:208996 2003 AZ84" "Sol" #2=
#3_"2003 AZ84:208996 2003 AZ84" "Sol" #3=
".:2003 AZ84:208996 2003 AZ84" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Radius	361.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	249.93086084504
		SemiMajorAxis	39.67720961425341
		Eccentricity	0.175004983176668
		Inclination	13.55364896948906
		AscendingNode	251.9826435352414
		ArgOfPericenter	13.82712555907433
		MeanAnomaly	227.6810749664907
	}
	UniformRotation
	{
		Period	13.44
	}
	LunarLambert	0.5
	Albedo	0.107
	InfoURL	"https://en.wikipedia.org/wiki/(208996)_2003_AZ84"
}

#1_"2005 208996 I" "Sol/208996 2003 AZ84" #1=
#2_"2005 208996 I" "Sol/208996 2003 AZ84" #2=
#3_"2005 208996 I" "Sol/208996 2003 AZ84" #3=
".:2005 208996 I" "Sol/208996 2003 AZ84" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	36
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	12
		SemiMajorAxis	7200
	}
	LunarLambert	0.5
	Albedo	0.107
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-208996.html"
}

#1_"217628 Lugh:Lugh:1990 HA" "Sol" #1=
#2_"*Луг:217628 Lugh:Lugh:1990 HA" "Sol" #2=
#3_"1990 HA:*Луг:217628 Lugh:Lugh" "Sol" #3=
".:Lugh:217628 Lugh:1990 HA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.071895764324
		SemiMajorAxis	2.549914585956
		Eccentricity	0.703560435691
		Inclination	4.022158053949
		AscendingNode	183.150423229185
		ArgOfPericenter	310.17826964027
		MeanAnomaly	8.403709673061
	}
	UniformRotation
	{
		Period	8.55
	}
	LunarLambert	0.5
	Albedo	0.27
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=217628"
}

#1_"225088 2007 OR10:2007 OR10" "Sol" #1=
#2_"2007 OR10:225088 2007 OR10" "Sol" #2=
#3_"2007 OR10:225088 2007 OR10" "Sol" #3=
".:2007 OR10:225088 2007 OR10" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"2007 OR10.dds"
	BumpMap	"2007 OR10-bump.png"
	BumpHeight	5
	Radius	767.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	550.193842856252
		SemiMajorAxis	67.143660749521
		Eccentricity	0.505774232246
		Inclination	30.867868535119
		AscendingNode	336.825782311384
		ArgOfPericenter	207.185147713379
		MeanAnomaly	104.57993524916
	}
	UniformRotation
	{
		Period	44.81
	}
	LunarLambert	0.5
	Albedo	0.089
	InfoURL	"https://en.wikipedia.org/wiki/(225088)_2007_OR10"
}

#1_"2010 225088 I" "Sol/(225088) 2007 OR10" #1=
#2_"2010 225088 I" "Sol/(225088) 2007 OR10" #2=
#3_"2010 225088 I" "Sol/(225088) 2007 OR10" #3=
".:2010 225088 I" "Sol/(225088) 2007 OR10" #4=
{
	Class	"moon"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"2007 OR10.dds"
	Radius	150
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	6
		SemiMajorAxis	15000
	}
	LunarLambert	0.5
	Albedo	0.089
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-225088.html"
}

#1_"229762 2007 UK126:2007 UK126" "Sol" #1=
#2_"2007 UK126:229762 2007 UK126" "Sol" #2=
#3_"2007 UK126:229762 2007 UK126" "Sol" #3=
".:2007 UK126:229762 2007 UK126" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Radius	295
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	636.715319959358
		SemiMajorAxis	74.010169385068
		Eccentricity	0.493023331887
		Inclination	23.33982668057
		AscendingNode	131.290079231636
		ArgOfPericenter	346.283083881174
		MeanAnomaly	342.318462350102
	}
	UniformRotation
	{
		Period	11.05
	}
	LunarLambert	0.5
	Albedo	0.167
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=229762"
}

#1_"2008 229762 I" "Sol/229762 2007 UK126" #1=
#2_"2008 229762 I" "Sol/229762 2007 UK126" #2=
#3_"2008 229762 I" "Sol/229762 2007 UK126" #3=
".:2008 229762 I" "Sol/229762 2007 UK126" #4=
{
	Class	"moon"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	51.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	5.9
		SemiMajorAxis	3600
	}
	LunarLambert	0.5
	Albedo	0.167
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-229762.html"
}

#1_"230965 2004 XA192:2004 XA192" "Sol" #1=
#2_"2004 XA192:230965 2004 XA192" "Sol" #2=
#3_"2004 XA192:230965 2004 XA192" "Sol" #3=
".:2004 XA192:230965 2004 XA192" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Mesh	"roughsphere.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	169.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	326.027313504606
		SemiMajorAxis	47.369324186511
		Eccentricity	0.251234574039
		Inclination	38.075194310509
		AscendingNode	328.756069915374
		ArgOfPericenter	132.364681630428
		MeanAnomaly	355.340912836301
	}
	UniformRotation
	{
		Period	7.88
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=230965"
}

#1_"245158 Thomasandrews:Thomasandrews:2004 TU18" "Sol" #1=
#2_"*Томасэндрюс:245158 Thomasandrews:Thomasandrews:2004 TU18" "Sol" #2=
#3_"2004 TU18:*Томасэндрюс:245158 Thomasandrews:Thomasandrews" "Sol" #3=
".:Thomasandrews:245158 Thomasandrews:2004 TU18" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.696
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.240212116058
		SemiMajorAxis	2.18966071269
		Eccentricity	0.231222156301
		Inclination	3.783379967839
		AscendingNode	292.09190281977
		ArgOfPericenter	34.302452153319
		MeanAnomaly	92.488367620248
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=245158"
}

#1_"255447 2005 YN24:2005 YN24" "Sol" #1=
#2_"2005 YN24:255447 2005 YN24" "Sol" #2=
#3_"2005 YN24:255447 2005 YN24" "Sol" #3=
".:2005 YN24:255447 2005 YN24" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	1.209
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	5.452931928733
		SemiMajorAxis	3.097998829359
		Eccentricity	0.116448465055
		Inclination	0.004689871375
		AscendingNode	263.137471940182
		ArgOfPericenter	261.555594298735
		MeanAnomaly	289.22425911009
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=255447"
}

#1_"274301 Wikipedia:Wikipedia:1997 RO4:2007 FK34:2008 QH24" "Sol" #1=
#2_"*Википедия:274301 Wikipedia:Wikipedia:1997 RO4:2008 QH24" "Sol" #2=
#3_"1997 RO4:*Википедия:274301 Wikipedia:Wikipedia:2008 QH24" "Sol" #3=
".:Wikipedia:274301 Wikipedia:1997 RO4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.75
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.6736229387969
		SemiMajorAxis	2.380807328140707
		Eccentricity	0.1471441538452252
		Inclination	6.734198372083918
		AscendingNode	183.4098644148427
		ArgOfPericenter	139.7289228207057
		MeanAnomaly	266.17973254268
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=274301"
}

#1_"276049 2002 CE26:2002 CE26" "Sol" #1=
#2_"2002 CE26:276049 2002 CE26" "Sol" #2=
#3_"2002 CE26:276049 2002 CE26" "Sol" #3=
".:2002 CE26:276049 2002 CE26" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"276049 2002 CE26.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	1.825
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.339538727226
		SemiMajorAxis	2.234183574503
		Eccentricity	0.559278408717
		Inclination	47.287834026251
		AscendingNode	161.925640716389
		ArgOfPericenter	228.062851768922
		MeanAnomaly	14.870044764343
	}
	UniformRotation
	{
		Period	3.2931
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=276049"
}

#1_"2004 276049 I" "Sol/276049 2002 CE26" #1=
#2_"2004 276049 I" "Sol/276049 2002 CE26" #2=
#3_"2004 276049 I" "Sol/276049 2002 CE26" #3=
".:2004 276049 I" "Sol/276049 2002 CE26" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.65
		SemiMajorAxis	4.7
		Eccentricity	0.02
		Inclination	22.5
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-276049.html"
}

#1_"278361 2007 JJ43:2007 JJ43" "Sol" #1=
#2_"2007 JJ43:278361 2007 JJ43" "Sol" #2=
#3_"2007 JJ43:278361 2007 JJ43" "Sol" #3=
".:2007 JJ43:278361 2007 JJ43" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	365
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	331.978024166492
		SemiMajorAxis	47.943980608652
		Eccentricity	0.157899836687
		Inclination	12.076152525091
		AscendingNode	272.475399234998
		ArgOfPericenter	7.352843941723
		MeanAnomaly	336.324253978643
	}
	UniformRotation
	{
		Period	6.04
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=278361"
}

#1_"297300 1998 SC15:1998 SC15" "Sol" #1=
#2_"1998 SC15:297300 1998 SC15" "Sol" #2=
#3_"1998 SC15:297300 1998 SC15" "Sol" #3=
".:1998 SC15:297300 1998 SC15" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.16
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.43607842965
		SemiMajorAxis	1.272858043049
		Eccentricity	0.414551641253
		Inclination	16.081452650565
		AscendingNode	198.75448460915
		ArgOfPericenter	277.406898537642
		MeanAnomaly	27.049799191876
	}
	UniformRotation
	{
		Period	15
	}
	LunarLambert	0.5
	Albedo	0.36
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=297300"
}

#New4
#1_"2006 VW139 System" "Sol" #1=
#2_"Система 2006 VW139:2006 VW139 System" "Sol" #2=
#3_"2006 VW139 System" "Sol" #3=
".:2006 VW139 System" "Sol" #4=
{
	Class	"asteroid"  # Барицентр
	# Class	"comet"
	Mesh	""
	Radius	12
	# Radius	1.8
	OrbitColor	[ 0.611765 0.317647 0.12549 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5.323662730267
		SemiMajorAxis	3.048841783714
		Eccentricity	0.201071589807
		Inclination	3.240216022712
		AscendingNode	83.186599437835
		ArgOfPericenter	281.004448415523
		MeanAnomaly	55.529428868998
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-300163.html"
}

#New4-Name
#1_"300163 2006 VW139:2006 VW139:288P" "Sol/2006 VW139 System" #1=
#2_"2006 VW139:300163 2006 VW139:288P" "Sol/2006 VW139 System" #2=
#3_"2006 VW139:300163 2006 VW139:288P" "Sol/2006 VW139 System" #3=
".:2006 VW139:300163 2006 VW139:288P" "Sol/2006 VW139 System" #4=
{
	Class	"asteroid" # Классифицируется и как комета
	Mesh	"asteroid-small.cmod"
	Texture	"comet.dds"
	Radius	0.9
	OrbitColor	[ 0.611765 0.317647 0.12549 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	140
		SemiMajorAxis	52
		Eccentricity	0.77
		ArgOfPericenter	180
	}
	UniformRotation
	{
		Period	3360
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=300163"
}

#New4
#1_"2011 300163 I:288P-B" "Sol/2006 VW139 System" #1=
#2_"2011 300163 I:288P-B" "Sol/2006 VW139 System" #2=
#3_"2011 300163 I:288P-B" "Sol/2006 VW139 System" #3=
".:2011 300163 I:288P-B" "Sol/2006 VW139 System" #4=
{
	Class	"asteroid"  # Классифицируется и как комета
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"comet.dds"
	Radius	0.9
	OrbitColor	[ 0.611765 0.317647 0.12549 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	140
		SemiMajorAxis	52
		Eccentricity	0.77
	}
	UniformRotation
	{
		Period	3360
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-300163.html"
}

#1_"301844 1990 UA:1990 UA:2009 FJ44" "Sol" #1=
#2_"1990 UA:301844 1990 UA" "Sol" #2=
#3_"1990 UA:301844 1990 UA" "Sol" #3=
".:1990 UA:301844 1990 UA:2009 FJ44" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.10518049231
		SemiMajorAxis	1.642558161461
		Eccentricity	0.526174846317
		Inclination	0.928248966452
		AscendingNode	104.245243403265
		ArgOfPericenter	202.584209903328
		MeanAnomaly	201.369923907643
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.16
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=301844"
}

#1_"301964 2000 EJ37:2000 EJ37:2000 GW5" "Sol" #1=
#2_"2000 EJ37:301964 2000 EJ37" "Sol" #2=
#3_"2000 EJ37:301964 2000 EJ37" "Sol" #3=
".:2000 EJ37:301964 2000 EJ37:2000 GW5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	5.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	9.971866906024
		SemiMajorAxis	4.632820931037
		Eccentricity	0.704706345112
		Inclination	10.055316635
		AscendingNode	178.440876913139
		ArgOfPericenter	115.660496361888
		MeanAnomaly	135.984228453696
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.069
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=301964"
}

#1_"303775 2005 QU182:2005 QU182" "Sol" #1=
#2_"2005 QU182:303775 2005 QU182" "Sol" #2=
#3_"2005 QU182:303775 2005 QU182" "Sol" #3=
".:2005 QU182:303775 2005 QU182" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Radius	208
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1165.77693426936
		SemiMajorAxis	110.765582904562
		Eccentricity	0.666898689872
		Inclination	14.024341019675
		AscendingNode	78.461379064241
		ArgOfPericenter	223.832389271697
		MeanAnomaly	13.446641904937
	}
	UniformRotation
	{
		Period	9.61
	}
	LunarLambert	0.5
	Albedo	0.328
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=303775"
}

#1_"305543 2008 QY40:2008 QY40" "Sol" #1=
#2_"2008 QY40:305543 2008 QY40" "Sol" #2=
#3_"2008 QY40:305543 2008 QY40" "Sol" #3=
".:2008 QY40:305543 2008 QY40" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	200.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	485.28531640355
		SemiMajorAxis	61.75317607109
		Eccentricity	0.404002207536
		Inclination	25.158000324647
		AscendingNode	43.209793103623
		ArgOfPericenter	332.055634816185
		MeanAnomaly	353.463876321668
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=305543"
}

#1_"307261 2002 MS4:2002 MS4" "Sol" #1=
#2_"2002 MS4:307261 2002 MS4" "Sol" #2=
#3_"2002 MS4:307261 2002 MS4" "Sol" #3=
".:2002 MS4:307261 2002 MS4" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	467
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	268.694387225093
		SemiMajorAxis	41.638997174947
		Eccentricity	0.146672780841
		Inclination	17.689326825563
		AscendingNode	216.043219403184
		ArgOfPericenter	215.613712674413
		MeanAnomaly	214.667830046244
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.051
	InfoURL	"https://en.wikipedia.org/wiki/(307261)_2002_MS4"
}

#1_"307616 2003 QW90:2003 QW90" "Sol" #1=
#2_"2003 QW90:307616 2003 QW90" "Sol" #2=
#3_"2003 QW90:307616 2003 QW90" "Sol" #3=
".:2003 QW90:307616 2003 QW90" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	183
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	288.922109861804
		SemiMajorAxis	43.703382399464
		Eccentricity	0.078454821724
		Inclination	10.375509507334
		AscendingNode	17.76121596514
		ArgOfPericenter	88.405794518185
		MeanAnomaly	275.387891380606
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=307616"
}

#1_"307982 2004 PG115:2004 PG115" "Sol" #1=
#2_"2004 PG115:307982 2004 PG115" "Sol" #2=
#3_"2004 PG115:307982 2004 PG115" "Sol" #3=
".:2004 PG115:307982 2004 PG115" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	230.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	844.27050859512
		SemiMajorAxis	89.326903165885
		Eccentricity	0.592579600577
		Inclination	16.280252586586
		AscendingNode	230.452789895996
		ArgOfPericenter	75.588868849146
		MeanAnomaly	4.970544769301
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=307982"
}

#1_"308193 2005 CB79:2005 CB79" "Sol" #1=
#2_"2005 CB79:308193 2005 CB79" "Sol" #2=
#3_"2005 CB79:308193 2005 CB79" "Sol" #3=
".:2005 CB79:308193 2005 CB79" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"haumeanfamily.dds"
	Radius	79
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	288.183234352244
		SemiMajorAxis	43.628840652977
		Eccentricity	0.14586773414
		Inclination	28.588899583255
		AscendingNode	112.758811212259
		ArgOfPericenter	89.877765276924
		MeanAnomaly	318.445342150022
	}
	UniformRotation
	{
		Period	6.76
	}
	LunarLambert	0.5
	Albedo	0.7
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=308193"
}

#1_"308635 2005 YU55:2005 YU55" "Sol" #1=
#2_"2005 YU55:308635 2005 YU55" "Sol" #2=
#3_"2005 YU55:308635 2005 YU55" "Sol" #3=
".:2005 YU55:308635 2005 YU55" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.180
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.245168113361
		SemiMajorAxis	1.157390355015
		Eccentricity	0.430609000564
		Inclination	0.340567365365
		AscendingNode	35.890417317674
		ArgOfPericenter	273.630320665973
		MeanAnomaly	218.579311139277
	}
	UniformRotation
	{
		Period	18
	}
	LunarLambert	0.5
	Albedo	0.042
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=308635"
}

#1_"308933 2006 SQ372:2006 SQ372" "Sol" #1=
#2_"2006 SQ372:308933 2006 SQ372" "Sol" #2=
#3_"2006 SQ372:308933 2006 SQ372" "Sol" #3=
".:2006 SQ372:308933 2006 SQ372" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	53
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	20229.3839326954
		SemiMajorAxis	742.419954953847
		Eccentricity	0.967447972053
		Inclination	19.482197022913
		AscendingNode	197.360470817409
		ArgOfPericenter	122.42081931513
		MeanAnomaly	0.148330983754
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=308933"
}

#1_"311999 2007 NS2:2007 NS2" "Sol" #1=
#2_"2007 NS2:311999 2007 NS2" "Sol" #2=
#3_"2007 NS2:311999 2007 NS2" "Sol" #3=
".:2007 NS2:311999 2007 NS2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.880975095202
		SemiMajorAxis	1.523759976442
		Eccentricity	0.054014072045
		Inclination	18.62132719199
		AscendingNode	282.497751056666
		ArgOfPericenter	176.83705786474
		MeanAnomaly	179.984182906281
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=311999"
}

#1_"315530 2008 AP129:2008 AP129" "Sol" #1=
#2_"2008 AP129:315530 2008 AP129" "Sol" #2=
#3_"2008 AP129:315530 2008 AP129" "Sol" #3=
".:2008 AP129:315530 2008 AP129" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	230.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	272.782235609211
		SemiMajorAxis	42.060256939514
		Eccentricity	0.142598987268
		Inclination	27.387830744501
		AscendingNode	14.972633341024
		ArgOfPericenter	59.762160605497
		MeanAnomaly	42.987189987269
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=315530"
}

#1_"323137 2003 BM80:2003 BM80:2003 FV112:282P" "Sol" #1=
#2_"2003 BM80:323137 2003 BM80:282P" "Sol" #2=
#3_"2003 BM80:323137 2003 BM80:282P" "Sol" #3=
".:2003 BM80:323137 2003 BM80:282P" "Sol" #4=
{
	Class	"asteroid"
	# Class "comet"  # Классифицируется и как комета
	Mesh	"asteroid-large.cmod"
	Texture	"comet.dds"
	Radius	1.83
	OrbitColor	[ 0.611765 0.317647 0.12549 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	8.76305476758
		SemiMajorAxis	4.250417090267
		Eccentricity	0.18907468983
		Inclination	5.810850517334
		AscendingNode	9.358834661476
		ArgOfPericenter	217.036614086769
		MeanAnomaly	145.385548865131
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=323137"
}

#1_"336756 2010 NV1:2010 NV1" "Sol" #1=
#2_"2010 NV1:336756 2010 NV1" "Sol" #2=
#3_"2010 NV1:336756 2010 NV1" "Sol" #3=
".:2010 NV1:336756 2010 NV1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	22
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5794.55851454231
		SemiMajorAxis	322.607728312608
		Eccentricity	0.970813294541
		Inclination	140.817880612088
		AscendingNode	136.197859813573
		ArgOfPericenter	132.950328298358
		MeanAnomaly	0.247533253962
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=336756"
}

#1_"Mors-Somnus" "Sol" #1=
#2_"*Мор-Сомн:Mors-Somnus" "Sol" #2=
#3_"Mors-Somnus:*Мор-Сомн" "Sol" #3=
".:Mors-Somnus" "Sol" #4=
{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	8414
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	245.906114891338
		SemiMajorAxis	39.25009847971
		Eccentricity	0.265248846503
		Inclination	11.291232915202
		AscendingNode	196.725561706546
		ArgOfPericenter	205.747858744005
		MeanAnomaly	356.233586916376
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-341520.html"
}

#1_"341520 Mors:Mors:2007 TY430" "Sol/Mors-Somnus" #1=
#2_"*Мор:341520 Mors:Mors:2007 TY430" "Sol/Mors-Somnus" #2=
#3_"2007 TY430:*Мор:341520 Mors:Mors" "Sol/Mors-Somnus" #3=
".:Mors:341520 Mors:2007 TY430" "Sol/Mors-Somnus" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	51
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Mors-Somnus" }
    }
	EllipticalOrbit
	{
		Period	971.7
		SemiMajorAxis	9890
		Eccentricity	0.1492
		Inclination	15.68
		ArgOfPericenter	180
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Mors-Somnus" }
    }
	UniformRotation
	{
		Period	9.28
		Inclination	15.68
	}
	LunarLambert	0.5
	Albedo	0.23
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=341520"
}

#1_"Somnus:341520 Mors I:Mors I:2007 341520 I" "Sol/Mors-Somnus" #1=
#2_"*Сомн:Somnus:341520 Mors I:*Мор I:Mors I:2007 341520 I" "Sol/Mors-Somnus" #2=
#3_"2007 341520 I:*Сомн:Somnus:341520 Mors I:*Мор I:Mors I" "Sol/Mors-Somnus" #3=
".:Somnus:341520 Mors I:Mors I:2007 341520 I" "Sol/Mors-Somnus" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	48.5
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Mors-Somnus" }
    }
	EllipticalOrbit
	{
		Period	971.7
		SemiMajorAxis	11150
		Eccentricity	0.1492
		Inclination	15.68
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Mors-Somnus" }
	}
	UniformRotation
	{
		Period	9.28
		Inclination	15.68
	}
	LunarLambert	0.5
	Albedo	0.23
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-341520.html"
}

#1_"341843 2008 EV5:2008 EV5" "Sol" #1=
#2_"2008 EV5:341843 2008 EV5" "Sol" #2=
#3_"2008 EV5:341843 2008 EV5" "Sol" #3=
".:2008 EV5:341843 2008 EV5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"341843 2008 EV5.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	0.225
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.938136105662
		SemiMajorAxis	0.958307967672
		Eccentricity	0.083577189398
		Inclination	7.436834536889
		AscendingNode	93.398923486685
		ArgOfPericenter	234.802826431667
		MeanAnomaly	242.931396453509
	}
	UniformRotation
	{
		Period	3.725
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=341843"
}

#1_"350513 2000 BG19:2000 BG19" "Sol" #1=
#2_"2000 BG19:350513 2000 BG19" "Sol" #2=
#3_"2000 BG19:350513 2000 BG19" "Sol" #3=
".:2000 BG19:350513 2000 BG19" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.885
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.333538899256
		SemiMajorAxis	2.658008291399
		Eccentricity	0.560626770254
		Inclination	12.574927994803
		AscendingNode	147.5819404287
		ArgOfPericenter	79.565714427212
		MeanAnomaly	123.791538854793
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.043
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=350513"
}

#1_"353222 2009 YD7:2009 YD7" "Sol" #1=
#2_"2009 YD7:353222 2009 YD7" "Sol" #2=
#3_"2009 YD7:353222 2009 YD7" "Sol" #3=
".:2009 YD7:353222 2009 YD7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	22
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1451.01804566339
		SemiMajorAxis	128.167055669214
		Eccentricity	0.89558296744
		Inclination	30.771406789004
		AscendingNode	126.094748786185
		ArgOfPericenter	326.827572038955
		MeanAnomaly	0.233977073235
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=353222"
}

#1_"357439 2004 BL86:2004 BL86" "Sol" #1=
#2_"2004 BL86:357439 2004 BL86" "Sol" #2=
#3_"2004 BL86:357439 2004 BL86" "Sol" #3=
".:2004 BL86:357439 2004 BL86" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.16
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.841199119448
		SemiMajorAxis	1.502202121005
		Eccentricity	0.403073151653
		Inclination	23.743573957492
		AscendingNode	126.720353168534
		ArgOfPericenter	311.254983378116
		MeanAnomaly	354.033057172678
	}
	UniformRotation
	{
		Period	2.6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=357439"
}

#1_"2015 357439 I" "Sol/357439 2004 BL86" #1=
#2_"2015 357439 I" "Sol/357439 2004 BL86" #2=
#3_"2015 357439 I" "Sol/357439 2004 BL86" #3=
".:2015 357439 I" "Sol/357439 2004 BL86" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.035
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.6
		SemiMajorAxis	0.5
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-357439.html"
}

#1_"360191 1988 TA:1988 TA" "Sol" #1=
#2_"1988 TA:360191 1988 TA" "Sol" #2=
#3_"1988 TA:360191 1988 TA" "Sol" #3=
".:1988 TA:360191 1988 TA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.910780214137
		SemiMajorAxis	1.539814324851
		Eccentricity	0.47860085317
		Inclination	2.530497258321
		AscendingNode	194.734976064099
		ArgOfPericenter	105.186155584027
		MeanAnomaly	272.606768031206
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=360191"
}

#1_"363135 2001 QQ199:2001 QQ199:1989 UL2:1989 VZ4" "Sol" #1=
#2_"2001 QQ199:363135 2001 QQ199" "Sol" #2=
#3_"2001 QQ199:363135 2001 QQ199" "Sol" #3=
".:2001 QQ199:363135 2001 QQ199" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	8.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	12.261636007567
		SemiMajorAxis	5.317328338849
		Eccentricity	0.431292635965
		Inclination	42.490175318134
		AscendingNode	213.084907630554
		ArgOfPericenter	193.165609459283
		MeanAnomaly	17.416719927766
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.059
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=363135"
}

#1_"367789 2011 AG5:2011 AG5" "Sol" #1=
#2_"2011 AG5:367789 2011 AG5" "Sol" #2=
#3_"2011 AG5:367789 2011 AG5" "Sol" #3=
".:2011 AG5:367789 2011 AG5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.07
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.711422710578
		SemiMajorAxis	1.430757591788
		Eccentricity	0.390211528799
		Inclination	3.68064666029
		AscendingNode	135.682980566514
		ArgOfPericenter	53.519300485252
		MeanAnomaly	60.809516745966
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=367789"
}

#1_"367943 Duende:Duende:2012 DA14" "Sol" #1=
#2_"*Дуэнде:367943 Duende:Duende:2012 DA14" "Sol" #2=
#3_"2012 DA14:*Дуэнде:367943 Duende:Duende" "Sol" #3=
".:Duende:367943 Duende:2012 DA14" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"367943 duende.cmod"
	Texture	"duende.jpg"
	Radius	0.02
	Visible	false
	Clickable	false
	Timeline
	[
		{
			Ending	2456293.5  # 2013 Jan 01
			EllipticalOrbit
			{
				Epoch	2456293.5  # 2013 Jan 01
				Period	1.002950878591512
				SemiMajorAxis	1.001953670522722
				Eccentricity	0.1082353726456081
				Inclination	10.3374808342006
				AscendingNode	147.2482152647928
				ArgOfPericenter	271.0669957574775
				MeanAnomaly	31.4221578237236
			}
			UniformRotation
			{
				Period	9.1
			}
		}
		{
			Ending	2456400.5  # 2013 Apr 18
			SampledOrbit	"Duende Earth flyby.xyzv"
			UniformRotation
			{
				Period	9.1
			}
		}
		{
			EllipticalOrbit
			{
				Epoch	2456400.5  # 2013 Apr 18
				Period	0.8685642697649971
				SemiMajorAxis	0.9103236763846146
				Eccentricity	0.0894002928958333
				Inclination	11.60809245040132
				AscendingNode	146.9957750699485
				ArgOfPericenter	195.535598519299
				MeanAnomaly	231.0967040638303
			}
			UniformRotation
			{
				Period	9.1
			}
		}
	]
	LunarLambert	0.5
	Albedo	0.44
	InfoURL	"https://en.wikipedia.org/wiki/367943_Duende"
}

#1_"385185 1993 RO:1993 RO" "Sol" #1=
#2_"1993 RO:385185 1993 RO" "Sol" #2=
#3_"1993 RO:385185 1993 RO" "Sol" #3=
".:1993 RO:385185 1993 RO" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	46
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	245.87526989184
		SemiMajorAxis	39.24681621192376
		Eccentricity	0.1970068774493703
		Inclination	3.717780468401911
		AscendingNode	170.372939058769
		ArgOfPericenter	188.9859926201195
		MeanAnomaly	24.89471119915283
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=385185"
}

#1_"385250 2001 DH47:2001 DH47" "Sol" #1=
#2_"2001 DH47:385250 2001 DH47" "Sol" #2=
#3_"2001 DH47:385250 2001 DH47" "Sol" #3=
".:2001 DH47:385250 2001 DH47" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.281
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.881072696296
		SemiMajorAxis	1.523812686462
		Eccentricity	0.034628799188
		Inclination	24.402060775768
		AscendingNode	147.422786586973
		ArgOfPericenter	17.48464780733
		MeanAnomaly	112.843491004834
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.275
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=385250"
}

#1_"385268 2001 RC12:2001 RC12" "Sol" #1=
#2_"2001 RC12:385268 2001 RC12" "Sol" #2=
#3_"2001 RC12:385268 2001 RC12" "Sol" #3=
".:2001 RC12:385268 2001 RC12" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.78218405347
		SemiMajorAxis	3.221482720842
		Eccentricity	0.639728227032
		Inclination	27.336135221906
		AscendingNode	208.924378973769
		ArgOfPericenter	185.459969273986
		MeanAnomaly	99.651121715136
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=385268"
}

#1_"Manwe-Thorondor" "Sol" #1=
#2_"*Манвэ-Торондор:Manwe-Thorondor" "Sol" #2=
#3_"Manwe-Thorondor:*Манвэ-Торондор" "Sol" #3=
".:Manwe-Thorondor" "Sol" #4=
{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	466
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	287.795397216125
		SemiMajorAxis	43.589688057866
		Eccentricity	0.114683913137
		Inclination	2.666615383328
		AscendingNode	68.527642335707
		ArgOfPericenter	21.581614404649
		MeanAnomaly	273.453508129914
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-385446.html"
}

#1_"385446 Manwe:Manwe:2003 QW111" "Sol/Manwe-Thorondor" #1=
#2_"*Манвэ:385446 Manwe:Manwe:2003 QW111" "Sol/Manwe-Thorondor" #2=
#3_"2003 QW111:*Манвэ:385446 Manwe:Manwe" "Sol/Manwe-Thorondor" #3=
".:Manwe:385446 Manwe:2003 QW111" "Sol/Manwe-Thorondor" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	80
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Manwe-Thorondor" }
    }
	EllipticalOrbit
	{
		Epoch	2454400.0  # 2007 Oct 26 12:00
		Period	110.176
		SemiMajorAxis	1066
		Eccentricity	0.5632
		Inclination	25.58
		AscendingNode	163.56
		ArgOfPericenter	70.8
		MeanAnomaly	126.51
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Manwe-Thorondor" }
    }
	UniformRotation
	{
		Period	2644.224
		Inclination	25.58
		AscendingNode	163.56
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=385446"
}

#1_"Thorondor:385446 Manwe I:Manwe I:2006 385446 I" "Sol/Manwe-Thorondor" #1=
#2_"*Торондор:Thorondor:385446 Manwe I:*Манвэ I:Manwe I:2006 385446 I" "Sol/Manwe-Thorondor" #2=
#3_"2006 385446 I:*Торондор:Thorondor:385446 Manwe I:*Манвэ I:Manwe I" "Sol/Manwe-Thorondor" #3=
".:2006 385446 I:*Торондор:Thorondor:385446 Manwe I:*Манвэ I:Manwe I" "Sol/Manwe-Thorondor" #4=

{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"asteroid-smooth.dds"
	Radius	46
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000	{ Center "Sol/Manwe-Thorondor" }
    }
	EllipticalOrbit
	{
		Epoch	2454400.0  # 2007 Oct 26 12:00
		Period	110.176
		SemiMajorAxis	5608
		Eccentricity	0.5632
		Inclination	25.58
		AscendingNode	163.56
		ArgOfPericenter	250.8
		MeanAnomaly	126.51
	}
	BodyFrame
	{
		EquatorJ2000	{ Center "Sol/Manwe-Thorondor" }
    }
	UniformRotation
	{
		Period	2644.224
		Inclination	25.58
		AscendingNode	163.56
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-385446.html"
}

#1_"385571 Otrera:Otrera:2004 UP10" "Sol" #1=
#2_"*Отрера:85571 Otrera:Otrera:2004 UP10" "Sol" #2=
#3_"2004 UP10:Otrera:*Отрера:85571 Otrera" "Sol" #3=
".:Otrera:85571 Otrera:2004 UP10" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	165.37047006501
		SemiMajorAxis	30.1277365996962
		Eccentricity	0.02689999028874916
		Inclination	1.434717221799064
		AscendingNode	34.75902479652976
		ArgOfPericenter	7.321797211531099
		MeanAnomaly	346.0081739233894
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=385571"
}

#1_"385695 2005 TO74:2005 TO74" "Sol" #1=
#2_"2005 TO74:385695 2005 TO74" "Sol" #2=
#3_"2005 TO74:385695 2005 TO74" "Sol" #3=
".:2005 TO74:385695 2005 TO74" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	165.32983400684
		SemiMajorAxis	30.12280092364857
		Eccentricity	0.05462057700436393
		Inclination	5.258146713122516
		AscendingNode	169.4478082636072
		ArgOfPericenter	305.2708286985734
		MeanAnomaly	278.7586267602533
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=385695"
}

#1_"386723 2009 YE7:2009 YE7" "Sol" #1=
#2_"2009 YE7:386723 2009 YE7" "Sol" #2=
#3_"2009 YE7:386723 2009 YE7" "Sol" #3=
".:2009 YE7:386723 2009 YE7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"haumeanfamily.dds"
	Radius	100
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	295.934344068833
		SemiMajorAxis	44.407682710432
		Eccentricity	0.141552198336
		Inclination	29.078892914185
		AscendingNode	141.727803692064
		ArgOfPericenter	99.071087737857
		MeanAnomaly	179.530828292858
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.7
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=386723"
}

#1_"391211 2006 HZ51:2006 HZ51" "Sol" #1=
#2_"2006 HZ51:391211 2006 HZ51" "Sol" #2=
#3_"2006 HZ51:391211 2006 HZ51" "Sol" #3=
".:2006 HZ51:391211 2006 HZ51" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.400
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.6128356003825
		SemiMajorAxis	1.89700840458625
		Eccentricity	0.4502953743306538
		Inclination	12.41558790209681
		AscendingNode	84.31787292808959
		ArgOfPericenter	193.3474156234173
		MeanAnomaly	69.36414227597766
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=391211"
}

#1_"401857 2000 PG3:2000 PG3" "Sol" #1=
#2_"2000 PG3:401857 2000 PG3" "Sol" #2=
#3_"2000 PG3:401857 2000 PG3" "Sol" #3=
".:2000 PG3:401857 2000 PG3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	2.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.74330400191
		SemiMajorAxis	2.823027909035
		Eccentricity	0.855931128055
		Inclination	22.011370662842
		AscendingNode	323.621305574907
		ArgOfPericenter	141.151375176456
		MeanAnomaly	337.503848352787
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.046
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=401857"
}

#1_"405058 2001 TX16:2001 TX16" "Sol" #1=
#2_"2001 TX16:405058 2001 TX16" "Sol" #2=
#3_"2001 TX16:405058 2001 TX16" "Sol" #3=
".:2001 TX16:405058 2001 TX16" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.775768422199
		SemiMajorAxis	3.580691468723
		Eccentricity	0.59818635409
		Inclination	8.137989043501
		AscendingNode	69.486713431369
		ArgOfPericenter	53.384184583617
		MeanAnomaly	323.601197841981
	}
	UniformRotation
	{
		Period	4.8005
	}
	LunarLambert	0.5
	Albedo	0.181
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=405058"
}

#1_"410777 2009 FD:2009 FD" "Sol" #1=
#2_"2009 FD:410777 2009 FD" "Sol" #2=
#3_"2009 FD:410777 2009 FD" "Sol" #3=
".:2009 FD:410777 2009 FD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"2009 FD.dds"
	Radius	0.075
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.254465722528
		SemiMajorAxis	1.16314465993
		Eccentricity	0.493011018742
		Inclination	3.136242738471
		AscendingNode	9.482690264815
		ArgOfPericenter	281.301550416621
		MeanAnomaly	150.372073510951
	}
	UniformRotation
	{
		Period	4
	}
	LunarLambert	0.5
	Albedo	0.01
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=410777"
}

#1_"2015 410777 I" "Sol/410777 2009 FD" #1=
#2_"2015 410777 I" "Sol/410777 2009 FD" #2=
#3_"2015 410777 I" "Sol/410777 2009 FD" #3=
".:2015 410777 I" "Sol/410777 2009 FD" #4=
{
	Class	"moon"
	Mesh	"asteroid-small.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"2009 FD.dds"
	Radius	0.045
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Period	0.6
		SemiMajorAxis	0.25
	}
	LunarLambert	0.5
	Albedo	0.01
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am-410777.html"
}

#1_"416400 2003 UZ117:2003 UZ117" "Sol" #1=
#2_"2003 UZ117:416400 2003 UZ117" "Sol" #2=
#3_"2003 UZ117:416400 2003 UZ117" "Sol" #3=
".:2003 UZ117:416400 2003 UZ117" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"haumeanfamily.dds"
	Radius	200.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	295.440197839786
		SemiMajorAxis	44.358234804498
		Eccentricity	0.135979420804
		Inclination	27.439025002405
		AscendingNode	204.664446980112
		ArgOfPericenter	246.888044581981
		MeanAnomaly	337.324450672436
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.7
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=416400"
}

#1_"418265 2008 EA32:2008 EA32" "Sol" #1=
#2_"2008 EA32:418265 2008 EA32" "Sol" #2=
#3_"2008 EA32:418265 2008 EA32" "Sol" #3=
".:2008 EA32:418265 2008 EA32" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.053
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.483415290896
		SemiMajorAxis	0.615944319207
		Eccentricity	0.304943312373
		Inclination	28.264974234571
		AscendingNode	100.970418190116
		ArgOfPericenter	181.854612670448
		MeanAnomaly	216.53350989399
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=418265"
}

#1_"418993 2009 MS9:2009 MS9" "Sol" #1=
#2_"2009 MS9:418993 2009 MS9" "Sol" #2=
#3_"2009 MS9:418993 2009 MS9" "Sol" #3=
".:2009 MS9:418993 2009 MS9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	23
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6535.900690328
		SemiMajorAxis	349.5678592731666
		Eccentricity	0.9685235109246424
		Inclination	68.03036379494537
		AscendingNode	220.2361486214805
		ArgOfPericenter	128.6960357895334
		MeanAnomaly	0.100110440908546
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=418993"
}

#1_"419624 2010 SO16:2010 SO16" "Sol" #1=
#2_"2010 SO16:419624 2010 SO16" "Sol" #2=
#3_"2010 SO16:419624 2010 SO16" "Sol" #3=
".:2010 SO16:419624 2010 SO16" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.0030874729
		SemiMajorAxis	1.002044640789
		Eccentricity	0.075329275855
		Inclination	14.524292412559
		AscendingNode	40.437086756671
		ArgOfPericenter	108.73222447996
		MeanAnomaly	271.53644886586
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.12
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=419624"
}

#1_"434620 2005 VD:2005 VD" "Sol" #1=
#2_"2005 VD:434620 2005 VD" "Sol" #2=
#3_"2005 VD:434620 2005 VD" "Sol" #3=
".:2005 VD:434620 2005 VD" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	4.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	17.196438136353
		SemiMajorAxis	6.662238864569
		Eccentricity	0.251555495436
		Inclination	172.865527129458
		AscendingNode	173.264022609487
		ArgOfPericenter	178.884004323376
		MeanAnomaly	181.98405712399
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=434620"
}

#1_"437360 2013 TV158:2013 TV158" "Sol" #1=
#2_"2013 TV158:437360 2013 TV158" "Sol" #2=
#3_"2013 TV158:437360 2013 TV158" "Sol" #3=
".:2013 TV158:437360 2013 TV158" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	121
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1182.2999807203
		SemiMajorAxis	111.80974409802
		Eccentricity	0.6739665595474088
		Inclination	31.17392806905228
		AscendingNode	181.1208149696198
		ArgOfPericenter	232.2563899943668
		MeanAnomaly	357.6565798162086
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=437360"
}

#1_"468861 2013 LU28:2013 LU28:2014 LJ9:2015 KB157" "Sol" #1=
#2_"2013 LU28:468861 2013 LU28" "Sol" #2=
#3_"2013 LU28:468861 2013 LU28" "Sol" #3=
".:2013 LU28:468861 2013 LU28" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2257.4329183116
		SemiMajorAxis	172.0829203333133
		Eccentricity	0.9491602521483892
		Inclination	125.4076607409372
		AscendingNode	276.1120603341421
		ArgOfPericenter	153.1262598240647
		MeanAnomaly	358.477078143434
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=468861"
}

#1_"469219 2016 HO3:2016 HO3" "Sol" #1=
#2_"2016 HO3:469219 2016 HO3" "Sol" #2=
#3_"2016 HO3:469219 2016 HO3" "Sol" #3=
".:2016 HO3:469219 2016 HO3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.035
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	1.001864390966
		SemiMajorAxis	1.001229934908
		Eccentricity	0.104142909298
		Inclination	7.77139561765
		AscendingNode	66.513257981625
		ArgOfPericenter	307.227651638961
		MeanAnomaly	297.532105913738
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=469219"
}

#1_"474640 2004 VN112:2004 VN112" "Sol" #1=
#2_"2004 VN112:474640 2004 VN112" "Sol" #2=
#3_"2004 VN112:474640 2004 VN112" "Sol" #3=
".:2004 VN112:474640 2004 VN112" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	111
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5601.39641722066
		SemiMajorAxis	315.397856896431
		Eccentricity	0.849986242919
		Inclination	25.592703902187
		AscendingNode	65.982100500607
		ArgOfPericenter	326.990576992077
		MeanAnomaly	0.519050100416
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=474640"
}

#1_"486958 2014 MU69:2014 MU69:1110113Y:PT1" "Sol" #1=
#2_"486958 2014 MU69:2014 MU69:1110113Y:PT1" "Sol" #2=
#3_"2014 MU69:486958 2014 MU69:1110113Y:PT1" "Sol" #3=
".:486958:2014 MU69:486958 2014 MU69:1110113Y:PT1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"486958 2014 MU69.cmod"
	Orientation	[ 90 0 1 0 ]
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.609 0.507 ]
	BlendTexture	true
	Radius	17.112
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458600.5  # 2019 Apr 27
		Period	297.67
		SemiMajorAxis	44.5813998
		Eccentricity	0.0417249
		Inclination	2.45116
		AscendingNode	158.99773
		ArgOfPericenter	174.41771
		MeanAnomaly	316.55086
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.095
	InfoURL	"https://en.wikipedia.org/wiki/(486958)_2014_MU69"
}

#1_"514107 2015 BZ509:2015 BZ509:Bee-Zed" "Sol" #1=
#2_"*Би-Зет:514107 Bee-Zed:2015 BZ509" "Sol" #2=
#3_"2015 BZ509:Bee-Zed:514107 Bee-Zed" "Sol" #3=
".:Bee-Zed:514107 Bee-Zed:2015 BZ509" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	1.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458200.5  # 2018 Mar 23
		Period	11.644756450554
		SemiMajorAxis	5.137456271383
		Eccentricity	0.380542214435
		Inclination	163.000545716926
		AscendingNode	307.380235395089
		ArgOfPericenter	257.380294765841
		MeanAnomaly	66.37542122095
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"https://en.wikipedia.org/wiki/(514107)_2015_BZ509"
}


#1_"1989 UP" "Sol" #1=
#2_"1989 UP" "Sol" #2=
#3_"1989 UP" "Sol" #3=
".:1989 UP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.545658854098
		SemiMajorAxis	1.864352375854
		Eccentricity	0.472623258466
		Inclination	3.856131407668
		AscendingNode	53.263111165166
		ArgOfPericenter	17.570386376216
		MeanAnomaly	300.495888653835
	}
	UniformRotation
	{
		Period	6.98
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1989+UP"
}

#1_"1989 VB" "Sol" #1=
#2_"1989 VB" "Sol" #2=
#3_"1989 VB" "Sol" #3=
".:1989 VB" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.543395612438
		SemiMajorAxis	1.86324719885
		Eccentricity	0.460360861872
		Inclination	2.131636329449
		AscendingNode	38.852585135266
		ArgOfPericenter	329.786933735957
		MeanAnomaly	322.060003405426
	}
	UniformRotation
	{
		Period	16
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1989+VB"
}

#1_"1990 UP" "Sol" #1=
#2_"1990 UP" "Sol" #2=
#3_"1990 UP" "Sol" #3=
".:1990 UP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.533324644377
		SemiMajorAxis	1.329690632181
		Eccentricity	0.170754432204
		Inclination	28.218050682279
		AscendingNode	33.216887355761
		ArgOfPericenter	294.204043104712
		MeanAnomaly	311.445401055624
	}
	UniformRotation
	{
		Period	20
	}
	LunarLambert	0.5
	Albedo	0.14
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1990+UP"
}

#1_"1993 RP" "Sol" #1=
#2_"1993 RP" "Sol" #2=
#3_"1993 RP" "Sol" #3=
".:1993 RP" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2449246.5  # 1993 Sept 16
		Period	246.649465146708
		SemiMajorAxis	39.329158166913
		Eccentricity	0.113552190982
		Inclination	2.570458109528
		AscendingNode	192.090284427736
		ArgOfPericenter	180.63140495229
		MeanAnomaly	0.009472327108
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1993+RP"
}

#1_"1994 XM1" "Sol" #1=
#2_"1994 XM1" "Sol" #2=
#3_"1994 XM1" "Sol" #3=
".:1994 XM1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.0075
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2449695.5  # 1994 Dec 09
		Period	2.840537979629
		SemiMajorAxis	2.005679791679
		Eccentricity	0.553079282968
		Inclination	5.62169257321
		AscendingNode	77.149095458677
		ArgOfPericenter	42.001634501795
		MeanAnomaly	349.085960493495
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1994+XM1"
}

#1_"1995 GJ" "Sol" #1=
#2_"1995 GJ" "Sol" #2=
#3_"1995 GJ" "Sol" #3=
".:1995 GJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	87.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2449811.5  # 1995 Apr 04
		Period	281.022285691608
		SemiMajorAxis	42.903070302397
		Eccentricity	0.090825220742
		Inclination	22.931398268659
		AscendingNode	338.928932027629
		ArgOfPericenter	180.290518939469
		MeanAnomaly	0.003724916616
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1995+GJ"
}

#1_"1996 PW" "Sol" #1=
#2_"1996 PW" "Sol" #2=
#3_"1996 PW" "Sol" #3=
".:1996 PW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	7.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4285.86621829863
		SemiMajorAxis	263.847877899857
		Eccentricity	0.990317554494
		Inclination	29.686351742767
		AscendingNode	144.652033323755
		ArgOfPericenter	181.763226822607
		MeanAnomaly	1.542263331232
	}
	UniformRotation
	{
		Period	35.44
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1996+PW"
}

#1_"1997 SZ10" "Sol" #1=
#2_"1997 SZ10" "Sol" #2=
#3_"1997 SZ10" "Sol" #3=
".:1997 SZ10" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	331.754892572473
		SemiMajorAxis	47.922495219501
		Eccentricity	0.362376239814
		Inclination	11.810150026314
		AscendingNode	9.495206438636
		ArgOfPericenter	341.972191727621
		MeanAnomaly	27.996154219058
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1997+SZ10"
}

#1_"1998 KY26" "Sol" #1=
#2_"1998 KY26" "Sol" #2=
#3_"1998 KY26" "Sol" #3=
".:1998 KY26" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"1998 KY26.cmod"
	MeshCenter	[ -0.000718 -0.000099 0.000556 ]
	Texture	"1998 KY26.jpg"
	Radius	0.015
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.368899121085
		SemiMajorAxis	1.232845993843401
		Eccentricity	0.2019176893830575
		Inclination	1.48044409000416
		AscendingNode	84.36214896718073
		ArgOfPericenter	209.3725697026434
		MeanAnomaly	359.5729719228407
	}
	UniformRotation
	{
		Period	0.1784
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1998+KY26"
}

#1_"1998 WW31 System" "Sol" #1=
#2_"*Система 1998 WW31:1998 WW31 System" "Sol" #2=
#3_"1998 WW31 System:*Система 1998 WW31" "Sol" #3=
".:1998 WW31 System" "Sol" #4=
{
	Class	"asteroid"  # Барицентр
	Mesh	""
	Radius	1493
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	299.49848629776646
		SemiMajorAxis	44.76352579065019
		Eccentricity	0.08283917190609871
		Inclination	6.794733295270969
		AscendingNode	237.0905583202673
		ArgOfPericenter	51.82578585086611
		MeanAnomaly	135.202910379568
	}
	Albedo	0
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am1998ww31.html"
}

#1_"1998 WW31" "Sol/1998 WW31 System" #1=
#2_"1998 WW31" "Sol/1998 WW31 System" #2=
#3_"1998 WW31" "Sol/1998 WW31 System" #3=
".:1998 WW31" "Sol/1998 WW31 System" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	74
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000 { Center "Sol/1998 WW31 System" }
    }
	EllipticalOrbit
	{
		Epoch	2452300.5  # 2002 Jan 26
		Period	587.3
		SemiMajorAxis	8249
		Eccentricity	0.819
		Inclination	41.4
		AscendingNode	94.6
		ArgOfPericenter	168.5
		MeanAnomaly	30.8
	}
	BodyFrame
	{
		EquatorJ2000 { Center "Sol/1998 WW31 System" }
    }
	UniformRotation
	{
		Period	14095.2
		Inclination	41.4
		AscendingNode	94.6
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1998+WW31"
}

#1_"2000 1998 WW31 I" "Sol/1998 WW31 System" #1=
#2_"2000 1998 WW31 I" "Sol/1998 WW31 System" #2=
#3_"2000 1998 WW31 I" "Sol/1998 WW31 System" #3=
".:2000 1998 WW31 I" "Sol/1998 WW31 System" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Orientation	[ 180 1 0 0 ]
	Texture	"darkasteroid-smooth.dds"
	Radius	61.5
	Visible	false
	Clickable	false
	OrbitFrame
	{
		EquatorJ2000 { Center "Sol/1998 WW31 System" }
    }
	EllipticalOrbit
	{
		Epoch	2452300.5  # 2002 Jan 26
		Period	587.3
		SemiMajorAxis	14371
		Eccentricity	0.819
		Inclination	41.4
		AscendingNode	94.6
		ArgOfPericenter	348.5
		MeanAnomaly	30.8
	}
	BodyFrame
	{
		EquatorJ2000 { Center "Sol/1998 WW31 System" }
    }
	UniformRotation
	{
		Period	14095.2
		Inclination	41.4
		AscendingNode	94.6
	}
	LunarLambert	0.5
	Albedo	0.07
	InfoURL	"http://www.johnstonsarchive.net/astro/astmoons/am1998ww31.html"
}

#1_"1999 CD158" "Sol" #1=
#2_"1999 CD158" "Sol" #2=
#3_"1999 CD158" "Sol" #3=
".:1999 CD158" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	210
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	290.868038659909
		SemiMajorAxis	43.899394839552
		Eccentricity	0.141226419233
		Inclination	25.416481444426
		AscendingNode	118.976199010426
		ArgOfPericenter	142.908313236622
		MeanAnomaly	247.387034591019
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1999+CD158"
}

#1_"1999 CF119" "Sol" #1=
#2_"1999 CF119" "Sol" #2=
#3_"1999 CF119" "Sol" #3=
".:1999 CF119" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	858.210778879992
		SemiMajorAxis	90.307504561113
		Eccentricity	0.571382027664
		Inclination	19.680667912199
		AscendingNode	303.40116459671
		ArgOfPericenter	200.057181200011
		MeanAnomaly	1.748053251748
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1999+CF119"
}

#1_"1999 CL119" "Sol" #1=
#2_"1999 CL119" "Sol" #2=
#3_"1999 CL119" "Sol" #3=
".:1999 CL119" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	139
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	324.067348125161
		SemiMajorAxis	47.179287945822
		Eccentricity	0.012015758261
		Inclination	23.241387367715
		AscendingNode	125.121283442642
		ArgOfPericenter	44.013210024457
		MeanAnomaly	335.965866157584
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1999+CL119"
}

#1_"1999 CY118" "Sol" #1=
#2_"1999 CY118" "Sol" #2=
#3_"1999 CY118" "Sol" #3=
".:1999 CY118" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	875.516117500155
		SemiMajorAxis	91.517460854306
		Eccentricity	0.621923781472
		Inclination	25.550973612708
		AscendingNode	163.075044365609
		ArgOfPericenter	15.125579664362
		MeanAnomaly	3.766984075971
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1999+CY118"
}

#1_"1999 CZ118" "Sol" #1=
#2_"1999 CZ118" "Sol" #2=
#3_"1999 CZ118" "Sol" #3=
".:1999 CZ118" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1288.96810336228
		SemiMajorAxis	118.437521954363
		Eccentricity	0.68306063237
		Inclination	27.714844008537
		AscendingNode	345.139513332119
		ArgOfPericenter	236.310569693128
		MeanAnomaly	355.394006869506
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1999+CZ118"
}

#1_"1999 DG8" "Sol" #1=
#2_"1999 DG8" "Sol" #2=
#3_"1999 DG8" "Sol" #3=
".:1999 DG8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	53
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2451226.5  # 1999 Feb 17
		Period	745.584297707965
		SemiMajorAxis	82.222819898044
		Eccentricity	0.598495736997
		Inclination	39.995523018781
		AscendingNode	322.95901121981
		ArgOfPericenter	72.751634037186
		MeanAnomaly	33.55333108864
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1999+DG8"
}

#1_"1999 DP8" "Sol" #1=
#2_"1999 DP8" "Sol" #2=
#3_"1999 DP8" "Sol" #3=
".:1999 DP8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2451226.5  # 1999 Feb 17
		Period	1245.70924558878
		SemiMajorAxis	115.77256542455
		Eccentricity	0.699919092851
		Inclination	38.405863172961
		AscendingNode	136.921884492043
		ArgOfPericenter	283.453948909822
		MeanAnomaly	13.890715123265
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1999+DP8"
}

#1_"1999 LE31" "Sol" #1=
#2_"1999 LE31" "Sol" #2=
#3_"1999 LE31" "Sol" #3=
".:1999 LE31" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	8.4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	23.19208795676
		SemiMajorAxis	8.132444312635
		Eccentricity	0.467596005029
		Inclination	151.806793416692
		AscendingNode	291.991470461887
		ArgOfPericenter	32.158679488062
		MeanAnomaly	248.987857689689
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.056
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1999+LE31"
}

#1_"1999 RZ214" "Sol" #1=
#2_"1999 RZ214" "Sol" #2=
#3_"1999 RZ214" "Sol" #3=
".:1999 RZ214" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	60.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	774.607370010077
		SemiMajorAxis	84.342981345134
		Eccentricity	0.564472133122
		Inclination	20.507315876796
		AscendingNode	214.507881028035
		ArgOfPericenter	114.462409039241
		MeanAnomaly	16.661364403504
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=1999+RZ214"
}

#1_"2000 AB229" "Sol" #1=
#2_"2000 AB229" "Sol" #2=
#3_"2000 AB229" "Sol" #3=
".:2000 AB229" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	3.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	381.198164269558
		SemiMajorAxis	52.572875568252
		Eccentricity	0.956401900485
		Inclination	68.877011731299
		AscendingNode	313.863648709398
		ArgOfPericenter	171.889181973509
		MeanAnomaly	14.155315215384
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2000+AB229"
}

#1_"2000 CP105" "Sol" #1=
#2_"2000 CP105" "Sol" #2=
#3_"2000 CP105" "Sol" #3=
".:2000 CP105" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	63.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2451590.5  # 2000 Feb 16
		Period	758.683126344538
		SemiMajorAxis	83.183045219757
		Eccentricity	0.585519140177
		Inclination	19.424933367101
		AscendingNode	133.139827974726
		ArgOfPericenter	1.851640414593
		MeanAnomaly	359.70129665493
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2000+CP105"
}

#1_"2000 DG8" "Sol" #1=
#2_"2000 DG8" "Sol" #2=
#3_"2000 DG8" "Sol" #3=
".:2000 DG8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	7.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	35.340099814474
		SemiMajorAxis	10.768942209125
		Eccentricity	0.792982456292
		Inclination	129.478385489378
		AscendingNode	279.239348262759
		ArgOfPericenter	222.302886727437
		MeanAnomaly	141.659913099936
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.053
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2000+DG8"
}

#1_"2000 HE46" "Sol" #1=
#2_"2000 HE46" "Sol" #2=
#3_"2000 HE46" "Sol" #3=
".:2000 HE46" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	3.2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	114.138109519128
		SemiMajorAxis	23.529623705405
		Eccentricity	0.899972525431
		Inclination	158.448358935018
		AscendingNode	313.124315997766
		ArgOfPericenter	82.038975557089
		MeanAnomaly	46.432614922652
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2000+HE46"
}

#1_"2000 KP65" "Sol" #1=
#2_"2000 KP65" "Sol" #2=
#3_"2000 KP65" "Sol" #3=
".:2000 KP65" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	17.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	836.947371874738
		SemiMajorAxis	88.809610456871
		Eccentricity	0.963295674284
		Inclination	45.623370222101
		AscendingNode	223.627331290363
		ArgOfPericenter	321.986391126674
		MeanAnomaly	6.69159388568
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2000+KP65"
}

#1_"2000 PF30:1999 OL4" "Sol" #1=
#2_"2000 PF30" "Sol" #2=
#3_"2000 PF30" "Sol" #3=
".:2000 PF30" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	661.618232200635
		SemiMajorAxis	75.927571282234
		Eccentricity	0.501220837605
		Inclination	6.321290989338
		AscendingNode	293.746144326196
		ArgOfPericenter	336.96729042441
		MeanAnomaly	17.822562066407
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2000+PF30"
}

#1_"2000 PH30" "Sol" #1=
#2_"2000 PH30" "Sol" #2=
#3_"2000 PH30" "Sol" #3=
".:2000 PH30" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	60.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	665.948592793637
		SemiMajorAxis	76.258513529643
		Eccentricity	0.498098501089
		Inclination	8.070372893658
		AscendingNode	127.252175566578
		ArgOfPericenter	241.866714682734
		MeanAnomaly	345.982020994797
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2000+PH30"
}

#1_"2000 SB1" "Sol" #1=
#2_"2000 SB1" "Sol" #2=
#3_"2000 SB1" "Sol" #3=
".:2000 SB1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	2.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	6.102998603239
		SemiMajorAxis	3.339566112764
		Eccentricity	0.540907622397
		Inclination	22.181467449287
		AscendingNode	277.002627778677
		ArgOfPericenter	145.172826977462
		MeanAnomaly	105.855759823759
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.056
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2000+SB1"
}

#1_"2000 SQ331" "Sol" #1=
#2_"2000 SQ331" "Sol" #2=
#3_"2000 SQ331" "Sol" #3=
".:2000 SQ331" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	16
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2451811.5  # 2000 Sept 24
		Period	583.268823899073
		SemiMajorAxis	69.808296617191
		Eccentricity	0.706731845641
		Inclination	5.436712368
		AscendingNode	86.003787012661
		ArgOfPericenter	332.542685090102
		MeanAnomaly	0.000648262888
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2000+SQ331"
}

#1_"2000 YY1" "Sol" #1=
#2_"2000 YY1" "Sol" #2=
#3_"2000 YY1" "Sol" #3=
".:2000 YY1" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	83.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	515.12992341308
		SemiMajorAxis	64.259752829847
		Eccentricity	0.536575555654
		Inclination	7.868500371312
		AscendingNode	209.712580302977
		ArgOfPericenter	292.491289791442
		MeanAnomaly	340.503253134483
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2000+YY1"
}

#1_"2001 FK194" "Sol" #1=
#2_"2001 FK194" "Sol" #2=
#3_"2001 FK194" "Sol" #3=
".:2001 FK194" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2451994.5  # 2001 Mar 26
		Period	667.158157899917
		SemiMajorAxis	76.350824696
		Eccentricity	0.63313588066
		Inclination	8.816166200231
		AscendingNode	182.559616865448
		ArgOfPericenter	358.484901686704
		MeanAnomaly	0.005818426887
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2001+FK194"
}

#1_"2001 FN194" "Sol" #1=
#2_"2001 FN194" "Sol" #2=
#3_"2001 FN194" "Sol" #3=
".:2001 FN194" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	48
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2451994.5  # 2001 Mar 26
		Period	548.06808347412
		SemiMajorAxis	66.970602547623
		Eccentricity	0.477549705101
		Inclination	7.418267854334
		AscendingNode	0.080122507035
		ArgOfPericenter	181.855055046417
		MeanAnomaly	0.007226069529
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2001+FN194"
}

#1_"2001 KX67" "Sol" #1=
#2_"2001 KX67" "Sol" #2=
#3_"2001 KX67" "Sol" #3=
".:2001 KX67" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.6
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.510042150372
		SemiMajorAxis	3.119592104947
		Eccentricity	0.576411529134
		Inclination	20.699129762056
		AscendingNode	244.825985978238
		ArgOfPericenter	115.227572221596
		MeanAnomaly	138.981010517497
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.045
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2001+KX67"
}

#1_"2001 KZ76" "Sol" #1=
#2_"2001 KZ76" "Sol" #2=
#3_"2001 KZ76" "Sol" #3=
".:2001 KZ76" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	60.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2452062.5  # 2001 Jun 02
		Period	702.173559502708
		SemiMajorAxis	78.999470391915
		Eccentricity	0.516196522982
		Inclination	25.715477573904
		AscendingNode	41.943336062803
		ArgOfPericenter	137.12802868677
		MeanAnomaly	10.266754092403
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2001+KZ76"
}

#1_"2001 OB74" "Sol" #1=
#2_"2001 OB74" "Sol" #2=
#3_"2001 OB74" "Sol" #3=
".:2001 OB74" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.397739216167
		SemiMajorAxis	3.077058814984
		Eccentricity	0.496837129836
		Inclination	16.297813384969
		AscendingNode	259.423580642734
		ArgOfPericenter	40.551129805917
		MeanAnomaly	189.802288517647
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.061
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2001+OB74"
}

#1_"2001 OM109" "Sol" #1=
#2_"2001 OM109" "Sol" #2=
#3_"2001 OM109" "Sol" #3=
".:2001 OM109" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	561.877757945517
		SemiMajorAxis	68.090902789952
		Eccentricity	0.492424152546
		Inclination	3.558742719725
		AscendingNode	306.893015446694
		ArgOfPericenter	291.107543754196
		MeanAnomaly	34.260455543069
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2001+OM109"
}

#1_"2001 OT108" "Sol" #1=
#2_"2001 OT108" "Sol" #2=
#3_"2001 OT108" "Sol" #3=
".:2001 OT108" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2452116.5  # 2001 Jul 26
		Period	547.636390507944
		SemiMajorAxis	66.935431084343
		Eccentricity	0.515526447915
		Inclination	1.394077021129
		AscendingNode	129.331006041477
		ArgOfPericenter	177.287122027949
		MeanAnomaly	0.002265809448
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2001+OT108"
}

#1_"2001 QF6" "Sol" #1=
#2_"2001 QF6" "Sol" #2=
#3_"2001 QF6" "Sol" #3=
".:2001 QF6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	2.7
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	19.41930777911
		SemiMajorAxis	7.224653594015
		Eccentricity	0.687459030804
		Inclination	24.167876018957
		AscendingNode	143.89657940437
		ArgOfPericenter	240.494720008197
		MeanAnomaly	238.3998173667
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2001+QF6"
}

#1_"2001 QF298" "Sol" #1=
#2_"2001 QF298" "Sol" #2=
#3_"2001 QF298" "Sol" #3=
".:2001 QF298" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.732 0.476 ]
	BlendTexture	true
	Radius	204.1
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	246.07719549943
		SemiMajorAxis	39.268300961434
		Eccentricity	0.112429647235
		Inclination	22.400761157234
		AscendingNode	164.229279472073
		ArgOfPericenter	40.557092332093
		MeanAnomaly	153.599133540512
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.071
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2001+QF298"
}

#1_"2001 QL169" "Sol" #1=
#2_"2001 QL169" "Sol" #2=
#3_"2001 QL169" "Sol" #3=
".:2001 QL169" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.36
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.575068460394
		SemiMajorAxis	3.144087821325
		Eccentricity	0.506302048759
		Inclination	14.099234148196
		AscendingNode	111.134283111846
		ArgOfPericenter	212.492100786949
		MeanAnomaly	150.711012375283
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.107
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2001+QL169"
}

#1_"2001 QR322" "Sol" #1=
#2_"2001 QR322" "Sol" #2=
#3_"2001 QR322" "Sol" #3=
".:2001 QR322" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	78
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	166.03154356582
		SemiMajorAxis	30.20797423119975
		Eccentricity	0.02657460528885745
		Inclination	1.323324782419271
		AscendingNode	151.6604015769765
		ArgOfPericenter	158.2472342823448
		MeanAnomaly	73.80611561291988
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2001+QR322"
}

#1_"2001 SJ262" "Sol" #1=
#2_"2001 SJ262" "Sol" #2=
#3_"2001 SJ262" "Sol" #3=
".:2001 SJ262" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.17
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.05321816004
		SemiMajorAxis	2.944692141222
		Eccentricity	0.575025482345
		Inclination	10.803527036817
		AscendingNode	210.436684586524
		ArgOfPericenter	164.931235688293
		MeanAnomaly	215.437596946802
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.177
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2001+SJ262"
}

#1_"2002 BM26" "Sol" #1=
#2_"2002 BM26" "Sol" #2=
#3_"2002 BM26" "Sol" #3=
".:2002 BM26" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.42
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.480575914233
		SemiMajorAxis	1.832439086416
		Eccentricity	0.444431565731
		Inclination	16.215264753262
		AscendingNode	319.653032338184
		ArgOfPericenter	180.431841937289
		MeanAnomaly	60.066063498446
	}
	UniformRotation
	{
		Period	2.7
	}
	LunarLambert	0.5
	Albedo	0.023
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2002+BM26"
}

#1_"2002 CT46" "Sol" #1=
#2_"2002 CT46" "Sol" #2=
#3_"2002 CT46" "Sol" #3=
".:2002 CT46" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.08
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.636082307065
		SemiMajorAxis	2.364559982929
		Eccentricity	0.529247438982
		Inclination	15.709931287745
		AscendingNode	157.407503518598
		ArgOfPericenter	356.218439325534
		MeanAnomaly	189.304260470931
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.32
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2002+CT46"
}

#1_"2002 CX58" "Sol" #1=
#2_"2002 CX58" "Sol" #2=
#3_"2002 CX58" "Sol" #3=
".:2002 CX58" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.065
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.671344885587
		SemiMajorAxis	2.794403737255
		Eccentricity	0.660840715519
		Inclination	2.535096421208
		AscendingNode	110.16578382381
		ArgOfPericenter	75.735393960562
		MeanAnomaly	258.236296846467
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.126
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2002+CX58"
}

#1_"2002 CX174" "Sol" #1=
#2_"2002 CX174" "Sol" #2=
#3_"2002 CX174" "Sol" #3=
".:2002 CX174" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.365923211473
		SemiMajorAxis	3.06495545813
		Eccentricity	0.513733259894
		Inclination	21.641085804887
		AscendingNode	355.6534143116
		ArgOfPericenter	225.001049657842
		MeanAnomaly	120.863187946476
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.031
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2002+CX174"
}

#1_"2002 CY248" "Sol" #1=
#2_"2002 CY248" "Sol" #2=
#3_"2002 CY248" "Sol" #3=
".:2002 CY248" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	191.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	316.782432662323
		SemiMajorAxis	46.46956333563
		Eccentricity	0.141580463523
		Inclination	7.015124278907
		AscendingNode	300.661850204256
		ArgOfPericenter	336.162410792643
		MeanAnomaly	230.062562372277
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2002+CY248"
}

#1_"2002 GB32" "Sol" #1=
#2_"2002 GB32" "Sol" #2=
#3_"2002 GB32" "Sol" #3=
".:2002 GB32" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	63.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3083.82956734813
		SemiMajorAxis	211.862833927239
		Eccentricity	0.833188091249
		Inclination	14.179590650443
		AscendingNode	176.997862879997
		ArgOfPericenter	36.897395198565
		MeanAnomaly	0.090606675378
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2002+GB32"
}

#1_"2002 PL153" "Sol" #1=
#2_"2002 PL153" "Sol" #2=
#3_"2002 PL153" "Sol" #3=
".:2002 PL153" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2452501.5  # 2002 Aug 15
		Period	287.699101763691
		SemiMajorAxis	43.579964198749
		Eccentricity	0.000003523003
		Inclination	0.477540484441
		AscendingNode	351.854016900784
		ArgOfPericenter	205.55167479282
		MeanAnomaly	112.036559976617
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2002+PL153"
}

#1_"2002 RN109" "Sol" #1=
#2_"2002 RN109" "Sol" #2=
#3_"2002 RN109" "Sol" #3=
".:2002 RN109" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	18441.5654157911
		SemiMajorAxis	698.006908070632
		Eccentricity	0.996120725096
		Inclination	57.895286520248
		AscendingNode	170.502425772818
		ArgOfPericenter	212.480471755512
		MeanAnomaly	0.232981239108
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2002+RN109"
}

#1_"2002 XV93" "Sol" #1=
#2_"2002 XV93" "Sol" #2=
#3_"2002 XV93" "Sol" #3=
".:2002 XV93" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	274.6
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	248.323711973826
		SemiMajorAxis	39.506933937167
		Eccentricity	0.126505727244
		Inclination	13.276635614348
		AscendingNode	19.120689919798
		ArgOfPericenter	162.484100012124
		MeanAnomaly	281.49967962745
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.040
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2002+XV93"
}

#1_"2003 FH129" "Sol" #1=
#2_"2003 FH129" "Sol" #2=
#3_"2003 FH129" "Sol" #3=
".:2003 FH129" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	50.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	615.879063368303
		SemiMajorAxis	72.386596769883
		Eccentricity	0.617696861132
		Inclination	18.666642997729
		AscendingNode	171.556775663818
		ArgOfPericenter	297.102321701197
		MeanAnomaly	19.521722534486
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+FH129"
}

#1_"2003 FZ129" "Sol" #1=
#2_"2003 FZ129" "Sol" #2=
#3_"2003 FZ129" "Sol" #3=
".:2003 FZ129" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	490.431033568555
		SemiMajorAxis	62.188940941955
		Eccentricity	0.389071543529
		Inclination	5.787424890842
		AscendingNode	28.025121142025
		ArgOfPericenter	161.057887528225
		MeanAnomaly	9.15048842879
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+FZ129"
}

#1_"2003 HB57" "Sol" #1=
#2_"2003 HB57" "Sol" #2=
#3_"2003 HB57" "Sol" #3=
".:2003 HB57" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2069.46193536704
		SemiMajorAxis	162.392571979165
		Eccentricity	0.765454169435
		Inclination	15.488114672739
		AscendingNode	197.84846972655
		ArgOfPericenter	10.666028227582
		MeanAnomaly	1.028105148468
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+HB57"
}

#1_"2003 LA7" "Sol" #1=
#2_"2003 LA7" "Sol" #2=
#3_"2003 LA7" "Sol" #3=
".:2003 LA7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	110.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	659.934727672092
		SemiMajorAxis	75.798716832126
		Eccentricity	0.525489891469
		Inclination	5.640529643758
		AscendingNode	34.108448600867
		ArgOfPericenter	271.700171630317
		MeanAnomaly	345.28660108544
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+LA7"
}

#1_"2003 OS33" "Sol" #1=
#2_"2003 OS33" "Sol" #2=
#3_"2003 OS33" "Sol" #3=
".:2003 OS33" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	60.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	585.540464035371
		SemiMajorAxis	69.98943272917
		Eccentricity	0.529957152804
		Inclination	20.727152350053
		AscendingNode	131.527961123449
		ArgOfPericenter	162.659213225668
		MeanAnomaly	16.677256547855
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+OS33"
}

#1_"2003 QK91" "Sol" #1=
#2_"2003 QK91" "Sol" #2=
#3_"2003 QK91" "Sol" #3=
".:2003 QK91" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	91.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	551.918683081897
		SemiMajorAxis	67.283916359934
		Eccentricity	0.428511462592
		Inclination	4.011634446573
		AscendingNode	276.117969931198
		ArgOfPericenter	69.446722301432
		MeanAnomaly	354.836502258768
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+QK91"
}

#1_"2003 QM112" "Sol" #1=
#2_"2003 QM112" "Sol" #2=
#3_"2003 QM112" "Sol" #3=
".:2003 QM112" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	3.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	776.922917883156
		SemiMajorAxis	84.510983049618
		Eccentricity	0.84392761913
		Inclination	16.398749957345
		AscendingNode	148.417986887868
		ArgOfPericenter	179.046072768558
		MeanAnomaly	5.404963329861
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+QM112"
}

#1_"2003 QX111" "Sol" #1=
#2_"2003 QX111" "Sol" #2=
#3_"2003 QX111" "Sol" #3=
".:2003 QX111" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Mesh	"roughsphere.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	179
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	245.527391184643
		SemiMajorAxis	39.20978835017
		Eccentricity	0.132363571848
		Inclination	9.547948309851
		AscendingNode	157.564776134917
		ArgOfPericenter	99.606642071559
		MeanAnomaly	100.155467575898
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+QX111"
}

#1_"2003 QX113" "Sol" #1=
#2_"2003 QX113" "Sol" #2=
#3_"2003 QX113" "Sol" #3=
".:2003 QX113" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	252.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	347.609796971291
		SemiMajorAxis	49.437428246626
		Eccentricity	0.255932407565
		Inclination	6.771400177877
		AscendingNode	158.067039187604
		ArgOfPericenter	24.766436034128
		MeanAnomaly	136.184142481689
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+QX113"
}

#1_"2003 QY91" "Sol" #1=
#2_"2003 QY91" "Sol" #2=
#3_"2003 QY91" "Sol" #3=
".:2003 QY91" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	63.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2452875.5  # 2003 Aug 24
		Period	749.128257436131
		SemiMajorAxis	82.483165154696
		Eccentricity	0.612592808062
		Inclination	26.153740717837
		AscendingNode	169.031245139937
		ArgOfPericenter	189.8771074231
		MeanAnomaly	0.002080417692
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+QY91"
}

#1_"2003 SQ222" "Sol" #1=
#2_"2003 SQ222" "Sol" #2=
#3_"2003 SQ222" "Sol" #3=
".:2003 SQ222" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.0025
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.847405480028
		SemiMajorAxis	1.505576001264
		Eccentricity	0.518879866339
		Inclination	3.560067108418
		AscendingNode	4.420944771436
		ArgOfPericenter	280.881559585308
		MeanAnomaly	49.21280095121
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+SQ222"
}

#1_"2003 SQ317" "Sol" #1=
#2_"2003 SQ317" "Sol" #2=
#3_"2003 SQ317" "Sol" #3=
".:2003 SQ317" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"haumeanfamily.dds"
	Radius	132.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	277.808145168017
		SemiMajorAxis	42.575312896652
		Eccentricity	0.078340323434
		Inclination	28.614620251677
		AscendingNode	176.336872605867
		ArgOfPericenter	194.263593243682
		MeanAnomaly	1.283977018286
	}
	UniformRotation
	{
		Period	7.5
	}
	LunarLambert	0.5
	Albedo	0.7
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+SQ317"
}

#1_"2003 SS422" "Sol" #1=
#2_"2003 SS422" "Sol" #2=
#3_"2003 SS422" "Sol" #3=
".:2003 SS422" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	83.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2743.17286139129
		SemiMajorAxis	195.958143155407
		Eccentricity	0.798780676292
		Inclination	16.807114450507
		AscendingNode	151.109758228342
		ArgOfPericenter	210.011622395191
		MeanAnomaly	0.719746699988
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+SS422"
}

#1_"2003 UZ413" "Sol" #1=
#2_"2003 UZ413" "Sol" #2=
#3_"2003 UZ413" "Sol" #3=
".:2003 UZ413" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.732 0.476 ]
	BlendTexture	true
	Radius	318
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	245.798898442344
		SemiMajorAxis	39.238688808051
		Eccentricity	0.220860064489
		Inclination	12.042489650859
		AscendingNode	136.173914512113
		ArgOfPericenter	145.22711548
		MeanAnomaly	107.035824068952
	}
	UniformRotation
	{
		Period	4.14
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+UZ413"
}

#1_"2003 WN188" "Sol" #1=
#2_"2003 WN188" "Sol" #2=
#3_"2003 WN188" "Sol" #3=
".:2003 WN188" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	54.374562597724
		SemiMajorAxis	14.352417178634
		Eccentricity	0.848234705495
		Inclination	27.055635316872
		AscendingNode	123.664097940926
		ArgOfPericenter	40.914837284847
		MeanAnomaly	70.583684513645
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+WN188"
}

#1_"2003 WV157" "Sol" #1=
#2_"2003 WV157" "Sol" #2=
#3_"2003 WV157" "Sol" #3=
".:2003 WV157" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	1.8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	5.545687640253
		SemiMajorAxis	3.133031788864
		Eccentricity	0.521299558295
		Inclination	20.431526962253
		AscendingNode	252.173546785012
		ArgOfPericenter	250.509529044722
		MeanAnomaly	342.213232714601
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+WV157"
}

#1_"2003 YQ179" "Sol" #1=
#2_"2003 YQ179" "Sol" #2=
#3_"2003 YQ179" "Sol" #3=
".:2003 YQ179" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	100.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	857.282812840256
		SemiMajorAxis	90.242394365979
		Eccentricity	0.5871950765
		Inclination	20.843174957809
		AscendingNode	109.764479426819
		ArgOfPericenter	30.581055037896
		MeanAnomaly	357.909044842269
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2003+YQ179"
}

#1_"2004 KV18" "Sol" #1=
#2_"2004 KV18" "Sol" #2=
#3_"2004 KV18" "Sol" #3=
".:2004 KV18" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	36.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	165.98627887208
		SemiMajorAxis	30.20248364063817
		Eccentricity	0.1871913744849332
		Inclination	13.58987944145693
		AscendingNode	235.5980036187156
		ArgOfPericenter	294.8321925386239
		MeanAnomaly	65.14961522299002
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2004+KV18"
}

#1_"2004 NN8" "Sol" #1=
#2_"2004 NN8" "Sol" #2=
#3_"2004 NN8" "Sol" #3=
".:2004 NN8" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	969.346310225353
		SemiMajorAxis	97.944602081159
		Eccentricity	0.976377445916
		Inclination	165.466157476189
		AscendingNode	165.10646247
		ArgOfPericenter	262.341219931081
		MeanAnomaly	3.7578763991
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2004+NN8"
}

#1_"2004 NT33" "Sol" #1=
#2_"2004 NT33" "Sol" #2=
#3_"2004 NT33" "Sol" #3=
".:2004 NT33" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Radius	211.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	284.496977598936
		SemiMajorAxis	43.2559946774
		Eccentricity	0.147791532355
		Inclination	31.23117700196
		AscendingNode	241.042362299237
		ArgOfPericenter	36.977713029063
		MeanAnomaly	38.793886703472
	}
	UniformRotation
	{
		Period	7.87
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2004+NT33"
}

#1_"2004 TF282" "Sol" #1=
#2_"2004 TF282" "Sol" #2=
#3_"2004 TF282" "Sol" #3=
".:2004 TF282" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	121
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	730.523987050277
		SemiMajorAxis	81.111827353219
		Eccentricity	0.51398577569
		Inclination	23.179937935807
		AscendingNode	234.981623831247
		ArgOfPericenter	171.478648648816
		MeanAnomaly	6.102302810452
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2004+TF282"
}

#1_"2004 VG131" "Sol" #1=
#2_"2004 VG131" "Sol" #2=
#3_"2004 VG131" "Sol" #3=
".:2004 VG131" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	516.229955376658
		SemiMajorAxis	64.351202442072
		Eccentricity	0.507790263519
		Inclination	13.647174881647
		AscendingNode	42.73519427365
		ArgOfPericenter	345.598938719925
		MeanAnomaly	10.14311086298
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2004+VG131"
}

#1_"2004 VH131" "Sol" #1=
#2_"2004 VH131" "Sol" #2=
#3_"2004 VH131" "Sol" #3=
".:2004 VH131" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	466.390100444214
		SemiMajorAxis	60.139629402343
		Eccentricity	0.628945725879
		Inclination	11.978309734
		AscendingNode	39.642627484111
		ArgOfPericenter	308.379191611985
		MeanAnomaly	18.9210938385
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2004+VH131"
}

#1_"2004 VM131" "Sol" #1=
#2_"2004 VM131" "Sol" #2=
#3_"2004 VM131" "Sol" #3=
".:2004 VM131" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	569.672430059348
		SemiMajorAxis	68.719184921686
		Eccentricity	0.698933928581
		Inclination	14.032662146765
		AscendingNode	225.917565299827
		ArgOfPericenter	138.034295410403
		MeanAnomaly	11.915508002187
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2004+VM131"
}

#1_"2004 XP14" "Sol" #1=
#2_"2004 XP14" "Sol" #2=
#3_"2004 XP14" "Sol" #3=
".:2004 XP14" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.130
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.078310596008
		SemiMajorAxis	1.051535115634
		Eccentricity	0.158457414088
		Inclination	32.951612169275
		AscendingNode	281.047956477371
		ArgOfPericenter	273.693269073538
		MeanAnomaly	4.543330504196
	}
	UniformRotation
	{
		Period	100
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2004+XP14"
}

#1_"2004 XR190" "Sol" #1=
#2_"2004 XR190" "Sol" #2=
#3_"2004 XR190" "Sol" #3=
".:2004 XR190" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	290
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	438.44713749626
		SemiMajorAxis	57.71287256830396
		Eccentricity	0.1094918923387402
		Inclination	46.59497186792814
		AscendingNode	252.3628385298381
		ArgOfPericenter	281.6361935007498
		MeanAnomaly	277.636302515104
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2004+XR190"
}

#1_"2005 EF304" "Sol" #1=
#2_"2005 EF304" "Sol" #2=
#3_"2005 EF304" "Sol" #3=
".:2005 EF304" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	76.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	815.695829932092
		SemiMajorAxis	87.299822336444
		Eccentricity	0.558458155649
		Inclination	18.681218105809
		AscendingNode	15.529676372757
		ArgOfPericenter	198.075182225839
		MeanAnomaly	357.912073094933
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2005+EF304"
}

#1_"2005 HC4" "Sol" #1=
#2_"2005 HC4" "Sol" #2=
#3_"2005 HC4" "Sol" #3=
".:2005 HC4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.1725
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2453493.5  # 2005 May 03
		Period	2.456682782016
		SemiMajorAxis	1.820653302258
		Eccentricity	0.961191628131
		Inclination	8.396712132033
		AscendingNode	63.790127695788
		ArgOfPericenter	309.012717004489
		MeanAnomaly	341.417302761524
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2005+HC4"
}

#1_"2005 LC54" "Sol" #1=
#2_"2005 LC54" "Sol" #2=
#3_"2005 LC54" "Sol" #3=
".:2005 LC54" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	100.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	550.529312771103
		SemiMajorAxis	67.170950997701
		Eccentricity	0.460934545666
		Inclination	22.453538494677
		AscendingNode	65.561391350521
		ArgOfPericenter	236.712948149411
		MeanAnomaly	343.820883800445
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2005+LC54"
}

#1_"2005 OE" "Sol" #1=
#2_"2005 OE" "Sol" #2=
#3_"2005 OE" "Sol" #3=
".:2005 OE" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	4
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	498.838642617647
		SemiMajorAxis	62.89767483972
		Eccentricity	0.951410976507
		Inclination	67.580744322122
		AscendingNode	153.452480077497
		ArgOfPericenter	115.991988381675
		MeanAnomaly	7.119040116484
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2005+OE"
}

#1_"2005 PT21" "Sol" #1=
#2_"2005 PT21" "Sol" #2=
#3_"2005 PT21" "Sol" #3=
".:2005 PT21" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	73
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	640.635701276282
		SemiMajorAxis	74.313655247929
		Eccentricity	0.517758825443
		Inclination	7.917180858107
		AscendingNode	177.153307255622
		ArgOfPericenter	106.975092101118
		MeanAnomaly	22.389115056709
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2005+PT21"
}

#1_"2005 PU21" "Sol" #1=
#2_"2005 PU21" "Sol" #2=
#3_"2005 PU21" "Sol" #3=
".:2005 PU21" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	121
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2301.32988430809
		SemiMajorAxis	174.306580552049
		Eccentricity	0.832526183967
		Inclination	6.18036436088
		AscendingNode	192.484218387179
		ArgOfPericenter	228.074735301457
		MeanAnomaly	355.974002743008
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2005+PU21"
}

#1_"2005 RH52" "Sol" #1=
#2_"2005 RH52" "Sol" #2=
#3_"2005 RH52" "Sol" #3=
".:2005 RH52" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	60.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1872.9041031598
		SemiMajorAxis	151.939803087566
		Eccentricity	0.743293455996
		Inclination	20.468372760343
		AscendingNode	306.196322427989
		ArgOfPericenter	32.518406649266
		MeanAnomaly	2.203991640236
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2005+RH52"
}

#1_"2005 RP43" "Sol" #1=
#2_"2005 RP43" "Sol" #2=
#3_"2005 RP43" "Sol" #3=
".:2005 RP43" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	132.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	900.026418488674
		SemiMajorAxis	93.217625651155
		Eccentricity	0.588962561459
		Inclination	22.97422916953
		AscendingNode	344.274636118993
		ArgOfPericenter	346.432938291129
		MeanAnomaly	8.118682429776
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2005+RP43"
}

#1_"2005 SB223" "Sol" #1=
#2_"2005 SB223" "Sol" #2=
#3_"2005 SB223" "Sol" #3=
".:2005 SB223" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	160.994168265263
		SemiMajorAxis	29.593838197086
		Eccentricity	0.906881466981
		Inclination	91.401359492461
		AscendingNode	219.655775997338
		ArgOfPericenter	252.464332252778
		MeanAnomaly	20.249228644476
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2005+SB223"
}

#1_"2005 TN53" "Sol" #1=
#2_"2005 TN53" "Sol" #2=
#3_"2005 TN53" "Sol" #3=
".:2005 TN53" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	165.34240216952
		SemiMajorAxis	30.12432750219291
		Eccentricity	0.06758462009922045
		Inclination	25.03293327607598
		AscendingNode	9.319094851881543
		ArgOfPericenter	88.32312166767332
		MeanAnomaly	297.928344911501
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2005+TN53"
}

#1_"2005 TN74" "Sol" #1=
#2_"2005 TN74" "Sol" #2=
#3_"2005 TN74" "Sol" #3=
".:2005 TN74" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	76.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	276.46247524235
		SemiMajorAxis	42.437715129108
		Eccentricity	0.243397296702
		Inclination	2.171718687294
		AscendingNode	179.226255500552
		ArgOfPericenter	224.853529663009
		MeanAnomaly	349.648038362632
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2005+TN74"
}

#1_"2005 VX3" "Sol" #1=
#2_"2005 VX3" "Sol" #2=
#3_"2005 VX3" "Sol" #3=
".:2005 VX3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	3.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	62830.8877936256
		SemiMajorAxis	1580.43508650495
		Eccentricity	0.997387803461
		Inclination	112.349412729582
		AscendingNode	255.273306719426
		ArgOfPericenter	196.53622264137
		MeanAnomaly	0.060450741537
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2005+VX3"
}

#1_"2005 WY55" "Sol" #1=
#2_"2005 WY55" "Sol" #2=
#3_"2005 WY55" "Sol" #3=
".:2005 WY55" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.11
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.926289315865
		SemiMajorAxis	2.488758352936
		Eccentricity	0.720496246626
		Inclination	7.271343670895
		AscendingNode	248.260376811505
		ArgOfPericenter	286.099748926279
		MeanAnomaly	88.336335535314
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.19
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2005+WY55"
}

#1_"2006 HO122" "Sol" #1=
#2_"2006 HO122" "Sol" #2=
#3_"2006 HO122" "Sol" #3=
".:2006 HO122" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	53
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2453876.5  # 2006 May 21
		Period	598.085109268344
		SemiMajorAxis	70.98553475245
		Eccentricity	0.512328450898
		Inclination	17.27064205953
		AscendingNode	199.033305132416
		ArgOfPericenter	45.363559927313
		MeanAnomaly	350.100844964501
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2006+HO122"
}

#1_"2006 HQ122" "Sol" #1=
#2_"2006 HQ122" "Sol" #2=
#3_"2006 HQ122" "Sol" #3=
".:2006 HQ122" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	121
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	878.0553971234
		SemiMajorAxis	91.694328898078
		Eccentricity	0.589176270457
		Inclination	21.633821577162
		AscendingNode	217.121356875174
		ArgOfPericenter	345.67866559989
		MeanAnomaly	5.583703002993
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2006+HQ122"
}

#1_"2006 HV122" "Sol" #1=
#2_"2006 HV122" "Sol" #2=
#3_"2006 HV122" "Sol" #3=
".:2006 HV122" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	132.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	730.337969024344
		SemiMajorAxis	81.098057417592
		Eccentricity	0.535992063055
		Inclination	16.029296030394
		AscendingNode	40.69094522633
		ArgOfPericenter	237.039943613134
		MeanAnomaly	347.579150234182
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2006+HV122"
}

#1_"2006 HX122" "Sol" #1=
#2_"2006 HX122" "Sol" #2=
#3_"2006 HX122" "Sol" #3=
".:2006 HX122" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	145.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	583.485815000613
		SemiMajorAxis	69.825609206157
		Eccentricity	0.48250338073
		Inclination	12.876117702894
		AscendingNode	250.511319125939
		ArgOfPericenter	258.008417640256
		MeanAnomaly	39.268622706414
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2006+HX122"
}

#1_"2006 QH181" "Sol" #1=
#2_"2006 QH181" "Sol" #2=
#3_"2006 QH181" "Sol" #3=
".:2006 QH181" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	303.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	553.513322713129
		SemiMajorAxis	67.413454765352
		Eccentricity	0.435967070335
		Inclination	19.100525367065
		AscendingNode	73.855196139285
		ArgOfPericenter	211.339880897221
		MeanAnomaly	101.238434950083
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2006+QH181"
}

#1_"2006 QM111" "Sol" #1=
#2_"2006 QM111" "Sol" #2=
#3_"2006 QM111" "Sol" #3=
".:2006 QM111" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.006
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4.184246633362
		SemiMajorAxis	2.596605954855
		Eccentricity	0.729886118016
		Inclination	1.44910680292
		AscendingNode	155.11584099083
		ArgOfPericenter	257.317341479647
		MeanAnomaly	342.714220789652
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2006+QM111"
}

#1_"2006 RJ103" "Sol" #1=
#2_"2006 RJ103" "Sol" #2=
#3_"2006 RJ103" "Sol" #3=
".:2006 RJ103" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	69.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	164.69602723858
		SemiMajorAxis	30.04576600914959
		Eccentricity	0.03179319951571633
		Inclination	8.161479907186168
		AscendingNode	120.9637201187057
		ArgOfPericenter	25.44900269934533
		MeanAnomaly	253.7765462466779
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2006+RJ103"
}

#1_"2006 UL321" "Sol" #1=
#2_"2006 UL321" "Sol" #2=
#3_"2006 UL321" "Sol" #3=
".:2006 UL321" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	66.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2454020.5  # 2006 Oct 12
		Period	4210.99839087228
		SemiMajorAxis	260.7641997
		Eccentricity	0.9099041
		Inclination	37.36673
		AscendingNode	342.9202
		ArgOfPericenter	353.79724
		MeanAnomaly	0.05873
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2006+UL321"
}

#1_"2007 DA61" "Sol" #1=
#2_"2007 DA61" "Sol" #2=
#3_"2007 DA61" "Sol" #3=
".:2007 DA61" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	9495.32307116371
		SemiMajorAxis	448.402159756604
		Eccentricity	0.994081843383
		Inclination	76.860265158742
		AscendingNode	145.768995463819
		ArgOfPericenter	349.585474764423
		MeanAnomaly	0.295134704612
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+DA61"
}

#1_"2007 EB26" "Sol" #1=
#2_"2007 EB26" "Sol" #2=
#3_"2007 EB26" "Sol" #3=
".:2007 EB26" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.350
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2454170.5  # 2007 Mar 11
		Period	0.405233965361
		SemiMajorAxis	0.547602082897
		Eccentricity	0.788666268126
		Inclination	8.486737757819
		AscendingNode	63.220175657598
		ArgOfPericenter	236.706096876753
		MeanAnomaly	237.912859490284
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+EB26"
}

#1_"2007 JH43" "Sol" #1=
#2_"2007 JH43" "Sol" #2=
#3_"2007 JH43" "Sol" #3=
".:2007 JH43" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	252.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	247.577815671201
		SemiMajorAxis	39.427782285258
		Eccentricity	0.028803479807
		Inclination	18.164191612269
		AscendingNode	64.586127990607
		ArgOfPericenter	4.53634588665
		MeanAnomaly	174.900228067336
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+JH43"
}

#1_"2007 TA418" "Sol" #1=
#2_"2007 TA418" "Sol" #2=
#3_"2007 TA418" "Sol" #3=
".:2007 TA418" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	80
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	619.61974159406
		SemiMajorAxis	72.67940490684
		Eccentricity	0.505125998598
		Inclination	21.953057422997
		AscendingNode	121.7887010291
		ArgOfPericenter	297.815836227015
		MeanAnomaly	356.277493947485
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+TA418"
}

#1_"2007 TG422" "Sol" #1=
#2_"2007 TG422" "Sol" #2=
#3_"2007 TG422" "Sol" #3=
".:2007 TG422" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	127.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	10244.8481159694
		SemiMajorAxis	471.69891934659
		Eccentricity	0.924616719594
		Inclination	18.603412576952
		AscendingNode	112.892163767204
		ArgOfPericenter	285.656326416834
		MeanAnomaly	0.418981273306
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+TG422"
}

#1_"2007 TR436" "Sol" #1=
#2_"2007 TR436" "Sol" #2=
#3_"2007 TR436" "Sol" #3=
".:2007 TR436" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	27.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2454403.5  # 2007 Oct 30
		Period	500.007933760561
		SemiMajorAxis	62.995925704204
		Eccentricity	0.595265480667
		Inclination	31.712288558149
		AscendingNode	195.676071439695
		ArgOfPericenter	179.554571929002
		MeanAnomaly	0.031286323116
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+TR436"
}

#1_"2007 TU24" "Sol" #1=
#2_"2007 TU24" "Sol" #2=
#3_"2007 TU24" "Sol" #3=
".:2007 TU24" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.125
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.919534360962
		SemiMajorAxis	2.042695313327
		Eccentricity	0.534437059754
		Inclination	5.623373311237
		AscendingNode	127.040881310941
		ArgOfPericenter	334.246938236786
		MeanAnomaly	132.948356908746
	}
	UniformRotation
	{
		Period	26
	}
	LunarLambert	0.5
	Albedo	0.24
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+TU24"
}

#1_"2007 TU431" "Sol" #1=
#2_"2007 TU431" "Sol" #2=
#3_"2007 TU431" "Sol" #3=
".:2007 TU431" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	18.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2454406.5  # 2007 Nov 02
		Period	1440.31619056847
		SemiMajorAxis	127.536088621574
		Eccentricity	0.832117882056
		Inclination	6.670769188227
		AscendingNode	195.721266588651
		ArgOfPericenter	223.074720744955
		MeanAnomaly	357.385426570052
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+TU431"
}

#1_"2007 UD6" "Sol" #1=
#2_"2007 UD6" "Sol" #2=
#3_"2007 UD6" "Sol" #3=
".:2007 UD6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.367712137018
		SemiMajorAxis	1.232133216647
		Eccentricity	0.242641272836
		Inclination	1.693907950059
		AscendingNode	205.957146960663
		ArgOfPericenter	131.158707773399
		MeanAnomaly	109.095963354576
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+UD6"
}

#1_"2007 VF189" "Sol" #1=
#2_"2007 VF189" "Sol" #2=
#3_"2007 VF189" "Sol" #3=
".:2007 VF189" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.32584765903
		SemiMajorAxis	1.206860155403
		Eccentricity	0.385204094038
		Inclination	6.980905612575
		AscendingNode	51.824480568788
		ArgOfPericenter	83.538221734269
		MeanAnomaly	75.700093282086
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+VF189"
}

#1_"2007 VJ305" "Sol" #1=
#2_"2007 VJ305" "Sol" #2=
#3_"2007 VJ305" "Sol" #3=
".:2007 VJ305" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	105.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2634.93047569002
		SemiMajorAxis	190.768781410795
		Eccentricity	0.815492714183
		Inclination	11.994491874667
		AscendingNode	24.383492027504
		ArgOfPericenter	338.485469456388
		MeanAnomaly	1.217092671239
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+VJ305"
}

#1_"2007 VK184" "Sol" #1=
#2_"2007 VK184" "Sol" #2=
#3_"2007 VK184" "Sol" #3=
".:2007 VK184" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.065
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.267840963538
		SemiMajorAxis	1.726114479145
		Eccentricity	0.56994994068
		Inclination	1.222464738966
		AscendingNode	253.960073228971
		ArgOfPericenter	73.170963923734
		MeanAnomaly	65.419765164928
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+VK184"
}

#1_"2007 VL305" "Sol" #1=
#2_"2007 VL305" "Sol" #2=
#3_"2007 VL305" "Sol" #3=
".:2007 VL305" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	55.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	164.95499325161
		SemiMajorAxis	30.07725349027903
		Eccentricity	0.06475866465667357
		Inclination	28.14136970773779
		AscendingNode	188.6651749148974
		ArgOfPericenter	218.6111383808168
		MeanAnomaly	3.031177322854124
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+VL305"
}

#1_"2007 WD5" "Sol" #1=
#2_"2007 WD5" "Sol" #2=
#3_"2007 WD5" "Sol" #3=
".:2007 WD5" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.025
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.857043870902
		SemiMajorAxis	2.459409903985
		Eccentricity	0.597114489042
		Inclination	2.427870363384
		AscendingNode	68.496911452781
		ArgOfPericenter	309.607573352208
		MeanAnomaly	307.071840428188
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+WD5"
}

#1_"2007 XV50" "Sol" #1=
#2_"2007 XV50" "Sol" #2=
#3_"2007 XV50" "Sol" #3=
".:2007 XV50" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	230.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	313.289392358703
		SemiMajorAxis	46.127330898373
		Eccentricity	0.066050400286
		Inclination	22.871238187359
		AscendingNode	53.586699175444
		ArgOfPericenter	276.838623803734
		MeanAnomaly	95.854912151024
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+XV50"
}

#1_"2007 YV56" "Sol" #1=
#2_"2007 YV56" "Sol" #2=
#3_"2007 YV56" "Sol" #3=
".:2007 YV56" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.136
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.977209344538
		SemiMajorAxis	1.575298893806
		Eccentricity	0.622005695173
		Inclination	6.245015014301
		AscendingNode	102.531070433034
		ArgOfPericenter	265.571751044368
		MeanAnomaly	210.06974009856
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2007+YV56"
}

#1_"2008 EA9" "Sol" #1=
#2_"2008 EA9" "Sol" #2=
#3_"2008 EA9" "Sol" #3=
".:2008 EA9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.006
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.090004511902
		SemiMajorAxis	1.059123803809
		Eccentricity	0.079805853401
		Inclination	0.424619518996
		AscendingNode	129.47700825326
		ArgOfPericenter	335.853894966614
		MeanAnomaly	125.689312290784
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2008+EA9"
}

#1_"2008 HJ" "Sol" #1=
#2_"2008 HJ" "Sol" #2=
#3_"2008 HJ" "Sol" #3=
".:2008 HJ" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.0850367903413
		SemiMajorAxis	1.632063354512258
		Eccentricity	0.406594951292017
		Inclination	0.9256164918966964
		AscendingNode	47.47064304026185
		ArgOfPericenter	204.157142587267
		MeanAnomaly	48.76948142704903
	}
	UniformRotation
	{
		Period	0.01185
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2008+HJ"
}

#1_"2008 KV42" "Sol" #1=
#2_"2008 KV42" "Sol" #2=
#3_"2008 KV42" "Sol" #3=
".:2008 KV42" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000  0.750 0.583 ]
	BlendTexture	true
	Radius	38
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	266.031430351422
		SemiMajorAxis	41.363425557948
		Eccentricity	0.489157253805
		Inclination	103.483367591958
		AscendingNode	261.013058996648
		ArgOfPericenter	133.225673774886
		MeanAnomaly	331.638101569729
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2008+KV42"
}

#1_"2008 LC18" "Sol" #1=
#2_"2008 LC18" "Sol" #2=
#3_"2008 LC18" "Sol" #3=
".:2008 LC18" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	46
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	163.66100445757
		SemiMajorAxis	29.91975319046906
		Eccentricity	0.08482566115756981
		Inclination	27.57571612516088
		AscendingNode	88.51804137776764
		ArgOfPericenter	7.718862162264387
		MeanAnomaly	178.0755493079093
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2008+LC18"
}

#1_"2008 LP17" "Sol" #1=
#2_"2008 LP17" "Sol" #2=
#3_"2008 LP17" "Sol" #3=
".:2008 LP17" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	105.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	848.119242970128
		SemiMajorAxis	89.598170759123
		Eccentricity	0.666907224529
		Inclination	14.113645759898
		AscendingNode	72.459515667954
		ArgOfPericenter	164.358271603872
		MeanAnomaly	0.503893319681
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2008+LP17"
}

#1_"2008 NW4" "Sol" #1=
#2_"2008 NW4" "Sol" #2=
#3_"2008 NW4" "Sol" #3=
".:2008 NW4" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	200.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	301.404161252065
		SemiMajorAxis	44.953208487314
		Eccentricity	0.186767994255
		Inclination	23.185561430872
		AscendingNode	285.17514671302
		ArgOfPericenter	41.57434817184
		MeanAnomaly	354.314846898324
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2008+NW4"
}

#1_"2008 OG19" "Sol" #1=
#2_"2008 OG19" "Sol" #2=
#3_"2008 OG19" "Sol" #3=
".:2008 OG19" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	264.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	537.603113361186
		SemiMajorAxis	66.115362266746
		Eccentricity	0.416540580366
		Inclination	13.163366220711
		AscendingNode	164.033014541444
		ArgOfPericenter	140.773744797835
		MeanAnomaly	0.746276793691
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2008+OG19"
}

#1_"2008 ST291" "Sol" #1=
#2_"2008 ST291" "Sol" #2=
#3_"2008 ST291" "Sol" #3=
".:2008 ST291" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	318
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	980.27062848776
		SemiMajorAxis	98.679102750152
		Eccentricity	0.569410155135
		Inclination	20.824703812437
		AscendingNode	331.155500081088
		ArgOfPericenter	324.612160738543
		MeanAnomaly	22.256497958519
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2008+ST291"
}

#1_"2008 TC3:8TA9D69" "Sol" #1=
#2_"2008 TC3:8TA9D69" "Sol" #2=
#3_"2008 TC3:8TA9D69" "Sol" #3=
".:2008 TC3:8TA9D69" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.00205
	Timeline
	[
		{
			Ending	2454746.5  # 2008 Oct 07
			EllipticalOrbit
			{
				Epoch	2454746.5  # 2008 Oct 07
				Period	1.4963201888031
				SemiMajorAxis	1.308210274095829
				Eccentricity	0.3120705549445109
				Inclination	2.542250783566425
				AscendingNode	194.1011377295283
				ArgOfPericenter	234.4488539002965
				MeanAnomaly	330.7545625601349
			}
			UniformRotation
			{
				Period	0.0269409
			}
		}
		{
			Ending	2454746.615937500  # 2008 Oct 07 02:46:57
			SampledOrbit	"2008 TC3 Earth impact.xyzv"
			UniformRotation
			{
				Period	0.0269409
			}
		}
	]
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"https://en.wikipedia.org/wiki/2008_TC3"
}

#1_"2008 TS26" "Sol" #1=
#2_"2008 TS26" "Sol" #2=
#3_"2008 TS26" "Sol" #3=
".:2008 TS26" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.00042
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2454748.5  # 2008 Oct 09
		Period	2.664566703218
		SemiMajorAxis	1.921965537896
		Eccentricity	0.568991688985
		Inclination	0.810539672596
		AscendingNode	16.428566629633
		ArgOfPericenter	301.64682988112
		MeanAnomaly	14.885143817263
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2008+TS26"
}

#1_"2008 UA332" "Sol" #1=
#2_"2008 UA332" "Sol" #2=
#3_"2008 UA332" "Sol" #3=
".:2008 UA332" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	200.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2454794.5  # 2008 Nov 24
		Period	300.20183364079
		SemiMajorAxis	44.833580672765
		Eccentricity	0.015197618451
		Inclination	32.10937686309
		AscendingNode	97.511009842026
		ArgOfPericenter	287.469142405734
		MeanAnomaly	0.075952828723
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2008+UA332"
}

#1_"2008 VM" "Sol" #1=
#2_"2008 VM" "Sol" #2=
#3_"2008 VM" "Sol" #3=
".:2008 VM" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.002
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2454773.5  # 2008 Nov 03
		Period	1.54153364116
		SemiMajorAxis	1.334432271889
		Eccentricity	0.392782591321
		Inclination	4.088979314101
		AscendingNode	42.011317209813
		ArgOfPericenter	69.169562170063
		MeanAnomaly	327.263105460782
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2008+VM"
}

#1_"2009 DD45" "Sol" #1=
#2_"2009 DD45" "Sol" #2=
#3_"2009 DD45" "Sol" #3=
".:2009 DD45" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.0095
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.382316965354
		SemiMajorAxis	1.24088906448
		Eccentricity	0.204834619564
		Inclination	13.743873583958
		AscendingNode	161.938961687622
		ArgOfPericenter	13.89923082905
		MeanAnomaly	53.656637571515
	}
	UniformRotation
	{
		Period	1.2
	}
	LunarLambert	0.5
	Albedo	0.36
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2009+DD45"
}

#1_"2009 DO111" "Sol" #1=
#2_"2009 DO111" "Sol" #2=
#3_"2009 DO111" "Sol" #3=
".:2009 DO111" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.059
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.075480755592
		SemiMajorAxis	1.049694594839
		Eccentricity	0.280284500968
		Inclination	2.983084149908
		AscendingNode	2.161888158494
		ArgOfPericenter	273.098611146694
		MeanAnomaly	52.739834439471
	}
	UniformRotation
	{
		Period	0.0489
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2009+DO111"
}

#1_"2009 KN30" "Sol" #1=
#2_"2009 KN30" "Sol" #2=
#3_"2009 KN30" "Sol" #3=
".:2009 KN30" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	578.499740978303
		SemiMajorAxis	69.427252307917
		Eccentricity	0.561434508092
		Inclination	4.625062159986
		AscendingNode	284.673891784466
		ArgOfPericenter	306.142482454965
		MeanAnomaly	7.722905624329
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2009+KN30"
}

#1_"2009 RR" "Sol" #1=
#2_"2009 RR" "Sol" #2=
#3_"2009 RR" "Sol" #3=
".:2009 RR" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.013
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.6828627271977
		SemiMajorAxis	1.414795466608694
		Eccentricity	0.4669751841227707
		Inclination	6.146141401182397
		AscendingNode	174.2178491165097
		ArgOfPericenter	256.2253612817325
		MeanAnomaly	18.33566487565509
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2009+RR"
}

#1_"2009 VA" "Sol" #1=
#2_"2009 VA" "Sol" #2=
#3_"2009 VA" "Sol" #3=
".:2009 VA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.0035
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2455141.5  # 2009 Nov 06
		Period	1.70638848823
		SemiMajorAxis	1.427950458431
		Eccentricity	0.357347940186
		Inclination	7.541062135444
		AscendingNode	224.542021620433
		ArgOfPericenter	223.991045395267
		MeanAnomaly	338.9461324035
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2009+VA"
}

#1_"2009 WQ6" "Sol" #1=
#2_"2009 WQ6" "Sol" #2=
#3_"2009 WQ6" "Sol" #3=
".:2009 WQ6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.003
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.806738783585
		SemiMajorAxis	0.866595618913
		Eccentricity	0.408627258434
		Inclination	5.816210616374
		AscendingNode	55.668540131875
		ArgOfPericenter	227.289139975614
		MeanAnomaly	186.294484671164
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2009+WQ6"
}

#1_"2009 WR52" "Sol" #1=
#2_"2009 WR52" "Sol" #2=
#3_"2009 WR52" "Sol" #3=
".:2009 WR52" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.051009699863
		SemiMajorAxis	1.033710706934
		Eccentricity	0.155305205959
		Inclination	4.241845950496
		AscendingNode	61.027930490084
		ArgOfPericenter	269.882080768299
		MeanAnomaly	359.445060477638
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.08
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2009+WR52"
}

#1_"2010 BK118" "Sol" #1=
#2_"2010 BK118" "Sol" #2=
#3_"2010 BK118" "Sol" #3=
".:2010 BK118" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	23
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	11159.0337125303
		SemiMajorAxis	499.358283234687
		Eccentricity	0.987776301724
		Inclination	143.909854889349
		AscendingNode	175.994691758766
		ArgOfPericenter	179.105382188932
		MeanAnomaly	0.084086491627
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+BK118"
}

#1_"2010 EK139" "Sol" #1=
#2_"2010 EK139" "Sol" #2=
#3_"2010 EK139" "Sol" #3=
".:2010 EK139" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Radius	235
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	580.29409668309
		SemiMajorAxis	69.57074171110006
		Eccentricity	0.5319539947648039
		Inclination	29.42738095156401
		AscendingNode	346.0995401413554
		ArgOfPericenter	284.4434589289875
		MeanAnomaly	345.205269303839
	}
	UniformRotation
	{
		Period	7.07
	}
	LunarLambert	0.5
	Albedo	0.25
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+EK139"
}

#1_"2010 EL139" "Sol" #1=
#2_"2010 EL139" "Sol" #2=
#3_"2010 EL139" "Sol" #3=
".:2010 EL139" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	210
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	247.981667161274
		SemiMajorAxis	39.470647307356
		Eccentricity	0.06992381303
		Inclination	22.969573823078
		AscendingNode	330.987763600972
		ArgOfPericenter	204.727336576079
		MeanAnomaly	30.569958286294
	}
	UniformRotation
	{
		Period	6.32
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+EL139"
}

#1_"2010 EQ65" "Sol" #1=
#2_"2010 EQ65" "Sol" #2=
#3_"2010 EQ65" "Sol" #3=
".:2010 EQ65" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	115.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	733.857257585497
		SemiMajorAxis	81.35837410324
		Eccentricity	0.577348296913
		Inclination	23.576031498905
		AscendingNode	336.089599749903
		ArgOfPericenter	237.929789402089
		MeanAnomaly	355.140927555401
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+EQ65"
}

#1_"2010 ER65" "Sol" #1=
#2_"2010 ER65" "Sol" #2=
#3_"2010 ER65" "Sol" #3=
".:2010 ER65" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	183
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	991.28794017463
		SemiMajorAxis	99.41709763378
		Eccentricity	0.597551165505
		Inclination	21.238321985105
		AscendingNode	212.636939949115
		ArgOfPericenter	324.151583469109
		MeanAnomaly	2.997969010771
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+ER65"
}

#1_"2010 ET65" "Sol" #1=
#2_"2010 ET65" "Sol" #2=
#3_"2010 ET65" "Sol" #3=
".:2010 ET65" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	200.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	496.825822895459
		SemiMajorAxis	62.728365618268
		Eccentricity	0.368339900962
		Inclination	30.568741695556
		AscendingNode	189.574192685918
		ArgOfPericenter	353.754779363471
		MeanAnomaly	1.03381967394
	}
	UniformRotation
	{
		Period	7.88
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+ET65"
}

#1_"2010 FX86" "Sol" #1=
#2_"2010 FX86" "Sol" #2=
#3_"2010 FX86" "Sol" #3=
".:2010 FX86" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	303.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	320.955471470501
		SemiMajorAxis	46.876774486763
		Eccentricity	0.055849603138
		Inclination	25.178577178679
		AscendingNode	310.78626116381
		ArgOfPericenter	350.844769457977
		MeanAnomaly	286.684606314892
	}
	UniformRotation
	{
		Period	15.8
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+FX86"
}

#1_"2010 GB174" "Sol" #1=
#2_"2010 GB174" "Sol" #2=
#3_"2010 GB174" "Sol" #3=
".:2010 GB174" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	111
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	6935.07137168339
		SemiMajorAxis	363.659682408141
		Eccentricity	0.865833386601
		Inclination	21.560511139298
		AscendingNode	130.713364409156
		ArgOfPericenter	347.767171314041
		MeanAnomaly	3.405673548894
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+GB174"
}

#1_"2010 GW64" "Sol" #1=
#2_"2010 GW64" "Sol" #2=
#3_"2010 GW64" "Sol" #3=
".:2010 GW64" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	496.80099269096
		SemiMajorAxis	62.726275588526
		Eccentricity	0.940704586919
		Inclination	105.272508486062
		AscendingNode	301.56003983948
		ArgOfPericenter	152.72594736065
		MeanAnomaly	3.366270784253
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+GW64"
}

#1_"2010 GW147" "Sol" #1=
#2_"2010 GW147" "Sol" #2=
#3_"2010 GW147" "Sol" #3=
".:2010 GW147" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	8
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2311.36530159066
		SemiMajorAxis	174.812945856033
		Eccentricity	0.969218905079
		Inclination	99.622672005393
		AscendingNode	313.334115744175
		ArgOfPericenter	50.114074191982
		MeanAnomaly	0.889369943424
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+GW147"
}

#1_"2010 HE79:2002 JR146" "Sol" #1=
#2_"2010 HE79" "Sol" #2=
#3_"2010 HE79" "Sol" #3=
".:2010 HE79" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	200.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	243.619971979585
		SemiMajorAxis	39.006452788684
		Eccentricity	0.182639276338
		Inclination	15.725212150875
		AscendingNode	238.690889389432
		ArgOfPericenter	282.073056675233
		MeanAnomaly	58.932528647139
	}
	UniformRotation
	{
		Period	19.49
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+HE79"
}

#1_"2010 JH124" "Sol" #1=
#2_"2010 JH124" "Sol" #2=
#3_"2010 JH124" "Sol" #3=
".:2010 JH124" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	3.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	568.459115285446
		SemiMajorAxis	68.621576046805
		Eccentricity	0.961986670519
		Inclination	53.440738339302
		AscendingNode	135.86145176403
		ArgOfPericenter	117.545199178692
		MeanAnomaly	2.33887676278
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+JH124"
}

#1_"2010 JJ124" "Sol" #1=
#2_"2010 JJ124" "Sol" #2=
#3_"2010 JJ124" "Sol" #3=
".:2010 JJ124" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	105.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	768.029111327101
		SemiMajorAxis	83.864787915368
		Eccentricity	0.718436388585
		Inclination	37.78298634739
		AscendingNode	268.79819112434
		ArgOfPericenter	339.163147235512
		MeanAnomaly	0.989205252818
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+JJ124"
}

#New4
#1_"2010 JO179" "Sol" #1=
#2_"2010 JO179" "Sol" #2=
#3_"2010 JO179" "Sol" #3=
".:2010 JO179" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"lightasteroid-smooth.dds"
	Radius	375
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	706.105018052863
		SemiMajorAxis	79.294073754085
		Eccentricity	0.501586173721
		Inclination	32.044538851481
		AscendingNode	147.116944529976
		ArgOfPericenter	10.720743944828
		MeanAnomaly	33.353691064878
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.7
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+JO179"
}

#1_"2010 KZ39" "Sol" #1=
#2_"2010 KZ39" "Sol" #2=
#3_"2010 KZ39" "Sol" #3=
".:2010 KZ39" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	348.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	303.456339636445
		SemiMajorAxis	45.15702702228
		Eccentricity	0.055319097372
		Inclination	26.090663247136
		AscendingNode	53.174428179854
		ArgOfPericenter	319.153059043246
		MeanAnomaly	248.414549588124
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+KZ39"
}

#1_"2010 PU75" "Sol" #1=
#2_"2010 PU75" "Sol" #2=
#3_"2010 PU75" "Sol" #3=
".:2010 PU75" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	167
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	771.203729927712
		SemiMajorAxis	84.095730235389
		Eccentricity	0.572957392007
		Inclination	8.897432854994
		AscendingNode	78.3149863812
		ArgOfPericenter	256.327811954321
		MeanAnomaly	354.028224301046
	}
	UniformRotation
	{
		Period	12.39
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+PU75"
}

#1_"2010 RE64" "Sol" #1=
#2_"2010 RE64" "Sol" #2=
#3_"2010 RE64" "Sol" #3=
".:2010 RE64" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	303.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	531.960974277203
		SemiMajorAxis	65.651962635915
		Eccentricity	0.450410975517
		Inclination	13.534187154976
		AscendingNode	67.481909501572
		ArgOfPericenter	21.066773275268
		MeanAnomaly	318.118975313938
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+RE64"
}

#1_"2010 RF12" "Sol" #1=
#2_"2010 RF12" "Sol" #2=
#3_"2010 RF12" "Sol" #3=
".:2010 RF12" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.0035
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.092106403998
		SemiMajorAxis	1.060484929123
		Eccentricity	0.188173136395
		Inclination	0.882356659045
		AscendingNode	163.841171751256
		ArgOfPericenter	267.577262986389
		MeanAnomaly	256.917676522886
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.21
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+RF12"
}

#1_"2010 RF43" "Sol" #1=
#2_"2010 RF43" "Sol" #2=
#3_"2010 RF43" "Sol" #3=
".:2010 RF43" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	333
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	345.785243188663
		SemiMajorAxis	49.264283260424
		Eccentricity	0.251083079785
		Inclination	30.671094544067
		AscendingNode	25.264769071191
		ArgOfPericenter	191.518671915055
		MeanAnomaly	93.657417172578
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+RF43"
}

#1_"2010 RF64" "Sol" #1=
#2_"2010 RF64" "Sol" #2=
#3_"2010 RF64" "Sol" #3=
".:2010 RF64" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	220
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	280.740771972314
		SemiMajorAxis	42.874413452293
		Eccentricity	0.171244657812
		Inclination	28.721322703241
		AscendingNode	131.132581826115
		ArgOfPericenter	209.691568982134
		MeanAnomaly	20.090443170716
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+RF64"
}

#1_"2010 RM45" "Sol" #1=
#2_"2010 RM45" "Sol" #2=
#3_"2010 RM45" "Sol" #3=
".:2010 RM45" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	110.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	515.183248238434
		SemiMajorAxis	64.264187414631
		Eccentricity	0.600872907798
		Inclination	18.939200100022
		AscendingNode	86.081076368907
		ArgOfPericenter	339.548304171273
		MeanAnomaly	336.43131034274
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+RM45"
}

#1_"2010 TJ" "Sol" #1=
#2_"2010 TJ" "Sol" #2=
#3_"2010 TJ" "Sol" #3=
".:2010 TJ" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	220
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	496.132354273405
		SemiMajorAxis	62.669981268234
		Eccentricity	0.362667199455
		Inclination	38.882024268611
		AscendingNode	91.365755258946
		ArgOfPericenter	274.259040017826
		MeanAnomaly	10.0024314667
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+TJ"
}

#1_"2010 TK7" "Sol" #1=
#2_"2010 TK7" "Sol" #2=
#3_"2010 TK7" "Sol" #3=
".:2010 TK7" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.999831342723
		SemiMajorAxis	0.99987496921
		Eccentricity	0.190668287104
		Inclination	20.888318394348
		AscendingNode	96.506614163807
		ArgOfPericenter	45.902402677181
		MeanAnomaly	319.801100127887
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+TK7"
}

#1_"2010 TS191" "Sol" #1=
#2_"2010 TS191" "Sol" #2=
#3_"2010 TS191" "Sol" #3=
".:2010 TS191" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	163.555368669243
		SemiMajorAxis	29.906877238633
		Eccentricity	0.04334649337
		Inclination	6.56341826683
		AscendingNode	129.635900978586
		ArgOfPericenter	302.169195854768
		MeanAnomaly	340.4500378425
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+TS191"
}

#1_"2010 TT191" "Sol" #1=
#2_"2010 TT191" "Sol" #2=
#3_"2010 TT191" "Sol" #3=
".:2010 TT191" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	164.521315282077
		SemiMajorAxis	30.024513591636
		Eccentricity	0.072142716841
		Inclination	4.285186179671
		AscendingNode	249.293229452944
		ArgOfPericenter	6.258460926274
		MeanAnomaly	168.737249341419
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+TT191"
}

#1_"2010 VK201" "Sol" #1=
#2_"2010 VK201" "Sol" #2=
#3_"2010 VK201" "Sol" #3=
".:2010 VK201" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	264.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	284.190449972225
		SemiMajorAxis	43.224918683489
		Eccentricity	0.109150788282
		Inclination	28.85986272757
		AscendingNode	156.591758174213
		ArgOfPericenter	82.914324731144
		MeanAnomaly	172.528971135503
	}
	UniformRotation
	{
		Period	7.59
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+VK201"
}

#1_"2010 VR11" "Sol" #1=
#2_"2010 VR11" "Sol" #2=
#3_"2010 VR11" "Sol" #3=
".:2010 VR11" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	175
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	268.18278660623
		SemiMajorAxis	41.586125948864
		Eccentricity	0.14861105145
		Inclination	30.891081875875
		AscendingNode	86.72088678284
		ArgOfPericenter	35.05994524727
		MeanAnomaly	320.221703722986
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+VR11"
}

#1_"2010 VZ98" "Sol" #1=
#2_"2010 VZ98" "Sol" #2=
#3_"2010 VZ98" "Sol" #3=
".:2010 VZ98" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	220
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1934.59535065708
		SemiMajorAxis	155.258227935761
		Eccentricity	0.778963045247
		Inclination	4.509135322538
		AscendingNode	117.46709099972
		ArgOfPericenter	313.849879685374
		MeanAnomaly	357.585175250208
	}
	UniformRotation
	{
		Period	9.72
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2010+VZ98"
}


#1_"2011 EO40" "Sol" #1=
#2_"2011 EO40" "Sol" #2=
#3_"2011 EO40" "Sol" #3=
".:2011 EO40" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.120
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.1273865551643
		SemiMajorAxis	1.654088740207769
		Eccentricity	0.5401623319591924
		Inclination	3.362858146975864
		AscendingNode	50.30283511413233
		ArgOfPericenter	17.07473083921291
		MeanAnomaly	312.5857684563506
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.12
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+EO40"
}

#1_"2011 FW62" "Sol" #1=
#2_"2011 FW62" "Sol" #2=
#3_"2011 FW62" "Sol" #3=
".:2011 FW62" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	220
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2455666.5  # 2011 Apr 15
		Period	251.338756628867
		SemiMajorAxis	39.826074947065
		Eccentricity	0.170778896628
		Inclination	26.778317047781
		AscendingNode	250.159848754631
		ArgOfPericenter	131.477270193152
		MeanAnomaly	126.298276970804
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+FW62"
}

#1_"2011 FY9" "Sol" #1=
#2_"2011 FY9" "Sol" #2=
#3_"2011 FY9" "Sol" #3=
".:2011 FY9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	459.110480358537
		SemiMajorAxis	59.512199694952
		Eccentricity	0.744759704087
		Inclination	37.73486900692
		AscendingNode	214.304454109866
		ArgOfPericenter	300.800055348868
		MeanAnomaly	4.957520432283
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+FY9"
}

#1_"2011 GM27" "Sol" #1=
#2_"2011 GM27" "Sol" #2=
#3_"2011 GM27" "Sol" #3=
".:2011 GM27" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	200.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	290.71057937359
		SemiMajorAxis	43.88355033214105
		Eccentricity	0.03088085504893522
		Inclination	13.03924132392566
		AscendingNode	257.0856440312772
		ArgOfPericenter	211.4713974878041
		MeanAnomaly	73.01363846432169
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+GM27"
}

#1_"2011 HM102" "Sol" #1=
#2_"2011 HM102" "Sol" #2=
#3_"2011 HM102" "Sol" #3=
".:2011 HM102" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	53
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2456597.5  # 2013 Nov 01
		Period	164.65013654073
		SemiMajorAxis	30.04018447314188
		Eccentricity	0.07922009031032798
		Inclination	29.42755958016819
		AscendingNode	100.9889060604037
		ArgOfPericenter	150.2338765686575
		MeanAnomaly	26.39853693948664
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+HM102"
}

#1_"2011 HO60" "Sol" #1=
#2_"2011 HO60" "Sol" #2=
#3_"2011 HO60" "Sol" #3=
".:2011 HO60" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	132.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	913.768746360246
		SemiMajorAxis	94.164108344925
		Eccentricity	0.611309540939
		Inclination	22.207795717113
		AscendingNode	353.13870922124
		ArgOfPericenter	243.050652542042
		MeanAnomaly	359.75890426817
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+HO60"
}

#1_"2011 KW48:VNH0004" "Sol" #1=
#2_"2011 KW48:VNH0004" "Sol" #2=
#3_"2011 KW48:VNH0004" "Sol" #3=
".:2011 KW48:VNH0004" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	38
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457026.5  # 2015 Jan 04
		Period	228.73528321473
		SemiMajorAxis	37.40100790074254
		Eccentricity	0.1340958176783411
		Inclination	3.631049937744919
		AscendingNode	246.1276187516301
		ArgOfPericenter	45.71672214175091
		MeanAnomaly	354.3988916357844
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+KW48"
}

#1_"2011 LT17" "Sol" #1=
#2_"2011 LT17" "Sol" #2=
#3_"2011 LT17" "Sol" #3=
".:2011 LT17" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.103
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.153244438258
		SemiMajorAxis	1.099703087496
		Eccentricity	0.287425604216
		Inclination	20.897332011286
		AscendingNode	83.495590704107
		ArgOfPericenter	270.574972357863
		MeanAnomaly	309.425939462945
	}
	UniformRotation
	{
		Period	1.291
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+LT17"
}

#1_"2011 OR17:2010 KZ127" "Sol" #1=
#2_"2011 OR17" "Sol" #2=
#3_"2011 OR17" "Sol" #3=
".:2011 OR17" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	5.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	4399.33252445262
		SemiMajorAxis	268.484400975047
		Eccentricity	0.988459750071
		Inclination	110.345298398118
		AscendingNode	271.586516114621
		ArgOfPericenter	13.989514772626
		MeanAnomaly	0.268700024304
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+OR17"
}

#1_"2011 QF99" "Sol" #1=
#2_"2011 QF99" "Sol" #2=
#3_"2011 QF99" "Sol" #3=
".:2011 QF99" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	25.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	83.586091743816
		SemiMajorAxis	19.11688868610214
		Eccentricity	0.1783479946234328
		Inclination	10.8119164581489
		AscendingNode	222.5070707446544
		ArgOfPericenter	287.0430343010917
		MeanAnomaly	273.3567849593775
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+QF99"
}

#1_"2011 SC191:2003 GX20" "Sol" #1=
#2_"2011 SC191" "Sol" #2=
#3_"2011 SC191" "Sol" #3=
".:2011 SC191" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.881071188511
		SemiMajorAxis	1.523811872181
		Eccentricity	0.044038278622
		Inclination	18.744899957728
		AscendingNode	5.783081159864
		ArgOfPericenter	196.32408269031
		MeanAnomaly	63.68823979715
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.275
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+SC191"
}

#1_"2011 SL25" "Sol" #1=
#2_"2011 SL25" "Sol" #2=
#3_"2011 SL25" "Sol" #3=
".:2011 SL25" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.2875
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.881127255013
		SemiMajorAxis	1.523842150808
		Eccentricity	0.11446937478
		Inclination	21.495666738872
		AscendingNode	9.416447999556
		ArgOfPericenter	53.285030738101
		MeanAnomaly	206.092572281302
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.275
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+SL25"
}

#1_"2011 SO277" "Sol" #1=
#2_"2011 SO277" "Sol" #2=
#3_"2011 SO277" "Sol" #3=
".:2011 SO277" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	66.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	164.750582571
		SemiMajorAxis	30.052400721994
		Eccentricity	0.015130491417
		Inclination	9.639705967202
		AscendingNode	113.528434308599
		ArgOfPericenter	112.114183172018
		MeanAnomaly	161.147858868822
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+SO277"
}

#1_"2011 UN63:2009 SA170" "Sol" #1=
#2_"2011 UN63" "Sol" #2=
#3_"2011 UN63" "Sol" #3=
".:2011 UN63" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.28
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.88098227022
		SemiMajorAxis	1.523763851382
		Eccentricity	0.064678514975
		Inclination	20.360744685591
		AscendingNode	223.561046485915
		ArgOfPericenter	165.233633208151
		MeanAnomaly	251.744558426591
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.275
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+UN63"
}

#1_"2011 UP411" "Sol" #1=
#2_"2011 UP411" "Sol" #2=
#3_"2011 UP411" "Sol" #3=
".:2011 UP411" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	42
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	660.315139279747
		SemiMajorAxis	75.827842886557
		Eccentricity	0.491402827456
		Inclination	13.433577413877
		AscendingNode	231.968155627988
		ArgOfPericenter	160.521267576496
		MeanAnomaly	1.174173265858
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+UP411"
}

#1_"2011 UQ412" "Sol" #1=
#2_"2011 UQ412" "Sol" #2=
#3_"2011 UQ412" "Sol" #3=
".:2011 UQ412" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	63.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	554.298550153694
		SemiMajorAxis	67.47719594311
		Eccentricity	0.48428174199
		Inclination	16.716200509955
		AscendingNode	219.948212522612
		ArgOfPericenter	197.767507631677
		MeanAnomaly	354.294426049367
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+UQ412"
}

#1_"2011 UW412" "Sol" #1=
#2_"2011 UW412" "Sol" #2=
#3_"2011 UW412" "Sol" #3=
".:2011 UW412" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	35
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	690.718453941353
		SemiMajorAxis	78.137930496038
		Eccentricity	0.521034621345
		Inclination	12.974813591434
		AscendingNode	233.184485257381
		ArgOfPericenter	134.241479259785
		MeanAnomaly	7.842957836602
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+UW412"
}

#1_"2011 WG157" "Sol" #1=
#2_"2011 WG157" "Sol" #2=
#3_"2011 WG157" "Sol" #3=
".:2011 WG157" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	83.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	163.868964725598
		SemiMajorAxis	29.945093386563
		Eccentricity	0.030831934555
		Inclination	22.320702225824
		AscendingNode	352.260370430896
		ArgOfPericenter	215.77024192
		MeanAnomaly	209.192846851371
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2011+WG157"
}

#1_"2012 DG61" "Sol" #1=
#2_"2012 DG61" "Sol" #2=
#3_"2012 DG61" "Sol" #3=
".:2012 DG61" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"comet.dds"
	Radius	0.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458200.5  # 2018 Mar 23
		Period	5.860626166867
		SemiMajorAxis	3.250552701631
		Eccentricity	0.738139115711
		Inclination	15.33811525474
		AscendingNode	70.000629809315
		ArgOfPericenter	186.126233551549
		MeanAnomaly	348.806751180022
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2012+DG61"
}

#1_"2012 DR30:2009 FW54" "Sol" #1=
#2_"2012 DR30" "Sol" #2=
#3_"2012 DR30" "Sol" #3=
".:2012 DR30:2009 FW54" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	85.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	44908.5154345173
		SemiMajorAxis	1263.41781825316
		Eccentricity	0.988488108546
		Inclination	77.956921266757
		AscendingNode	341.393708805772
		ArgOfPericenter	195.319521502043
		MeanAnomaly	0.029868081802
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2012+DR30"
}

#1_"2012 HD2" "Sol" #1=
#2_"2012 HD2" "Sol" #2=
#3_"2012 HD2" "Sol" #3=
".:2012 HD2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	477.576809956567
		SemiMajorAxis	61.097487613793
		Eccentricity	0.958192680596
		Inclination	146.896977315459
		AscendingNode	21.990581003095
		ArgOfPericenter	200.09642608
		MeanAnomaly	1.726669761465
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2012+HD2"
}

#1_"2012 HG2" "Sol" #1=
#2_"2012 HG2" "Sol" #2=
#3_"2012 HG2" "Sol" #3=
".:2012 HG2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	0.009
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.296635817022
		SemiMajorAxis	1.189067588016
		Eccentricity	0.181719205676
		Inclination	0.111221532137
		AscendingNode	143.358955971178
		ArgOfPericenter	26.390777009424
		MeanAnomaly	40.254909805479
	}
	UniformRotation
	{
		Period	0.0227
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2012+HG2"
}

#1_"2012 KA51" "Sol" #1=
#2_"2012 KA51" "Sol" #2=
#3_"2012 KA51" "Sol" #3=
".:2012 KA51" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	13.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2456072.5  # 2012 May 25
		Period	3362.74893926604
		SemiMajorAxis	224.452352383065
		Eccentricity	0.978125842726
		Inclination	70.66149118707
		AscendingNode	344.953285711402
		ArgOfPericenter	95.037973293664
		MeanAnomaly	0.058425778341
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2012+KA51"
}

#1_"2012 TC4" "Sol" #1=
#2_"2012 TC4" "Sol" #2=
#3_"2012 TC4" "Sol" #3=
".:2012 TC4" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.0075
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457997.5  # 2017 Sept 01
		Period	1.6666118993296
		SemiMajorAxis	1.405672614776047
		Eccentricity	0.3358040970876091
		Inclination	0.8564420913769386
		AscendingNode	198.2499503386388
		ArgOfPericenter	222.5614740812817
		MeanAnomaly	315.0315821585153
	}
	UniformRotation
	{
		Period	0.2038
	}
	LunarLambert	0.5
	Albedo	0.2
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2012+TC4"
}

#1_"2012 UE34" "Sol" #1=
#2_"2012 UE34" "Sol" #2=
#3_"2012 UE34" "Sol" #3=
".:2012 UE34" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.049
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.162131151487
		SemiMajorAxis	1.105345278199
		Eccentricity	0.099217487586
		Inclination	9.657897697115
		AscendingNode	198.487853882181
		ArgOfPericenter	18.410856092037
		MeanAnomaly	114.011171366299
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2012+UE34"
}

#1_"2012 UK177" "Sol" #1=
#2_"2012 UK177" "Sol" #2=
#3_"2012 UK177" "Sol" #3=
".:2012 UK177" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	890.184056930438
		SemiMajorAxis	92.536784923614
		Eccentricity	0.61837189908
		Inclination	24.84010846387
		AscendingNode	251.50975274467
		ArgOfPericenter	162.669167717472
		MeanAnomaly	356.279384440526
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2012+UK177"
}

#1_"2012 UR177" "Sol" #1=
#2_"2012 UR177" "Sol" #2=
#3_"2012 UR177" "Sol" #3=
".:2012 UR177" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	58
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	636.126529897176
		SemiMajorAxis	73.964536043961
		Eccentricity	0.493322836285
		Inclination	16.345490890794
		AscendingNode	291.616414480577
		ArgOfPericenter	158.174784162859
		MeanAnomaly	342.547424364031
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2012+UR177"
}

#1_"2012 UV177" "Sol" #1=
#2_"2012 UV177" "Sol" #2=
#3_"2012 UV177" "Sol" #3=
".:2012 UV177" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	32
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	163.69130582346
		SemiMajorAxis	29.923446114217
		Eccentricity	0.071928865233
		Inclination	20.85190235252
		AscendingNode	265.62234782
		ArgOfPericenter	206.899322476684
		MeanAnomaly	295.372569703213
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2012+UV177"
}

#1_"2012 VP113" "Sol" #1=
#2_"2012 VP113" "Sol" #2=
#3_"2012 VP113" "Sol" #3=
".:2012 VP113" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid-smooth.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	351
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	4090.22680526068
		SemiMajorAxis	255.756173444886
		Eccentricity	0.685250552695
		Inclination	24.085640402949
		AscendingNode	90.731476669345
		ArgOfPericenter	293.836652567502
		MeanAnomaly	3.421954714993
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"https://en.wikipedia.org/wiki/2012_VP113"
}

#1_"2012 WD36" "Sol" #1=
#2_"2012 WD36" "Sol" #2=
#3_"2012 WD36" "Sol" #3=
".:2012 WD36" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	91.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	677.201925285545
		SemiMajorAxis	77.115199758468
		Eccentricity	0.515276617069
		Inclination	23.714852599214
		AscendingNode	177.390825953874
		ArgOfPericenter	293.665131479262
		MeanAnomaly	336.589667265143
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2012+WD36"
}

#1_"2012 XB112" "Sol" #1=
#2_"2012 XB112" "Sol" #2=
#3_"2012 XB112" "Sol" #3=
".:2012 XB112" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.00125
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.037921491425
		SemiMajorAxis	1.025110939787
		Eccentricity	0.144637542904
		Inclination	1.32664770829
		AscendingNode	76.989806208777
		ArgOfPericenter	87.540932417542
		MeanAnomaly	262.262101020978
	}
	UniformRotation
	{
		Period	0.043333
	}
	LunarLambert	0.5
	Albedo	0.31
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2012+XB112"
}

#1_"2013 AZ60" "Sol" #1=
#2_"2013 AZ60" "Sol" #2=
#3_"2013 AZ60" "Sol" #3=
".:2013 AZ60" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	20
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	28554.121846266
		SemiMajorAxis	934.2011640454119
		Eccentricity	0.9915358129911662
		Inclination	16.52928889576902
		AscendingNode	349.2171882064804
		ArgOfPericenter	158.0446357086123
		MeanAnomaly	0.0004791092983887568
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+AZ60"
}

#1_"2013 BL76" "Sol" #1=
#2_"2013 BL76" "Sol" #2=
#3_"2013 BL76" "Sol" #3=
".:2013 BL76" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	15
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	44381.5149450983
		SemiMajorAxis	1253.51426395699
		Eccentricity	0.993319900508
		Inclination	98.607141368809
		AscendingNode	180.198132864871
		ArgOfPericenter	166.113321084745
		MeanAnomaly	0.017153812033
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+BL76"
}

#1_"2013 BN27" "Sol" #1=
#2_"2013 BN27" "Sol" #2=
#3_"2013 BN27" "Sol" #3=
".:2013 BN27" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	0.85
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	498.526442999709
		SemiMajorAxis	62.871428972861
		Eccentricity	0.975134982123
		Inclination	101.779615207211
		AscendingNode	128.018740994672
		ArgOfPericenter	300.400756824953
		MeanAnomaly	1.546582825486
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+BN27"
}

#1_"2013 FC28" "Sol" #1=
#2_"2013 FC28" "Sol" #2=
#3_"2013 FC28" "Sol" #3=
".:2013 FC28" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	210
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	314.23176481253
		SemiMajorAxis	46.21978506093539
		Eccentricity	0.08204757767957835
		Inclination	16.27974028912368
		AscendingNode	193.1832653625346
		ArgOfPericenter	93.9223264183063
		MeanAnomaly	255.174966183573
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+FC28"
}

#1_"2013 FT28" "Sol" #1=
#2_"2013 FT28" "Sol" #2=
#3_"2013 FT28" "Sol" #3=
".:2013 FT28" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	101
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5518.50250000074
		SemiMajorAxis	312.278458994993
		Eccentricity	0.860509360545
		Inclination	17.329026165599
		AscendingNode	217.780172817898
		ArgOfPericenter	40.264851223146
		MeanAnomaly	357.255446303848
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+FT28"
}

#1_"2013 FY27" "Sol" #1=
#2_"2013 FY27" "Sol" #2=
#3_"2013 FY27" "Sol" #3=
".:2013 FY27" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Radius	376
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2456549.5  # 2013 Sept 14
		Period	460.30334599126
		SemiMajorAxis	59.61523858579225
		Eccentricity	0.4037466760868446
		Inclination	33.12113097009031
		AscendingNode	187.0505237776004
		ArgOfPericenter	133.2396603750165
		MeanAnomaly	221.6213835536648
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.15
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+FY27"
}

#1_"2013 FZ27" "Sol" #1=
#2_"2013 FZ27" "Sol" #2=
#3_"2013 FZ27" "Sol" #3=
".:2013 FZ27" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	348.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	336.31891076801
		SemiMajorAxis	48.36101311960537
		Eccentricity	0.2146112959931362
		Inclination	14.01441905038581
		AscendingNode	284.9338166672324
		ArgOfPericenter	340.8287482572005
		MeanAnomaly	278.8882857948716
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+FZ27"
}

#1_"2013 GP136" "Sol" #1=
#2_"2013 GP136" "Sol" #2=
#3_"2013 GP136" "Sol" #3=
".:2013 GP136" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	105.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	1897.6071004462
		SemiMajorAxis	153.272907679419
		Eccentricity	0.731758493567
		Inclination	33.474741548564
		AscendingNode	210.711560086141
		ArgOfPericenter	42.142447626781
		MeanAnomaly	356.195617079565
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+GP136"
}

#1_"2013 JW63" "Sol" #1=
#2_"2013 JW63" "Sol" #2=
#3_"2013 JW63" "Sol" #3=
".:2013 JW63" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	200.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	318.667006374252
		SemiMajorAxis	46.653682791554
		Eccentricity	0.184350432466
		Inclination	7.753415479166
		AscendingNode	309.193156448101
		ArgOfPericenter	18.48395400332
		MeanAnomaly	294.83144654003
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+JW63"
}

#1_"2013 KY18" "Sol" #1=
#2_"2013 KY18" "Sol" #2=
#3_"2013 KY18" "Sol" #3=
".:2013 KY18" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	105.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	166.541032677142
		SemiMajorAxis	30.269740700292
		Eccentricity	0.120499623543
		Inclination	6.651378706598
		AscendingNode	84.403455436914
		ArgOfPericenter	269.290736900946
		MeanAnomaly	277.318301492949
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+KY18"
}

#1_"2013 LA2" "Sol" #1=
#2_"2013 LA2" "Sol" #2=
#3_"2013 LA2" "Sol" #3=
".:2013 LA2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	0.9
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2456448.5  # 2013 Jun 05
		Period	20.586985447773
		SemiMajorAxis	7.511437134375
		Eccentricity	0.594150227923
		Inclination	175.188725464096
		AscendingNode	240.989499008522
		ArgOfPericenter	326.062025198131
		MeanAnomaly	6.637760156786
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+LA2"
}

#1_"2013 LD16" "Sol" #1=
#2_"2013 LD16" "Sol" #2=
#3_"2013 LD16" "Sol" #3=
".:2013 LD16" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	1.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	714.906475199434
		SemiMajorAxis	79.951635521461
		Eccentricity	0.968171239311
		Inclination	154.748480053619
		AscendingNode	25.782998544855
		ArgOfPericenter	186.063132150989
		MeanAnomaly	0.579305645361
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+LD16"
}

#1_"2013 ND15" "Sol" #1=
#2_"2013 ND15" "Sol" #2=
#3_"2013 ND15" "Sol" #3=
".:2013 ND15" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.035
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457200.5  # 2015 Jun 27
		Period	0.61542551641485
		SemiMajorAxis	0.7235105434686168
		Eccentricity	0.6116255190617593
		Inclination	4.796248524399885
		AscendingNode	95.84212866032168
		ArgOfPericenter	19.6935033509466
		MeanAnomaly	238.5150188751832
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.12
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+ND15"
}

#1_"2013 RF98" "Sol" #1=
#2_"2013 RF98" "Sol" #2=
#3_"2013 RF98" "Sol" #3=
".:2013 RF98" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	40.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	6526.52460424782
		SemiMajorAxis	349.233463894242
		Eccentricity	0.896668058083
		Inclination	29.579219375872
		AscendingNode	67.586660038911
		ArgOfPericenter	311.728690022558
		MeanAnomaly	0.435234637457
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+RF98"
}

#1_"2013 SY99:uo3L91" "Sol" #1=
#2_"2013 SY99:uo3L91" "Sol" #2=
#3_"2013 SY99:uo3L91" "Sol" #3=
".:2013 SY99:uo3L91" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.670 0.375 ]
	BlendTexture	true
	Radius	101
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	17455.2208419262
		SemiMajorAxis	672.891068357202
		Eccentricity	0.925780332863
		Inclination	4.233856634627
		AscendingNode	29.473286619351
		ArgOfPericenter	32.324849271819
		MeanAnomaly	359.2265096028
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+SY99"
}

#1_"2013 TV135" "Sol" #1=
#2_"2013 TV135" "Sol" #2=
#3_"2013 TV135" "Sol" #3=
".:2013 TV135" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.205
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	3.7901504316957
		SemiMajorAxis	2.43089106225854
		Eccentricity	0.5913595627908189
		Inclination	6.75152269021055
		AscendingNode	333.437600873487
		ArgOfPericenter	23.6871120187438
		MeanAnomaly	115.5811004080614
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2013+TV135"
}

#1_"2014 AA" "Sol" #1=
#2_"2014 AA" "Sol" #2=
#3_"2014 AA" "Sol" #3=
".:2014 AA" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.0015
	Ending	"2014 01 02 05:02:00"
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2456658.5  # 2014 Jan 01
		Period	1.2519206281189
		SemiMajorAxis	1.161570914329746
		Eccentricity	0.210903385513902
		Inclination	1.4109467942359
		AscendingNode	101.613014674528
		ArgOfPericenter	52.3157504212017
		MeanAnomaly	324.0051879996831
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"https://en.wikipedia.org/wiki/2014_AA"
}

#1_"2014 FC69" "Sol" #1=
#2_"2014 FC69" "Sol" #2=
#3_"2014 FC69" "Sol" #3=
".:2014 FC69" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	257.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	630.03220430851
		SemiMajorAxis	73.49137358052909
		Eccentricity	0.4542113088582214
		Inclination	30.09559750584638
		AscendingNode	250.1455744298129
		ArgOfPericenter	191.1725964170932
		MeanAnomaly	83.33794902269683
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2014+FC69"
}

#1_"2014 FE72" "Sol" #1=
#2_"2014 FE72" "Sol" #2=
#3_"2014 FE72" "Sol" #3=
".:2014 FE72" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	127.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	84970.8830820834
		SemiMajorAxis	1932.74527263063
		Eccentricity	0.981198063521
		Inclination	20.615556968002
		AscendingNode	336.801904658796
		ArgOfPericenter	134.384028436663
		MeanAnomaly	0.219672601088
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2014+FE72"
}

#1_"2014 FZ71" "Sol" #1=
#2_"2014 FZ71" "Sol" #2=
#3_"2014 FZ71" "Sol" #3=
".:2014 FZ71" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	91.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	667.607217416366
		SemiMajorAxis	76.385081659787
		Eccentricity	0.26779386717
		Inclination	25.440879242512
		AscendingNode	305.854647318505
		ArgOfPericenter	243.764770815244
		MeanAnomaly	349.173648480818
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2014+FZ71"
}

#1_"2014 HQ124" "Sol" #1=
#2_"2014 HQ124" "Sol" #2=
#3_"2014 HQ124" "Sol" #3=
".:2014 HQ124" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.162
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	0.78477910676
		SemiMajorAxis	0.850797398605
		Eccentricity	0.259147183119
		Inclination	26.369702512683
		AscendingNode	257.572365830706
		ArgOfPericenter	144.493926356876
		MeanAnomaly	106.074817084135
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.46
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2014+HQ124"
}

#1_"2014 QO441" "Sol" #1=
#2_"2014 QO441" "Sol" #2=
#3_"2014 QO441" "Sol" #3=
".:2014 QO441" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	48
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	164.339832465966
		SemiMajorAxis	30.002429581655
		Eccentricity	0.108770601317
		Inclination	18.835176281964
		AscendingNode	106.98626882924
		ArgOfPericenter	114.485162197994
		MeanAnomaly	171.142249928196
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2014+QO441"
}

#1_"2014 QP441" "Sol" #1=
#2_"2014 QP441" "Sol" #2=
#3_"2014 QP441" "Sol" #3=
".:2014 QP441" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	30.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	164.057506876547
		SemiMajorAxis	29.968058199593
		Eccentricity	0.06474277397
		Inclination	19.411785830337
		AscendingNode	96.51961632806
		ArgOfPericenter	4.923015419882
		MeanAnomaly	300.998798104676
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2014+QP441"
}

#1_"2014 RC" "Sol" #1=
#2_"2014 RC" "Sol" #2=
#3_"2014 RC" "Sol" #3=
".:2014 RC" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.011
	Visible	false
	Clickable	false
	Timeline
	[
		{
			Ending	2456907.5  # 2014 Sept 07
			EllipticalOrbit
			{
				Epoch	2456907.5  # 2014 Sept 07
				Period	1.6484992476219
				SemiMajorAxis	1.395469559571079
				Eccentricity	0.4025874493549393
				Inclination	1.450604017374244
				AscendingNode	345.4602665122169
				ArgOfPericenter	65.90388400623823
				MeanAnomaly	329.8929085243304
			}
			UniformRotation
			{
				Period	0.004389
			}
		}
		{
			Ending	2456908.5  # 2014 Sept 08
			SampledOrbit	"2014 RC 2014-09-07 - 2014-09-08.xyzv"
			UniformRotation
			{
				Period	0.004389
			}
		}
		{
			EllipticalOrbit
			{
				Epoch	2456908.5  # 2014 Sept 08
				Period	1.5240575106138
				SemiMajorAxis	1.324327616215712
				Eccentricity	0.3818591352927818
				Inclination	4.618963742412432
				AscendingNode	345.0246379018984
				ArgOfPericenter	71.07359966744463
				MeanAnomaly	325.9984463858894
			}
			UniformRotation
			{
				Period	0.004389
			}
		}
	]
	LunarLambert	0.5
	Albedo	0.24
	InfoURL	"https://en.wikipedia.org/wiki/2014_RC"
}

#1_"2014 SR349" "Sol" #1=
#2_"2014 SR349" "Sol" #2=
#3_"2014 SR349" "Sol" #3=
".:2014 SR349" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	101
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	5031.13634941262
		SemiMajorAxis	293.610730386425
		Eccentricity	0.837853966786
		Inclination	17.984542404363
		AscendingNode	34.754289519258
		ArgOfPericenter	341.229006583163
		MeanAnomaly	357.436397031792
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2014+SR349"
}

#1_"2014 UM33:2010 TQ182" "Sol" #1=
#2_"2014 UM33" "Sol" #2=
#3_"2014 UM33" "Sol" #3=
".:2014 UM33" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	303.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	282.50233820586
		SemiMajorAxis	43.05357601545013
		Eccentricity	0.1570236233945242
		Inclination	17.36481995483274
		AscendingNode	236.6254083206408
		ArgOfPericenter	267.8764861971547
		MeanAnomaly	268.5452231561115
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2014+UM33"
}

#1_"2014 UR116:2008 XB" "Sol" #1=
#2_"2014 UR116" "Sol" #2=
#3_"2014 UR116" "Sol" #3=
".:2014 UR116" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.185
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	2.982779592687
		SemiMajorAxis	2.072090122903
		Eccentricity	0.72805140532
		Inclination	6.576538038789
		AscendingNode	6.006663176638
		ArgOfPericenter	286.82214781596
		MeanAnomaly	30.901130894098
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2014+UR116"
}

#1_"2014 UZ224" "Sol" #1=
#2_"2014 UZ224" "Sol" #2=
#3_"2014 UZ224" "Sol" #3=
".:2014 UZ224" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Color	[ 1.000 0.609 0.507 ]
	BlendTexture	true
	Radius	317.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	1132.45737104527
		SemiMajorAxis	108.644840603755
		Eccentricity	0.65089923203
		Inclination	26.785384838617
		AscendingNode	131.084768059672
		ArgOfPericenter	29.709247314154
		MeanAnomaly	320.275516175698
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.131
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2014+UZ224"
}

#1_"2014 WT69" "Sol" #1=
#2_"2014 WT69" "Sol" #2=
#3_"2014 WT69" "Sol" #3=
".:2014 WT69" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"darkasteroid-smooth.dds"
	Radius	159.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2456981.5  # 2014 Nov 20
		Period	671.11708060858
		SemiMajorAxis	76.65257109429912
		Eccentricity	0.4188628497078152
		Inclination	10.17700109503644
		AscendingNode	267.6355592353411
		ArgOfPericenter	139.5586437451629
		MeanAnomaly	0.1038632569691494
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2014+WT69"
}

#1_"2014 YX49" "Sol" #1=
#2_"2014 YX49" "Sol" #2=
#3_"2014 YX49" "Sol" #3=
".:2014 YX49" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	83.674941309465
		SemiMajorAxis	19.130433415445
		Eccentricity	0.276539103101
		Inclination	25.550972899459
		AscendingNode	91.444246139114
		ArgOfPericenter	280.584052564266
		MeanAnomaly	75.586982182328
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2014+YX49"
}

#1_"2015 BP519:Caju" "Sol" #1=
#2_"*Кешью:2015 BP519:Caju" "Sol" #2=
#3_"2015 BP519:Caju" "Sol" #3=
".:Caju:2015 BP519" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	275
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458200.5  # 2018 Mar 23
		Period	8931.70368044489
		SemiMajorAxis	430.477776770896
		Eccentricity	0.918367455506
		Inclination	54.117310590973
		AscendingNode	135.191523852021
		ArgOfPericenter	348.390853361671
		MeanAnomaly	358.359010589217
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.04
	InfoURL	"https://en.wikipedia.org/wiki/2015_BP519"
}

#1_"2015 FK37" "Sol" #1=
#2_"2015 FK37" "Sol" #2=
#3_"2015 FK37" "Sol" #3=
".:2015 FK37" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"asteroid.dds"
	Radius	2.54
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1067.8196019752
		SemiMajorAxis	104.4703679830376
		Eccentricity	0.952949197679866
		Inclination	155.841819124856
		AscendingNode	171.9545375338056
		ArgOfPericenter	317.5489483164333
		MeanAnomaly	0.1097875996163555
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2015+FK37"
}

#1_"2015 GT50:o5p060" "Sol" #1=
#2_"2015 GT50:o5p060" "Sol" #2=
#3_"2015 GT50:o5p060" "Sol" #3=
".:2015 GT50:o5p060" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	44
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	6127.9497757584
		SemiMajorAxis	334.866212396542
		Eccentricity	0.885166309685
		Inclination	8.779186418442
		AscendingNode	46.099319986454
		ArgOfPericenter	129.245140213705
		MeanAnomaly	1.020820003363
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2015+GT50"
}

#1_"2015 JD3" "Sol" #1=
#2_"2015 JD3" "Sol" #2=
#3_"2015 JD3" "Sol" #3=
".:2015 JD3" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.015
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457000.5  # 2014 Dec 09
		Period	1.088847104223
		SemiMajorAxis	1.058373926138
		Eccentricity	0.009334599205
		Inclination	2.730265631914
		AscendingNode	44.116858913207
		ArgOfPericenter	71.518431914111
		MeanAnomaly	335.722120844492
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2015+JD3"
}

#1_"2015 KG163:o5m52" "Sol" #1=
#2_"2015 KG163:o5m52" "Sol" #2=
#3_"2015 KG163:o5m52" "Sol" #3=
".:2015 KG163:o5m52" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Visible	false
	Clickable	false
	Radius	50.5
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	23094.6602959823
		SemiMajorAxis	810.965260849798
		Eccentricity	0.950053039845
		Inclination	13.967050842575
		AscendingNode	219.059053296922
		ArgOfPericenter	32.005766789446
		MeanAnomaly	359.926322653273
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2015+KG163"
}

#1_"2015 RR245" "Sol" #1=
#2_"2015 RR245" "Sol" #2=
#3_"2015 RR245" "Sol" #3=
".:2015 RR245" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"darkasteroid-smooth.dds"
	Radius	400.5
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	734.080288260337
		SemiMajorAxis	81.374857321562
		Eccentricity	0.585869746744
		Inclination	7.575668336455
		AscendingNode	211.679654794831
		ArgOfPericenter	261.399409965423
		MeanAnomaly	322.586643276766
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2015+RR245"
}

#New4
#1_"2015 RX245:o5t52" "Sol" #1=
#2_"2015 RX245:o5t52" "Sol" #2=
#3_"2015 RX245:o5t52" "Sol" #3=
".:2015 RX245:o5t52" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Radius	127.5
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	8362.79812350692
		SemiMajorAxis	411.998473793487
		Eccentricity	0.889688965019
		Inclination	12.166493919358
		AscendingNode	8.604905014136
		ArgOfPericenter	65.398416271118
		MeanAnomaly	357.916261751349
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2015+RX245"
}


#1_"2015 TB145" "Sol" #1=
#2_"2015 TB145" "Sol" #2=
#3_"2015 TB145" "Sol" #3=
".:2015 TB145" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"roughsphere.cmod"
	Texture	"comet.dds"
	Radius	0.3
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	3.045172933911
		SemiMajorAxis	2.100886091197
		Eccentricity	0.860122146711
		Inclination	39.690174874985
		AscendingNode	37.711969690724
		ArgOfPericenter	121.757193946164
		MeanAnomaly	204.686603793446
	}
	UniformRotation
	{
		Period	2.938
	}
	LunarLambert	0.5
	Albedo	0.06
	InfoURL	"https://en.wikipedia.org/wiki/2015_TB145"
}

#1_"2015 TN178" "Sol" #1=
#2_"2015 TN178" "Sol" #2=
#3_"2015 TN178" "Sol" #3=
".:2015 TN178" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.750 0.583 ]
	BlendTexture	true
	Radius	2
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	454.478160891149
		SemiMajorAxis	59.111213854214
		Eccentricity	0.959436929941
		Inclination	90.935721019616
		AscendingNode	225.865787885554
		ArgOfPericenter	275.149947443083
		MeanAnomaly	359.937483455611
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.09
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2015+TN178"
}

#1_"2016 JH" "Sol" #1=
#2_"2016 JH" "Sol" #2=
#3_"2016 JH" "Sol" #3=
".:2016 JH" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.008
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	1.634663853535
		SemiMajorAxis	1.387650739413
		Eccentricity	0.256761343679
		Inclination	0.828762953983
		AscendingNode	67.604285946441
		ArgOfPericenter	126.3836963188
		MeanAnomaly	70.108866342042
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2016+JH"
}

#1_"2016 NW" "Sol" #1=
#2_"2016 NW" "Sol" #2=
#3_"2016 NW" "Sol" #3=
".:2016 NW" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.41
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457600.5  # 2016 Jul 31
		Period	5.539942559417
		SemiMajorAxis	3.130867629218
		Eccentricity	0.567271812233
		Inclination	17.383437093587
		AscendingNode	296.649505697087
		ArgOfPericenter	49.082639642628
		MeanAnomaly	352.492296656344
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2016+NW"
}

#1_"2016 WF9" "Sol" #1=
#2_"2016 WF9" "Sol" #2=
#3_"2016 WF9" "Sol" #3=
".:2016 WF9" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"comet.dds"
	Radius	0.375
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	4.86467210716
		SemiMajorAxis	2.870980528802
		Eccentricity	0.658045971093
		Inclination	14.995705185355
		AscendingNode	125.426222471365
		ArgOfPericenter	342.433673417618
		MeanAnomaly	3.004193267633
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.05
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2016+WF9"
}

#1_"2017 AG13" "Sol" #1=
#2_"2017 AG13" "Sol" #2=
#3_"2017 AG13" "Sol" #3=
".:2017 AG13" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.0135
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	0.945312793868
		SemiMajorAxis	0.963189092
		Eccentricity	0.428856847291
		Inclination	16.449611542525
		AscendingNode	289.264196450905
		ArgOfPericenter	297.884546048139
		MeanAnomaly	330.865257104157
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2017+AG13"
}

#1_"2017 BQ6" "Sol" #1=
#2_"2017 BQ6" "Sol" #2=
#3_"2017 BQ6" "Sol" #3=
".:2017 BQ6" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.1
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2457800.5  # 2017 Feb 16
		Period	2.719024524269
		SemiMajorAxis	1.948064273321
		Eccentricity	0.531161947536
		Inclination	9.004229628562
		AscendingNode	133.04699354966
		ArgOfPericenter	43.558019922294
		MeanAnomaly	352.565112207918
	}
	UniformRotation
	{
		Period	3
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2017+BQ6"
}


#1_"2017 BX" "Sol" #1=
#2_"2017 BX" "Sol" #2=
#3_"2017 BX" "Sol" #3=
".:2017 BX" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.005
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458000.5  # 2017 Sept 04
		Period	1.763945320224
		SemiMajorAxis	1.459882639706
		Eccentricity	0.357491823983
		Inclination	4.613418755513
		AscendingNode	124.396828521905
		ArgOfPericenter	35.269565376416
		MeanAnomaly	108.151967229783
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.1
	InfoURL	"http://ssd.jpl.nasa.gov/sbdb.cgi?sstr=2017+BX"
}

#1_"2017 OF69" "Sol" #1=
#2_"2017 OF69" "Sol" #2=
#3_"2017 OF69" "Sol" #3=
".:2017 OF69" "Sol" #4=
{
	Class	"asteroid"  # Кандидат в карликовые планеты
	Texture	"asteroid-smooth.dds"
	Radius	265
	OrbitColor	[ 0.27451 0.078431 0.54902 ]
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458200.5  # 2018 Mar 23
		Period	248.511413670616
		SemiMajorAxis	39.526839633617
		Eccentricity	0.208189448457
		Inclination	13.653319432811
		AscendingNode	218.493530577123
		ArgOfPericenter	216.133280372127
		MeanAnomaly	248.632759244255
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.175
	InfoURL	"https://en.wikipedia.org/wiki/2017_OF69"
}

#1_"2018 LA:ZLAF9B2" "Sol" #1=
#2_"2018 LA:ZLAF9B2" "Sol" #2=
#3_"2018 LA:ZLAF9B2" "Sol" #3=
".:2018 LA:ZLAF9B2" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-small.cmod"
	Texture	"asteroid-smooth.dds"
	Radius	0.0016
	Ending	"2018 06 02 16:56:30"
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2458271.5  # 2018 Jun 02
		Period	1.614655933188
		SemiMajorAxis	1.376304490963
		Eccentricity	0.431805384263
		Inclination	4.296820839591
		AscendingNode	71.869629418404
		ArgOfPericenter	256.048232208176
		MeanAnomaly	326.725166028163
	}
	UniformRotation
	{
		Period	6
	}
	LunarLambert	0.5
	Albedo	0.225
	InfoURL	"https://en.wikipedia.org/wiki/2018_LA"
}

#1_"1I-Oumuamua:Oumuamua:A-2017 U1:2017 U1:P10Ee5V" "Sol" #1=
#2_"*Оумуамуа:1I-Oumuamua:Oumuamua:A-2017 U1:2017 U1:P10Ee5V" "Sol" #2=
#3_"2017 U1:*Оумуамуа:1I-Oumuamua:Oumuamua:A-2017 U1:P10Ee5V" "Sol" #3=
".:1I-Oumuamua:Oumuamua:A-2017 U1:2017 U1:P10Ee5V" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"asteroid-large.cmod"
	Texture	"darkasteroid.dds"
	Color	[ 1.000 0.922 0.918 ]
	BlendTexture	true
	SemiAxes	[ 0.09 0.015 0.015 ]
	Beginning	"1997 09 09"
	Ending	"2037 09 09"
	Visible	false
	Clickable	false
	SampledTrajectory
	{
		Source	"1I-Oumuamua.xyzv"
		DoublePrecision	true
		Interpolation	"cubic"
	}
	PrecessingRotation
	{
		Period	8.1
		Inclination	85
		PrecessionPeriod	0.001
	}
	Albedo	0.08
	InfoURL	"https://en.wikipedia.org/wiki/Oumuamua"
}

#==========================================
# Часть 2. Метеориты
#==========================================
#1_"Jackson Lake:Great Daylight Fireball:US19720810" "Sol" #1=
#2_"*Джексон Лайк:Jackson Lake:*Великий дневной свет:Great Daylight Fireball:US19720810" "Sol" #2=
#3_"Jackson Lake:*Джексон Лайк:Great Daylight Fireball:*Великий дневной свет:US19720810" "Sol" #3=
".:Jackson Lake:Great Daylight Fireball:US19720810" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"jackson-lake.cms"
	Texture	"asteroid-smooth.dds"
	Radius	0.0015
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2441540.35208  # 1972 Aug 10 20:27
		Period	1.785009
		SemiMajorAxis	1.47149265
		Eccentricity	0.3633
		Inclination	15.22
		AscendingNode	318.665
		ArgOfPericenter	315.76
		MeanAnomaly	20.3094
	}
	UniformRotation
	{
		Period	2.5
	}
	LunarLambert	0.5
	Albedo	0.159
	InfoURL	"https://en.wikipedia.org/wiki/1972_Great_Daylight_Fireball"
}

#1_"Sikhote-Alin meteorite" "Sol" #1=
#2_"*Сихотэ-Алинский метеорит:Sikhote-Alin meteorite" "Sol" #2=
#3_"Sikhote-Alin meteorite:*Сихотэ-Алинский метеорит" "Sol" #3=
".:Sikhote-Alin meteorite" "Sol" #4=

{
	Class	"asteroid"
	Mesh	"sikhote-alin.cms"
	Texture	"asteroid-smooth.dds"
	Radius	0.002
	Ending	"1947 02 11 23:42:56"
	Visible	false
	Clickable	false
	EllipticalOrbit
	{
		Epoch	2432229.52986  # 1947 Feb 13 00:43
		Period	3.1811546
		SemiMajorAxis	2.12724
		Eccentricity	0.536
		Inclination	9.4
		AscendingNode	323.203
		ArgOfPericenter	181.3
		MeanAnomaly	359.982
	}
	UniformRotation
	{
		Period	2.5
	}
	LunarLambert	0.5
	Albedo	0.13
	InfoURL	"https://en.wikipedia.org/wiki/Sikhote-Alin_meteorite"
}

#1_"Chelyabinsk meteorite" "Sol" #1=
#2_"*Челябинский метеорит:Chelyabinsk meteorite" "Sol" #2=
#3_"Chelyabinsk meteorite:*Челябинский метеорит" "Sol" #3=
".:Chelyabinsk meteorite" "Sol" #4=
{
	Class	"asteroid"
	Mesh	"chelyabinsk meteorite.cms"
	Texture	"chelyabinsk meteorite.jpg"
	Radius	0.0085  # Диаметр ~17 м
	Visible	false
	Clickable	false
	Timeline
	[
		{
			# Стадия 1
			# Движение объекта в межпланетном пространстве Солнечной системы по замкнутой эллиптической орбите
			# Конец: 29.12.2011 23:33:15 UTC - объект в афелии - в 361919881.6 км от центра Солнца

			Ending	2455925.48218493
			EllipticalOrbit
			{
				Epoch	2455925.48218493
				Period	2.008473126
				SemiMajorAxis	1.591861265
				Eccentricity	0.519783811
				Inclination	3.972004292
				AscendingNode	326.480906728
				ArgOfPericenter	109.716843184
				MeanAnomaly	180.0
			}
			UniformRotation
			{
				Inclination	45  # Неизвестно
				AscendingNode	160  # Неизвестно
				Period	0.02  # Неизвестно
			}
		}
		{
			# Стадия 2
			# Движение объекта в межпланетном пространстве Солнечной системы по просчитанной траектории
			# Просчитано с шагом в 30 с, данные записаны с шагом от 30 с 360 с
			# Начало: 29.12.2011 23:33:15 UTC - объект в афелии - в 361919881.6 км от центра Солнца
			# Конец: 15.02.2013 01:26:45 UTC - объект на расстоянии в 102367.5 км от центра Земли

			Ending	2456338.56100437
			OrbitFrame	{ EclipticJ2000 {Center "Sol"} }
			SampledOrbit	"Chelyabinsk meteorite free flight helio ecl2000.xyzv"
			UniformRotation
			{
				Inclination	45  # Неизвестно
				AscendingNode	160  # Неизвестно
				Period	0.02  # Неизвестно
			}
		}
		{
			# Стадия 3
			# Приближение объекта к Земле
			# Просчитано с шагом в 10 с, данные записаны с шагом от 10 с до 60 с
			# Начало: 15.02.2013 01:26:45 UTC - объект на расстоянии в 102367.5 км от центра Земли
			# Конец: 15.02.2013 03:20:15 UTC - объект входит в плотные слои атмосферы Земли

			Ending	2456338.63982381
			OrbitFrame	{ EclipticJ2000 {Center "Sol/Earth"} }
			SampledOrbit	"Chelyabinsk meteorite free flight geo ecl2000.xyzv"
			UniformRotation
			{
				Inclination	45  # Неизвестно
				AscendingNode	160  # Неизвестно
				Period	0.02  # Неизвестно
			}
		}
		{
			# Стадия 4
			# Полёт и разрушение объекта в атмосфере Земли. Падение осколков на поверхность Земли
			# Рассчитано по данным чешской модели падения с экстраполяцией
			# Начало: 15.02.2013 03:20:15 UTC - объект входит в плотные слои атмосферы Земли
			# Конец: 15.02.2013 03:20:48 UTC - осколки объекта падают на поверхность Земли

			Ending	2456338.64019996
			OrbitFrame	{ EquatorJ2000 {Center "Sol/Earth"} }
			SampledOrbit	"Chelyabinsk meteorite impact trajectory geo equ2000.xyzv"
			UniformRotation
			{
				Inclination	45  # Неизвестно
				AscendingNode	160  # Неизвестно
				Period	0.02  # Неизвестно
			}
		}
	]
	LunarLambert	0.5
	Albedo	0.28  # 0.28 ± 0.13
	InfoURL	"https://en.wikipedia.org/wiki/Chelyabinsk_meteorite"
}